(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    361837,       8048]*)
(*NotebookOutlinePosition[    362481,       8070]*)
(*  CellTagsIndexPosition[    362437,       8066]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    StyleBox[\( (*\ 
        This\ file\ produces\ one\ raw\ of\ Fig . \ 1\ of\ the\ paper\ ' 
          Testing\ GRBs\ as\ Standard\ Candles'\ \((E\_\[Gamma] - \
\[CapitalEpsilon]\_peak)\) . \ 
            The\ parameter\ a1\ corresponds\ to\ the\ parameters\ b\_j\ in\ \
the\ paper\ \[IndentingNewLine]while\ the\ parameter\ b1\ corresponds\ to\ \
the\ parameters\ a\_j . \ 
            The\ produced\ Figs\ examine\ the\ dependence\ of\ the\ \
parameters\ a\_j, \ b\_j\ on\ redshift\ \(\(z\)\(.\)\)*) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Set\ Directory\ to\ Read\ GRB\ data\ from, \ 
        Input\ Packages\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{\(SetDirectory["\<D:/mathdata/grb\>"];\), "\[IndentingNewLine]",
   
    RowBox[{\($TextStyle = {FontFamily \[Rule] "\<Times\>", 
          FontSize \[Rule] 20}\), ";", 
      StyleBox[" ",
        "MR"], 
      StyleBox[\(Off[]\),
        "MR"], 
      StyleBox[";",
        "MR"], 
      StyleBox[\(Off[General::spell]\),
        "MR"], 
      StyleBox[";",
        "MR"], 
      RowBox[{"Off", 
        StyleBox["[",
          "MR"], \(NIntegrate::"\<inum\>"\), 
        StyleBox["]",
          "MR"]}], 
      StyleBox[";",
        "MR"]}], "\[IndentingNewLine]", \(<< 
      Statistics`LinearRegression`\), "\[IndentingNewLine]", \(<< 
      Graphics`Graphics`\), "\[IndentingNewLine]", \(<< 
      Graphics`MultipleListPlot`\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Read\ Data\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(data1 = 
        ReadList["\<grbdat.txt\>", {Number, Number, Number, Number, Number, 
            Number, Number, Number, Number, Number, Number, Number, Number, 
            Number, Number, Number}];\)\), "\[IndentingNewLine]", 
    \(\(ndat = Length[data1];\)\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Rescale\ Data, \ Define\ new\ Arrays\ with\ Data\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(zz = data1[\([#, 1]\)] &;\)\), "\n", 
    \(\(pbolo = data1[\([#, 2]\)] &;\)\), "\n", 
    \(\(spbolo = data1[\([#, 3]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(sbolo = data1[\([#, 4]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(ssbolo = data1[\([#, 5]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(fbeam = data1[\([#, 6]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(sfbeam = data1[\([#, 7]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(tlag = 
        data1[\([#, 8]\)]/\((\((1 + zz[#])\) 
                0.1)\) &;\)\), "\[IndentingNewLine]", 
    \(\(stlag = 
        data1[\([#, 9]\)]/\((\((1 + zz[#])\) 
                0.1)\) &;\)\), "\[IndentingNewLine]", 
    \(\(var = 
        data1[\([#, 10]\)]\ \((1 + zz[#])\)/
              0.02 &;\)\), "\[IndentingNewLine]", 
    \(\(svar = 
        data1[\([#, 11]\)] \((1 + zz[#])\)/
              0.02 &;\)\), "\[IndentingNewLine]", 
    \(\(epeak = 
        data1[\([#, 12]\)]\ \((1 + zz[#])\)/
              300 &;\)\), "\[IndentingNewLine]", 
    \(\(sepeak1 = 
        data1[\([#, 13]\)] \((1 + zz[#])\)/
              300 &;\)\), "\[IndentingNewLine]", 
    \(\(sepeak2 = 
        data1[\([#, 14]\)] \((1 + zz[#])\)/
              300 &;\)\), "\[IndentingNewLine]", 
    \(\(trt = 
        data1[\([#, 
                15]\)]/\((\((1 + 
                    zz[#])\)\ 0.1)\) &;\)\), "\[IndentingNewLine]", 
    \(\(strt = data1[\([#, 16]\)]/\((\((1 + zz[#])\)\ 0.1)\) &;\)\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Fix\ \[CapitalOmega]\_m, \ 
        evaluate\ \(d\_L\) \((z)\)\ and\ evaluate\ L, \ 
        E\_\[Gamma]\ and\ corresponding\ errors\ \((for\ E\_\[Gamma]\ find\ \
error\ of\ Log \((E\_\[Gamma])\))\)\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(Clear[f, dl, dld]; om = 0.26; w0 = \(-1\); w1 = 0; h0 = 10^5\ h; \ 
    c = 3\ 10^8; h = 0.72; res = {};\), "\[IndentingNewLine]", 
    \(\(f[z_] := 
        1/Sqrt[om*\((1 + z)\)^3\  + \((1 - 
                    om)\)*\((1 + z)\)^\((3 \((1 + w0\  + \ w1)\))\) 
                Exp[3\ w1\ \((\((1/\((1 + z)\))\) - 1)\)]];\)\), "\n", 
    \(\(dl[zz_] := 
        c \((1 + zz)\)\ NIntegrate[f[z], {z, 0, zz}]/h0;\)\)}], "Input"],

Cell[BoxData[{
    \(\(dld = dl[zz[#]] 3\ 10^24 &;\)\), "\n", 
    \(\(ll = 4\ Pi\ dld[#]^2\ pbolo[#] &;\)\), "\n", 
    \(\(sll = 4\ Pi\ dld[#]^2\ spbolo[#] &;\)\), "\[IndentingNewLine]", 
    \(eg = 4\ Pi\ dld[#]^2\ sbolo[#]\ fbeam[#]/\((1 + zz[#])\) &; 
    seg = Sqrt[\((ssbolo[#]/sbolo[#])\)^2\  + \ \((sfbeam[#]/fbeam[#])\)^2]/
          Log[10] &;\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Define\ redshift\ bin\ ranges\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zreg = {0, 1, 2, 3, 7}\)], "Input"],

Cell[BoxData[
    \({0, 1, 2, 3, 7}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Do", "[", 
      RowBox[{
        RowBox[{\(zmin = zreg[\([i]\)]\), ";", \(zmax = zreg[\([i + 1]\)]\), 
          ";", "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ For\ a\ given\ redshift\ bin, \ 
              construct\ arrays\ with\ \((Log \((E\_peak)\) - 
                    Log \((E\_\[Gamma])\))\)\ and\ corresponding\ errors\ *) \
\),
            FontSize->18], 
          "\n", \(Clear[egepeak, segepeak1, segepeak2, segepeak, zzt]\), ";", 
          "\n", \(egepeak = {}\), ";", \(segepeak1 = {}\), 
          ";", \(segepeak2 = {}\), ";", \(segepeak = {}\), ";", \(zzt = {}\), 
          ";", "\n", \(Do[\[IndentingNewLine]If[
              epeak[i] > 0\  && \ sbolo[i] > 0\  && \ 
                zz[i] \[GreaterEqual] zmin\  && \ 
                zz[i] \[LessEqual] \ zmax, \[IndentingNewLine]AppendTo[zzt, 
                zz[i]]; \[IndentingNewLine]AppendTo[
                egepeak, {Log[10, epeak[i]], 
                  Log[10, eg[i]]}]; \[IndentingNewLine]AppendTo[
                segepeak1, {sepeak1[i]/\((Log[10]\ epeak[i])\), 
                  seg[i]}]; \[IndentingNewLine]AppendTo[
                segepeak2, {sepeak2[i]/\((Log[10]\ epeak[i])\), 
                  seg[i]}]; \[IndentingNewLine]AppendTo[
                segepeak, {\((sepeak2[i] + 
                        sepeak1[i])\)/\((2\ Log[10]\ epeak[i])\), 
                  seg[i]}]], \[IndentingNewLine]{i, 1, ndat}]\), ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ 
              Symmetrically\ Minimize\ \[Chi]\^2\ to\ find\ best\ fit\ \
parameters\ a\_j\ \ \((b1)\), \ 
              b\_j\ \((a1)\)\ for\ the\ given\ redshift\ bin . \ 
                  Set\ proper\ value\ to\ intrinsic\ error\ s1 . \ 
                  Use\ covariance\ matrix\ cij\ to\ find\ errors\ of\ a\_j, \ \
\(\(b\_j\)\(.\)\)\ *) \),
            FontSize->18], 
          StyleBox["\[IndentingNewLine]",
            FontSize->18], "\n", \(egp[a1_, b1_, x_] := a1\  + \ b1\ x\), ";",
           "\[IndentingNewLine]", \(epeakp[a1_, b1_, x_] := \((x - a1)\)/b1\),
           ";", "\[IndentingNewLine]", \(chi2[a1_, b1_, s1_] := 
            Sum[\((\((egepeak[\([i, 2]\)] - 
                          egp[a1, b1, 
                            egepeak[\([i, 1]\)]])\)^2/\((segepeak[\([i, 
                              2]\)]^2 + s1^2)\))\), {i, 1, 
                  Length[segepeak]}] + 
              Sum[\((\((egepeak[\([i, 1]\)] - 
                          epeakp[a1, b1, 
                            egepeak[\([i, 2]\)]])\)^2/\((segepeak[\([i, 
                              1]\)]^2 + s1^2)\))\), {i, 1, 
                  Length[egepeak]}]\), ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", \(s1 = 0.17\), ";", "\n", \(par = {a1, b1}\),
           ";", "\n", \(akl[a1_, b1_, k_, l_] := 
            1/2  D[D[chi2[a1, b1, s1], par[\([k]\)]], par[\([l]\)]\ ]\), ";", 
          "\n", \(fmingrb = 
            FindMinimum[chi2\ [a1, b1, s1], {a1, 1}, {b1, \(-10\)}]\), ";", 
          "\n", \(a1o = fmingrb[\([2, 1, 2]\)]\), ";", 
          "\n", \(b1o = fmingrb[\([2, 2, 2]\)]\), ";", 
          "\n", \(aklo = 
            Table[If[
                k \[LessSlantEqual] 
                  l, \(akl[a1, b1, k, l] /. a1 \[Rule] a1o\) /. 
                  b1 \[Rule] b1o, \(akl[a1, b1, l, k] /. a1 \[Rule] a1o\) /. 
                  b1 \[Rule] b1o], {k, 1, 2}, {l, 1, 2}]\), 
          ";", \(cij = Inverse[aklo]\), 
          ";", \(spar = Table[Sqrt[cij[\([i, i]\)]], {i, 1, 2}]\), 
          ";", \(Print["\<a1= \>", a1o, "\<+-\>", 
            spar[\([1]\)], "\<  b1= \>", b1o, "\<+-\>", spar[\([2]\)]]\), 
          ";", \(cij // MatrixForm\), ";", 
          "\[IndentingNewLine]", \(erra1o = spar[\([1]\)]\), ";", 
          "\[IndentingNewLine]", \(errb1o = spar[\([2]\)]\), ";", 
          "\[IndentingNewLine]", \(chi2r = 
            Part[fmingrb, 1]/\((2\ Length[egepeak])\)\), ";", 
          "\[IndentingNewLine]", \(ngrb = Length[egepeak]\), ";", "  ", 
          "\[IndentingNewLine]", \(Print["\<chi2r=\>", chi2r, "\<  ngrb=\>", 
            ngrb, "\<  zmin=\>", zmin, "\<  zmax=\>", zmax]\), ";", 
          "\[IndentingNewLine]", "\n", \(meanz = Mean[zzt]\), ";", 
          "\[IndentingNewLine]", \(AppendTo[
            res, {meanz, a1o, erra1o, b1o, errb1o, chi2r, ngrb}]\)}], ",", 
        " ", \({i, 1, 4}\)}], "]"}]], "Input"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.545288523235286`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05270274807921493`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.6413771592140391`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.1274787398139319`\),
      SequenceForm[ 
      "a1= ", 50.545288523235286, "+-", .052702748079214927, "  b1= ", 
        1.6413771592140391, "+-", .1274787398139319],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.816542204039825`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]10\[InvisibleSpace]"  zmin="\
\[InvisibleSpace]0\[InvisibleSpace]"  zmax="\[InvisibleSpace]1\),
      SequenceForm[ 
      "chi2r=", .81654220403982503, "  ngrb=", 10, "  zmin=", 0, "  zmax=", 
        1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.549233489617805`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.06773990964240079`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.8514039159043647`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.1952330612988965`\),
      SequenceForm[ 
      "a1= ", 50.549233489617805, "+-", .067739909642400786, "  b1= ", 
        1.8514039159043647, "+-", .1952330612988965],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.5180639664812028`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]8\[InvisibleSpace]"  zmin="\
\[InvisibleSpace]1\[InvisibleSpace]"  zmax="\[InvisibleSpace]2\),
      SequenceForm[ 
      "chi2r=", .51806396648120279, "  ngrb=", 8, "  zmin=", 1, "  zmax=", 2],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.62737567257139`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.07695486405105484`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.0478974844883946`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.22112757107059217`\),
      SequenceForm[ 
      "a1= ", 50.627375672571389, "+-", .076954864051054839, "  b1= ", 
        1.0478974844883946, "+-", .22112757107059217],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.6860616679508745`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]4\[InvisibleSpace]"  zmin="\
\[InvisibleSpace]2\[InvisibleSpace]"  zmax="\[InvisibleSpace]3\),
      SequenceForm[ 
      "chi2r=", .68606166795087453, "  ngrb=", 4, "  zmin=", 2, "  zmax=", 3],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.504406475732395`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.09764961155431837`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.3971138025273637`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.16019783545849592`\),
      SequenceForm[ 
      "a1= ", 50.504406475732395, "+-", .097649611554318366, "  b1= ", 
        1.3971138025273637, "+-", .16019783545849592],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.5569087329975533`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]5\[InvisibleSpace]"  zmin="\
\[InvisibleSpace]3\[InvisibleSpace]"  zmax="\[InvisibleSpace]7\),
      SequenceForm[ 
      "chi2r=", 1.5569087329975533, "  ngrb=", 5, "  zmin=", 3, "  zmax=", 7],
      
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ Plot\ best\ fit\ parameter\ values\ b\_j\ \((a1dtpl)\), \ 
        a\_j\ \((b1dtpl)\)\ as\ function\ of\ redshift\ bin\ \((mean\ \
redshift\ of\ each\ bin)\)\ with\ errors\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(a1pl = {}; b1pl = {};\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]AppendTo[
        a1pl, {res[\([i, 1]\)], res[\([i, 2]\)], 
          res[\([i, 3]\)]}]; \[IndentingNewLine]AppendTo[
        b1pl, {res[\([i, 1]\)], res[\([i, 4]\)], res[\([i, 5]\)]}], {i, 1, 
        4}]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a1dtpl = 
        ErrorListPlot[a1pl, Frame \[Rule] True, 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(b1dtpl = 
        ErrorListPlot[b1pl, Frame \[Rule] True, 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.16897 0.274224 -99.6904 1.97801 [
[.10525 -0.0125 -7.03125 -24.5625 ]
[.10525 -0.0125 7.03125 0 ]
[.24237 -0.0125 -14.5625 -24.5625 ]
[.24237 -0.0125 14.5625 0 ]
[.37948 -0.0125 -7.03125 -24.5625 ]
[.37948 -0.0125 7.03125 0 ]
[.51659 -0.0125 -14.5625 -24.5625 ]
[.51659 -0.0125 14.5625 0 ]
[.6537 -0.0125 -7.03125 -24.5625 ]
[.6537 -0.0125 7.03125 0 ]
[.79081 -0.0125 -14.5625 -24.5625 ]
[.79081 -0.0125 14.5625 0 ]
[.92793 -0.0125 -7.03125 -24.5625 ]
[.92793 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00135 -39.1875 -12.2813 ]
[-0.0125 .00135 0 12.2813 ]
[-0.0125 .10025 -49.25 -12.2813 ]
[-0.0125 .10025 0 12.2813 ]
[-0.0125 .19915 -39.1875 -12.2813 ]
[-0.0125 .19915 0 12.2813 ]
[-0.0125 .29805 -49.25 -12.2813 ]
[-0.0125 .29805 0 12.2813 ]
[-0.0125 .39695 -39.1875 -12.2813 ]
[-0.0125 .39695 0 12.2813 ]
[-0.0125 .49585 -49.25 -12.2813 ]
[-0.0125 .49585 0 12.2813 ]
[-0.0125 .59475 -39.1875 -12.2813 ]
[-0.0125 .59475 0 12.2813 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10525 0 m
.10525 .00625 L
s
gsave
.10525 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.24237 0 m
.24237 .00625 L
s
gsave
.24237 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.37948 0 m
.37948 .00625 L
s
gsave
.37948 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.51659 0 m
.51659 .00625 L
s
gsave
.51659 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.6537 0 m
.6537 .00625 L
s
gsave
.6537 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.79081 0 m
.79081 .00625 L
s
gsave
.79081 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
1.000 setlinewidth
grestore
.92793 0 m
.92793 .00625 L
s
gsave
.92793 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.13268 0 m
.13268 .00375 L
s
.1601 0 m
.1601 .00375 L
s
.18752 0 m
.18752 .00375 L
s
.21494 0 m
.21494 .00375 L
s
.26979 0 m
.26979 .00375 L
s
.29721 0 m
.29721 .00375 L
s
.32463 0 m
.32463 .00375 L
s
.35206 0 m
.35206 .00375 L
s
.4069 0 m
.4069 .00375 L
s
.43432 0 m
.43432 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.48917 0 m
.48917 .00375 L
s
.54401 0 m
.54401 .00375 L
s
.57144 0 m
.57144 .00375 L
s
.59886 0 m
.59886 .00375 L
s
.62628 0 m
.62628 .00375 L
s
.68113 0 m
.68113 .00375 L
s
.70855 0 m
.70855 .00375 L
s
.73597 0 m
.73597 .00375 L
s
.76339 0 m
.76339 .00375 L
s
.81824 0 m
.81824 .00375 L
s
.84566 0 m
.84566 .00375 L
s
.87308 0 m
.87308 .00375 L
s
.9005 0 m
.9005 .00375 L
s
.07783 0 m
.07783 .00375 L
s
.05041 0 m
.05041 .00375 L
s
.02299 0 m
.02299 .00375 L
s
.95535 0 m
.95535 .00375 L
s
.98277 0 m
.98277 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00135 m
.00625 .00135 L
s
gsave
-0.0125 .00135 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.4) show
1.000 setlinewidth
grestore
0 .10025 m
.00625 .10025 L
s
gsave
-0.0125 .10025 -110.25 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.45) show
1.000 setlinewidth
grestore
0 .19915 m
.00625 .19915 L
s
gsave
-0.0125 .19915 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.5) show
1.000 setlinewidth
grestore
0 .29805 m
.00625 .29805 L
s
gsave
-0.0125 .29805 -110.25 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.55) show
1.000 setlinewidth
grestore
0 .39695 m
.00625 .39695 L
s
gsave
-0.0125 .39695 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.6) show
1.000 setlinewidth
grestore
0 .49585 m
.00625 .49585 L
s
gsave
-0.0125 .49585 -110.25 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.65) show
1.000 setlinewidth
grestore
0 .59475 m
.00625 .59475 L
s
gsave
-0.0125 .59475 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.7) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02113 m
.00375 .02113 L
s
0 .04091 m
.00375 .04091 L
s
0 .06069 m
.00375 .06069 L
s
0 .08047 m
.00375 .08047 L
s
0 .12003 m
.00375 .12003 L
s
0 .13981 m
.00375 .13981 L
s
0 .15959 m
.00375 .15959 L
s
0 .17937 m
.00375 .17937 L
s
0 .21893 m
.00375 .21893 L
s
0 .23871 m
.00375 .23871 L
s
0 .25849 m
.00375 .25849 L
s
0 .27827 m
.00375 .27827 L
s
0 .31783 m
.00375 .31783 L
s
0 .33761 m
.00375 .33761 L
s
0 .35739 m
.00375 .35739 L
s
0 .37717 m
.00375 .37717 L
s
0 .41673 m
.00375 .41673 L
s
0 .43651 m
.00375 .43651 L
s
0 .45629 m
.00375 .45629 L
s
0 .47607 m
.00375 .47607 L
s
0 .51563 m
.00375 .51563 L
s
0 .53541 m
.00375 .53541 L
s
0 .55519 m
.00375 .55519 L
s
0 .57497 m
.00375 .57497 L
s
0 .61453 m
.00375 .61453 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.10525 .61178 m
.10525 .61803 L
s
.24237 .61178 m
.24237 .61803 L
s
.37948 .61178 m
.37948 .61803 L
s
.51659 .61178 m
.51659 .61803 L
s
.6537 .61178 m
.6537 .61803 L
s
.79081 .61178 m
.79081 .61803 L
s
.92793 .61178 m
.92793 .61803 L
s
.125 Mabswid
.13268 .61428 m
.13268 .61803 L
s
.1601 .61428 m
.1601 .61803 L
s
.18752 .61428 m
.18752 .61803 L
s
.21494 .61428 m
.21494 .61803 L
s
.26979 .61428 m
.26979 .61803 L
s
.29721 .61428 m
.29721 .61803 L
s
.32463 .61428 m
.32463 .61803 L
s
.35206 .61428 m
.35206 .61803 L
s
.4069 .61428 m
.4069 .61803 L
s
.43432 .61428 m
.43432 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.48917 .61428 m
.48917 .61803 L
s
.54401 .61428 m
.54401 .61803 L
s
.57144 .61428 m
.57144 .61803 L
s
.59886 .61428 m
.59886 .61803 L
s
.62628 .61428 m
.62628 .61803 L
s
.68113 .61428 m
.68113 .61803 L
s
.70855 .61428 m
.70855 .61803 L
s
.73597 .61428 m
.73597 .61803 L
s
.76339 .61428 m
.76339 .61803 L
s
.81824 .61428 m
.81824 .61803 L
s
.84566 .61428 m
.84566 .61803 L
s
.87308 .61428 m
.87308 .61803 L
s
.9005 .61428 m
.9005 .61803 L
s
.07783 .61428 m
.07783 .61803 L
s
.05041 .61428 m
.05041 .61803 L
s
.02299 .61428 m
.02299 .61803 L
s
.95535 .61428 m
.95535 .61803 L
s
.98277 .61428 m
.98277 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00135 m
1 .00135 L
s
.99375 .10025 m
1 .10025 L
s
.99375 .19915 m
1 .19915 L
s
.99375 .29805 m
1 .29805 L
s
.99375 .39695 m
1 .39695 L
s
.99375 .49585 m
1 .49585 L
s
.99375 .59475 m
1 .59475 L
s
.125 Mabswid
.99625 .02113 m
1 .02113 L
s
.99625 .04091 m
1 .04091 L
s
.99625 .06069 m
1 .06069 L
s
.99625 .08047 m
1 .08047 L
s
.99625 .12003 m
1 .12003 L
s
.99625 .13981 m
1 .13981 L
s
.99625 .15959 m
1 .15959 L
s
.99625 .17937 m
1 .17937 L
s
.99625 .21893 m
1 .21893 L
s
.99625 .23871 m
1 .23871 L
s
.99625 .25849 m
1 .25849 L
s
.99625 .27827 m
1 .27827 L
s
.99625 .31783 m
1 .31783 L
s
.99625 .33761 m
1 .33761 L
s
.99625 .35739 m
1 .35739 L
s
.99625 .37717 m
1 .37717 L
s
.99625 .41673 m
1 .41673 L
s
.99625 .43651 m
1 .43651 L
s
.99625 .45629 m
1 .45629 L
s
.99625 .47607 m
1 .47607 L
s
.99625 .51563 m
1 .51563 L
s
.99625 .53541 m
1 .53541 L
s
.99625 .55519 m
1 .55519 L
s
.99625 .57497 m
1 .57497 L
s
.99625 .61453 m
1 .61453 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.02381 .18449 m
.02381 .39298 L
s
.015 w
.02381 .28873 Mdot
.002 w
.23962 .16255 m
.23962 .43053 L
s
.015 w
.23962 .29654 Mdot
.002 w
.47683 .29888 m
.47683 .60332 L
s
.015 w
.47683 .4511 Mdot
.002 w
.97619 .01472 m
.97619 .40102 L
s
.015 w
.97619 .20787 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{653.25, 403.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:=0001Tb000`400?l00000o`00003oo`3ooooo
0?ooohl0oooo003o0?ooool0ooooS`3oool00?l0ooooo`3ooon?0?ooo`00o`3ooooo0?ooohl0oooo
003o0?ooool0ooooS`3oool00?l0ooooo`3ooon?0?ooo`00o`3ooooo0?ooohl0oooo003o0?ooool0
ooooS`3oool007@0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`120?ooo`030?no
M000000000000080000000L007Bo0?ooo`3oool0oooo0=nLB0000000B9cO0080oooo00H0_g@00000
0000000000000018W03Ooom30?ooo`030=nLB0000000000000D0000000<0M;oo0?ooo`3oool0?`3o
ool00`3OW4P00000000000050000000607Boo`3oool0oooo0=nLB0000000B9cO0P3oool01P2oM000
000000000000000004RL0=oood<0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`13
0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool00`3oool00`3OW4P0000004RLg`02
0?ooo`060;md00000000000000000000B9`0goooB03oool00`3o_g@0000007Boo`0Y0?ooo`00MP3o
ool00`2oM000001d0;ooo`170?ooo`030;md000007@0_ooo00@0oooo00L0gia800000018W=l0oooo
0?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool0@`3oool00`3OW4P000000000000400000003
001d_`3oool0oooo0400oooo00<0gia8000000000000100000002P00M;l0oooo0?ooo`3OW4P00000
04RLg`3oool0oooO09a80018W=l20?ooo`030?oOW018B9`0gooo0480oooo00P0omnL04P00000B9`0
gooo0?ooo`3ogi`0B01809cOod<0oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B01809cOo`<0
oooo00L0gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool0A`3oool0
0`3o_g@0000007Boo`0Y0?ooo`00MP3oool00`2oM000001d0;ooo`170?ooo`030;md000007@0_ooo
00h0oooo00<0omnL04Qd_`3oool0@`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo
0480oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`0;0?ooo`030?oOW018M;l0oooo
04L0oooo00<0okmd0018W03Oool0B03oool00`3o_g@004RL0=ooo`0<0?ooo`030?oOW018M;l0oooo
04H0oooo00<0okmd0000001d_ol0:@3oool007H0oooo00<0_g@00000M02oool0A`3oool00`2oM000
001d0;ooo`0>0?ooo`030?oo_`1d04P0W=oo04@0oooo00<0gia804RLg`3oool0A`3oool00`3OW4P0
B9cO0?ooo`0?0?ooo`030?oo_`1d04P0W=oo04L0oooo00<0okmd0000B02Lgol0B03oool00`3o_g@0
001809cOo`0<0?ooo`030?oo_`1d04P0W=oo0440oooo00<0gia80000000000001@0000000`0004P0
W=oo0?ooo`0V0?ooo`00MP3oool00`2oM000001d0;ooo`170?ooo`030;md000007@0_ooo00h0oooo
00<0oono07@0001d_ol0A@3oool00`3OW4P0M;oo0?ooo`170?ooo`030=nLB01d_ol0oooo00h0oooo
00<0oono07@0001d_ol0A`3oool00`2oM000001809cOo`180?ooo`030;md000004P0W=oo00`0oooo
00<0oono07@0001d_ol0@@3oool00`3ogi`0B7Bo0?ooo`020?ooo`030?noM0000000M;oo02T0oooo
001f0?ooo`030;md000007@0_ooo04L0oooo00<0_g@00000M02oool03P3oool00`3o_g@0000007Bo
o`150?ooo`030?oog`2LB4P0W=oo04L0oooo00<0oooO09a8B02Lgol03P3oool00`3o_g@0000007Bo
o`160?ooo`040;md00000000001d0;ooodL0oooo00@0_g@00000000007@0_ooo303oool00`3o_g@0
000007Boo`120?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@0000007Boo`0Y0?ooo`00MP3oool00`2o
M000001d0;ooo`170?ooo`030;md000007@0_ooo00d0oooo00@0omnL04P0000007@0_oooAP3oool0
0`3ogi`0B01d0;ooo`170?ooo`030?oOW01807@0_ooo00`0oooo00@0omnL04P0000007@0_ooo@`3o
ool00`3ookl0M000000000020000000304RLg`3oool0oooo04<0oooo00<0oono07@0000000000P00
00000`18W=l0oooo0?ooo`0:0?ooo`040?oOW0180000001d0;oood80oooo00L0oono07@0M02oool0
oooo0?noM0000000M;oo02T0oooo001f0?ooo`030;md000007@0_ooo04L0oooo00<0_g@00000M02o
ool02@3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo04H0oooo00<0_g@004RL
g`3oool0A`3oool00`2oM000B9cO0?ooo`070?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO
0?ooo`3oool0A03oool00`3o_g@0001809cOo`180?ooo`030?noM00004P0W=oo00T0oooo00@0gmoO
0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`120?ooo`060?noM000M;l0oooo0?noM0000000
M;oo:@3oool007H0oooo00<0_g@00000M02oool0A`3oool00`2oM000001d0;ooo`090?ooo`030?no
M000000000000080000000<007Bo0?ooo`3oool0A`3oool00`3OW4P0001d0;ooo`170?ooo`030=nL
B00007@0_ooo00L0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`160?ooo`030?oO
W018M;l0oooo04P0oooo00<0omnL04Qd_`3oool0203oool00`3o_g@000000000000200000003001d
_`3oool0oooo04@0oooo00D0_g@007Boo`3o_g@0000007Boo`0Y0?ooo`00MP3oool00`2oM000001d
0;ooo`170?ooo`030;md000007@0_ooo00T0oooo00D0oooO09a800000000001d0;ooo`1:0?ooo`03
0?noM0000000M;oo04L0oooo00<0okmd0000001d_ol01`3oool01@3ooml0W4P00000000007@0_ooo
04T0oooo00<0oooO09a80018W=l0B03oool00`3ooml0W4P004RLg`080?ooo`050?oog`2LB0000000
0000M02oool0A`3oool01@3ookl0M01d0;noM0000000M;oo02T0oooo001f0?ooo`030;md000007@0
_ooo04L0oooo00<0_g@00000M02oool02P3oool00`3o_g@007Bo0?ooo`150?ooo`030?oOW02L_ol0
oooo00<0oooo00<0_g@00000001d_ol0@@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000
M;oo00P0oooo00<0okmd001d_`3oool0A@3oool00`3ooml0W7BL0=ooo`020?ooo`030?oog`2LB000
07Bo04<0oooo00<0oooO09adW03Oool00P3oool00`3ooml0W4P0001d_`090?ooo`030?noM000M;l0
oooo04T0oooo00@0okmd000000000000M;oo:@3oool007@0oooo00D0gia8000000000000001d0;oo
o`150?ooo`050=nLB000000000000000M02oool02P3oool00`3ooml0W4P000000002000000030000
M02oool0oooo0440oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=oood80oooo00P0_g@0
07Boo`3oool0oooo0=nLB000000004RL0=ooo`P0oooo00<0oooO09a8000000000P0000000`0007@0
_ooo0?ooo`110?ooo`070?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`140?ooo`070?oOW018B9`0
gooo0?ooo`3OW4P0000007Boo`090?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool0
A03oool0103ooml0W4P00000001d_olY0?ooo`00M@3oool0103ookl0M0000000M02ooom60?ooo`04
0?oo_`1d0000001d0;ooo`/0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`110?oo
o`050;md00000000000000000000M;l0A@3oool01@2oM000000000000000000007Bo00/0oooo00<0
okmd0000000000000P0000000`1d_ol0oooo0?ooo`110?ooo`050?oOW0180000000000000018W=l0
AP3oool01@3ogi`0B000000000000000B9cO00/0oooo00<0okmd0000000000000P0000000`1d_ol0
oooo0?ooo`140?ooo`030?oOW0180000M;oo02T0oooo003o0?ooool0ooooS`3oool00?l0ooooo`3o
oon?0?ooo`00o`3ooooo0?ooohl0oooo003o0?ooool0ooooS`3oool00?l0ooooo`3ooon?0?ooo`00
o`3ooooo0?ooohl0oooo003o0?ooool0ooooS`3oool000d0oooo00H0_g@000000000000000000018
W03Oool60?ooo`040;md00000000000004RLg`@0oooo00<0gia800000018W=l01P3oool00`3o_g@0
000007Boo`3o0?ooool0ooooHP3oool000`0oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL
0=ooo`030?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO
00H0oooo00<0okmd0000001d_ol0o`3ooooo0?ooof80oooo000B0?ooo`030?oOW018M;l0oooo0080
oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0;0?ooo`030?noM0000000M;oo0?l0
ooooo`3ooomR0?ooo`004P3oool0203ookl0M01809cOo`3oool0oooO09a80000B9`0gooo0P3oool0
0`3ooml0W4P0001d_`060?ooo`030=nLB0000000000000D0000000<0001809cOo`3oool0o`3ooooo
0?oooel0oooo000B0?ooo`070?oo_`1d0000M;oo0?ooo`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo00D0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`3o0?ooool0ooooHP3o
ool00180oooo00L0okmd0000001d_ol0oooo0?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0
1P3oool01`3OW4P0M;oo0?ooo`3oool0okmd0000001d_ol02`3ooooo00000?l00000E`0000000140
oooo00P0omnL04P0000007@0_ooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia80000B02Lgol01P3o
ool01`3ookl0M01d0;ooo`3oool0okmd0000001d_ol02`3oool5000000T0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo1@00000000d0oooo
00@0gmoO0?ooo`3oool0_g@00P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia8
0000B02Lgol01`3oool01P3o_g@007Bo0?ooo`3o_g@0000007Boo`/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
203oool1000000003@3oool00`3o_g@000000000000200000007001d_`3oool0oooo0?ooo`3ookl0
M000001d_`040?ooo`030;md000007@0_ooo00P0oooo00D0_g@007Boo`3o_g@0000007Boo`0;0?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0:03oool1000000003@3oool01@3ooml0
W4P00000000007@0_ooo00D0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`090?oo
o`050?oo_`1d07@0_kmd0000001d_ol02`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo02P0oooo0@00000000h0oooo00<0okmd001d_`3oool01P3oool00`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo00X0oooo00@0okmd000000000000M;oo2`3oool00`000000oooo0?ooo`3o
0?ooool0ooooD`3oool1000000003P3oool00`3ooml0W4P000000002000000030000M02oool0oooo
0080oooo00H0_g@00018W03Oool0oooo0;md0000M;l;0?ooo`040?oog`2LB000000007Boo`/0oooo
00<000000?ooo`3oool0o`3ooooo0?oooe<0oooo0@00000000l0oooo00<0okmd0000000000000P00
00000`1d_ol0oooo0?ooo`020?ooo`040;md000000000000001d_`d0oooo00<0omnL04P0001d_ol0
2`3oool00`000000oooo0?ooo`3o0?ooool0ooooD`3oool100000000>03oool00`000000oooo0?oo
o`3o0?ooool0ooooD`3oool100000000>03oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool0
0`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo0?l0ooooo`3ooom40?oo
o`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooooo0?oood@0
oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`3o0?ooool0oooo
A03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`<00000o`3ooooo0?oood@0oooo00<0
00000?ooo`3oool02@3oool400000000>03oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool0
0`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo0?l0ooooo`3ooom40?oo
o`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooooo0?oood@0
oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`3o0?ooool0oooo
A03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo0?l0ooooo`3o
oom40?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooooo
0?oood@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`3o0?oo
ool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo0?l0
ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool0
o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?oo
o`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`<00000o`3ooooo
0?oood@0oooo00<000000?ooo`3oool02@3oool400000000>03oool00`000000oooo0?ooo`3o0?oo
ool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo0?l0
ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool0
o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?oo
o`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0
oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?oo
o`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000
oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000
003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool100000000>03oool0
0`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?oo
o`030000003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00000003P0
oooo0`00003o0?ooool0ooooA03oool00`000000oooo0?ooo`090?ooo`@00000000h0?ooo`030000
003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool100000000>03oool0
0`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?oo
o`030000003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00000003P0
oooo00<000000?ooo`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool100000000
>03oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000
000h0?ooo`030000003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00
000003P0oooo00<000000?ooo`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool1
00000000>03oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?oo
o`400000000h0?ooo`030000003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00`0
oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0
303oool100000000>03oool300000?l0ooooo`3ooom40?ooo`030000003oool0oooo00T0oooo1000
000003P0oooo00<000000?ooo`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool1
00000000>03oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?oo
o`400000000h0?ooo`030000003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00`0
oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0
303oool100000000>03oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?oo
o`0<0?ooo`40000000030?ooo`060;md00000000000000000000B9`0gooo1P3oool0102oM0000000
00000018W=l40?ooo`030=nLB0000000B9cO00H0oooo00<0okmd0000001d_ol00`3oool01P2oM000
000000000000000004RL0=ooo``0oooo00<000000?ooo`3oool0o`3ooooo0?oood@0oooo00<00000
0?ooo`3oool0303oool1000000000P3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo
00<0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l01P3o
ool00`3o_g@0000007Boo`020?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool02`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`4000000008
0?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0;
0?ooo`030?noM0000000M;oo00P0oooo00<0omnL04Qd_`3oool02P3oool00`000000oooo0?ooo`3o
0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`40000000080?ooo`080?oo_`1d04P0W=oo
0?ooo`3ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00H0oooo00<0gia8000000000000
1@0000000`0004P0W=oo0?ooo`050?ooo`030?oo_`1d04P0W=oo00X0oooo00<000000?ooo`3oool0
o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool100000000203oool01`3ookl0M00007Bo
o`3oool0oono07@00000M;l0103oool00`2oM000001d0;ooo`050?ooo`030?oOW018M;l0oooo0080
oooo00<0okmd0000001d_ol0203oool00`3ookl0M00007Boo`0:0?ooo`030000003oool0oooo0?l0
ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00000000P0oooo00L0okmd0000001d_ol0
oooo0?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01P3oool01`3OW4P0M;oo0?ooo`3oool0
okmd0000001d_ol0203oool00`3o_g@0000007Boo`0:0?ooo`030000003oool0oooo0?l0ooooo`3o
oom40?ooo`030000003oool0oooo00`0oooo0@00000000L0oooo00P0omnL04P0000007@0_ooo0?oo
o`3ogi`0B00004RLg`@0oooo00<0gia80000B02Lgol01P3oool01`3ookl0M01d0;ooo`3oool0okmd
0000001d_ol01`3oool0103ogi`0B0000000M02oool:0?ooo`D00000o`3ooooo0?oood80oooo00<0
00000?ooo`3oool0203oool5000000000`3oool0103Ogml0oooo0?ooo`2oM0020000000604RLg`3o
ool0oooo0?oOW0180000B9cO103oool00`3OW4P0001809cOo`070?ooo`060?noM000M;l0oooo0?no
M0000000M;oo0`3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00T0oooo00<0
00000?ooo`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool1000000000`3oool0
0`3o_g@000000000000200000007001d_`3oool0oooo0?ooo`3ookl0M000001d_`040?ooo`030;md
000007@0_ooo00P0oooo00D0_g@007Boo`3o_g@0000007Boo`030?ooo`030?noM000000000000080
000000<007Bo0?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000
oooo0?ooo`0<0?ooo`40000000030?ooo`050?oog`2LB00000000000M02oool01@3oool00`2oM000
04RL0=ooo`020?ooo`030?oog`2LB00007Bo00T0oooo00D0oono07@0M02o_g@0000007Boo`030?oo
o`050?oog`2LB00000000000M02oool03@3oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool0
0`000000oooo0?ooo`0<0?ooo`40000000040?ooo`030?noM000M;l0oooo00H0oooo00<0okmd0000
B02Lgol00P3oool00`3ogi`0B00007Boo`0:0?ooo`040?noM0000000000007Boo`@0oooo00<0okmd
001d_`3oool03P3oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<
0?ooo`40000000040?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool00P3oool01P2o
M00004RL0=ooo`3oool0_g@0001d_`/0oooo00@0oooO09a800000000M;oo103oool00`3ooml0W4P0
00000002000000030000M02oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooooo0?oood@0oooo
00<000000?ooo`3oool0303oool1000000001@3oool00`3o_g@00000000000020000000307Boo`3o
ool0oooo0080oooo00@0_g@000000000000007Bo3@3oool00`3ogi`0B00007Boo`050?ooo`030?no
M000000000000080000000<0M;oo0?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooool0oooo
A03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo0?l0ooooo`3o
oom40?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooooo
0?oood@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`3o0?oo
ool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo0?l0
ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool0
o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool100000000>03oool300000?l0ooooo`3o
oom40?ooo`030000003oool0oooo00T0oooo1000000003P0oooo00<000000?ooo`3oool0o`3ooooo
0?oood@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`3o0?oo
ool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo0?l0
ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool0
o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?oo
o`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0
oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?oo
o`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000
oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000
003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool100000000>03oool3
00000?l0ooooo`3ooom40?ooo`030000003oool0oooo00T0oooo1000000003P0oooo00<000000?oo
o`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000
oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000
003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool100000000>03oool0
0`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?oo
o`030000003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00000003P0
oooo00<000000?ooo`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool100000000
>03oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000
000h0?ooo`030000003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00`0oooo0@00
000003P0oooo00<000000?ooo`3oool0o`3ooooo0?oood@0oooo00<000000?ooo`3oool0303oool1
00000000>03oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?oo
o`400000000h0?ooo`<00000o`3ooooo0?oood@0oooo00<000000?ooo`3oool02@3oool400000000
>03oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool00`000000oooo0?ooo`0<0?ooo`400000
000h0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0o`3ooond0?ooo`030000003o
ool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3o
0?oook@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0o`3ooond0?ooo`030000003oool0oooo00`0
oooo0@00000003P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3o0?oook@0oooo
00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0o`3ooond0?ooo`030000003oool0oooo00`0oooo0@000000
03P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3o0?oook@0oooo00<000000?oo
o`3oool0303oool100000000>03oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0?l0
oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0o`3ooond0?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo0`00
002<0?ooo`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`090?ooo`@00000000h
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0o`3ooond0?ooo`030000003oool0
oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3o0?oo
ok@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooond0?ooo`030000003oool0oooo00`0
oooo0@00000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?oook@0oooo00<0
00000?ooo`3oool0303oool1000000003@3oool01P2oM000000000000000000004RL0=ooo`H0oooo
00@0_g@0000000000000B9cO103oool00`3OW4P0000004RLg`020?ooo`060;md0000000000000000
0000B9`0gooo303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool0o`3ooond0?ooo`030000003oool0oooo00`0oooo0@00000000`0oooo00<0oooO09a8
0018W=l00P3oool00`3ogi`0B4RL0=ooo`030?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d
_`030?ooo`070=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0
oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000000B0?ooo`030?oOW018M;l0oooo0080oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0<0?ooo`030?oOW018M;l0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo
]03oool00`000000oooo0?ooo`0<0?ooo`400000000B0?ooo`080?oo_`1d04P0W=oo0?ooo`3ooml0
W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00`0oooo00<0oono07@0B02Lgol02P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooond0?oo
o`030000003oool0oooo00`0oooo0@0000000180oooo00L0oono07@0001d_ol0oooo0?oo_`1d0000
07Bo00@0oooo00<0_g@00000M02oool02`3oool00`3ookl0M00007Boo`0:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?oook@0oooo00<00000
0?ooo`3oool0303oool1000000004P3oool01`3o_g@0000007Boo`3oool0omnL04P00018W=l0103o
ool00`2oM000001d0;ooo`0;0?ooo`030?noM0000000M;oo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?oo
o`0<0?ooo`400000000A0?ooo`080?oOW0180000001d0;ooo`3oool0omnL04P00018W=l40?ooo`03
0=nLB00004P0W=oo00X0oooo00@0omnL04P0000007@0_ooo2P3oool5000000T0oooo00<000000?oo
o`3oool0OP3oool00`000000oooo0?ooo`3o0?oook@0oooo00<000000?ooo`3oool0203oool50000
00003@3oool0103Ogml0oooo0?ooo`2oM0020000000604RLg`3oool0oooo0?oOW0180000B9cO103o
ool00`3OW4P0001809cOo`060?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool0
2@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
o`3ooond0?ooo`030000003oool0oooo00`0oooo0@00000000d0oooo00<0okmd0000000000000P00
00001`00M;l0oooo0?ooo`3oool0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`03
0?noM000000000000080000000<007Bo0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooond0?ooo`8000003@3oool100000000
3@3oool01@3ooml0W4P00000000007@0_ooo00D0oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`070?ooo`050?oog`2LB00000000000M02oool03@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooonb0?ooo`H000002`3oool10000
00003P3oool00`3o_g@007Bo0?ooo`060?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d
_ol0203oool00`3o_g@007Bo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`3o0?oook80oooo1P00000;0?ooo`400000000>0?ooo`030?oo
g`2LB00000000080000000<0001d0;ooo`3oool00P3oool01P2oM00004RL0=ooo`3oool0_g@0001d
_`T0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`090?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?oook40oooo2000000:0?oo
o`400000000?0?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool00P3oool0102oM000
000000000000M;l;0?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool0203oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooona0?oo
o`P000002P3oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool0o`3ooonb0?ooo`H000002`3oool100000000>03oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooonb0?ooo`H00000
2`3oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool0o`3ooond0?ooo`8000003@3oool100000000>03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooond0?ooo`030000003oool0
oooo00`0oooo0@00000003P0oooo0`00000;0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool0o`3ooond0?ooo`030000003oool0oooo00T0oooo1000000003P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo]03oool00`000000
oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
OP3oool00`000000oooo0?ooo`3o0?oook@0oooo00<000000?ooo`3oool0303oool100000000>03o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3o
oond0?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<
0?ooo`400000000h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`3o0?oook@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooond0?ooo`03
0000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000
000h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?oo
o`3o0?oook@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooond0?ooo`030000003oool0
oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?oook@0
oooo00<000000?ooo`3oool0303oool100000000>03oool3000000/0oooo00<000000?ooo`3oool0
OP3oool00`000000oooo0?ooo`3o0?oook@0oooo00<000000?ooo`3oool02@3oool400000000>03o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3o
oond0?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<
0?ooo`400000000h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`3o0?oook@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooond0?ooo`03
0000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000
000h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?oo
o`3o0?oook@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooond0?ooo`030000003oool0
oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?oook@0
oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooond0?ooo`030000003oool0oooo00`0oooo
0@00000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`<000002`3oool0
0`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`09
0?ooo`@00000000h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`3o0?oook@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooond0?ooo`03
0000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000
000h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?oo
o`3o0?oook@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooond0?ooo`030000003oool0
oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?oook@0
oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooond0?ooo`030000003oool0oooo00`0oooo
0@00000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?oook@0oooo00<00000
0?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool0o`3ooond0?ooo`030000003oool0oooo00`0oooo0@00000003P0
oooo0`00000;0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooond0?ooo`03
0000003oool0oooo00T0oooo1000000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000
000h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?oo
o`3o0?oook@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0:
0?ooo`800000P03oool00`000000oooo0?ooo`3o0?oook@0oooo00<000000?ooo`3oool0303oool1
00000000>03oool00`000000oooo0?ooo`080?ooo`H00000OP3oool00`000000oooo0?ooo`3o0?oo
ok@0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`080?ooo`H0
0000OP3oool00`000000oooo0?ooo`3o0?oook@0oooo00<000000?ooo`3oool0303oool100000000
0`3oool01P2oM000000000000000000004RL0=ooo`H0oooo00@0_g@0000000000000B9cO103oool0
0`3OW4P0000004RLg`020?ooo`060;md00000000000000000000B9`0gooo103oool01P2oM0000000
00000000000004RL0=ooo``0oooo00<000000?ooo`3oool01`3oool8000007d0oooo00<000000?oo
o`3oool0o`3ooond0?ooo`030000003oool0oooo00`0oooo0@0000000080oooo00<0oooO09a80018
W=l00P3oool00`3ogi`0B4RL0=ooo`030?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`03
0?ooo`070=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo0080oooo
00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0;0?ooo`030000003oool0oooo00L0oooo
2000001m0?ooo`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`0<0?ooo`400000
00080?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Bo
o`0<0?ooo`030?oOW018M;l0oooo00L0oooo00<0omnL04Qd_`3oool02P3oool00`000000oooo0?oo
o`080?ooo`H00000O@3oool200000?l0oooo]P3oool00`000000oooo0?ooo`0<0?ooo`4000000008
0?ooo`080?oo_`1d04P0W=oo0?ooo`3ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00`0
oooo00<0oono07@0B02Lgol01`3oool00`3ookl0M01809cOo`0:0?ooo`030000003oool0oooo00P0
oooo1P00001k0?ooo`H00000o`3ooond0?ooo`030000003oool0oooo00`0oooo0@00000000P0oooo
00L0oono07@0001d_ol0oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02`3oool00`3o
okl0M00007Boo`070?ooo`030?oo_`1d0000M;oo00X0oooo00<000000?ooo`3oool02P3oool20000
07d0oooo1P00003o0?oook@0oooo00<000000?ooo`3oool0303oool100000000203oool01`3o_g@0
000007Boo`3oool0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0;0?ooo`030?noM0000000
M;oo00L0oooo00<0okmd0000001d_ol02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo07X0oooo2000003o0?oook<0oooo00<000000?ooo`3oool0303oool1000000001`3oool0203o
gi`0B0000000M02oool0oooo0?oOW0180000B9cO103oool00`3OW4P0001809cOo`0:0?ooo`040?oO
W0180000001d0;ooo`H0oooo00@0omnL04P0000007@0_ooo2P3oool5000000T0oooo00<000000?oo
o`3oool0NP3oool8000008T0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo
00P0oooo1@00000000<0oooo00@0gmoO0?ooo`3oool0_g@00P0000001P18W=l0oooo0?ooo`3ogi`0
B00004RLg`@0oooo00<0gia80000B02Lgol01P3oool0103Ogml0oooo0?ooo`2oM0020000000504RL
g`3oool0oooo0?ooo`3Ogml00P3oool0102oM000000000000018W=l;0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0N`3oool6000008X0oooo00<000000?ooo`3oool0o`3ooolW0?oo
o`030000003oool0oooo00`0oooo0@00000000<0oooo00<0okmd0000000000000P0000001`00M;l0
oooo0?ooo`3oool0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`030?noM0000000
00000080000000<007Bo0?ooo`3oool00P3oool00`3o_g@000000000000200000003001d_`3oool0
oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1k0?ooo`H00000RP3oool0
0`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0303oool1000000000`3oool01@3o
oml0W4P00000000007@0_ooo00D0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`07
0?ooo`050?oog`2LB00000000000M02oool01@3oool01@3ooml0W4P00000000007@0_ooo00d0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1m0?ooo`800000S03oool00`000000oooo
0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0303oool100000000103oool00`3o_g@007Bo0?oo
o`060?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool00`3o_g@007Bo0?oo
o`070?ooo`030?noM000M;l0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003o
ool0oooo00`0oooo0@00000000@0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`02
0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo2@3oool00`3ooml0W4P000000002000000030000
M02oool0oooo0080oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`090?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0<0?ooo`40000000050?ooo`030?noM000
000000000080000000<0M;oo0?ooo`3oool00P3oool0102oM000000000000000M;l;0?ooo`030?no
M000000000000080000000<0M;oo0?ooo`3oool00P3oool00`3o_g@00000000000020000000307Bo
o`3oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo
0@00000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@00
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@000000
03P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo
08X0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@00000003P0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo08X0
oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo
0`00000;0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool02@3oool400000000>03oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`3o0?ooobL0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o
0?ooobL0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo07h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?oo
obL0oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0
oooo00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0oooo
00<000000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<0
00000?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<00000
0?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?oo
o`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3o
ool0303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo
00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0
303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0303o
ool100000000>03oool3000000/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`2:
0?ooo`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`090?ooo`@00000000h0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`2:0?ooo`03
0000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`2:0?ooo`030000003o
ool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0
oooo0?l0oooo9`3oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo
0?l0oooo9`3oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0
oooo9`3oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0oooo
9`3oool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0OP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0oooo9`3o
ool00`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0oooo9`3oool0
0`000000oooo0?ooo`0<0?ooo`400000000h0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0OP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0oooo9`3oool00`00
0000oooo0?ooo`0<0?ooo`400000000h0?ooo`<000002`3oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo08X0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00T0
oooo1000000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo
0@00000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@00
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@000000
03P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo
08X0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@00000003P0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo08X0
oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo08X0oooo
00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo08X0oooo00<00000
0?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo08X0oooo00<000000?oo
o`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0
o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@00000003P0oooo0`00000;0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<0
00000?ooo`3oool02@3oool400000000>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<00000
0?ooo`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?oo
o`3oool0303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3o
ool0303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo
00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0
303oool100000000>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0303o
ool1000000003@3oool01P2oM000000000000000000004RL0=ooo`H0oooo00@0_g@0000000000000
B9cO103oool00`3OW4P0000004RLg`030?ooo`060?oog`2LB00000000000000007@0_ooo2`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0RP3oool0
0`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0303oool100000000303oool00`3o
oml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00<0oooo00L0oooO09a80000M;l0oooo0?oog`2L
B00007Bo00<0oooo00<0gia800000018W=l00P3oool0203ookl0M0000018W03Oool0oooo0=nLB000
04P0W=oo2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool0RP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0303oool10000
00004P3oool00`3ogi`0B7Bo0?ooo`020?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d
_ol01`3oool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo00T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@0000000180oooo00P0oono07@0B02Lgol0
oooo0?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l01P3oool00`3ookl0M000001d_`04
0?ooo`030=nLB00007@0_ooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0
oooo00`0oooo0@0000000180oooo00L0oono07@0001d_ol0oooo0?oo_`1d000007Bo00@0oooo00<0
_g@00000M02oool01@3oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0W=oo00T0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0oooo9`3o
ool00`000000oooo0?ooo`0<0?ooo`400000000B0?ooo`070?noM0000000M;oo0?ooo`3ogi`0B000
04RLg`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04P00018W=l00`3oool0103ookl0M000
0000M02oool90?ooo`D00000RP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0
oooo9`3oool00`000000oooo0?ooo`080?ooo`D00000000A0?ooo`080?oOW0180000001d0;ooo`3o
ool0omnL04P00018W=l40?ooo`030=nLB00004P0W=oo00D0oooo00T0oono07@00000000004RL0=oo
o`3oool0_g@000000018W=l02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo08X0
oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00`0oooo0@00000000d0oooo
00@0gmoO0?ooo`3oool0_g@00P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia8
0000B02Lgol01@3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool02@3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0o`3o
oolW0?ooo`030000003oool0oooo00`0oooo0@00000000d0oooo00<0okmd0000000000000P000000
1`00M;l0oooo0?ooo`3oool0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`030?no
M0000000B9cO00l0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0<0?ooo`400000000=0?ooo`050?oog`2L
B00000000000M02oool01@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo
00@0oooO09a8000004P0W=oo3P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo08X0
oooo00<000000?ooo`3oool0o`3ooolf0?ooo`400000000>0?ooo`030?noM000M;l0oooo00H0oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`080?ooo`040?oo_`1d0000001d0;ooo`d0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0
oooo=P3oool1000000003P3oool00`3ooml0W4P000000002000000030000M02oool0oooo0080oooo
00H0_g@00018W03Oool0oooo0;md0000M;l:0?ooo`040?oog`2LB0000000001d_``0oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0oooo=P3oool1
000000003`3oool00`3o_g@00000000000020000000307Boo`3oool0oooo0080oooo00@0_g@00000
0000000007Bo3@3oool01@3ogi`0B00000000000B9`0gooo00T0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000>03oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0o`3ooolf
0?ooo`400000000h0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000>03oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`400000
000h0?ooo`<00000S03oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0oooo<`3o
ool400000000>03oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo08X0oooo00<00000
0?ooo`3oool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool0RP3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000
>03oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0
o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000>03oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0o`3ooolf0?oo
o`400000000h0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0RP3oool00`000000
oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000
003oool0oooo0?l0oooo=P3oool100000000>03oool00`000000oooo0?ooo`3o0?oooaX0oooo00<0
00000?ooo`3oool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo0?l0oooo6P3oool0
0`000000oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo0`00003o0?oooaX0oooo00<000000?oo
o`3oool0o`3ooolc0?ooo`@00000000h0?ooo`030000003oool0oooo0?l0oooo6P3oool00`000000
oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000
003oool0oooo0?l0oooo=P3oool100000000>03oool00`000000oooo0?ooo`3o0?oooaX0oooo00<0
00000?ooo`3oool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo0?l0oooo6P3oool0
0`000000oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?oo
o`030000003oool0oooo0?l0oooo=P3oool100000000>03oool00`000000oooo0?ooo`3o0?oooaT0
oooo0P00003o0?ooocP0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`H00000
o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo0?l0oooo5`3oool600000?l0oooo=P3o
ool100000000>03oool00`000000oooo0?ooo`3o0?oooaH0oooo2000003o0?ooocD0oooo0@000000
03P0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`P00000o`3ooole0?ooo`400000000h0?ooo`03
0000003oool0oooo0?l0oooo5`3oool600000?l0oooo=P3oool100000000>03oool300000?l0oooo
5`3oool600000?l0oooo<`3oool400000000>03oool00`000000oooo0?ooo`3o0?oooaT0oooo0P00
003o0?ooocP0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0
oooo0?l0oooo=P3oool100000000>03oool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?oo
o`3oool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo0?l0oooo6P3oool00`000000
oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000
003oool0oooo0?l0oooo=P3oool100000000>03oool00`000000oooo0?ooo`3o0?oooaX0oooo00<0
00000?ooo`3oool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo0?l0oooo6P3oool0
0`000000oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?oo
o`030000003oool0oooo0?l0oooo=P3oool100000000>03oool00`000000oooo0?ooo`3o0?oooaX0
oooo00<000000?ooo`3oool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo0?l0oooo
6P3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3o
oolJ0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000>03oool300000?l0oooo6P3oool0
0`000000oooo0?ooo`3o0?oooc<0oooo1000000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?oo
o`030000003oool0oooo0?l0oooo=P3oool100000000>03oool00`000000oooo0?ooo`3o0?oooaX0
oooo00<000000?ooo`3oool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo0?l0oooo
6P3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3o
oolJ0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000>03oool00`000000oooo0?ooo`3o
0?oooaX0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`40000000030?ooo`060;md000000000000
00000000B9`0gooo1P3oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO00<0oooo
00H0oooO09a80000000000000000M02oool30?ooo`060;md00000000000000000000B9`0gooo303o
ool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`4000000002
0?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool00`3oool01`3ooml0W4P0001d_`3o
ool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`0<0?oo_`1d000004RL0=ooo`3o
ool0gia80000B02Lgol0oooo0?oog`2LB000B9cO0P3oool00`3ogi`0B4RL0=ooo`0;0?ooo`030000
003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000000P0oooo00<0
omnL04Qd_`3oool00P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<0
_g@00000M02oool00`3oool00`2oM00007Bo0?ooo`060?ooo`030?oOW018M;l0oooo00X0oooo00<0
00000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000203oool0
203ookl0M01809cOo`3oool0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`060?ooo`03
0?oo_`1d000007Bo00@0oooo00<0gia80000M02oool01P3oool00`3ookl0M01809cOo`0:0?ooo`03
0000003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000000P0oooo
00L0oono07@0001d_ol0oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01@3oool00`3o
gi`0B00004RLg`040?ooo`030;md000004P0W=oo00H0oooo00<0oono07@0001d_ol02P3oool00`00
0000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`40000000080?ooo`07
0?noM0000000M;oo0?ooo`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL
04P00018W=l00`3oool0103ookl0M0000000M02oool60?ooo`030?noM0000000M;oo00X0oooo1@00
003o0?oooaP0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`D0000000070?ooo`080?oOW0180000
001d0;ooo`3oool0omnL04P00018W=l40?ooo`030=nLB00004P0W=oo00D0oooo00T0oono07@00000
000004RL0=ooo`3oool0_g@000000018W=l01P3oool0103ogi`0B0000000M02oool:0?ooo`030000
003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000000<0oooo00@0
gmoO0?ooo`3oool0_g@00P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia80000
B02Lgol01@3oool01@3ooml0W4P00000M02ogi`0B0000080000000D0B9cO0?ooo`3oool0oooo0=oO
g`020?ooo`040;md00000000000004RLg`/0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000
003oool0oooo0?l0oooo=P3oool1000000000`3oool00`3o_g@000000000000200000007001d_`3o
ool0oooo0?ooo`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo00<0okmd00000018
W=l01`3oool00`3o_g@000000000000200000003001d_`3oool0oooo00X0oooo00<000000?ooo`3o
ool0o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo=P3oool1000000000`3oool01@3ooml0W4P0
0000000007@0_ooo00D0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`070?ooo`04
0?oog`2LB000001809cOo`H0oooo00D0oooO09a800000000001d0;ooo`0=0?ooo`030000003oool0
oooo0?l0oooo6P3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000000@0oooo00<0okmd001d
_`3oool01P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo00@0oono07@0
000007@0_ooo1P3oool00`3o_g@007Bo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo6P3oool0
0`000000oooo0?ooo`3o0?ooocH0oooo0@00000000@0oooo00<0oooO09a8000000000P0000000`00
07@0_ooo0?ooo`020?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo2P3oool0103ooml0W4P00000
0000M;l50?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool02@3oool00`000000oooo
0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`40000000050?ooo`030?noM000
000000000080000000<0M;oo0?ooo`3oool00P3oool0102oM000000000000000M;l=0?ooo`050?oO
W018000000000018W03Oool00`3oool00`3o_g@00000000000020000000307Boo`3oool0oooo00P0
oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000
>03oool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`400000
000h0?ooo`030000003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00
000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo=P3oool1
00000000>03oool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool0o`3ooolf0?oo
o`400000000h0?ooo`<00000o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo<`3oool400000000
>03oool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`400000
000h0?ooo`030000003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00
000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo=P3oool1
00000000>03oool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool0o`3ooolf0?oo
o`400000000h0?ooo`030000003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`3o0?ooocH0
oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo
=P3oool100000000>03oool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool0o`3o
oolf0?ooo`400000000h0?ooo`030000003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`3o
0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo
0?l0oooo=P3oool100000000>03oool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3o
ool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo0?l0oooo6P3oool00`000000oooo
0?ooo`3o0?ooocH0oooo0@00000003P0oooo0`00003o0?oooaX0oooo00<000000?ooo`3oool0o`3o
oolc0?ooo`@00000000h0?ooo`030000003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`3o
0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo
0?l0oooo=P3oool100000000>03oool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3o
ool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo0?l0oooo6P3oool00`000000oooo
0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003o
ool0oooo0?l0oooo=P3oool100000000>03oool00`000000oooo0?ooo`3o0?oooaX0oooo00<00000
0?ooo`3oool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo0?l0oooo6P3oool00`00
0000oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`03
0000003oool0oooo0?l0oooo=P3oool100000000>03oool00`000000oooo0?ooo`3o0?oooaX0oooo
00<000000?ooo`3oool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo0?l0oooo6P3o
ool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooolJ
0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000>03oool300000?l0oooo6P3oool00`00
0000oooo0?ooo`3o0?oooc<0oooo1000000003P0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`03
0000003oool0oooo0?l0oooo=P3oool100000000>03oool00`000000oooo0?ooo`3o0?oooaX0oooo
00<000000?ooo`3oool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo0?l0oooo6P3o
ool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooolJ
0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000>03oool00`000000oooo0?ooo`3o0?oo
oaX0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0oooo0?l0
oooo6P3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?ooo`3oool0
o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000>03oool00`000000oooo0?oo
o`3o0?oooaX0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0
oooo0?l0oooo6P3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?oo
o`3oool0o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000>03oool300000?l0
oooo6P3oool00`000000oooo0?ooo`3o0?oooc<0oooo1000000003P0oooo00<000000?ooo`3oool0
o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000>03oool00`000000oooo0?oo
o`3o0?oooaX0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`400000000h0?ooo`030000003oool0
oooo0?l0oooo6P3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000003P0oooo00<000000?oo
o`3oool0o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000>03oool00`000000
oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`400000000h0?ooo`030000
003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@00000000d0oooo00H0
_g@000000000000000000018W03Oool60?ooo`040;md00000000000004RLg`@0oooo00<0gia80000
0018W=l0103oool00`3ogi`0B01d0;ooo`0=0?ooo`030000003oool0oooo0?l0oooo6P3oool00`00
0000oooo0?ooo`3o0?ooocH0oooo0@00000000`0oooo00<0oooO09a80018W=l00P3oool00`3ogi`0
B4RL0=ooo`030?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000
B9cO00D0oooo00<0_g@007Boo`3oool0303oool00`000000oooo0?ooo`3o0?oooaX0oooo00<00000
0?ooo`3oool0o`3ooolf0?ooo`400000000B0?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000
B02Lgol00P3oool00`3ogi`0B00007Boo`0:0?ooo`030?noM000M;l0oooo00`0oooo00<000000?oo
o`3oool0o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo=P3oool1000000004P3oool0203ookl0
M01809cOo`3oool0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0:0?ooo`030?oo_`1d
07@0_ooo00`0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo=P3o
ool1000000004P3oool01`3ookl0M00007Boo`3oool0oono07@00000M;l0103oool00`2oM000001d
0;ooo`0:0?ooo`030;md001d_ol0oooo00/0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000
003oool0oooo0?l0oooo=P3oool1000000004P3oool01`3o_g@0000007Boo`3oool0omnL04P00018
W=l0103oool00`2oM000001d0;ooo`0:0?ooo`030?noM000M;l0oooo00/0oooo1@00003o0?oooaP0
oooo00<000000?ooo`3oool0o`3ooolb0?ooo`D00000000A0?ooo`080?oOW0180000001d0;ooo`3o
ool0omnL04P00018W=l40?ooo`030=nLB00004P0W=oo00X0oooo00<0oono07@0M02oool02`3oool0
0`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`400000000=0?oo
o`040=oOg`3oool0oooo0;md0080000000H0B9cO0?ooo`3oool0omnL04P00018W=l40?ooo`030=nL
B00004P0W=oo00/0oooo00<0_g@007Boo`3oool02P3oool00`000000oooo0?ooo`3o0?oooaX0oooo
00<000000?ooo`3oool0o`3ooolf0?ooo`400000000=0?ooo`030?noM000000000000080000000L0
07Bo0?ooo`3oool0oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02`3oool00`3o_g@0
07Bo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`3o0?ooocH0
oooo0@00000000d0oooo00D0oooO09a800000000001d0;ooo`050?ooo`030;md0000B9`0gooo0080
oooo00<0oooO09a80000M;l01P3oool00`3ogkl0_moo0?ooo`030?ooo`030?oo_`1d07@0_ooo00X0
oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo=P3oool100000000
3P3oool00`3o_g@007Bo0?ooo`060?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0
1P3oool00`3ooml0W4Qd0;ooo`040?ooo`030;md001d_ol0oooo00T0oooo00<000000?ooo`3oool0
o`3ooolJ0?ooo`030000003oool0oooo0?l0oooo=P3oool1000000003P3oool00`3ooml0W4P00000
0002000000030000M02oool0oooo0080oooo00H0_g@00018W03Oool0oooo0;md0000M;l80?ooo`03
0=nLB0000000000000@0000000<007Bo0?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooool0
ooooD`3oool1000000003`3oool00`3o_g@00000000000020000000307Boo`3oool0oooo0080oooo
00@0_g@000000000000007Bo2@3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00P0
oooo00<000000?ooo`3oool0o`3ooooo0?oooe<0oooo0@00000003P0oooo00<000000?ooo`3oool0
o`3ooooo0?oooe<0oooo0@00000003P0oooo00<000000?ooo`3oool0o`3ooooo0?oooe<0oooo0@00
000003P0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0X0?ooo`400000000h0?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0:03oool100000000>03oool3000000/0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0
oooo1000000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0203oool100000000>03ooooo00000?l00000E`00
00000?l0ooooo`3ooon?0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 652.25}, {402.75, 0}} -> {0.268945, 50.371, \
0.00612444, 0.00084907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.16897 0.274224 -0.384214 0.482515 [
[.10525 -0.0125 -7.03125 -24.5625 ]
[.10525 -0.0125 7.03125 0 ]
[.24237 -0.0125 -14.5625 -24.5625 ]
[.24237 -0.0125 14.5625 0 ]
[.37948 -0.0125 -7.03125 -24.5625 ]
[.37948 -0.0125 7.03125 0 ]
[.51659 -0.0125 -14.5625 -24.5625 ]
[.51659 -0.0125 14.5625 0 ]
[.6537 -0.0125 -7.03125 -24.5625 ]
[.6537 -0.0125 7.03125 0 ]
[.79081 -0.0125 -14.5625 -24.5625 ]
[.79081 -0.0125 14.5625 0 ]
[.92793 -0.0125 -7.03125 -24.5625 ]
[.92793 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0018 -29.125 -12.2813 ]
[-0.0125 .0018 0 12.2813 ]
[-0.0125 .0983 -14.0625 -12.2813 ]
[-0.0125 .0983 0 12.2813 ]
[-0.0125 .1948 -29.125 -12.2813 ]
[-0.0125 .1948 0 12.2813 ]
[-0.0125 .29131 -29.125 -12.2813 ]
[-0.0125 .29131 0 12.2813 ]
[-0.0125 .38781 -29.125 -12.2813 ]
[-0.0125 .38781 0 12.2813 ]
[-0.0125 .48431 -29.125 -12.2813 ]
[-0.0125 .48431 0 12.2813 ]
[-0.0125 .58082 -14.0625 -12.2813 ]
[-0.0125 .58082 0 12.2813 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10525 0 m
.10525 .00625 L
s
gsave
.10525 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.24237 0 m
.24237 .00625 L
s
gsave
.24237 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.37948 0 m
.37948 .00625 L
s
gsave
.37948 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.51659 0 m
.51659 .00625 L
s
gsave
.51659 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.6537 0 m
.6537 .00625 L
s
gsave
.6537 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.79081 0 m
.79081 .00625 L
s
gsave
.79081 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
1.000 setlinewidth
grestore
.92793 0 m
.92793 .00625 L
s
gsave
.92793 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.13268 0 m
.13268 .00375 L
s
.1601 0 m
.1601 .00375 L
s
.18752 0 m
.18752 .00375 L
s
.21494 0 m
.21494 .00375 L
s
.26979 0 m
.26979 .00375 L
s
.29721 0 m
.29721 .00375 L
s
.32463 0 m
.32463 .00375 L
s
.35206 0 m
.35206 .00375 L
s
.4069 0 m
.4069 .00375 L
s
.43432 0 m
.43432 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.48917 0 m
.48917 .00375 L
s
.54401 0 m
.54401 .00375 L
s
.57144 0 m
.57144 .00375 L
s
.59886 0 m
.59886 .00375 L
s
.62628 0 m
.62628 .00375 L
s
.68113 0 m
.68113 .00375 L
s
.70855 0 m
.70855 .00375 L
s
.73597 0 m
.73597 .00375 L
s
.76339 0 m
.76339 .00375 L
s
.81824 0 m
.81824 .00375 L
s
.84566 0 m
.84566 .00375 L
s
.87308 0 m
.87308 .00375 L
s
.9005 0 m
.9005 .00375 L
s
.07783 0 m
.07783 .00375 L
s
.05041 0 m
.05041 .00375 L
s
.02299 0 m
.02299 .00375 L
s
.95535 0 m
.95535 .00375 L
s
.98277 0 m
.98277 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0018 m
.00625 .0018 L
s
gsave
-0.0125 .0018 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .0983 m
.00625 .0983 L
s
gsave
-0.0125 .0983 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .1948 m
.00625 .1948 L
s
gsave
-0.0125 .1948 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .29131 m
.00625 .29131 L
s
gsave
-0.0125 .29131 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .38781 m
.00625 .38781 L
s
gsave
-0.0125 .38781 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
0 .48431 m
.00625 .48431 L
s
gsave
-0.0125 .48431 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
0 .58082 m
.00625 .58082 L
s
gsave
-0.0125 .58082 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02592 m
.00375 .02592 L
s
0 .05005 m
.00375 .05005 L
s
0 .07418 m
.00375 .07418 L
s
0 .12243 m
.00375 .12243 L
s
0 .14655 m
.00375 .14655 L
s
0 .17068 m
.00375 .17068 L
s
0 .21893 m
.00375 .21893 L
s
0 .24306 m
.00375 .24306 L
s
0 .26718 m
.00375 .26718 L
s
0 .31543 m
.00375 .31543 L
s
0 .33956 m
.00375 .33956 L
s
0 .36368 m
.00375 .36368 L
s
0 .41194 m
.00375 .41194 L
s
0 .43606 m
.00375 .43606 L
s
0 .46019 m
.00375 .46019 L
s
0 .50844 m
.00375 .50844 L
s
0 .53256 m
.00375 .53256 L
s
0 .55669 m
.00375 .55669 L
s
0 .60494 m
.00375 .60494 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.10525 .61178 m
.10525 .61803 L
s
.24237 .61178 m
.24237 .61803 L
s
.37948 .61178 m
.37948 .61803 L
s
.51659 .61178 m
.51659 .61803 L
s
.6537 .61178 m
.6537 .61803 L
s
.79081 .61178 m
.79081 .61803 L
s
.92793 .61178 m
.92793 .61803 L
s
.125 Mabswid
.13268 .61428 m
.13268 .61803 L
s
.1601 .61428 m
.1601 .61803 L
s
.18752 .61428 m
.18752 .61803 L
s
.21494 .61428 m
.21494 .61803 L
s
.26979 .61428 m
.26979 .61803 L
s
.29721 .61428 m
.29721 .61803 L
s
.32463 .61428 m
.32463 .61803 L
s
.35206 .61428 m
.35206 .61803 L
s
.4069 .61428 m
.4069 .61803 L
s
.43432 .61428 m
.43432 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.48917 .61428 m
.48917 .61803 L
s
.54401 .61428 m
.54401 .61803 L
s
.57144 .61428 m
.57144 .61803 L
s
.59886 .61428 m
.59886 .61803 L
s
.62628 .61428 m
.62628 .61803 L
s
.68113 .61428 m
.68113 .61803 L
s
.70855 .61428 m
.70855 .61803 L
s
.73597 .61428 m
.73597 .61803 L
s
.76339 .61428 m
.76339 .61803 L
s
.81824 .61428 m
.81824 .61803 L
s
.84566 .61428 m
.84566 .61803 L
s
.87308 .61428 m
.87308 .61803 L
s
.9005 .61428 m
.9005 .61803 L
s
.07783 .61428 m
.07783 .61803 L
s
.05041 .61428 m
.05041 .61803 L
s
.02299 .61428 m
.02299 .61803 L
s
.95535 .61428 m
.95535 .61803 L
s
.98277 .61428 m
.98277 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0018 m
1 .0018 L
s
.99375 .0983 m
1 .0983 L
s
.99375 .1948 m
1 .1948 L
s
.99375 .29131 m
1 .29131 L
s
.99375 .38781 m
1 .38781 L
s
.99375 .48431 m
1 .48431 L
s
.99375 .58082 m
1 .58082 L
s
.125 Mabswid
.99625 .02592 m
1 .02592 L
s
.99625 .05005 m
1 .05005 L
s
.99625 .07418 m
1 .07418 L
s
.99625 .12243 m
1 .12243 L
s
.99625 .14655 m
1 .14655 L
s
.99625 .17068 m
1 .17068 L
s
.99625 .21893 m
1 .21893 L
s
.99625 .24306 m
1 .24306 L
s
.99625 .26718 m
1 .26718 L
s
.99625 .31543 m
1 .31543 L
s
.99625 .33956 m
1 .33956 L
s
.99625 .36368 m
1 .36368 L
s
.99625 .41194 m
1 .41194 L
s
.99625 .43606 m
1 .43606 L
s
.99625 .46019 m
1 .46019 L
s
.99625 .50844 m
1 .50844 L
s
.99625 .53256 m
1 .53256 L
s
.99625 .55669 m
1 .55669 L
s
.99625 .60494 m
1 .60494 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.02381 .34626 m
.02381 .46929 L
s
.015 w
.02381 .40778 Mdot
.002 w
.23962 .41491 m
.23962 .60332 L
s
.015 w
.23962 .50912 Mdot
.002 w
.47683 .01472 m
.47683 .22811 L
s
.015 w
.47683 .12141 Mdot
.002 w
.97619 .21262 m
.97619 .36721 L
s
.015 w
.97619 .28991 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{653.25, 403.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:=0001Tb000`400?l00000o`00003oo`3ooooo
0?ooohl0oooo003o0?ooool0ooooS`3oool00?l0ooooo`3ooon?0?ooo`00o`3ooooo0?ooohl0oooo
003o0?ooool0ooooS`3oool00?l0ooooo`3ooon?0?ooo`00J03oool00`3o_g@00000000000020000
0003001d_`3oool0oooo04<0oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3oool0
gia800000018W=l00P3oool01P2oM000000000000000000004RL0=oood@0oooo00<0gia800000000
00001@0000000`1d_ol0oooo0?ooo`0o0?ooo`030=nLB0000000000000D0000000H0M;oo0?ooo`3o
ool0gia800000018W=l20?ooo`060;md00000000000000000000B9`0goooA03oool00`3ooml0W4P0
00000002000000030018W03Oool0oooo04<0oooo00<0oooO09a8000000000P0000000`00B9`0gooo
0?ooo`030?ooo`030=nLB0000000B9cO0080oooo00H0_g@000000000000000000018W03Ooom90?oo
o`030?noM0000000M;oo0340oooo001Z0?ooo`030;md000007@0_ooo04P0oooo00<0_g@00000M02o
ool0103oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`14
0?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool0@03oool00`3OW4P0000000000004
0000000:001d_`3oool0oooo0=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`80oooo00<0omnL04Q8
W03Oool0@`3oool0203ogi`0B0000018W03Oool0oooo0?oOW01804P0W=oo@`3oool0203ogi`0B000
0018W03Oool0oooo0?oOW01804P0W=oo0`3oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l0
0P3oool00`3ogi`0B4RL0=ooo`180?ooo`030?noM0000000M;oo0340oooo001Z0?ooo`030;md0000
07@0_ooo04P0oooo00<0_g@00000M02oool03P3oool00`3ogi`0B7Bo0?ooo`140?ooo`030=nLB018
W=l0oooo0080oooo00<0oooO09a8M02oool0@P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2L
B7@0_ooo00/0oooo00<0omnL04Qd_`3oool0B03oool00`3o_g@004RL0=ooo`180?ooo`030?noM000
B9`0gooo00`0oooo00<0omnL04Qd_`3oool0A`3oool00`3o_g@0000007Boo`0a0?ooo`00JP3oool0
0`2oM000001d0;ooo`180?ooo`030;md000007@0_ooo00h0oooo00<0oono07@0B02Lgol0A@3oool0
0`3OW4P0B9cO0?ooo`170?ooo`030=nLB018W=l0oooo00l0oooo00<0oono07@0B02Lgol0B03oool0
0`3o_g@0001809cOo`180?ooo`030?noM00004P0W=oo00`0oooo00<0oono07@0B02Lgol0@P3oool0
0`3OW4P0000000000005000000030000B02Lgol0oooo02h0oooo001Z0?ooo`030;md000007@0_ooo
04P0oooo00<0_g@00000M02oool03P3oool00`3ookl0M00007Boo`160?ooo`030=nLB01d_ol0oooo
04L0oooo00<0gia807Boo`3oool03P3oool00`3ookl0M00007Boo`180?ooo`030;md000004P0W=oo
04P0oooo00<0_g@00000B02Lgol0303oool00`3ookl0M00007Boo`120?ooo`030?oOW018M;l0oooo
0080oooo00<0okmd0000001d_ol0<@3oool006X0oooo00<0_g@00000M02oool0B03oool00`2oM000
001d0;ooo`0>0?ooo`030?noM0000000M;oo04H0oooo00<0oooO09a8B02Lgol0A`3oool00`3ooml0
W4Q809cOo`0>0?ooo`030?noM0000000M;oo04L0oooo00@0_g@00000000007@0_oooA`3oool0102o
M00000000000M02oool<0?ooo`030?noM0000000M;oo04<0oooo00L0gia807Boo`3oool0oooo0?no
M0000000M;oo0340oooo001Z0?ooo`030;md000007@0_ooo04P0oooo00<0_g@00000M02oool03@3o
ool0103ogi`0B0000000M02ooom70?ooo`030?oOW01807@0_ooo04L0oooo00<0omnL04P0M02oool0
303oool0103ogi`0B0000000M02ooom40?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3o
ool0@`3oool00`3ookl0M000000000020000000304RLg`3oool0oooo00X0oooo00@0omnL04P00000
07@0_ooo@`3oool01`3ookl0M01d0;ooo`3oool0okmd0000001d_ol0<@3oool006X0oooo00<0_g@0
0000M02oool0B03oool00`2oM000001d0;ooo`090?ooo`040=oOg`3oool0oooo0;md0080000000<0
B9cO0?ooo`3oool0A`3oool00`2oM000B9cO0?ooo`170?ooo`030;md0018W=l0oooo00L0oooo00@0
gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`150?ooo`030?noM00004P0W=oo04P0oooo
00<0okmd0000B02Lgol02@3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo04<0
oooo00H0okmd001d_`3oool0okmd0000001d_ola0?ooo`00JP3oool00`2oM000001d0;ooo`180?oo
o`030;md000007@0_ooo00T0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`180?oo
o`030=nLB00007@0_ooo04L0oooo00<0gia80000M02oool01`3oool00`3o_g@00000000000020000
0003001d_`3oool0oooo04L0oooo00<0omnL04Qd_`3oool0B03oool00`3ogi`0B7Bo0?ooo`080?oo
o`030?noM000000000000080000000<007Bo0?ooo`3oool0A@3oool01@2oM000M;oo0?noM0000000
M;oo0340oooo001Z0?ooo`030;md000007@0_ooo04P0oooo00<0_g@00000M02oool02@3oool01@3o
oml0W4P00000000007@0_ooo04/0oooo00<0okmd0000001d_ol0A`3oool00`3o_g@0000007Boo`07
0?ooo`050?oog`2LB00000000000M02oool0BP3oool00`3ooml0W4P004RLg`180?ooo`030?oog`2L
B000B9cO00P0oooo00D0oooO09a800000000001d0;ooo`180?ooo`050?oo_`1d07@0_kmd0000001d
_ol0<@3oool006X0oooo00<0_g@00000M02oool0B03oool00`2oM000001d0;ooo`0:0?ooo`030?no
M000M;l0oooo04H0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`110?ooo`030?oO
W02L_ol0oooo00<0oooo00<0_g@00000001d_ol0203oool00`3o_g@007Bo0?ooo`160?ooo`030?oo
g`2LM9`0gooo0080oooo00<0oooO09a80000M;l0@`3oool00`3ooml0W7BL0=ooo`020?ooo`030?oo
g`2LB00007Bo00T0oooo00<0okmd001d_`3oool0BP3oool0103o_g@000000000001d_ola0?ooo`00
J03oool01@3OW4P000000000000007@0_ooo04H0oooo00D0gia8000000000000001d0;ooo`0:0?oo
o`030?oog`2LB00000000080000000<0001d0;ooo`3oool0@P3oool0202oM000M;oo0?ooo`3oool0
gia800000000B9`0gooo@P3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo203oool0
0`3ooml0W4P000000002000000030000M02oool0oooo0480oooo00L0omnL04Q8W03Oool0oooo0=nL
B0000000M;oo04@0oooo00L0omnL04Q8W03Oool0oooo0=nLB0000000M;oo00T0oooo00<0oooO09a8
000000000P0000000`0007@0_ooo0?ooo`150?ooo`040?oog`2LB000000007Booc40oooo001Y0?oo
o`040?oo_`1d0000001d0;ooodL0oooo00@0oono07@0000007@0_ooo2`3oool00`3o_g@000000000
00020000000307Boo`3oool0oooo0480oooo00D0_g@00000000000000000001d_`150?ooo`050;md
00000000000000000000M;l02`3oool00`3o_g@00000000000020000000307Boo`3oool0oooo0480
oooo00D0omnL04P000000000000004RLg`160?ooo`050?oOW0180000000000000018W=l02`3oool0
0`3o_g@00000000000020000000307Boo`3oool0oooo04D0oooo00<0omnL04P0001d_ol0<@3oool0
0?l0ooooo`3ooon?0?ooo`00o`3ooooo0?ooohl0oooo003o0?ooool0ooooS`3oool00?l0ooooo`3o
oon?0?ooo`00o`3ooooo0?ooohl0oooo003o0?ooool0ooooS`3oool00?l0ooooo`3ooon?0?ooo`00
o`3ooooo0?ooohl0oooo000<0?ooo`040;md00000000000004RLg`@0oooo00<0gia800000018W=l0
0`3oool01P3ogi`0B000000000000000001809cOool0ooooo`3ooom_0?ooo`002P3oool01`3ooml0
W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`080?oOW0180000
04RL0=ooo`3oool0omnL04P0001d_ooo0?ooool0ooooKP3oool000X0oooo00<0okmd0000B02Lgol0
0P3oool00`3ogi`0B00007Boo`070?ooo`030;md000007@0_ooo00<0oooo00<0gia80018W03Oool0
o`3ooooo0?ooofd0oooo00090?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0
1`3oool00`2oM000001d0;ooo`030?ooo`030;md0000B9`0gooo0?l0ooooo`3ooom]0?ooo`002@3o
ool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo00<0okmd0000B02Lgol00P3o
ool00`3OW4P00000001d_`3o0?ooool0ooooKP3oool000T0oooo00<0omnL04P00018W=l0103oool0
0`2oM000001d0;ooo`070?ooo`070=nLB000M;l0oooo0;md00000000001d0;ooo`0;0?ooool00000
o`00001K000000P0oooo00090?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0203o
ool01@3o_g@0000000000000B9`0gooo00`0oooo1@0000090?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`D00000203oool000T0oooo00<0
omnL04P00018W=l0103oool00`3OW4P0001809cOo`070?ooo`050?oOW0180000000000000018W=l0
3@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00090?ooo`030?oo_`1d
000007Bo00@0oooo00<0_g@00000M02oool01P3oool01`3ogi`0B0000000B02Lgol0oooo0=nLB000
M;l0303oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool01P3oool000X0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`070?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a8001d_ol02`3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1@0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool01P3oool000X0oooo00<0okmd0000B02Lgol00P3o
ool00`3ogi`0B00007Boo`070?ooo`030=nLB000B9`0gooo0080oooo00<0oooO09a80018W=l02`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooE`3oool00`000000oooo0?ooo`060?ooo`002`3oool0
1P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00<0omnL04P00018W=l00P3oool00`3o_g@00018
09cOo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooomG0?ooo`030000003oool0oooo00H0oooo
000<0?ooo`040;md000000000000001d_`X0oooo00H0oono07@00000000000000000B02Lgol<0?oo
o`030000003oool0oooo0?l0ooooo`3ooomG0?ooo`030000003oool0oooo00H0oooo000/0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomG0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000
003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool0
1P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03o
ool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo00<00000
0?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo
0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool002`0
oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000
oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0
o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`<00000o`3ooolL0?ooo`030000003o
ool0oooo0?l0oooo=P3oool3000000P0oooo000/0?ooo`030000003oool0oooo0?l0oooo703oool0
0`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?oo
o`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`060?oo
o`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`03
0000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo
0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3o
oolL0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`060?ooo`00;03oool0
0`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0
oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?oo
ocP0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`03
0000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo
0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo
000/0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<0
00000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0
oooo0?l0oooo>03oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oo
oa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`03
0000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3o
ool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo
>03oool00`000000oooo0?ooo`060?ooo`00;03oool300000?l0oooo703oool00`000000oooo0?oo
o`3o0?ooocH0oooo0`0000080?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo00<00000
0?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo
0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool002`0
oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000
oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0
o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0oooo703o
ool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool002`0oooo00<00000
0?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`06
0?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh0?oo
o`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0oooo703oool00`000000
oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0
o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`060?ooo`00;03o
ool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003o
ool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o
0?ooocP0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL0?oo
o`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000
oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0
oooo000/0?ooo`<00000o`3ooolL0?ooo`030000003oool0oooo0?l0oooo=P3oool3000000P0oooo
000/0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<0
00000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0
oooo0?l0oooo>03oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oo
oa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`03
0000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3o
ool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo
>03oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo00<0
00000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0
oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool0
02`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool00`00
0000oooo0?ooo`060?ooo`006P3oool00`3o_g@000000000000200000003001d_`3oool0oooo00X0
oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000
oooo0?ooo`060?ooo`00703oool00`2oM000001d0;ooo`0=0?ooo`030000003oool0oooo0?l0oooo
703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool001`0oooo00<0
_g@00000M02oool03@3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3o
oolh0?ooo`030000003oool0oooo00H0oooo000L0?ooo`030;md000007@0_ooo00d0oooo00<00000
0?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`06
0?ooo`00703oool00`2oM000001d0;ooo`0=0?ooo`030000003oool0oooo0?l0oooo703oool00`00
0000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool001`0oooo00<0_g@00000M02o
ool03@3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`03
0000003oool0oooo00H0oooo000L0?ooo`030;md000007@0_ooo00d0oooo1@00003o0?oooaX0oooo
00<000000?ooo`3oool0o`3ooold0?ooo`D00000203oool001`0oooo00<0_g@00000M02oool03@3o
ool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003o
ool0oooo00H0oooo000L0?ooo`030;md000007@0_ooo00d0oooo00<000000?ooo`3oool0o`3ooolL
0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`060?ooo`00703oool00`2o
M000001d0;ooo`0=0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?oo
ocP0oooo00<000000?ooo`3oool01P3oool001`0oooo00<0_g@00000M02oool03@3oool00`000000
oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0
oooo000J0?ooo`050=nLB000000000000000M02oool03@3oool00`000000oooo0?ooo`3o0?oooa`0
oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000K0?ooo`040?oo
_`1d0000001d0;ooo`d0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0
oooo>03oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo
00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003o
ool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3o
ool002`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool0
0`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?oo
o`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0
oooo6`3oool200000?l0oooo>P3oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo
0?ooo`3o0?oooaT0oooo1P00003o0?ooocP0oooo00<000000?ooo`3oool01P3oool002`0oooo00<0
00000?ooo`3oool0o`3ooolI0?ooo`H00000o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/
0?ooo`<00000o`3ooolH0?ooo`P00000o`3ooole0?ooo`<00000203oool002`0oooo00<000000?oo
o`3oool0o`3ooolH0?ooo`P00000o`3ooolg0?ooo`030000003oool0oooo00H0oooo000/0?ooo`03
0000003oool0oooo0?l0oooo6@3oool600000?l0oooo>03oool00`000000oooo0?ooo`060?ooo`00
;03oool00`000000oooo0?ooo`3o0?oooaT0oooo1P00003o0?ooocP0oooo00<000000?ooo`3oool0
1P3oool002`0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`800000o`3ooolj0?ooo`030000003o
ool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o
0?ooocP0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL0?oo
o`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000
oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0
oooo000/0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo
00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003o
ool0oooo0?l0oooo>03oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o
0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?oo
o`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?oo
o`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0
oooo>03oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo
00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003o
ool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3o
ool002`0oooo0`00003o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`<00000203oool0
02`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool00`00
0000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3o
ool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0oooo
703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool002`0oooo00<0
00000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?oo
o`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh
0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0oooo703oool00`00
0000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3o
ool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`060?ooo`00
;03oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000
003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?oo
o`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL
0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`060?ooo`00;03oool00`00
0000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo
00H0oooo000/0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0
oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000
003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`060?ooo`00;03oool300000?l0oooo703o
ool00`000000oooo0?ooo`3o0?ooocH0oooo0`0000080?ooo`00;03oool00`000000oooo0?ooo`3o
0?oooa`0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?oo
o`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?oo
o`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0
oooo>03oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo
00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003o
ool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3o
ool002`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool0
0`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?oo
o`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0
oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool000/0oooo
00<0okmd0000000000000P0000002@00M;l0oooo0?ooo`3oool0gia800000018W=l0oooo0=nLB007
0000000307Boo`3oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0
oooo0?l0oooo>03oool00`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`040?oo
o`030=nLB0000000B9cO0080oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`090?oo
o`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?oo
o`3oool01P3oool000d0oooo00<0_g@00000M02oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?oog`2LB7@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0
oooo>03oool00`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`0;0?ooo`030=nL
B018W=l0oooo00h0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo
>03oool00`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`0<0?ooo`030=nLB01d
_ol0oooo00d0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03o
ool00`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`0<0?ooo`030?oog`2LB4P0
W=oo00d0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool0
0`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`0=0?ooo`030?oOW01807@0_ooo
00`0oooo1@00003o0?oooaX0oooo00<000000?ooo`3oool0o`3ooold0?ooo`D00000203oool000d0
oooo00<0_g@00000M02oool03P3oool00`2oM000B9cO0?ooo`0;0?ooo`030000003oool0oooo0?l0
oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool000d0oooo
00<0_g@00000M02oool03P3oool00`3OW4P0001d0;ooo`0;0?ooo`030000003oool0oooo0?l0oooo
703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool000d0oooo00<0
_g@00000M02oool03P3oool00`3o_g@0000007Boo`0;0?ooo`030000003oool0oooo0?l0oooo703o
ool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool000d0oooo00<0_g@0
0000M02oool0203oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo00/0oooo00<00000
0?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`06
0?ooo`002`3oool01@3OW4P000000000000007@0_ooo00T0oooo00P0_g@007Boo`3oool0oooo0=nL
B000000004RL0=ooo`/0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0
oooo>03oool00`000000oooo0?ooo`060?ooo`00303oool0103ookl0M0000000M02oool:0?ooo`05
0;md00000000000000000000M;l03@3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?oo
o`3oool0o`3ooolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0
oooo703oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool01P3oool002`0oooo
00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo
0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3o
oolh0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0oooo703oool0
0`000000oooo0?ooo`3o0?ooobT0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`06
0?ooo`00;03oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolY0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3o
ool0o`3ooolL0?ooo`030000003oool0oooo0?l0oooo:@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo
0?ooo`3o0?ooobT0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00;03o
ool300000?l0oooo703oool00`000000oooo0?ooo`3o0?ooobT0oooo00<000000?ooo`3oool02P3o
ool3000000P0oooo000/0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o
0?ooobT0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00;03oool00`00
0000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`03
0000003oool0oooo0?l0oooo:@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0
oooo000/0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`3o0?ooobT0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?oo
o`3o0?oooa`0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0
oooo0?l0oooo:@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo000/0?oo
o`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?ooool0oooo
B03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3o
ool002`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0
ooooo`3ooom80?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool002`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`060?ooo`00;03oool300000?l0ooooo`3ooom80?ooo`030000003oool0oooo00X0oooo0`00
00080?ooo`00;03oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00
;03oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooooo
0?ooodP0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00;03oool00`00
0000oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00H0oooo000/0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?oo
o`3o0?ooool0ooooB03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo000/
0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?ooool0
ooooB03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo000/0?ooo`<00000
o`3ooooo0?ooodP0oooo00<000000?ooo`3oool02P3oool3000000P0oooo000/0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3o
ool002`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0
ooooo`3ooom80?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool002`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0ooooo`3ooom8
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?oo
o`002`3oool00`3o_g@000000000000200000007001d_`3oool0oooo0?ooo`3OW4P0000004RLg`06
0?ooo`030?noM0000000M;oo00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`040?oo
o`030=nLB0000000B9cO00H0oooo00<0okmd0000001d_ol0303oool00`000000oooo0?ooo`3o0?oo
ool0ooooB03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo000=0?ooo`03
0;md000007@0_ooo00d0oooo00<0okmd0000001d_ol0303oool00`000000oooo0?ooo`3o0?ooool0
ooooB03oool2000000d0oooo00<000000?ooo`3oool01P3oool000d0oooo00<0_g@00000M02oool0
203oool00`3OW4P0000000000005000000030000B02Lgol0oooo00T0oooo00<000000?ooo`3oool0
o`3ooooo0?ooodH0oooo1P00000;0?ooo`030000003oool0oooo00H0oooo000=0?ooo`030;md0000
07@0_ooo00P0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`0<0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom60?ooo`H000002`3oool00`000000oooo0?ooo`060?ooo`003@3oool0
0`2oM000001d0;ooo`090?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@0000007Boo`0<0?ooo`030000
003oool0oooo0?l0ooooo`3ooom50?ooo`P000002P3oool00`000000oooo0?ooo`060?ooo`003@3o
ool00`2oM000001d0;ooo`090?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0000007Boo`0<0?ooo`D0
0000o`3ooooo0?oood<0oooo200000060?ooo`D00000203oool000d0oooo00<0_g@00000M02oool0
2P3oool01P3o_g@007Bo0?ooo`3o_g@0000007Boo``0oooo00<000000?ooo`3oool0o`3ooooo0?oo
odH0oooo1P00000;0?ooo`030000003oool0oooo00H0oooo000=0?ooo`030;md000007@0_ooo00/0
oooo00D0_g@007Boo`3o_g@0000007Boo`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooom60?oo
o`H000002`3oool00`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`0;0?ooo`05
0?oo_`1d07@0_kmd0000001d_ol0303oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool20000
00d0oooo00<000000?ooo`3oool01P3oool000d0oooo00<0_g@00000M02oool0303oool0103o_g@0
00000000001d_ol<0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01P3oool000/0oooo00D0gia8000000000000001d0;ooo`0<0?oo
o`040?oog`2LB000000007Boo``0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00303oool0103ookl0M0000000M02oool=
0?ooo`030?oOW0180000M;oo00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?oo
ool0ooooB03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo000/0?ooo`03
0000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?ooool0ooooB03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0
oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool0
02`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo000/0?ooo`<00000o`3ooooo0?ooodP0oooo
00<000000?ooo`3oool02P3oool3000000P0oooo000/0?ooo`030000003oool0oooo0?l0ooooo`3o
oom80?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool002`0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`06
0?ooo`00;03oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0
o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00;03o
ool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00H0oooo000/0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
odP0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000
oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0
oooo000/0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o
0?ooool0ooooB03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo000/0?oo
o`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01P3oool002`0oooo0`00003o0?ooool0ooooB03oool00`000000oooo0?ooo`0:0?ooo`<0
0000203oool002`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`3o0?ooool0ooooB03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0
oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool0
02`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo
o`3ooolj0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool002`0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`06
0?ooo`00;03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00;03o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00H0oooo000/0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ocX0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00;03oool3000000/0
oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool02P3oool3000000P0
oooo000/0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o
0?ooool0ooooB@3oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0?l0ooooo`3ooom90?ooo`030000003oool0oooo00H0oooo000/0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooo0?ooodT0oooo00<000000?ooo`3o
ool01P3oool002`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooool0oooo
B@3oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom90?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0o`3ooooo0?ooodT0oooo00<000000?ooo`3oool01P3oool0
00/0oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3oool0gia800000018W=l00`3o
ool01P3ooml0W4P0000000000000001d0;ooo``0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`3o0?ooool0ooooB@3oool00`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d
0;ooo`040?ooo`030=nLB0000000B9cO0080oooo00P0oono07@00000B9`0gooo0?ooo`3OW4P00018
09cOo`/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooool0ooooB@3oool0
0`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`090?ooo`030;md000007@0_ooo
00<0oooo00<0_g@0001d_`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0?l0ooooo`3ooom90?ooo`030000003oool0oooo00H0oooo000=0?ooo`030;md000007@0_ooo00P0
oooo00<0oono07@00000M;l0103oool00`3OW4P0001d0;ooo`0:0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0o`3ooooo0?ooodT0oooo00<000000?ooo`3oool01P3oool000d0oooo
00<0_g@00000M02oool0203oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0W=oo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooool0ooooB@3oool00`000000oooo
0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`080?ooo`030?oOW0180000B9cO00<0oooo00@0
oono07@0000007@0_ooo2P3oool5000000T0oooo00<000000?ooo`3oool0o`3ooooo0?ooodD0oooo
1@0000080?ooo`003@3oool00`2oM000001d0;ooo`080?ooo`090?oo_`1d000000000018W03Oool0
oooo0;md00000000B9cO00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooB@3oool00`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`080?ooo`05
0?oog`2LB000001d0;oOW01800000P0000000`18W=l0oooo0?ooo`0:0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0o`3ooooo0?ooodT0oooo00<000000?ooo`3oool01P3oool000d0
oooo00<0_g@00000M02oool02@3oool00`3o_g@0000004RLg`0@0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0o`3ooooo0?ooodT0oooo00<000000?ooo`3oool01P3oool000d0oooo
00<0_g@00000M02oool02@3oool0103ooml0W4P00000B02Lgol?0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0o`3ooooo0?ooodT0oooo00<000000?ooo`3oool01P3oool000d0oooo
00<0_g@00000M02oool02P3oool0103ookl0M0000000M02oool>0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0o`3ooooo0?ooodT0oooo00<000000?ooo`3oool01P3oool000/0oooo
00D0gia8000000000000001d0;ooo`0;0?ooo`040?oog`2LB0000000001d_`d0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`3o0?ooool0ooooB@3oool00`000000oooo0?ooo`060?oo
o`00303oool0103ookl0M0000000M02oool=0?ooo`050?oOW018000000000018W03Oool02P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooom90?ooo`030000003oool0
oooo00H0oooo000/0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooo0?oo
odT0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool02P3oool200000?l0
ooooo`3ooom;0?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo00P0oooo
1P00003o0?ooool0ooooB@3oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?oo
o`080?ooo`H00000o`3ooooo0?ooodT0oooo00<000000?ooo`3oool01P3oool002`0oooo00<00000
0?ooo`3oool01`3oool800000?l0ooooo`3ooom80?ooo`030000003oool0oooo00H0oooo000/0?oo
o`030000003oool0oooo00L0oooo2000003o0?ooool0ooooB03oool00`000000oooo0?ooo`060?oo
o`00;03oool00`000000oooo0?ooo`080?ooo`H00000o`3ooooo0?ooodT0oooo00<000000?ooo`3o
ool01P3oool002`0oooo0`0000080?ooo`H00000o`3ooooo0?ooodL0oooo0`0000080?ooo`00;03o
ool00`000000oooo0?ooo`0:0?ooo`800000o`3ooooo0?oood/0oooo00<000000?ooo`3oool01P3o
ool002`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0
oooo0?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo07l0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo
00H0oooo000/0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0O`3oool00`000000
oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0?l0ooooaP3oool00`000000oooo
0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07l0oooo00<0
00000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<00000
0?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1o0?oo
o`030000003oool0oooo0?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0o`3oooo60?ooo`03
0000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
O`3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool01P3oool002`0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0?l0ooooaP3o
ool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo07l0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`3o0?oo
olH0oooo00<000000?ooo`3oool01P3oool002`0oooo0`00000;0?ooo`030000003oool0oooo07l0
oooo00<000000?ooo`3oool0o`3oooo40?ooo`<00000203oool002`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0?l0ooooaP3oool00`000000oooo
0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07l0oooo00<0
00000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<00000
0?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1o0?oo
o`030000003oool0oooo0?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0o`3oooo60?ooo`03
0000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
O`3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool01P3oool002`0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0?l0ooooaP3o
ool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo07l0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`3o0?oo
olH0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1o0?ooo`030000003oool0oooo0?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`00
;03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0
o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool01P3o
ool002`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0
oooo0?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo07l0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo
00H0oooo000/0?ooo`<000002`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0?l0
ooooa03oool3000000P0oooo000/0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
O`3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool01P3oool002`0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0?l0ooooaP3o
ool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo07l0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`3o0?oo
olH0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1o0?ooo`030000003oool0oooo0?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`00
;03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0?l0ooooaP3oool00`000000oooo
0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0?l0ooooaP3o
ool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`002`3oool00`3o_g@00000000000020000
0007001d_`3oool0oooo0?ooo`3OW4P0000004RLg`030?ooo`060?oOW018000000000000000004P0
W=oo303oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0?l0ooooaP3oool00`000000
oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`040?ooo`030=nLB0000000B9cO0080oooo
00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B00007Boo`/0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool01P3oool000d0oooo00<0_g@00000
M02oool02@3oool00`2oM000001d0;ooo`030?ooo`030=nLB000B9`0gooo00X0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool01P3oool000d0
oooo00<0_g@00000M02oool02@3oool00`2oM000001d0;ooo`030?ooo`030;md0000B9`0gooo00X0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3o
ool01P3oool000d0oooo00<0_g@00000M02oool02@3oool00`3o_g@0001809cOo`020?ooo`030=nL
B000000007Bo00/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?ooolH0oooo
00<000000?ooo`3oool01P3oool000d0oooo00<0_g@00000M02oool02P3oool01`3OW4P007Bo0?oo
o`2oM00000000000M02oool02`3oool5000008/0oooo00<000000?ooo`3oool0o`3oooo20?ooo`D0
0000203oool000d0oooo00<0_g@00000M02oool02`3oool01@3o_g@0000000000000B9`0gooo00`0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3o
ool01P3oool000d0oooo00<0_g@00000M02oool02P3oool01@3ogi`0B000000000000000B9cO00d0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3o
ool01P3oool000d0oooo00<0_g@00000M02oool02@3oool01`3ogi`0B0000000B02Lgol0oooo0=nL
B000M;l0303oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0?l0ooooaP3oool00`00
0000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`090?ooo`030=nLB00004P0W=oo0080
oooo00<0oooO09a8001d_ol02`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0?l0
ooooaP3oool00`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`090?ooo`030=nL
B000B9`0gooo0080oooo00<0oooO09a80018W=l02`3oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo0?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`002`3oool01@3OW4P000000000
000007@0_ooo00T0oooo00<0omnL04P00018W=l00P3oool00`3o_g@0001809cOo`0;0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo
000<0?ooo`040?oo_`1d0000001d0;ooo`X0oooo00H0oono07@00000000000000000B02Lgol<0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo
00H0oooo000/0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`03
0000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?oo
o`030000003oool0oooo08`0oooo0P00003o0?ooolP0oooo00<000000?ooo`3oool01P3oool002`0
oooo00<000000?ooo`3oool0RP3oool600000?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`00
;03oool00`000000oooo0?ooo`2:0?ooo`H00000o`3oooo60?ooo`030000003oool0oooo00H0oooo
000/0?ooo`<00000R@3oool800000?l0oooo``3oool3000000P0oooo000/0?ooo`030000003oool0
oooo08T0oooo2000003o0?ooolD0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?oo
o`3oool0RP3oool600000?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000
oooo0?ooo`2:0?ooo`H00000o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000
003oool0oooo08`0oooo0P00003o0?ooolP0oooo00<000000?ooo`3oool01P3oool002`0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool01P3o
ool002`0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<00000
0?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?oo
olH0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool01P3oool002`0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool01P3o
ool002`0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<00000
0?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?oo
olH0oooo00<000000?ooo`3oool01P3oool002`0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool01P3oool002`0oooo0`00002=0?ooo`030000
003oool0oooo0?l0ooooa03oool3000000P0oooo000/0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo
00H0oooo000/0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`03
0000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo
00H0oooo000/0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`03
0000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo
00H0oooo000/0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`03
0000003oool0oooo00H0oooo000/0?ooo`<00000S@3oool00`000000oooo0?ooo`3o0?oool@0oooo
0`0000080?ooo`00;03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0?l0ooooaP3o
ool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo0?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`00;03oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo0?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`00
;03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0?l0ooooaP3oool00`000000oooo
0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0?l0ooooaP3o
ool00`000000oooo0?ooo`060?ooo`00;03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`00603oool00`3OW4P00000000000050000
000307Boo`3oool0oooo00T0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?oo
olH0oooo00<000000?ooo`3oool01P3oool001T0oooo00<0gia8000000000000100000000`00M;l0
oooo0?ooo`090?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`03
0000003oool0oooo00H0oooo000J0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool0
2P3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0?l0ooooaP3oool00`000000oooo
0?ooo`060?ooo`006`3oool00`3OW4P0B9cO0?ooo`0>0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000L0?ooo`030=nLB01d_ol0
oooo00d0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<00000
0?ooo`3oool01P3oool001`0oooo00<0oooO09a8B02Lgol03@3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo0?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`007@3oool00`3ogi`0
B01d0;ooo`0<0?ooo`D00000R`3oool00`000000oooo0?ooo`3o0?oool80oooo1@0000080?ooo`00
7P3oool00`2oM000B9cO0?ooo`0;0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
o`3oooo60?ooo`030000003oool0oooo00H0oooo000N0?ooo`030=nLB00007@0_ooo00/0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool01P3o
ool001h0oooo00<0okmd0000001d_ol02`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0?l0ooooaP3oool00`000000oooo0?ooo`060?ooo`00603oool00`3ogi`0W;oo0?ooo`030?oo
o`030;md00000000M;oo00/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?oo
olH0oooo00<000000?ooo`3oool01P3oool001T0oooo00P0_g@007Boo`3oool0oooo0=nLB0000000
04RL0=ooo`/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<0
00000?ooo`3oool01P3oool001X0oooo00D0_g@00000000000000000001d_`0=0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0
oooo00H0oooo000/0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?oo
o`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?ooo`030000003oool0
oooo00H0oooo000/0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o`3oooo60?oo
o`030000003oool0oooo00H0oooo000/0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0o`3oooo60?ooo`030000003oool0oooo00H0oooo000/0?ooo`<00000o`3ooooo0?oooeD0oooo
0`0000080?ooo`00;03oool00`000000oooo0?ooo`3o0?ooool0ooooE`3oool00`000000oooo0?oo
o`060?ooo`00;03oool00`000000oooo0?ooo`3o0?ooool0ooooE`3oool00`000000oooo0?ooo`06
0?ooo`00;03oool00`000000oooo0?ooo`3o0?ooool0ooooE`3oool00`000000oooo0?ooo`060?oo
o`00;03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool01P3oool002`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`00;03o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo000/0?ooool00000o`00001K
000000P0oooo0000\
\>"],
  ImageRangeCache->{{{0, 652.25}, {402.75, 0}} -> {0.34574, 0.685489, \
0.00607991, 0.00345535}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ 
        Use\ Maximum\ Likelihood\ Method\ to\ find\ best\ fit\ straight\ \
lines\ going\ through\ the\ four\ datapoints\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    \(\(a1p[a1a1_, b1a1_, x_] := a1a1 + b1a1\ x;\)\)], "Input"],

Cell[BoxData[
    \(\(chi2a1[a1a1_, b1a1_] := 
        Sum[\((\((a1pl[\([i, 2]\)] - 
                    a1p[a1a1, b1a1, a1pl[\([i, 1]\)]])\)/\((a1pl[\([i, 
                      3]\)])\))\)^2, {i, 1, Length[a1pl]}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(par = {a1a1, b1a1};\)\), "\n", 
    \(\(akla1[a1a1_, b1a1_, k_, l_] := 
        1/2  D[D[chi2a1[a1a1, b1a1], par[\([k]\)]], 
            par[\([l]\)]\ ];\)\), "\n", 
    \(\(fmina1 = 
        FindMinimum[
          chi2a1\ [a1a1, b1a1], {a1a1, 1}, {b1a1, \(-10\)}];\)\), "\n", 
    \(\(a1a1o = fmina1[\([2, 1, 2]\)];\)\), "\n", 
    \(\(b1a1o = fmina1[\([2, 2, 2]\)];\)\), "\n", 
    \(akloa1 = 
      Table[If[k \[LessSlantEqual] 
            l, \(akla1[a1a1, b1a1, k, l] /. a1a1 \[Rule] a1a1o\) /. 
            b1a1 \[Rule] b1a1o, \(akla1[a1a1, b1a1, l, k] /. 
              a1a1 \[Rule] a1a1o\) /. b1a1 \[Rule] b1a1o], {k, 1, 2}, {l, 1, 
          2}]; cij = Inverse[akloa1]; 
    spara1 = Table[Sqrt[cij[\([i, i]\)]], {i, 1, 2}]; 
    Print["\<a1a1= \>", a1a1o, "\<+-\>", spara1[\([1]\)], "\<  b1a1= \>", 
      b1a1o, "\<+-\>", spara1[\([2]\)]]; 
    cij // MatrixForm\), "\[IndentingNewLine]", 
    \(chi2ra1 = Part[fmina1, 1]/\((Length[a1pl])\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("a1a1= "\[InvisibleSpace]50.559526317742105`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.060998615476489194`\[InvisibleSpace]" \
 b1a1= "\[InvisibleSpace]\(-0.001197453835146689`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.030408532062753183`\),
      SequenceForm[ 
      "a1a1= ", 50.559526317742105, "+-", .060998615476489194, 
        "  b1a1= ", -.001197453835146689, "+-", .030408532062753183],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.003720831090048587`", \(-0.0015345580108329575`\)},
            {\(-0.0015345580108329575`\), "0.0009246788222114884`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    \(0.29678306681204236`\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(a1pr = a1a1o + \ b1a1o\ z;\)\), "\[IndentingNewLine]", 
    \(\(a1prpl = 
        Plot[a1pr, {z, 0, 5}, 
          DisplayFunction \[Rule] Identity];\)\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ 
        Construct\ plot\ of\ best\ fit\ straight\ lines\ along\ with\ \
\(\(data\)\(.\)\)\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fb1 = 
      Show[a1prpl, a1dtpl, 
        Graphics[{Text[\*"\"\<1:\!\(E\_peak\)-\!\(E\_\(\(\[Gamma]\)\(\\\ \\\ \
\\\ \)\)\)Correlation Coefficient: r=0.3\>\"", {1.9, 50.45}]}], 
        Frame \[Rule] True, Axes \[Rule] False, 
        DisplayFunction \[Rule] $DisplayFunction, PlotRange \[Rule] All, 
        FrameLabel \[Rule] {"\<<z>\>", \*"\"\<\!\(b\_1\)\>\""}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 -99.6904 1.97801 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -7.03125 -24.5625 ]
[.21429 -0.0125 7.03125 0 ]
[.40476 -0.0125 -7.03125 -24.5625 ]
[.40476 -0.0125 7.03125 0 ]
[.59524 -0.0125 -7.03125 -24.5625 ]
[.59524 -0.0125 7.03125 0 ]
[.78571 -0.0125 -7.03125 -24.5625 ]
[.78571 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.375 -49.125 ]
[.5 -0.0125 19.375 -24.5625 ]
[-0.0125 .00135 -39.1875 -12.2813 ]
[-0.0125 .00135 0 12.2813 ]
[-0.0125 .10025 -49.25 -12.2813 ]
[-0.0125 .10025 0 12.2813 ]
[-0.0125 .19915 -39.1875 -12.2813 ]
[-0.0125 .19915 0 12.2813 ]
[-0.0125 .29805 -49.25 -12.2813 ]
[-0.0125 .29805 0 12.2813 ]
[-0.0125 .39695 -39.1875 -12.2813 ]
[-0.0125 .39695 0 12.2813 ]
[-0.0125 .49585 -49.25 -12.2813 ]
[-0.0125 .49585 0 12.2813 ]
[-0.0125 .59475 -39.1875 -12.2813 ]
[-0.0125 .59475 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -73.8125 -10.8125 ]
[-0.01875 .30902 -49.25 10.8125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.38571 .10025 -170.688 -13.0938 ]
[.38571 .10025 170.688 13.0938 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.375 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
75.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
84.813 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
97.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00135 m
.00625 .00135 L
s
gsave
-0.0125 .00135 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.4) show
1.000 setlinewidth
grestore
0 .10025 m
.00625 .10025 L
s
gsave
-0.0125 .10025 -110.25 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.45) show
1.000 setlinewidth
grestore
0 .19915 m
.00625 .19915 L
s
gsave
-0.0125 .19915 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.5) show
1.000 setlinewidth
grestore
0 .29805 m
.00625 .29805 L
s
gsave
-0.0125 .29805 -110.25 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.55) show
1.000 setlinewidth
grestore
0 .39695 m
.00625 .39695 L
s
gsave
-0.0125 .39695 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.6) show
1.000 setlinewidth
grestore
0 .49585 m
.00625 .49585 L
s
gsave
-0.0125 .49585 -110.25 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.65) show
1.000 setlinewidth
grestore
0 .59475 m
.00625 .59475 L
s
gsave
-0.0125 .59475 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.7) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02113 m
.00375 .02113 L
s
0 .04091 m
.00375 .04091 L
s
0 .06069 m
.00375 .06069 L
s
0 .08047 m
.00375 .08047 L
s
0 .12003 m
.00375 .12003 L
s
0 .13981 m
.00375 .13981 L
s
0 .15959 m
.00375 .15959 L
s
0 .17937 m
.00375 .17937 L
s
0 .21893 m
.00375 .21893 L
s
0 .23871 m
.00375 .23871 L
s
0 .25849 m
.00375 .25849 L
s
0 .27827 m
.00375 .27827 L
s
0 .31783 m
.00375 .31783 L
s
0 .33761 m
.00375 .33761 L
s
0 .35739 m
.00375 .35739 L
s
0 .37717 m
.00375 .37717 L
s
0 .41673 m
.00375 .41673 L
s
0 .43651 m
.00375 .43651 L
s
0 .45629 m
.00375 .45629 L
s
0 .47607 m
.00375 .47607 L
s
0 .51563 m
.00375 .51563 L
s
0 .53541 m
.00375 .53541 L
s
0 .55519 m
.00375 .55519 L
s
0 .57497 m
.00375 .57497 L
s
0 .61453 m
.00375 .61453 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -133.344 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.8125 16.2813 translate
90 rotate
-71.8125 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00135 m
1 .00135 L
s
.99375 .10025 m
1 .10025 L
s
.99375 .19915 m
1 .19915 L
s
.99375 .29805 m
1 .29805 L
s
.99375 .39695 m
1 .39695 L
s
.99375 .49585 m
1 .49585 L
s
.99375 .59475 m
1 .59475 L
s
.125 Mabswid
.99625 .02113 m
1 .02113 L
s
.99625 .04091 m
1 .04091 L
s
.99625 .06069 m
1 .06069 L
s
.99625 .08047 m
1 .08047 L
s
.99625 .12003 m
1 .12003 L
s
.99625 .13981 m
1 .13981 L
s
.99625 .15959 m
1 .15959 L
s
.99625 .17937 m
1 .17937 L
s
.99625 .21893 m
1 .21893 L
s
.99625 .23871 m
1 .23871 L
s
.99625 .25849 m
1 .25849 L
s
.99625 .27827 m
1 .27827 L
s
.99625 .31783 m
1 .31783 L
s
.99625 .33761 m
1 .33761 L
s
.99625 .35739 m
1 .35739 L
s
.99625 .37717 m
1 .37717 L
s
.99625 .41673 m
1 .41673 L
s
.99625 .43651 m
1 .43651 L
s
.99625 .45629 m
1 .45629 L
s
.99625 .47607 m
1 .47607 L
s
.99625 .51563 m
1 .51563 L
s
.99625 .53541 m
1 .53541 L
s
.99625 .55519 m
1 .55519 L
s
.99625 .57497 m
1 .57497 L
s
.99625 .61453 m
1 .61453 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .31689 m
.06244 .31641 L
.10458 .31589 L
.14415 .3154 L
.18221 .31492 L
.22272 .31442 L
.26171 .31394 L
.30316 .31342 L
.34309 .31292 L
.3815 .31245 L
.42237 .31194 L
.46172 .31145 L
.49955 .31098 L
.53984 .31048 L
.57861 .31 L
.61984 .30948 L
.65954 .30899 L
.69774 .30851 L
.73838 .30801 L
.77751 .30752 L
.81909 .30701 L
.85916 .30651 L
.89771 .30603 L
.93871 .30552 L
.97619 .30505 L
s
.002 w
.15771 .18449 m
.15771 .39298 L
s
.015 w
.15771 .28873 Mdot
.002 w
.30762 .16255 m
.30762 .43053 L
s
.015 w
.30762 .29654 Mdot
.002 w
.47238 .29888 m
.47238 .60332 L
s
.015 w
.47238 .4511 Mdot
.002 w
.81924 .01472 m
.81924 .40102 L
s
.015 w
.81924 .20787 Mdot
gsave
.38571 .10025 -231.688 -17.0938 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
73.063 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
78.563 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
90.813 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(peak) show
117.938 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
130.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
143.125 26.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
159.063 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Correlation) show
255.188 23.000 moveto
(Coefficient) show
345.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
355.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
362.313 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
375.250 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
400.375 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{609.188, 376.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009Q0001N2000`400?l00000o`00003oo`3ooooo
0?ooof<0oooo003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo
003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo003o0?oooe<0
oooo00@0okmd001d_`3oool0_g@01P0000001@18W=l0oooo0?ooo`2oM4P0W=oo0?l0oooo0@3oool0
0?l0ooooD@3oool0203o_g@000000000M02oool0oooo0?oo_`1d000007Bo0`3oool0203ogi`0M9cO
0?ooo`3oool0omnL04P0000004P0W=oooP3oool00?l0ooooC`3oool0103o_g@000000000B02Lgol4
0?ooo`030?oOW0180000M;oo0080oooo00<0oooO0;nog`3oool00`3oool0103ogi`0B0000000B02L
gool0?ooo`00o`3ooom=0?ooo`040?oOW0180000001809cOo`L0oooo00<0gia80000B02Lgol02@3o
ool0103o_g@000000000B02Lgooj0?ooo`00o`3ooom;0?ooo`040?oOW0180000001809cOo`T0oooo
00@0oooO09a80000B9`0gooo2P3oool0103o_g@000000000M02ooooh0?ooo`00o`3ooom:0?ooo`03
0;md000004P0W=oo00`0oooo00<0oono07@00000M;l0303oool00`3o_g@0000004RLg`3g0?ooo`00
o`3ooom;0?ooo`040?oOW0180000001809cOo`L0oooo00L0omnL09boo`3oool0oooo0?noM0000000
M;oo00T0oooo00@0okmd0000000007@0_ooon03oool00?l0ooooC@3oool0103ogi`0B0000000B02L
gol50?ooo`030?oo_`2LW=l0oooo0080oooo00<0_g@00000M02oool01P3oool0103o_g@000000000
B02Lgooj0?ooo`00o`3ooom?0?ooo`040?noM0000000001809cOo`<0oooo00<0oono07@000000000
100000000`00B9`0gooo0?ooo`020?ooo`040?oOW0180000001809cOoo`0oooo003o0?oooe40oooo
00@0okmd0000000007@0_ooo2`3oool0103ogi`0B0000000B02Lgoon0?ooo`00o`3ooomC0?ooo`03
0?noM000M;l0oooo00X0oooo00<0_gA809cOo`3oool0o`3oool00?l0ooooo`3ooomS0?ooo`00o`3o
oooo0?ooof<0oooo003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0
oooo003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo003o0?oo
ool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo003o0?ooool0ooooH`3o
ool00?l0ooooo`3ooomS0?ooo`00H@3oool0102oM000000000000018W=mM0?ooo`030?noM0000000
00000080000000<007Bo0?ooo`3oool0F@3oool00`3OW4P00000000000050000000307Boo`3oool0
oooo05P0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`1O0?ooo`030?noM0000000
M;oo05`0oooo00H0_g@000000000000000000018W03Oool?0?ooo`00G`3oool01`3ooml0W4P0001d
_`3oool0oooO09a80000M;l0GP3oool00`2oM000001d0;ooo`1M0?ooo`030=nLB0000000000000@0
000000<007Bo0?ooo`3oool0F03oool0203ogi`0B0000018W03Oool0oooo0?oOW01804P0W=ooG`3o
ool00`3o_g@0000007Boo`1K0?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool03P3o
ool005l0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`1M0?ooo`030;md000007@0
_ooo05h0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`1O0?ooo`030?noM000B9`0
gooo05h0oooo00<0okmd0000001d_ol0H@3oool00`3ogi`0B7Bo0?ooo`0=0?ooo`00GP3oool0103o
oml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo05d0oooo00<0_g@00000M02oool0G`3oool0
0`3OW4P0B9cO0?ooo`1S0?ooo`030?noM00004P0W=oo05T0oooo00<0gia80000000000001@000000
0`0004P0W=oo0?ooo`1N0?ooo`030?oo_`1d04P0W=oo00d0oooo001N0?ooo`030?oo_`1d000007Bo
00@0oooo00<0_g@00000M02oool0G03oool00`2oM000001d0;ooo`1P0?ooo`030=nLB01d_ol0oooo
0680oooo00<0_g@00000B02Lgol0F@3oool00`3ogi`0B7Bo0?ooo`020?ooo`030?noM0000000M;oo
0640oooo00<0oono07@0001d_ol03@3oool005h0oooo00<0omnL04P00018W=l0103oool00`2oM000
001d0;ooo`1L0?ooo`030;md000007@0_ooo0600oooo00<0oooO09a8B02Lgol0H@3oool0102oM000
00000000M02ooomJ0?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@0000007Boo`1Q0?ooo`030?noM000
0000M;oo00d0oooo001N0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0G03oool0
0`2oM000001d0;ooo`1Q0?ooo`030?oOW01807@0_ooo05d0oooo00<0oono07@0000000000P000000
0`18W=l0oooo0?ooo`1I0?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0000007Boo`1P0?ooo`040?oO
W0180000001d0;ooo`d0oooo001N0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
G03oool00`2oM000001d0;ooo`1R0?ooo`030;md0018W=l0oooo05h0oooo00<0okmd0000B02Lgol0
G@3oool01P3o_g@007Bo0?ooo`3o_g@0000007Booe`0oooo00@0gmoO0?ooo`3oool0_g@00P000000
0`18W=l0oooo0?ooo`0<0?ooo`00GP3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo
05`0oooo00<0_g@00000M02oool0HP3oool00`3OW4P0001d0;ooo`1O0?ooo`030?oOW018M;l0oooo
05d0oooo00D0_g@007Boo`3o_g@0000007Boo`1L0?ooo`030?noM000000000000080000000<007Bo
0?ooo`3oool03@3oool005l0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`1M0?oo
o`030;md000007@0_ooo0680oooo00<0okmd0000001d_ol0G`3oool00`3ooml0W4P004RLg`1M0?oo
o`050?oo_`1d07@0_kmd0000001d_ol0G03oool01@3ooml0W4P00000000007@0_ooo0100oooo001O
0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0G@3oool00`2oM000001d0;ooo`1L
0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0FP3oool00`3ooml0W7BL0=ooo`02
0?ooo`030?oog`2LB00007Bo05h0oooo00@0okmd000000000000M;ooG@3oool00`3o_g@007Bo0?oo
o`0A0?ooo`00H03oool01P2oM00004RL0=ooo`3oool0_g@0001d_e`0oooo00D0gia8000000000000
001d0;ooo`1M0?ooo`080;md001d_ol0oooo0?ooo`3OW4P000000018W03OoomK0?ooo`070?oOW018
B9`0gooo0?ooo`3OW4P0000007Boo`1N0?ooo`040?oog`2LB000000007Booed0oooo00<0oooO09a8
000000000P0000000`0007@0_ooo0?ooo`0<0?ooo`00H@3oool0102oM000000000000000M;mN0?oo
o`040?oo_`1d0000001d0;oooeh0oooo00D0_g@00000000000000000001d_`1N0?ooo`050?oOW018
0000000000000018W=l0H03oool00`3ogi`0B00007Boo`1N0?ooo`030?noM0000000000000800000
00<0M;oo0?ooo`3oool02`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo003o0?oo
ool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo003o0?ooool0ooooH`3o
ool00?l0ooooo`3ooomS0?ooo`00;03oool01P2oM000000000000000000004RL0=ooo`H0oooo00@0
_g@0000000000000B9cO103oool00`3OW4P0000004RLg`060?ooo`030?noM0000000M;oo0?l0oooo
o`3ooolG0?ooo`00:`3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00<0oooo00L0
oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l01P3oool00`3o_g@0
000007Boo`3o0?ooool0oooo5`3oool00340oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@00018
09cOo`020?ooo`030?oOW0180000M;oo00/0oooo00<0okmd0000001d_ol0o`3ooooo0?oooaL0oooo
000a0?ooo`080?oo_`1d04P0W=oo0?ooo`3ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo
00H0oooo00<0gia80000000000001@0000000`0004P0W=oo0?ooo`3o0?ooool0oooo503oool00340
oooo00L0oono07@0001d_ol0oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01@3oool0
0`3ogi`0B7Bo0?ooo`020?ooo`030?noM0000000M;oo0?l0ooooo`3ooolG0?ooo`00<@3oool01`3o
_g@0000007Boo`3oool0omnL04P00018W=l0103oool00`2oM000001d0;ooo`060?ooo`070=nLB01d
_ol0oooo0?ooo`3o_g@0000007Boo`0;0?ooool00000o`000008000000@0oooo000`0?ooo`080?oO
W0180000001d0;ooo`3oool0omnL04P00018W=l40?ooo`030=nLB00004P0W=oo00H0oooo00L0oono
07@0M02oool0oooo0?noM0000000M;oo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool002`0oooo00@0
gmoO0?ooo`3oool0_g@00P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia80000
B02Lgol01`3oool01P3o_g@007Bo0?ooo`3o_g@0000007Boo`/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3o
ool002`0oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3oool0oono07@00000M;l0
103oool00`2oM000001d0;ooo`080?ooo`050;md001d_ol0okmd0000001d_ol02`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0G`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0080oooo000/0?ooo`050?oog`2LB00000000000M02o
ool01@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00T0oooo00D0oono07@0M02o
_g@0000007Boo`0;0?ooo`030000003oool0oooo0?l0ooooo`3oool40?ooo`030000003oool0oooo
0080oooo000]0?ooo`030?noM000M;l0oooo00H0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0
B00007Boo`0:0?ooo`040?noM0000000000007Boo`/0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`@0oooo00<000000?ooo`3oool00P3oool002d0oooo00<0oooO09a8000000000P0000000`0007@0
_ooo0?ooo`020?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo2`3oool0103ooml0W4P00000001d
_ol;0?ooo`030000003oool0oooo0?l0ooooo`3oool40?ooo`030000003oool0oooo0080oooo000^
0?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool00P3oool0102oM000000000000000
M;l=0?ooo`030?oOW0180000M;oo00/0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0o`3ooonU
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?oo
o`3oool0o`3ooonU0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0
oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool00P3oool005L0oooo0`00003o0?ooojD0oooo00<000000?ooo`3oool0F@3oool3000000@0oooo
001G0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`1K0?ooo`030000003o
ool0oooo0080oooo001G0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?l0ooooY@3oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?l0
ooooY@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000
003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo
001G0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`1K0?ooo`030000003o
ool0oooo0080oooo001G0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?l0ooooY@3oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?l0
ooooY@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`<00000
o`3ooonU0?ooo`030000003oool0oooo05T0oooo0`0000040?ooo`00E`3oool00`000000oooo0?oo
o`3o0?ooojD0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool0
0`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`02
0?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooojD0oooo
00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?oo
o`3o0?ooojD0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool0
0`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`02
0?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool300000?l0ooooY@3oool00`000000oooo
0?ooo`1I0?ooo`<00000103oool005L0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0o`3ooonU
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?oo
o`3oool0o`3ooonU0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0
oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool00P3oool005L0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0o`3ooonU
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?oo
o`3oool0o`3ooonU0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0
oooo00<000000?ooo`3oool0=P3oool01@3ooml0W4P00000000004P0W=oo0380oooo00<0okmd001d
_`3oool0o`3ooole0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0
oooo0`00000g0?ooo`030?oo_`1d04P0W=oo03<0oooo00<0oono07@0B02Lgol0o`3ooole0?ooo`03
0000003oool0oooo05T0oooo0`0000040?ooo`00E`3oool00`000000oooo0?ooo`0g0?ooo`030?oo
_`1d04P0W=oo03@0oooo00<0gia804RLg`3oool0o`3ooold0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0=`3oool01P3ookl0M0000000
00000000001809cOo`80oooo01<0okmd000000000000B9cO0?ooo`3ookl0M0000000000004P0B4P0
0000B018B00000000000B02Lgml0W4P000000000B9`0gooo01`0oooo00<0oooO09adW03Oool0o`3o
oold0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<00000
0?ooo`3oool0=`3oool06@3ookl0M00004RLg`3oool0okmd0000M02oool0omnL04P0001d_ol0oooo
0=nLM02Lgol0gia80018W03Oool0oono07@0B02Lgol0oooO09a8001d_ol0oono07@0001d_ol07P3o
ool00`3ooml0W4P007Boo`3o0?oooc@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`020?ooo`00E`3oool00`000000oooo0?ooo`0g0?ooo`090?oo_`1d04P0W=oo0?ooo`3ooml0W4P0
07Boo`3OW4P007Bo0080oooo00d0oono07Ad_`3ookl0M000001d_`3ookl0M01809cOo`3ooml0W4P0
07Boo`2oM00007Bo01l0oooo00@0oooO09a8M01dM7@0_oooo`3ooolc0?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool00P3oool00280oooo00H0_g@000000000000000000018W03Oool6
0?ooo`040;md00000000000004RLg`@0oooo00<0gia800000018W=l01P3oool00`3o_g@0000007Bo
o`030?ooo`060;md00000000000000000000B9`0gooo303oool00`000000oooo0?ooo`0g0?ooo`09
0?oo_`1d04P0W=oo0?ooo`3ooml0W4P004RLg`3OW4P0B9cO00H0oooo00T0okmd0000000004P0W=oo
0?oog`2LB00000000000M02oool07`3oool0103ooml0W4Qd0;oOW01dW=oo0?oooc<0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`008@3oool00`3ooml0W4P004RLg`020?oo
o`030?oOW018B9`0gooo00<0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0
gia800000018W=l01P3oool00`3o_g@0000007Boo`020?ooo`030?oog`2LB000B9cO0080oooo00<0
omnL04Q8W03Oool02`3oool00`000000oooo0?ooo`0M0?ooo`030?noM000000000000080000000<0
07Bo0?ooo`3oool00P3oool01@3ooml0W4P00000B02Lgml0W4P000T0000000X007Bo0?ooo`3ookl0
M01809cOo`3oool0oooO09a80018W=l0gia8100000003000M;l0oooo0?ooo`3oool0oono07@0B02L
gol0oooO09a8001d_ml0W4P007Boo`l0oooo00<0oooO09a800000000200000000`00M;l0oooo0?oo
o`020?ooo`050?oo_`1d07@0_ooO09a8B02Lgol03@3oool00`2oM000000000000002000000030000
M02oool0oooo00<0oooo00H0omnL04P00000000000000000M02oool20?ooo`050=nLB00000000000
00000000M;l00P3oool01@3OW4P0000000000000000007Bo00@0oooo00D0omnL04P0000000000000
001d_`020?ooo`080?oo_`1d000000000000000004P0W=oo0?ooo`2oM0020000000<0000B02Lgkl0
M00000000000M;l0oooo0?oo_`1d000000000018W03Ookl0M0000P0000001P0004P0W=oo0?ooo`3o
ool0omnL04P00080000000D0001d0;ooo`3oool0oooo0;md00030000000607Bo_`1d000000000000
000007@0_ooo203oool00`2oM000000000000002000000030000M02oool0oooo00<0oooo00H0omnL
04P00000000000000000M02oool40?ooo`050?oOW0180000000000000000M;l00P3oool00`3o_g@0
000000000002000000030018W03O_g@0000000<0000000<004RL0=oo_`1d00000P0000001@0004P0
W=oo0?ooo`3oool0okmd00<0000000D004RL0=ooo`3oool0oono07@00002000000060000B02Lgol0
oooo0?ooo`3ogi`0B0000P0000001000M;l0oooo0?ooo`2oM0030000000;07Bo_`1d000000000000
000007@0_ooo0?oo_`1d000000000018W03Oool00P3oool0103ooml0W4P00000B02Lgol50?ooo`05
0=nLB0000000000000000000M;l04P3oool0102oM000000000000018W=l40?ooo`060=nLB0000000
B9cO0?ooo`3ooml0W4P00`0000000`00B9`0gooo0?ooo`0i0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool00P3oool002L0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo00/0oooo00<0okmd0000001d_ol0203oool00`3ogi`0B7Bo0?oo
o`0:0?ooo`030000003oool0oooo01l0oooo00<0_g@00000M02oool01@3oool02@3ooml0W4P00000
B02Lgol0oooo0?oo_`1d000004RL0=ooo`040?ooo`0L0?noM00007@0_ono07@000000000001d0;oo
o`3o_g@0001809cOo`3ookl0M4RL0=ooo`3ooml0W4P007Boo`3ogi`0B01d0;ooo`3ogi`0B01809cO
o`3ooml0W4P007Boo`3oool0_gA809cOoa00oooo00@0oono07@00000B9`0gooo103oool02`3o_g@0
001d0;ooo`3ookl0M4RL0=ooo`3o_g@007Bo0?ooo`3o_g@007Bo00/0oooo00@0okmd000000000000
M;oo0`3oool00`3ookl0M00007Boo`020?ooo`080?noM000000004RL0=ooo`3oool0okmd0000B02L
gol20?ooo`030?noM0000000M;oo00@0oooo00<0okmd0000001d_ol0103oool08@3o_g@000000000
B02Lgol0oooo0=nLB000B9`0gooo0?ooo`3ooml0W4P00018W03Oool0oooo0?noM000000007Bo0?oo
o`3ooml0W4P000000018W=l0okno0;ooo`3OW4P0001809cOo`3ogi`0W;oo0?ooo`2oM000001d0;oo
o`020?ooo`080?noM000000004RL0=ooo`3oool0okmd0000B02Lgol20?ooo`080=nLB00004P0W=oo
0?ooo`3ooml0W4P00018W03Oool70?ooo`040?noM0000000000007Boo`<0oooo00<0oono07@0001d
_ol00P3oool0203o_g@000000018W03Oool0oooo0?noM00004P0W=oo0P3oool03@3o_g@000000000
B02Lgol0oooo0=nLB000B9`0gooo0?ooo`3ooml0W4P00000M02oool00P3oool0103ooml0W4P00000
M02oool30?ooo`030;md000007@0_ooo0080oooo00<0gia80000000000000`0000001`00B9`0gooo
0?ooo`3oool0_g@00000M02oool00P3oool05`3o_g@000000000B02Lgol0oooo0=nLB000B9`0gooo
0?ooo`3OW4P0001809cOo`3oool0oooO09a80000B9`0gooo0?ooo`3OW4P0001809cOo`3ogi`0W;oo
0080oooo00@0oooO09a8000004P0W=oo1P3oool00`3o_g@0000007Boo`0A0?ooo`070?oog`2LB000
07Bo0?ooo`3ooml0W4P0001d_`030?ooo`0<0=nLB0000000B9cO0?ooo`3ogi`0B0000018W03Oool0
oooo0?oOW01804P0W=oo>@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo
000W0?ooo`080?oo_`1d04P0W=oo0?ooo`3ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo
00H0oooo00<0gia80000000000001@0000000`0004P0W=oo0?ooo`050?ooo`030?oo_`1d04P0W=oo
00X0oooo00<000000?ooo`3oool07`3oool00`2oM000001d0;ooo`0:0?ooo`040?oo_`1d000004RL
0=ooo`D0oooo00P0okmd04RLg`3ookl0M01809cO_`1d0000000004RLg`80oooo00@0omnL04P00000
000007Bo0P3oool03@2oM000000000000000B9`0gooo0?oog`2LB000M;oo0?oo_`1d000000000018
W03Oool03P3oool0103ookl0M0000018W03Oool50?ooo`0;0?noM018W=l0oooo0?oOW01800000018
09cOo`3oool0oono07@0M02oool02@3oool0103ogi`0B0000000B02Lgol60?ooo`060;mdB02Lgol0
oooO09a8000004P0W=oo0`3oool01`2oM00004RL0=ooo`3oool0okmd0000001d_ol0103oool00`3o
_g@0000007Boo`030?ooo`040?oo_`1d000004RL0=ooo`<0oooo00/0okmd07Boo`3oool0oooO09a8
0000B9`0gooo0?ooo`3o_g@0000007Boo`020?ooo`030?oOW0180000B9cO0080oooo00<0gia80000
B02Lgol00`3oool0202oM00004RL0=ooo`3oool0oooO09a8000004P0W=oo0`3oool0302oM00004RL
0=ooo`3oool0gia80000B02Lgol0oooo0?oog`2LB00004RL0=ooo`H0oooo00@0omnL04P0000004P0
W=oo1P3oool01P2oM4P0W=oo0?oog`2LB000001809cOo`<0oooo00L0_g@00018W03Oool0oono07@0
0000B9`0gooo00<0oooo00L0okmd07Boo`3oool0oooo0;md0000B9`0gooo00<0oooo00<0_g@00018
W03Oool00`3oool0202oM00004RL0=ooo`3oool0oono07@000000000B9cO0`3oool0303OW7@0W=oo
0?ooo`3oool0_g@00018W03Oool0oooo0?oo_`1d000004RL0=ooo`<0oooo00l0okmd07Boo`3oool0
gia80000B02Lgol0oooo0?oog`2LB00004RL0=ooo`3oool0gia80000B02Lgol03P3oool00`3o_g@0
000007Boo`0A0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0303oool00`3o_g@0
04RL0=ooo`0h0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool002L0oooo
00L0oono07@0001d_ol0oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01@3oool00`3o
gi`0B7Bo0?ooo`020?ooo`030?noM0000000M;oo00P0oooo00<0oono07@0001d_ol02P3oool00`00
0000oooo0?ooo`0O0?ooo`030;md000007@0_ooo00X0oooo00@0oono07@00000B9`0gooo6P3oool0
0`3ooml0W4P007Boo`0C0?ooo`040?oo_`1d000004RL0=oooaT0oooo00<0_g@000000018W=l02@3o
ool00`3ogi`0B000001d_`040?ooo`070=nLB00004P0W=oo0?ooo`3o_g@0000007Boo`040?ooo`03
0?noM0000000M;oo00<0oooo00<0omnL04P0001d_ol01`3oool0203ooml0W4P00018W03Oool0oooo
0?oo_`1d000007Bo0P3oool00`3ogi`0B00004RLg`020?ooo`030=nLB00004P0W=oo00<0oooo00L0
_g@00018W03Oool0oooo0?oOW018000007Bo00@0oooo00`0gia80000B02Lgol0oooo0=nLB00004P0
W=oo0?ooo`3ooml0W4P00018W03Oool60?ooo`030;md00000000B9cO00T0oooo00<0omnL04P00000
M;l0103oool01P3OW4P0001809cOo`3ogi`0B00007Boo`P0oooo00<0_g@00018W03Oool00`3oool0
0`2oM00004RL0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3o_g@00000001d_`080?ooo`070;md
0000B9`0gooo0?ooo`3ogi`0B00007Boo`070?ooo`0<0=nLB00004P0W=oo0?ooo`3ooml0W4P00018
W03Oool0oooo0=nLB00004P0W=oo3P3oool00`3o_g@0000007Boo`040?ooo`030;md000000000000
00L0000000H0B9cO0?ooo`3ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00`0oooo00<0
okmd0000B02Lgol0>03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo000W
0?ooo`070?noM0000000M;oo0?ooo`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00H0oooo
00L0gia807Boo`3oool0oooo0?noM0000000M;oo00P0oooo00<0okmd0000001d_ol02P3oool40000
01h0oooo00<0_g@00000M02oool02P3oool0103ookl0M0000018W03Oool30?ooo`030?noW02Lgol0
oooo01<0oooo00@0oooO09a800000000M;oo4`3oool0103ookl0M0000018W03Oool30?ooo`030?no
W02Lgol0oooo0180oooo00@0oono07@0000004P0W=oo2@3oool00`3o_g@0000004RLg`040?ooo`07
0=nLB0000000M;oo0?ooo`3o_g@0000007Boo`040?ooo`030?noM0000000M;oo00<0oooo00<0omnL
04P0B02Lgol01`3oool0103ooml0W4P00018W03Oool20?ooo`070?oog`2LB000000007Boo`3ogi`0
B00004RLg`020?ooo`030=nLB00004P0W=oo00<0oooo00L0_g@00018W03Oool0oooo0?noM0000000
B9cO00@0oooo00`0gia80000001d_ol0oooo0=nLB00004P0W=oo0?ooo`3ooml0W4P00018W03Oool5
0?ooo`040?oo_`1d0000001809cOo`T0oooo00<0okmd00000018W=l0103oool01P3OW4P0000007Bo
o`3ogi`0B01809cOo`P0oooo00<0_g@00018W03Oool00`3oool00`2oM00004RL0=ooo`030?ooo`07
0;md0000B9`0gooo0?ooo`3o_g@0000007Boo`080?ooo`070;md0000B9`0gooo0?ooo`3ogi`0B018
09cOo`070?ooo`0<0=nLB00004P0W=oo0?ooo`3ooml0W4P00018W03Oool0oooo0=nLB00004P0W=oo
3P3oool00`3o_g@0000007Boo`0@0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0
2`3oool00`2oM000001809cOo`0h0?ooo`030000003oool0oooo05P0oooo100000040?ooo`009P3o
ool0203ogi`0B0000000M02oool0oooo0?oOW0180000B9cO103oool00`3OW4P0001809cOo`060?oo
o`070?oo_`1d07@0_ooo0?ooo`3o_g@0000007Boo`070?ooo`040?oOW0180000001d0;ooo`X0oooo
00<000000?ooo`3oool07`3oool00`2oM000001d0;ooo`0:0?ooo`040?oo_`1d000004RL0=ooo`<0
oooo00<0_gA809cOo`3oool0503oool00`3ookl0M00007Boo`060?ooo`030;md00000000000000L0
000000L0B9cO0?ooo`3oool0oono07@00000B9`0gooo00<0oooo00<0_gA809cOo`3oool04P3oool0
103o_g@000000000M02oool90?ooo`030?oOW0180000B9cO00@0oooo00L0_g@00000B02Lgol0oooo
0?noM0000000M;oo00@0oooo00<0okmd0000001d_ol00`3oool00`3ogi`0B0000000000500000006
07Boo`3oool0oooO09a80000B9`0gooo1@3oool0102oM000000000000018W=l20?ooo`030=nLB000
04P0W=oo00<0oooo00L0_g@00018W03Oool0oooo0?oOW0180000B9cO00@0oooo00`0_g@00000B02L
gol0oooo0=nLB00004P0W=oo0?ooo`3ooml0W4P00018W03Oool50?ooo`040?noM0000000001d0;oo
o`T0oooo00<0omnL04P00018W=l0103oool01@2oM000001809cOo`3ogi`0B00000H0000000H0M;oo
0?ooo`3oool0_g@00018W03Oool30?ooo`030;md0000B9`0gooo00<0oooo00L0_g@00018W03Oool0
oooo0?noM00004P0W=oo00P0oooo00H0_g@00018W03Oool0oooo0?oOW01800060000000>07Boo`3o
ool0gia80000B02Lgol0oooo0?oog`2LB00004RL0=ooo`3oool0gia80000B02Lgol>0?ooo`030?no
M0000000M;oo0100oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0:0?ooo`040;md
00000000001d0;ooocP0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00
8P3oool0103Ogml0oooo0?ooo`2oM0020000000604RLg`3oool0oooo0?oOW0180000B9cO103oool0
0`3OW4P0001809cOo`070?ooo`060?noM000M;l0oooo0?noM0000000M;oo0`3oool0103Ogml0oooo
0?ooo`2oM0020000000304RLg`3oool0oooo00T0oooo00<000000?ooo`3oool07`3oool00`2oM000
001d0;ooo`0:0?ooo`030?oo_`1d0000000000@0000000<0001809cOo`3oool0:P3oool00`3ookl0
M00000000004000000030000B02Lgol0oooo0180oooo00@0okmd0000000007@0_ooo2@3oool00`3o
oml0W4P0001d_`030?ooo`080?oo_`1d0000001d0;ooo`3oool0okmd00000000M;l40?ooo`030?no
M000000007Bo00<0oooo00<0oooO09a8B02Lgol00`3oool0302oM000001809cOo`3oool0oooO09a8
0000B9`0gooo0?ooo`3ooml0W4P0001d_`80oooo00<0omnL04P00018W=l00P3oool00`3OW4P00018
09cOo`020?ooo`080?oog`2LB00004RL0=ooo`3oool0oooO09a80000M;l30?ooo`0=0?oo_`1d0000
001d0;ooo`3oool0_g@00000001d_ol0oooo0?oog`2LB00004RL0=ooo`050?ooo`040?noM0000000
001d0;ooo`T0oooo00<0oooO09a80000M;l00`3oool01`3ookl0M0000000M02oool0oooO09a8B02L
gol00`3oool00`2oM000001809cOo`020?ooo`030;md0000B9`0gooo00<0oooo00<0_g@00018W03O
ool00P3oool0203ooml0W4P00018W03Oool0oooo0?oo_`1d0000M;oo0P3oool03@3ooml0W4P00018
W03Oool0oooo0?oog`2LB00004RL0=ooo`3oool0oooO09a8B02Lgol00`3oool0402oM000001809cO
o`3oool0_g@00000001d_ol0oooo0?oog`2LB00004RL0=ooo`3oool0gia80000B02Lgol>0?ooo`03
0?noM000000007Bo0100oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`070?ooo`03
0?oo_`1d000000000080000000<0B9cO0?ooo`3oool0=`3oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo0080oooo000R0?ooo`030?noM000000000000080000000L007Bo0?ooo`3oool0
oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0203oool01@2oM000M;oo0?noM0000000
M;oo00<0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0:0?ooo`030000003oool0
oooo01l0oooo00<0_g@00000M02oool01@3oool02@3ooml0W4P00000B02Lgol0oooo0?oo_`1d0000
04RL0=ooo`030?ooo`030;mdB02Lgol0oooo02X0oooo00@0oono07@00000B9`0gooo0`3oool00`2o
M4P0W=oo0?ooo`0B0?ooo`040?oOW0180000001d0;ooo`X0oooo00X0omnL04P0001d_ol0oooo0?oo
g`2LB000000007Boo`3ooml0W4P00P0000001@1dM7@0B9cO0;md0000B7@0M4P00080000002H0M7Ad
04RLg`2oM00004RL0=ooo`3o_g@0001d0;ooo`3oool0omnL04P00000B9`0gooo0?ooo`3ooml0W4P0
0018W03Oool0oooo0?oog`2LB00004RL0=ooo`3oool0gia80000001d_ol0oooO0=oOo`3OW4P00018
09cOo`3oool0omnL04P00000000004RL0=ooo`80oooo0140omnL04P0001d_ol0oooo0?oog`2LB000
000007Boo`3ookl0M0000000000004P0B4P004RLg`3ookl0M000001d_`060?ooo`040?oOW0180000
001d0;ooo`X0oooo00P0omnL04P0001d_ol0oooo0?oog`2LB000000007Boo`80oooo00P0okmd0000
M02oool0oooo0?oOW018000004RL0=ooo`80oooo00<0_g@00018W03Oool00`3oool02@2oM00004RL
0=ooo`3oool0omnL04P00000000004RL0=ooo`020?ooo`0=0?noM00004P0W=oo0?ooo`3o_g@00000
0018W03Oool0omnL04P00000000004RL0=ooo`020?ooo`0E0?noM00007@0_ooo0?ooo`3ogi`0B000
0018W03Ookl0M0000000000004P0B4P004RLg`3ookl0M000001d_`3ooml0gmoo0=nLB00004P0W=oo
00@0oooo00@0oooO09a8000004P0W=oo103oool02P3ooml0W4P0000000000000M7Ad04RLg`2oM000
04RL0=ooo`2oM0090000000504RLg`3oool0omnL04P00018W=l0103oool00`3OW4P0001809cOo`09
0?ooo`030?noM00004P0W=oo03X0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`02
0?ooo`008P3oool01@3ooml0W4P00000000007@0_ooo00D0oooo00<0_g@00018W03Oool00P3oool0
0`3ooml0W4P0001d_`090?ooo`050?oo_`1d07@0_kmd0000001d_ol00`3oool01@3ooml0W4P00000
000007@0_ooo00d0oooo00<000000?ooo`3oool07`3oool00`2oM000001d0;ooo`050?ooo`090?oo
g`2LB000001809cOo`3oool0oono07@00000B9`0gooo00<0oooo00<0oknL09cOo`3oool0:P3oool0
103ookl0M0000018W03Oool30?ooo`030?noW02Lgol0oooo0180oooo00@0oono07@0000004P0W=oo
1P3oool00`3ooml0W7BL0=ooo`020?ooo`060?oo_`1d000000000000000004P0W=oo0`3oool03@3O
W4P0000007Boo`3OW4P00000001d_`3oool0gia80000001d_ol0gia800000000M;l00P3oool01P3o
gi`0B00000000000000004RL0=ooo`80oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0
0000000200000004001d_`3oool0oooo0;md00<0000000H0001809cOo`3ooml0W4P00018W03Oool3
0?ooo`060?oo_`1d000000000000000004P0W=oo0`3oool01`2oM000001809cOo`3OW4P000000000
B02Lgol01P3oool0103ookl0M0000000B02Lgol60?ooo`030?oog`2LM9`0gooo0080oooo00H0oono
07@00000000000000000B02Lgol40?ooo`080?oOW0180000000000000000B9`0gooo0?ooo`3OW4P4
000000030000B01dM4P0000000<0000000H0001809cOo`3ooml0W4P00018W03Oool30?ooo`060?oO
W0180000000000000000B9`0gooo0P3oool0103ooml0W4P00018W03Oool30?ooo`060?oOW0180000
000000000000B9`0gooo0P3oool02@2oM000001809cOo`3OW4P000000000B02Lgol0oooo0;md0003
000000080000B02Lgol0oooo0?ooo`3ooml0W4P00000B02Lgol60?ooo`060=nLB0000000M;oo0=nL
B000000007Bo3@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00X0oooo00<0omnL
04Qd_`3oool0>@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo000S0?oo
o`030?noM000M;l0oooo00H0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0:0?oo
o`040?noM0000000000007Boo`@0oooo00<0okmd001d_`3oool03P3oool00`000000oooo0?ooo`0O
0?ooo`030;md000007@0_ooo00X0oooo00@0oono07@00000B9`0gooo<03oool0103ookl0M0000018
W03OoolI0?ooo`030=nLB0000000B9cO00H0oooo00<0omnL04Q8W03Oool08P3oool0103ooml0W4P0
0018W03Oool;0?ooo`030=nLB00004P0W=oo0200oooo00<0gia800000018W=l01P3oool00`3ogi`0
B4RL0=ooo`0E0?ooo`030;md0000B9`0gooo00<0oooo00<0_g@00018W03Oool0:@3oool00`3OW4P0
001809cOo`0R0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l02`3oool00`3ooml0
W4P004RLg`0i0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool002<0oooo
00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`020?ooo`060;md0000B9`0gooo0?ooo`2o
M00007Bo2`3oool0103ooml0W4P00000001d_ol40?ooo`030?oog`2LB00000000080000000<0001d
0;ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`030;md000007@0_ooo00X0oooo00@0oono
07@00000B9`0gooo103oool00`3ookl0W9cO0?ooo`0Y0?ooo`040?oo_`1d000004RL0=ooo`@0oooo
00<0oono09bLg`3oool04P3oool0103ookl0M0000000B02Lgol50?ooo`030;md0000M;l0oooo0280
oooo00@0oooO09a80000B9`0gooo2`3oool00`3ookl0M01809cOo`0P0?ooo`040?oo_`1d00000018
09cOo`D0oooo00<0_g@0001d_`3oool05@3oool00`2oM00004RL0=ooo`030?ooo`030;md0000B9`0
gooo02T0oooo00<0oono07@0B02Lgol08P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000
M;oo00H0oooo00<0oooO09adW03Oool00P3oool00`3ooml0W4P0001d_`0i0?ooo`030000003oool0
oooo05/0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0okmd0000000000000P0000000`1d
_ol0oooo0?ooo`020?ooo`040;md000000000000001d_`d0oooo00<0omnL04P0001d_ol01@3oool0
0`3o_g@00000000000020000000307Boo`3oool0oooo00P0oooo00<000000?ooo`3oool07@3oool0
1@3OW4P000000000000007@0_ooo00X0oooo00@0oono07@00000B9`0gooo103oool00`3OW4P0B9cO
0?ooo`0Y0?ooo`040?oo_`1d000004RL0=ooo`@0oooo00<0gia804RLg`3oool04`3oool0103ookl0
M0000000B02Lgol20?ooo`040?oog`2LB0000000001d_b<0oooo00@0oooO09a80000B9`0gooo303o
ool00`3OW7@0W=oo0?ooo`0P0?ooo`040?oo_`1d0000001809cOo`80oooo00@0oooO09a800000000
07Bo5P3oool00`3OW4P0001d0;ooo`030?ooo`030=nLB00007@0_ooo02X0oooo00<0giad09cOo`3o
ool08P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00L0omnL04Q8W03Oool0oooo0=nL
B0000000M;oo03T0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3o
ool00`000000oooo0?ooo`0N0?ooo`040?oo_`1d0000001d0;ooo`P0oooo00<0oooO09a800000000
200000000`18W=l0oooo0?ooo`0V0?ooo`030?oog`2LB000000000P0000000<0B9cO0?ooo`3oool0
503oool0203OW4P00000000000000000001809cOo`3ookl0M7Bo8P3oool01@3ogi`0B00000000000
B9`0gooo0100oooo00@0oooO09a8000007@0_ooo7@3oool0203OW4P00000000000000000001809cO
o`3ookl0M7Bo5P3oool02`3ookl0M01809cOo`3oool0gia800000018W9`0M01809cOo`3oool0gia8
0080000000<0001d0;ooo`3oool02P3oool0103ooml0W4P00000M02ooolk0?ooo`040;md00000000
0000001d_`X0oooo00D0omnL04P000000000000004RLg`0j0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0Z`3oool0103ookl0M0000018
W03Oool@0?ooo`040?oog`2LB000001d0;oooc`0oooo00P0oooO09a80000000000000018W03Oool0
oooO09a80080000000@004Qd07A8000007@0_ooo2`3oool0103ooml0W4P00000M02ooon80?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0
o`3ooonU0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo0`00
003o0?ooojD0oooo00<000000?ooo`3oool0F@3oool3000000@0oooo001G0?ooo`030000003oool0
oooo0?l0ooooY@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?oo
o`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
0080oooo001G0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?l0ooooY@3o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0
oooo0?l0ooooY@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?oo
o`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
0080oooo001G0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`<00000o`3ooonU0?ooo`030000003o
ool0oooo05T0oooo0`0000040?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3o0?oo
ojD0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000
oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00
E`3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3o0?oo
ojD0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000
oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00
E`3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`020?ooo`00E`3oool300000?l0ooooY@3oool00`000000oooo0?ooo`1I0?ooo`<00000103o
ool005L0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`3o0?oo
o`H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000
oooo0?ooo`2L0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0
o`3oool60?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<0
00000?ooo`3oool0W03oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0
oooo0?l0oooo1P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?oo
o`030000003oool0oooo09`0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0W03oool00`000000
oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00
E`3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`<00000W03oool00`000000oooo0?oo
o`3o0?ooo`H0oooo00<000000?ooo`3oool0F@3oool3000000@0oooo001G0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`3o0?oo
o`H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3oool60?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo0080oooo000/0?ooo`060;md00000000000000000000B9`0
gooo1P3oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO0080oooo00H0_g@00000
0000000000000018W03Oool<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`020?ooo`00:`3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00<0oooo00L0oooO
09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00L0gia800000018W=l0oooo0?oog`2LB000B9cO
0080oooo00<0omnL04Q8W03Oool02`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool00P3oool00340oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo00`0oooo00<0omnL04Qd_`3oool02P3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo05/0
oooo00<000000?ooo`3oool00P3oool00340oooo00P0oono07@0B02Lgol0oooo0?oog`2LB00004RL
0=ooo`80oooo00<0oooO09a80000M;l0303oool00`3ookl0M01809cOo`0:0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00<@3oool01`3ookl0M00007Boo`3oool0
oono07@00000M;l0103oool00`2oM000001d0;ooo`0;0?ooo`030?oo_`1d0000M;oo00X0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo1P3o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo000a0?ooo`070?noM0000000
M;oo0?ooo`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00/0oooo00<0okmd0000001d_ol0
2P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
o`3oool60?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool00300oooo00P0
omnL04P0000007@0_ooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia80000B02Lgol02P3oool0103o
gi`0B0000000M02oool:0?ooo`@00000C@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo0?l0oooo1P3oool00`000000oooo0?ooo`1H0?ooo`@00000103oool002`0oooo00@0gmoO0?oo
o`3oool0_g@00P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia80000B02Lgol0
1P3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00T0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo1@3oool3000005`0
oooo00<000000?ooo`3oool00P3oool002`0oooo00<0okmd0000000000000P0000001`00M;l0oooo
0?ooo`3oool0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`030?noM00000000000
0080000000<007Bo0?ooo`3oool02P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0o`3oool40?ooo`D00000F`3oool00`000000oooo0?ooo`020?oo
o`00;03oool01@3ooml0W4P00000000007@0_ooo00D0oooo00<0_g@00018W03Oool00P3oool00`3o
oml0W4P0001d_`070?ooo`050?oog`2LB00000000000M02oool03@3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3oool30?ooo`L00000FP3oool0
0`000000oooo0?ooo`020?ooo`00;@3oool00`3o_g@007Bo0?ooo`060?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol0203oool00`3o_g@007Bo0?ooo`0>0?ooo`030000003oool0oooo
04h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo1`00001J0?oo
o`030000003oool0oooo0080oooo000]0?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3o
ool00P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`T0oooo00<0oooO09a8000000000P000000
0`0007@0_ooo0?ooo`090?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo1`00001J0?ooo`030000003oool0oooo0080oooo000^0?oo
o`030?noM000000000000080000000<0M;oo0?ooo`3oool00P3oool0102oM000000000000000M;l;
0?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool0203oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3oool40?ooo`D00000F`3oool0
0`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0o`3oool50?ooo`<00000G03oool00`000000oooo0?ooo`020?oo
o`00E`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0o`3oool60?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo
1P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`<00000CP3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo0?oo
o`1I0?ooo`<00000103oool005L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo0080oooo001G0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?oo
o`00E`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0o`3oool60?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo
1P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0
oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
0P3oool005L0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3o
ool60?ooo`030000003oool0oooo05T0oooo0`0000040?ooo`00E`3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0
oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
0P3oool005L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o
0?ooo`H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3oool60?oo
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool3000004h0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0F@3oool3000000@0oooo001G
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o
0?ooo`H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3oool60?oo
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo0080oooo001G0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?oo
o`00E`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0o`3oool60?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo
1P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool3000004h0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0F@3oool3
000000@0oooo001G0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?oo
o`00E`3oool00`000000oooo0?ooo`1=0?ooo`<00000C03oool00`000000oooo0?ooo`3o0?ooo`H0
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo
0?ooo`1<0?ooo`D00000B`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`020?ooo`008P3oool01P2oM000000000000000000004RL0=ooo`H0
oooo00@0_g@0000000000000B9cO103oool00`3OW4P0000004RLg`020?ooo`060;md000000000000
00000000B9`0gooo103oool01P2oM000000000000000000004RL0=ooo``0oooo00<000000?ooo`3o
ool0B`3oool7000004X0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo05/0
oooo00<000000?ooo`3oool00P3oool00240oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL
0=ooo`030?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`070=nLB0000000B9cO
0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo0080oooo00<0oooO09a80018W=l00P3o
ool00`3ogi`0B4RL0=ooo`0;0?ooo`030000003oool0oooo04/0oooo1`00001:0?ooo`030000003o
ool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo000W
0?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0<
0?ooo`030?oOW018M;l0oooo00L0oooo00<0omnL04Qd_`3oool02P3oool00`000000oooo0?ooo`1;
0?ooo`L00000B03oool300000?l0oooo203oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo0080oooo000W0?ooo`080?oo_`1d04P0W=oo0?ooo`3ooml0W4P00018W03Oool20?ooo`030?oo
g`2LB00007Bo00`0oooo00<0oono07@0B02Lgol01`3oool00`3ookl0M01809cOo`0:0?ooo`030000
003oool0oooo04`0oooo1@0000180?ooo`D00000o`3oool70?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool00P3oool000P0oooo00<0omnL09boo`3oool0703oool01`3ookl0M00007Bo
o`3oool0oono07@00000M;l0103oool00`2oM000001d0;ooo`0;0?ooo`030?oo_`1d0000M;oo00L0
oooo00<0oono07@0001d_ol02P3oool00`000000oooo0?ooo`1=0?ooo`<00000B03oool700000?l0
oooo1P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo00080?ooo`030;md
00000000000000T0000000<0001809cOo`3oool0403oool01`3o_g@0000007Boo`3oool0omnL04P0
0018W=l0103oool00`2oM000001d0;ooo`0;0?ooo`030?noM0000000M;oo00L0oooo00<0okmd0000
001d_ol02P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04L0oooo1`00003o0?oo
o`H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`001`3oool00`3ookl0
M0000000000;00000003001d_`3oool0oooo00h0oooo00P0omnL04P0000007@0_ooo0?ooo`3ogi`0
B00004RLg`@0oooo00<0gia80000B02Lgol02P3oool0103ogi`0B0000000M02oool60?ooo`040?oO
W0180000001d0;ooo`X0oooo1000001=0?ooo`030000003oool0oooo04L0oooo1`00001B0?ooo`03
0000003oool0oooo0;00oooo00<000000?ooo`3oool0F03oool4000000@0oooo000=0?ooo`030?oO
W018M;l0oooo00@0oooo00<0omnL04P0M02oool02`3oool0103Ogml0oooo0?ooo`2oM00200000006
04RLg`3oool0oooo0?oOW0180000B9cO103oool00`3OW4P0001809cOo`060?ooo`040=oOg`3oool0
oooo0;md0080000000D0B9cO0?ooo`3oool0oooo0=oOg`020?ooo`040;md00000000000004RLg`/0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`180?ooo`D00000D`3oool00`000000
oooo0?ooo`2`0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool000`0oooo
00<0oono07@0B02Lgol01P3oool00`2oM7@0_ooo0?ooo`0:0?ooo`030?noM0000000000000800000
00L007Bo0?ooo`3oool0oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o
_g@000000000000200000003001d_`3oool0oooo0080oooo00<0okmd0000000000000P0000000`00
M;l0oooo0?ooo`0:0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B@3oool30000
05@0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
0080oooo000<0?ooo`030?noM00004P0W=oo00D0oooo00<0oooO09adW03Oool02`3oool01@3ooml0
W4P00000000007@0_ooo00D0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`070?oo
o`050?oog`2LB00000000000M02oool01@3oool01@3ooml0W4P00000000007@0_ooo00d0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0/03oool00`000000oooo0?ooo`160?ooo`X000002`3oool00`000000oooo0?oo
o`020?ooo`00303oool0103ogi`0B0000000B02Lgol30?ooo`030?oog`2LB000M;oo00d0oooo00<0
okmd001d_`3oool01P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo00<0
okmd001d_`3oool01`3oool00`3o_g@007Bo0?ooo`0>0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0:H0ooooD`00
000E0?ooo`030000003oool0oooo0080oooo000=0?ooo`030;md00000000000000@0000000<007Bo
0?ooo`3oool0303oool00`3ooml0W4P000000002000000030000M02oool0oooo0080oooo00H0_g@0
0018W03Oool0oooo0;md0000M;l90?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool0
0P3oool00`3ooml0W4P000000002000000030000M02oool0oooo00T0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
E03ooomB000000X0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`003P3o
ool00`3OW4P00000000000020000000307Boo`3oool0oooo00h0oooo00<0okmd0000000000000P00
00000`1d_ol0oooo0?ooo`020?ooo`040;md000000000000001d_`/0oooo00<0okmd000000000000
0P0000000`1d_ol0oooo0?ooo`020?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool0
203oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`020?oooe800000G03oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo0080oooo001G0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`050?oooe800000[P3oool00`000000oooo0?ooo`1K0?ooo`030000003o
ool0oooo0080oooo001G0?ooo`030000003oool0oooo04h0oooo00@000000?ooo`3oool0ooooDP00
001=0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`020?ooo`00E`3oool00`000000oooo0?ooo`090?ooodT00000BP3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`02
0?ooo`003`3oool00`3ooml0W7BL0=ooo`060?ooo`030=nLW02oool0oooo03`0oooo0`00001>0?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2`0?oo
o`030000003oool0oooo05T0oooo0`0000040?ooo`003`3oool00`3o_g@000000000000600000003
0000M02oool0oooo03`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo0080oooo000H0?ooo`030=nLW02oool0oooo03`0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
/03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`2`0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool0
05L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
0080oooo001G0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0/03oool00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0;00oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool3000004h0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0;00oooo00<000000?oo
o`3oool0F@3oool3000000@0oooo001G0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2`0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0/03o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo0;00oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`2`0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0580
oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080
oooo001G0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0080oooo001G0?ooo`<00000CP3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1I0?oo
o`<00000103oool005L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0/03oool0
0`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo
04h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
0;00oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0DP3oool00`000000
oooo0?ooo`2`0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool005L0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo
001G0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`020?ooo`00E`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo0080oooo001G0?ooo`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1I0?ooo`<0
0000103oool005L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo0080oooo001G0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0
oooo05/0oooo00<000000?ooo`3oool00P3oool002`0oooo00H0_g@000000000000000000018W03O
ool60?ooo`040;md00000000000004RLg`@0oooo00<0gia800000018W=l00`3oool01P3ooml0W4P0
000000000000001d0;ooo`/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo0080oooo000[0?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8W03O
ool00`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`02
0?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000B02Lgol:0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0;00
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`00<@3oool00`3ogi`0B7Bo
0?ooo`020?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`2oM000001d
0;ooo`030?ooo`030;md0000M;l0oooo00T0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0/03oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo0080oooo000a0?ooo`080?oo_`1d04P0W=oo0?ooo`3ooml0
W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00H0oooo00<0oono07@00000M;l0103oool00`3O
W4P0001d0;ooo`090?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`020?ooo`00<@3oool01`3ookl0M00007Boo`3oool0oono07@00000M;l0103oool0
0`2oM000001d0;ooo`050?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000B02Lgol02@3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`2`0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool0
0340oooo00L0okmd0000001d_ol0oooo0?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01@3o
ool00`3ogi`0B00004RLg`030?ooo`040?oo_`1d0000001d0;ooo`T0oooo00<000000?ooo`3oool0
W03oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`020?ooo`00<03oool0203ogi`0B0000000M02oool0oooo0?oOW018
0000B9cO103oool00`3OW4P0001809cOo`050?ooo`090?oo_`1d000000000018W03Oool0oooo0;md
00000000B9cO00X0oooo1000002K0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
/03oool00`000000oooo0?ooo`1H0?ooo`@00000103oool002`0oooo00@0gmoO0?ooo`3oool0_g@0
0P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia80000B02Lgol01@3oool01@3o
oml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool02@3oool00`000000oooo0?ooo`2L
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0080oooo000/0?ooo`030?noM000000000000080000000L007Bo0?oo
o`3oool0oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@0000004RL
g`0?0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`2`0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool002`0oooo00D0oooO
09a800000000001d0;ooo`050?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l01`3o
ool0103ooml0W4P00000B02Lgol>0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool002d0oooo00<0
okmd001d_`3oool01P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo00@0
oono07@0000007@0_ooo3@3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo000]0?ooo`030?oog`2L
B00000000080000000<0001d0;ooo`3oool00P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`X0
oooo00@0oooO09a80000000007Bo303oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo000^0?ooo`03
0?noM000000000000080000000<0M;oo0?ooo`3oool00P3oool0102oM000000000000000M;l=0?oo
o`050?oOW018000000000018W03Oool02@3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?oo
o`030000003oool0oooo09`0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?oo
o`l0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0W03oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000oooo0?ooo`020?ooo`00
E`3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?ooo`<00000W03oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo0?l0oooo3@3oool3000000@0oooo001G0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<00000
0?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo0?l0oooo3`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000
oooo0?ooo`2L0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3oool?0?ooo`03
0000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool005L0oooo00<0
00000?ooo`3oool0W03oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo3`3o
ool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?oo
o`030000003oool0oooo09`0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?oo
o`l0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0l@3oool00`000000
oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0
l@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool005L0oooo0`00
003a0?ooo`030000003oool0oooo0?l0oooo3@3oool3000000@0oooo001G0?ooo`030000003oool0
oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?oo
o`030000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo
0080oooo001G0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`03
0000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0
o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?00oooo0`00
003o0?oooa00oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0k`3oool5
00000?l0oooo3`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3^0?oo
o`L00000o`3oool>0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0>h0
oooo1`00003o0?ooo`h0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0
kP3oool700000?l0oooo3P3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?oo
o`3_0?ooo`D00000o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?ooo`<00000l03oool3
00000?l0oooo3P3oool3000000@0oooo001G0?ooo`030000003oool0oooo0?40oooo00<000000?oo
o`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?40
oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000
003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo
001G0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003o
ool0oooo0080oooo001G0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?
0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?40oooo00<000000?oo
o`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?40
oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000
003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo
001G0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003o
ool0oooo0080oooo001G0?ooo`<00000l@3oool00`000000oooo0?ooo`3o0?ooo`d0oooo0`000004
0?ooo`00E`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo0?l0oooo3`3oool00`00
0000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo0?l0
oooo3`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3a0?ooo`030000
003oool0oooo0?l0oooo3`3oool00`000000oooo0?ooo`020?ooo`008P3oool01P2oM00000000000
0000000004RL0=ooo`H0oooo00@0_g@0000000000000B9cO103oool00`3OW4P0000004RLg`030?oo
o`060?oog`2LB00000000000000007@0_ooo0`3oool01P2oM000000000000000000004RL0=ooo``0
oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3o
ool00P3oool00240oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`030?ooo`070?oo
g`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00`0oono07@0
0000B9`0gooo0?ooo`3OW4P0001809cOo`3oool0oooO09a80018W=l20?ooo`030?oOW018B9`0gooo
00/0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?oo
o`3oool00P3oool002L0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo00L0oooo00<0_g@00000M02oool00`3oool00`2oM00007Bo0?ooo`060?ooo`03
0?oOW018M;l0oooo00X0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0
oooo00<000000?ooo`3oool00P3oool002L0oooo00P0oono07@0B02Lgol0oooo0?oog`2LB00004RL
0=ooo`80oooo00<0oooO09a80000M;l01P3oool00`3ookl0M000001d_`040?ooo`030=nLB00007@0
_ooo00H0oooo00<0oono07@0B02Lgol02P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0
oooo0?l0oooo3`3oool00`000000oooo0?ooo`020?ooo`009`3oool01`3ookl0M00007Boo`3oool0
oono07@00000M;l0103oool00`2oM000001d0;ooo`050?ooo`030?oOW0180000B9cO00@0oooo00<0
_g@00000B02Lgol01P3oool00`3ookl0M00007Boo`0:0?ooo`030000003oool0oooo0?40oooo00<0
00000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo000W0?ooo`070?noM0000000
M;oo0?ooo`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04P00018W=l0
0`3oool0103ookl0M0000000M02oool60?ooo`030?noM0000000M;oo00X0oooo00<000000?ooo`3o
ool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool002H0oooo
00P0omnL04P0000007@0_ooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia80000B02Lgol01@3oool0
2@3ookl0M00000000000B9`0gooo0?ooo`2oM000000004RLg`060?ooo`040?oOW0180000001d0;oo
o`X0oooo1000003`0?ooo`030000003oool0oooo0?l0oooo303oool4000000@0oooo000R0?ooo`04
0=oOg`3oool0oooo0;md0080000000H0B9cO0?ooo`3oool0omnL04P00018W=l40?ooo`030=nLB000
04P0W=oo00D0oooo00D0oooO09a8000007@0_mnL04P000020000000504RLg`3oool0oooo0?ooo`3O
gml00P3oool0102oM000000000000018W=l;0?ooo`030000003oool0oooo0?40oooo00<000000?oo
o`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo000R0?ooo`030?noM000000000000080
000000L007Bo0?ooo`3oool0oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool0
0`3o_g@0000004RLg`070?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool02P3oool0
0`000000oooo0?ooo`3a0?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000oooo0?ooo`02
0?ooo`008P3oool01@3ooml0W4P00000000007@0_ooo00D0oooo00<0_g@00018W03Oool00P3oool0
0`3ooml0W4P0001d_`070?ooo`040?oog`2LB000001809cOo`H0oooo00D0oooO09a800000000001d
0;ooo`0=0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000
003oool0oooo0080oooo000S0?ooo`030?noM000M;l0oooo00H0oooo00<0okmd0000B02Lgol00P3o
ool00`3ogi`0B00007Boo`080?ooo`040?oo_`1d0000001d0;ooo`H0oooo00<0okmd001d_`3oool0
3P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000oooo
0?ooo`020?ooo`008`3oool00`3ooml0W4P000000002000000030000M02oool0oooo0080oooo00H0
_g@00018W03Oool0oooo0;md0000M;l:0?ooo`040?oog`2LB0000000001d_`D0oooo00<0oooO09a8
000000000P0000000`0007@0_ooo0?ooo`090?ooo`030000003oool0oooo0?40oooo00<000000?oo
o`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo000T0?ooo`030?noM000000000000080
000000<0M;oo0?ooo`3oool00P3oool0102oM000000000000000M;l=0?ooo`050?oOW01800000000
0018W03Oool00`3oool00`3o_g@00000000000020000000307Boo`3oool0oooo00P0oooo00<00000
0?ooo`3oool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool0
05L0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?oo
o`3oool00P3oool005L0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0
oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0l@3oool00`000000oooo
0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool005L0oooo0`00003a0?ooo`030000003o
ool0oooo0?l0oooo3@3oool3000000@0oooo001G0?ooo`030000003oool0oooo0?40oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo
0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?ooo`03
0000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080
oooo001G0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000
003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3o
ool?0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?40oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?ooo`030000003oool0oooo
0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?ooo`03
0000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080
oooo001G0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000
003oool0oooo0080oooo001G0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3o
ool?0?ooo`030000003oool0oooo0080oooo001G0?ooo`<00000l@3oool00`000000oooo0?ooo`3o
0?ooo`d0oooo0`0000040?ooo`00E`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo
0?l0oooo3`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3a0?ooo`03
0000003oool0oooo0?l0oooo3`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo
0?ooo`3a0?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000oooo0?ooo`020?ooo`00E`3o
ool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000oooo0?oo
o`020?ooo`00E`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo0?l0oooo3`3oool0
0`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo
0?l0oooo3`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3a0?ooo`03
0000003oool0oooo0?l0oooo3`3oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo
0?ooo`3a0?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000oooo0?ooo`020?ooo`00E`3o
ool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000oooo0?oo
o`020?ooo`00E`3oool300000?40oooo00<000000?ooo`3oool0o`3oool=0?ooo`<00000103oool0
05L0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?oo
o`3oool00P3oool005L0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0
oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0l@3oool00`000000oooo
0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0l@3o
ool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool005L0oooo00<00000
0?ooo`3oool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool0
05L0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?oo
o`3oool00P3oool005L0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0
oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0l@3oool00`000000oooo
0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool005L0oooo00<000000?ooo`3oool0l@3o
ool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool005L0oooo0`00003a
0?ooo`030000003oool0oooo0?l0oooo3@3oool3000000@0oooo001G0?ooo`030000003oool0oooo
0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo001G0?ooo`03
0000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080
oooo001G0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000
003oool0oooo0080oooo000/0?ooo`060;md00000000000000000000B9`0gooo1P3oool0102oM000
000000000018W=l40?ooo`030=nLB0000000B9cO00@0oooo00<0omnL04P0M02oool03@3oool00`00
0000oooo0?ooo`3a0?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000oooo0?ooo`020?oo
o`00:`3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00<0oooo00L0oooO09a80000
M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l01@3oool00`2oM000M;oo0?ooo`0<
0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0
oooo0080oooo000a0?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000B02Lgol00P3oool00`3o
gi`0B00007Boo`0:0?ooo`030?noM000M;l0oooo00`0oooo00<000000?ooo`3oool0l@3oool00`00
0000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool00340oooo00P0oono07@0B02L
gol0oooo0?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l02P3oool00`3ookl0M01d0;oo
o`0<0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003o
ool0oooo0080oooo000a0?ooo`070?oo_`1d0000M;oo0?ooo`3ookl0M000001d_`040?ooo`030;md
000007@0_ooo00X0oooo00<0_g@007Boo`3oool02`3oool00`000000oooo0?ooo`3a0?ooo`030000
003oool0oooo0?l0oooo3`3oool00`000000oooo0?ooo`020?ooo`00<@3oool01`3o_g@0000007Bo
o`3oool0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0:0?ooo`030?noM000M;l0oooo00/0
oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3o
ool00P3oool00300oooo00P0omnL04P0000007@0_ooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia8
0000B02Lgol02P3oool00`3ookl0M01d0;ooo`0;0?ooo`@00000l03oool00`000000oooo0?ooo`3o
0?ooo``0oooo100000040?ooo`00;03oool0103Ogml0oooo0?ooo`2oM0020000000604RLg`3oool0
oooo0?oOW0180000B9cO103oool00`3OW4P0001809cOo`0;0?ooo`030;md001d_ol0oooo00X0oooo
00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool0
0P3oool002`0oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3oool0oono07@00000
M;l0103oool00`2oM000001d0;ooo`0;0?ooo`030?noM000M;l0oooo00X0oooo00<000000?ooo`3o
ool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool002`0oooo
00D0oooO09a800000000001d0;ooo`050?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000
M;l01P3oool00`3ogkl0_moo0?ooo`030?ooo`030?oo_`1d07@0_ooo00X0oooo00<000000?ooo`3o
ool0l@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool00P3oool002d0oooo
00<0okmd001d_`3oool01P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00H0oooo
00<0oooO09a8M02oool0103oool00`2oM000M;oo0?ooo`090?ooo`030000003oool0oooo0?40oooo
00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo000]0?ooo`030?oog`2L
B00000000080000000<0001d0;ooo`3oool00P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0
oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`080?ooo`030000003oool0oooo0?40
oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo0080oooo000^0?ooo`030?no
M000000000000080000000<0M;oo0?ooo`3oool00P3oool0102oM000000000000000M;l90?ooo`03
0?oOW0180000000000@0000000<0001809cOo`3oool0203oool00`000000oooo0?ooo`3o0?ooool0
oooo103oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooool0oooo
103oool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooool0oooo103o
ool00`000000oooo0?ooo`020?ooo`00E`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo05l0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0080oooo001G0?ooo`<000002@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00L0oooo0`0000040?ooo`00E`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00E`3ooooo00000?l00000
200000040?ooo`00\
\>"],
  ImageRangeCache->{{{0, 608.188}, {375.5, 0}} -> {-1.00978, 50.345, \
0.0101501, 0.000977427}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(b1p[a1b1_, b1b1_, x_] := a1b1\  + \ b1b1\ x;\)\)], "Input"],

Cell[BoxData[
    \(\(chi2b1[a1b1_, b1b1_] := 
        Sum[\((\((b1pl[\([i, 2]\)] - 
                    b1p[a1b1, b1b1, b1pl[\([i, 1]\)]])\)/\((b1pl[\([i, 
                      3]\)])\))\)^2, {i, 1, Length[b1pl]}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(par = {a1b1, b1b1};\)\), "\n", 
    \(\(aklb1[a1b1_, b1b1_, k_, l_] := 
        1/2  D[D[chi2b1[a1b1, b1b1], par[\([k]\)]], 
            par[\([l]\)]\ ];\)\), "\n", 
    \(\(fminb1 = 
        FindMinimum[
          chi2b1\ [a1b1, b1b1], {a1b1, 1}, {b1b1, \(-10\)}];\)\), "\n", 
    \(\(a1b1o = fminb1[\([2, 1, 2]\)];\)\), "\n", 
    \(\(b1b1o = fminb1[\([2, 2, 2]\)];\)\), "\n", 
    \(aklob1 = 
      Table[If[k \[LessSlantEqual] 
            l, \(aklb1[a1b1, b1b1, k, l] /. a1b1 \[Rule] a1b1o\) /. 
            b1b1 \[Rule] b1b1o, \(aklb1[a1b1, b1b1, l, k] /. 
              a1b1 \[Rule] a1b1o\) /. b1b1 \[Rule] b1b1o], {k, 1, 2}, {l, 1, 
          2}]; cij = Inverse[aklob1]; 
    sparb1 = Table[Sqrt[cij[\([i, i]\)]], {i, 1, 2}]; 
    Print["\<a1b1= \>", a1b1o, "\<+-\>", sparb1[\([1]\)], "\<  b1b1= \>", 
      b1b1o, "\<+-\>", sparb1[\([2]\)]]; 
    cij // MatrixForm\), "\[IndentingNewLine]", 
    \(chi2rb1 = Part[fminb1, 1]/\((Length[b1pl])\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("a1b1= "\[InvisibleSpace]1.7189492330359555`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.1419131503878222`\[InvisibleSpace]"  \
b1b1= "\[InvisibleSpace]\(-0.09399529488764813`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.057985765504616704`\),
      SequenceForm[ 
      "a1b1= ", 1.7189492330359555, "+-", .14191315038782221, 
        "  b1b1= ", -.093995294887648129, "+-", .057985765504616704],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.020139342252996646`", \(-0.006698627412838143`\)},
            {\(-0.006698627412838143`\), "0.0033623490011563967`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    \(1.5716972002444747`\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(b1pr = a1b1o + \ b1b1o\ z;\)\), "\[IndentingNewLine]", 
    \(\(b1prpl = 
        Plot[b1pr, {z, 0, 5}, 
          DisplayFunction \[Rule] Identity];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fa1 = 
      Show[b1prpl, b1dtpl, 
        Graphics[{Text[\*"\"\<1:\!\(E\_peak\)-\!\(E\_\(\(\[Gamma]\)\(\\\ \\\ \
\\\ \)\)\)Correlation Coefficient: r=0.47\>\"", {3.3, 2}]}], 
        Frame \[Rule] True, Axes \[Rule] False, 
        DisplayFunction \[Rule] $DisplayFunction, PlotRange \[Rule] All, 
        FrameLabel \[Rule] {"\<<z>\>", \*"\"\<\!\(a\_1\)\>\""}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 -0.384214 0.482515 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -7.03125 -24.5625 ]
[.21429 -0.0125 7.03125 0 ]
[.40476 -0.0125 -7.03125 -24.5625 ]
[.40476 -0.0125 7.03125 0 ]
[.59524 -0.0125 -7.03125 -24.5625 ]
[.59524 -0.0125 7.03125 0 ]
[.78571 -0.0125 -7.03125 -24.5625 ]
[.78571 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.375 -49.125 ]
[.5 -0.0125 19.375 -24.5625 ]
[-0.0125 .0018 -29.125 -12.2813 ]
[-0.0125 .0018 0 12.2813 ]
[-0.0125 .0983 -14.0625 -12.2813 ]
[-0.0125 .0983 0 12.2813 ]
[-0.0125 .1948 -29.125 -12.2813 ]
[-0.0125 .1948 0 12.2813 ]
[-0.0125 .29131 -29.125 -12.2813 ]
[-0.0125 .29131 0 12.2813 ]
[-0.0125 .38781 -29.125 -12.2813 ]
[-0.0125 .38781 0 12.2813 ]
[-0.0125 .48431 -29.125 -12.2813 ]
[-0.0125 .48431 0 12.2813 ]
[-0.0125 .58082 -14.0625 -12.2813 ]
[-0.0125 .58082 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -53.6875 -10.2188 ]
[-0.01875 .30902 -29.125 10.2188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.65238 .58082 -175.719 -13.0938 ]
[.65238 .58082 175.719 13.0938 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.375 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
75.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
84.813 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
97.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0018 m
.00625 .0018 L
s
gsave
-0.0125 .0018 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .0983 m
.00625 .0983 L
s
gsave
-0.0125 .0983 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .1948 m
.00625 .1948 L
s
gsave
-0.0125 .1948 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .29131 m
.00625 .29131 L
s
gsave
-0.0125 .29131 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .38781 m
.00625 .38781 L
s
gsave
-0.0125 .38781 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
0 .48431 m
.00625 .48431 L
s
gsave
-0.0125 .48431 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
0 .58082 m
.00625 .58082 L
s
gsave
-0.0125 .58082 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02592 m
.00375 .02592 L
s
0 .05005 m
.00375 .05005 L
s
0 .07418 m
.00375 .07418 L
s
0 .12243 m
.00375 .12243 L
s
0 .14655 m
.00375 .14655 L
s
0 .17068 m
.00375 .17068 L
s
0 .21893 m
.00375 .21893 L
s
0 .24306 m
.00375 .24306 L
s
0 .26718 m
.00375 .26718 L
s
0 .31543 m
.00375 .31543 L
s
0 .33956 m
.00375 .33956 L
s
0 .36368 m
.00375 .36368 L
s
0 .41194 m
.00375 .41194 L
s
0 .43606 m
.00375 .43606 L
s
0 .46019 m
.00375 .46019 L
s
0 .50844 m
.00375 .50844 L
s
0 .53256 m
.00375 .53256 L
s
0 .55669 m
.00375 .55669 L
s
0 .60494 m
.00375 .60494 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -112.625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.2188 16.2813 translate
90 rotate
-71.2188 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
71.875 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
79.438 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0018 m
1 .0018 L
s
.99375 .0983 m
1 .0983 L
s
.99375 .1948 m
1 .1948 L
s
.99375 .29131 m
1 .29131 L
s
.99375 .38781 m
1 .38781 L
s
.99375 .48431 m
1 .48431 L
s
.99375 .58082 m
1 .58082 L
s
.125 Mabswid
.99625 .02592 m
1 .02592 L
s
.99625 .05005 m
1 .05005 L
s
.99625 .07418 m
1 .07418 L
s
.99625 .12243 m
1 .12243 L
s
.99625 .14655 m
1 .14655 L
s
.99625 .17068 m
1 .17068 L
s
.99625 .21893 m
1 .21893 L
s
.99625 .24306 m
1 .24306 L
s
.99625 .26718 m
1 .26718 L
s
.99625 .31543 m
1 .31543 L
s
.99625 .33956 m
1 .33956 L
s
.99625 .36368 m
1 .36368 L
s
.99625 .41194 m
1 .41194 L
s
.99625 .43606 m
1 .43606 L
s
.99625 .46019 m
1 .46019 L
s
.99625 .50844 m
1 .50844 L
s
.99625 .53256 m
1 .53256 L
s
.99625 .55669 m
1 .55669 L
s
.99625 .60494 m
1 .60494 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .4452 m
.06244 .43601 L
.10458 .42597 L
.14415 .41655 L
.18221 .40749 L
.22272 .39784 L
.26171 .38856 L
.30316 .37869 L
.34309 .36918 L
.3815 .36004 L
.42237 .3503 L
.46172 .34094 L
.49955 .33193 L
.53984 .32233 L
.57861 .3131 L
.61984 .30329 L
.65954 .29383 L
.69774 .28474 L
.73838 .27506 L
.77751 .26574 L
.81909 .25584 L
.85916 .2463 L
.89771 .23712 L
.93871 .22736 L
.97619 .21843 L
s
.002 w
.15771 .34626 m
.15771 .46929 L
s
.015 w
.15771 .40778 Mdot
.002 w
.30762 .41491 m
.30762 .60332 L
s
.015 w
.30762 .50912 Mdot
.002 w
.47238 .01472 m
.47238 .22811 L
s
.015 w
.47238 .12141 Mdot
.002 w
.81924 .21262 m
.81924 .36721 L
s
.015 w
.81924 .28991 Mdot
gsave
.65238 .58082 -236.719 -17.0938 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
73.063 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
78.563 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
90.813 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(peak) show
117.938 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
130.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
143.125 26.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
159.063 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Correlation) show
255.188 23.000 moveto
(Coefficient) show
345.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
355.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
362.313 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
375.250 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.47) show
410.438 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{610, 377},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009R0001NB000`400?l00000o`00003oo`3ooooo
0?ooof@0oooo003o0?ooool0ooooI03oool00?l0ooooo`3ooomT0?ooo`00o`3ooooo0?ooof@0oooo
003o0?ooool0ooooI03oool00?l0ooooo`3ooomT0?ooo`00o`3ooooo0?ooof@0oooo003o0?ooodT0
oooo00@0okmd001d_`3oool0_g@01P0000001@18W=l0oooo0?ooo`2oM4P0W=oo0?l0oooo303oool0
0?l0ooooA`3oool0203o_g@000000000M02oool0oooo0?oo_`1d000007Bo0`3oool0203ogi`0M9cO
0?ooo`3oool0omnL04P0000004P0W=ooo`3oool:0?ooo`00o`3ooom50?ooo`040?noM00000000018
09cOo`@0oooo00<0omnL04P0001d_ol00P3oool00`3ooml0_koO0?ooo`030?ooo`040?oOW0180000
001809cOool0oooo203oool00?l0oooo@`3oool0103ogi`0B0000000B02Lgol70?ooo`030=nLB000
04P0W=oo00T0oooo00@0okmd0000000004P0W=ooo`3oool60?ooo`00o`3ooom10?ooo`040?oOW018
0000001809cOo`T0oooo00@0oooO09a80000B9`0gooo2P3oool0103o_g@000000000M02ooooo0?oo
o`@0oooo003o0?oood00oooo00<0_g@00000B02Lgol0303oool00`3ookl0M000001d_`0<0?ooo`03
0?noM0000000B9cO0?l0oooo0`3oool00?l0oooo@@3oool0103ogi`0B0000000B02Lgol70?ooo`07
0?oOW02L_ol0oooo0?ooo`3o_g@0000007Boo`090?ooo`040?noM0000000001d0;ooool0oooo103o
ool00?l0oooo@`3oool0103ogi`0B0000000B02Lgol50?ooo`030?oo_`2LW=l0oooo0080oooo00<0
_g@00000M02oool01P3oool0103o_g@000000000B02Lgooo0?ooo`H0oooo003o0?ooodD0oooo00@0
okmd0000000004P0W=oo0`3oool00`3ookl0M00000000004000000030018W03Oool0oooo0080oooo
00@0omnL04P0000004P0W=ooo`3oool80?ooo`00o`3ooom70?ooo`040?noM0000000001d0;ooo`/0
oooo00@0omnL04P0000004P0W=ooo`3oool:0?ooo`00o`3ooom90?ooo`030?noM000M;l0oooo00X0
oooo00<0_gA809cOo`3oool0o`3oool;0?ooo`00o`3ooooo0?ooof@0oooo003o0?ooool0ooooI03o
ool00?l0ooooo`3ooomT0?ooo`00o`3ooooo0?ooof@0oooo003o0?ooool0ooooI03oool00?l0oooo
o`3ooomT0?ooo`00o`3ooooo0?ooof@0oooo003o0?ooool0ooooI03oool00?l0ooooo`3ooomT0?oo
o`00o`3ooooo0?ooof@0oooo003o0?ooool0ooooI03oool00?l0ooooo`3ooomT0?ooo`00o`3ooooo
0?ooof@0oooo003o0?ooool0ooooI03oool005L0oooo00@0_g@0000000000000B9cOG@3oool00`3o
_g@000000000000200000003001d_`3oool0oooo05T0oooo00<0gia80000000000001@0000000`1d
_ol0oooo0?ooo`1H0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0H03oool00`3o
_g@0000007Boo`1K0?ooo`060;md00000000000000000000B9`0gooo6P3oool005D0oooo00L0oooO
09a80000M;l0oooo0?oog`2LB00007Bo05h0oooo00<0_g@00000M02oool0G@3oool00`3OW4P00000
0000000400000003001d_`3oool0oooo05P0oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B018
09cOof00oooo00<0okmd0000001d_ol0FP3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0
gooo01T0oooo001E0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0G@3oool00`2o
M000001d0;ooo`1N0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool0G`3oool00`3o
_g@004RL0=ooo`1O0?ooo`030?noM0000000M;oo0600oooo00<0omnL04Qd_`3oool0603oool005@0
oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`1M0?ooo`030;md000007@0_ooo
05l0oooo00<0gia804RLg`3oool0H`3oool00`3o_g@0001809cOo`1J0?ooo`030=nLB00000000000
00D0000000<0001809cOo`3oool0G@3oool00`3ookl0M01809cOo`0H0?ooo`00E03oool00`3ookl0
M000001d_`040?ooo`030;md000007@0_ooo05`0oooo00<0_g@00000M02oool0H03oool00`3OW4P0
M;oo0?ooo`1R0?ooo`030;md000004P0W=oo05X0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0
000007Boo`1P0?ooo`030?oo_`1d0000M;oo01P0oooo001D0?ooo`030?oOW0180000B9cO00@0oooo
00<0_g@00000M02oool0G03oool00`2oM000001d0;ooo`1P0?ooo`030?oog`2LB4P0W=oo0640oooo
00@0_g@00000000007@0_oooF`3oool01`3OW4P0M;oo0?ooo`3oool0okmd0000001d_ol0H03oool0
0`3o_g@0000007Boo`0H0?ooo`00E03oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo
05`0oooo00<0_g@00000M02oool0H@3oool00`3ogi`0B01d0;ooo`1M0?ooo`030?oo_`1d00000000
0080000000<0B9cO0?ooo`3oool0FP3oool01`3ookl0M01d0;ooo`3oool0okmd0000001d_ol0G`3o
ool0103ogi`0B0000000M02ooolH0?ooo`00E03oool00`3ogi`0B00004RLg`040?ooo`030=nLB000
04P0W=oo05`0oooo00<0_g@00000M02oool0HP3oool00`2oM000B9cO0?ooo`1N0?ooo`030?noM000
04P0W=oo05h0oooo00H0okmd001d_`3oool0okmd0000001d_omK0?ooo`040=oOg`3oool0oooo0;md
0080000000<0B9cO0?ooo`3oool05`3oool005@0oooo00<0oono07@00000M;l0103oool00`2oM000
001d0;ooo`1L0?ooo`030;md000007@0_ooo0680oooo00<0gia80000M02oool0G`3oool00`3ogi`0
B7Bo0?ooo`1N0?ooo`050;md001d_ol0okmd0000001d_ol0F`3oool00`3o_g@00000000000020000
0003001d_`3oool0oooo01P0oooo001E0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000
M;l0G@3oool00`2oM000001d0;ooo`1R0?ooo`030?noM0000000M;oo05l0oooo00<0oooO09a80018
W=l0GP3oool01@3ookl0M01d0;noM0000000M;oo05/0oooo00D0oooO09a800000000001d0;ooo`0K
0?ooo`00E@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo05d0oooo00<0_g@00000
M02oool0G03oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo05X0oooo00<0oooO09ad
W03Oool00P3oool00`3ooml0W4P0001d_`1O0?ooo`040?noM0000000000007Booe`0oooo00<0okmd
001d_`3oool0703oool005H0oooo00H0_g@00018W03Oool0oooo0;md0000M;mL0?ooo`050=nLB000
000000000000M02oool0G@3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0goooF`3oool0
1`3ogi`0B4RL0=ooo`3oool0gia80000001d_ol0G`3oool0103ooml0W4P00000001d_omL0?ooo`03
0?oog`2LB00000000080000000<0001d0;ooo`3oool05`3oool005L0oooo00@0_g@0000000000000
07BoGP3oool0103ookl0M0000000M02ooomN0?ooo`050;md00000000000000000000M;l0GP3oool0
1@3ogi`0B000000000000000B9cO0640oooo00<0omnL04P0001d_ol0G@3oool00`3o_g@000000000
00020000000307Boo`3oool0oooo01H0oooo003o0?ooool0ooooI03oool00?l0ooooo`3ooomT0?oo
o`00o`3ooooo0?ooof@0oooo003o0?ooool0ooooI03oool00?l0ooooo`3ooomT0?ooo`00o`3ooooo
0?ooof@0oooo000^0?ooo`040;md00000000000004RLg`@0oooo00<0gia800000018W=l00`3oool0
1P3ogi`0B000000000000000001809cOool0ooooo`3ooolR0?ooo`00;03oool01`3ooml0W4P0001d
_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`080?oOW018000004RL0=oo
o`3oool0omnL04P0001d_ooo0?ooool0oooo8@3oool002`0oooo00<0okmd0000B02Lgol00P3oool0
0`3ogi`0B00007Boo`070?ooo`030;md000007@0_ooo00<0oooo00<0gia80018W03Oool0o`3ooooo
0?ooob00oooo000[0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l01`3oool0
0`2oM000001d0;ooo`030?ooo`030;md0000B9`0gooo0?l0ooooo`3ooolP0?ooo`00:`3oool00`3o
okl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo00<0okmd0000B02Lgol00P3oool00`3O
W4P00000001d_`3o0?ooool0oooo8@3oool002/0oooo00<0omnL04P00018W=l0103oool00`2oM000
001d0;ooo`070?ooo`070=nLB000M;l0oooo0;md00000000001d0;ooo`090?ooool00000o`00000:
000000h0oooo000[0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0203oool01@3o
_g@0000000000000B9`0gooo00X0oooo1@0000080?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01P3oool4000000h0oooo000[0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000
B02Lgol01`3oool01@3ogi`0B000000000000000B9cO00/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool0
02/0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`070?oOW01800000018
09cOo`3oool0gia8001d_`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303o
ool002`0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`070?ooo`030=nLB00004P0
W=oo0080oooo00<0oooO09a8001d_ol02@3oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool0
0`000000oooo0?ooo`0<0?ooo`00;03oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo
00L0oooo00<0gia80018W03Oool00P3oool00`3ooml0W4P004RLg`090?ooo`030000003oool0oooo
0?l0ooooo`3oool60?ooo`030000003oool0oooo00`0oooo000]0?ooo`060;md0000B9`0gooo0?oo
o`2oM00007Bo203oool00`3ogi`0B00004RLg`020?ooo`030?noM00004P0W=oo00T0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0303oool002h0oooo00@0_g@00000
0000000007Bo2P3oool01P3ookl0M000000000000000001809cOo`X0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0lP3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool004`0oooo00<00000
0?ooo`3oool0lP3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool0
04`0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool0303oool004`0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0lP3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0lP3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool004`0oooo0`00003b
0?ooo`030000003oool0oooo0?l0oooo3P3oool3000000h0oooo001<0?ooo`030000003oool0oooo
0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo001<0?ooo`03
0000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0
oooo001<0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?80oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo
0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo001<0?ooo`03
0000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0
oooo001<0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?80oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo
0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo001<0?ooo`<0
0000lP3oool00`000000oooo0?ooo`3o0?ooo`h0oooo0`00000>0?ooo`00C03oool00`000000oooo
0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03o
ool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo
0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03o
ool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo
0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03o
ool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`0<0?ooo`00C03oool300000?80oooo00<000000?ooo`3oool0o`3oool>0?ooo`<000003P3oool0
04`0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool0303oool004`0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0lP3oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0lP3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool004`0oooo00<00000
0?ooo`3oool0lP3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool0
03`0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`080?ooo`030000003oool0oooo
0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo000n0?ooo`03
0;md000007@0_ooo00/0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?ooo`3o0?oooa00
oooo00<000000?ooo`3oool0303oool003h0oooo00<0_g@00000M02oool02`3oool00`000000oooo
0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00?P3o
ool00`2oM000001d0;ooo`0;0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00`0oooo000n0?ooo`030;md000007@0_ooo00/0oooo00<00000
0?ooo`3oool0lP3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool0
03h0oooo00<0_g@00000M02oool02`3oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00?P3oool00`2oM000001d0;ooo`0;0?ooo`D0
0000l03oool00`000000oooo0?ooo`3o0?ooo`d0oooo1000000>0?ooo`00?P3oool00`2oM000001d
0;ooo`0;0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo00`0oooo000n0?ooo`030;md000007@0_ooo00/0oooo00<000000?ooo`3oool0lP3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool003h0oooo00<0_g@0
0000M02oool02`3oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`0<0?ooo`00?P3oool00`2oM000001d0;ooo`0;0?ooo`030000003oool0oooo
0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo000l0?ooo`05
0=nLB000000000000000M02oool02`3oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00?@3oool0103ookl0M0000000M02oool;0?oo
o`030000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00`0oooo001<0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?40oooo0`00
003o0?oooa40oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0l03oool5
00000?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3_0?oo
o`L00000o`3oool?0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0>l0
oooo1`00003o0?ooo`l0oooo00<000000?ooo`3oool0303oool004`0oooo0`00003_0?ooo`L00000
o`3oool=0?ooo`<000003P3oool004`0oooo00<000000?ooo`3oool0l03oool500000?l0oooo403o
ool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3a0?ooo`<00000o`3ooolA
0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?80oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?80
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000
003oool0oooo0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo
001<0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?80oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?80
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000
003oool0oooo0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo
001<0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00`0oooo001<0?ooo`<00000lP3oool00`000000oooo0?ooo`3o0?ooo`h0oooo0`00000>
0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?oo
o`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03oool0
0`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<
0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?oo
o`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03oool0
0`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<
0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`0<0?ooo`00C03oool300000?80oooo00<000000?ooo`3oool0
o`3oool>0?ooo`<000003P3oool004`0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0lP3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?oo
o`3oool0lP3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool004`0
oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool0303oool004`0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool0303oool002d0oooo00<0okmd0000000000000P0000002@00M;l0oooo0?oo
o`3oool0gia800000018W=l0oooo0=nLB0070000000307Boo`3oool0oooo00L0oooo00<000000?oo
o`3oool0lP3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool002l0
oooo00<0_g@00000M02oool0103oool00`3OW4P0000004RLg`020?ooo`030=nLB0000000000000@0
000000<007Bo0?ooo`3oool01`3oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`0<0?ooo`00;`3oool00`2oM000001d0;ooo`0:0?ooo`030=nL
B018W=l0oooo0080oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`3b0?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00;`3oool00`2oM000001d0;oo
o`0;0?ooo`030=nLB018W=l0oooo00`0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool0303oool002l0oooo00<0_g@00000M02oool0303oool0
0`3OW4P0M;oo0?ooo`0;0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00`0oooo000_0?ooo`030;md000007@0_ooo00`0oooo00<0oooO09a8
B02Lgol02`3oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`0<0?ooo`00;`3oool00`2oM000001d0;ooo`0=0?ooo`030?oOW01807@0_ooo00X0
oooo1@00003`0?ooo`030000003oool0oooo0?l0oooo3@3oool4000000h0oooo000_0?ooo`030;md
000007@0_ooo00h0oooo00<0_g@004RLg`3oool02@3oool00`000000oooo0?ooo`3b0?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00;`3oool00`2oM000001d0;oo
o`0>0?ooo`030=nLB00007@0_ooo00T0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool0303oool002l0oooo00<0_g@00000M02oool03P3oool0
0`3o_g@0000007Boo`090?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00`0oooo000_0?ooo`030;md000007@0_ooo00P0oooo00<0omnL09bo
o`3oool00`3oool00`2oM000000007Boo`090?ooo`030000003oool0oooo0?80oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo000]0?ooo`050=nLB000000000000000
M02oool02@3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo2@3oool00`000000oooo
0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00;P3o
ool0103ookl0M0000000M02oool:0?ooo`050;md00000000000000000000M;l02`3oool00`000000
oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00
C03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0
oooo0;40oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`00
0000oooo0?ooo`3b0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo0;40
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo
0?ooo`3b0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0CP3oool2000000/0oooo
00<000000?ooo`3oool0303oool004`0oooo0`00003b0?ooo`030000003oool0oooo0;40oooo00<0
00000?ooo`3oool0BP3oool4000000/0oooo0`00000>0?ooo`00C03oool00`000000oooo0?ooo`3b
0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0AP3oool400000140oooo00<00000
0?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?ooo`2a0?oo
o`030000003oool0oooo0480oooo1000000E0?ooo`030000003oool0oooo00`0oooo001<0?ooo`03
0000003oool0oooo0?80oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0n0?ooo`@0
00006@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3b0?ooo`030000
003oool0oooo0;40oooo00<000000?ooo`3oool0>@3oool5000001d0oooo00<000000?ooo`3oool0
303oool004`0oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo03D0oooo1000
000R0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooY`3oool0
0`000000oooo0?ooo`0a0?ooo`@000009P3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`00
0000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool0;@3oool4000002X0oooo00<000000?oo
o`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo02T0
oooo1000000^0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0oooo
Y`3oool00`000000oooo0?ooo`0U0?ooo`@00000<P3oool00`000000oooo0?ooo`0<0?ooo`00C03o
ool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool08@3oool4000003H0oooo00<0
00000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0
oooo01d0oooo1000000j0?ooo`030000003oool0oooo00`0oooo001<0?ooo`<00000o`3ooonW0?oo
o`030000003oool0oooo01T0oooo1000000l0?ooo`<000003P3oool004`0oooo00<000000?ooo`3o
ool0o`3ooonW0?ooo`030000003oool0oooo01D0oooo100000120?ooo`030000003oool0oooo00`0
oooo001<0?ooo`030000003oool0oooo0?l0ooooY`3oool00`000000oooo0?ooo`0@0?ooo`D00000
AP3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooojL0oooo00<0
00000?ooo`3oool0303oool4000004/0oooo00<000000?ooo`3oool0303oool004`0oooo00<00000
0?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00P0oooo1000001?0?ooo`030000003oool0
oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooY`3oool00`000000oooo0?ooo`040?oo
o`@00000D`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooojL0
oooo00<000000?ooo`3oool01000001G0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000
003oool0oooo0?l0ooooY@3oool5000005/0oooo00<000000?ooo`3oool0303oool004`0oooo00<0
00000?ooo`3oool0o`3ooonQ0?ooo`@000000P3oool00`000000oooo0?ooo`1K0?ooo`030000003o
ool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooW@3oool4000000H0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?oo
oiT0oooo1000000:0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0303oool004`0
oooo00<000000?ooo`3oool0o`3ooonE0?ooo`@000003P3oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooT03oool500000180oooo
00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool300000?l0ooooS03o
ool4000001L0oooo00<000000?ooo`3oool0F@3oool3000000h0oooo001<0?ooo`030000003oool0
oooo0?l0ooooR03oool4000001/0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0<
0?ooo`00C03oool00`000000oooo0?ooo`3o0?oooh@0oooo1000000O0?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooon00?ooo`@0
00008`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000
003oool0oooo0?l0ooooN`3oool5000002L0oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooogL0oooo1000000/0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0303oool002d0oooo00<0okmd0000000000000P000000
1`00M;l0oooo0?ooo`3oool0gia800000018W=l01P3oool00`3o_g@0000007Boo`0:0?ooo`030000
003oool0oooo0?l0ooooL`3oool400000300oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`0<0?ooo`00;`3oool00`2oM000001d0;ooo`040?ooo`030=nLB0000000B9cO00H0oooo00<0
okmd0000001d_ol02P3oool00`000000oooo0?ooo`3o0?ooofl0oooo1000000d0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0303oool002l0oooo00<0_g@00000M02oool03@3oool0
0`3o_g@0000007Boo`0:0?ooo`030000003oool0oooo0?l0ooooJ`3oool4000003P0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0<0?ooo`00;`3oool00`2oM000001d0;ooo`080?oo
o`030=nLB0000000000000D0000000<0001809cOo`3oool01`3oool00`000000oooo0?ooo`3o0?oo
ofH0oooo1@00000k0?ooo`<00000G03oool00`000000oooo0?ooo`0<0?ooo`00;`3oool00`2oM000
001d0;ooo`080?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000001d_ol02P3oool00`000000
oooo0?ooo`3o0?ooof40oooo1@00000o0?ooo`D00000F`3oool00`000000oooo0?ooo`0<0?ooo`00
;`3oool00`2oM000001d0;ooo`090?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@0000007Boo`0:0?oo
o`030000003oool0oooo0?l0ooooG03oool5000004<0oooo1`00001J0?ooo`030000003oool0oooo
00`0oooo000_0?ooo`030;md000007@0_ooo00T0oooo00L0oono07@0M02oool0oooo0?noM0000000
M;oo00X0oooo1@00003o0?oooeD0oooo1@0000180?ooo`L00000E`3oool4000000h0oooo000_0?oo
o`030;md000007@0_ooo00X0oooo00H0okmd001d_`3oool0okmd0000001d_ol:0?ooo`030000003o
ool0oooo0?l0ooooD`3oool4000004d0oooo1`00001J0?ooo`030000003oool0oooo00`0oooo000_
0?ooo`030;md000007@0_ooo00/0oooo00D0_g@007Boo`3o_g@0000007Boo`0:0?ooo`030000003o
ool0oooo0?l0ooooC`3oool400000580oooo1@00001K0?ooo`030000003oool0oooo00`0oooo000G
0?ooo`060?oOW018000004RL0=ooo`3oool0_g@00P0000000`1d_ol0oooo0?ooo`0=0?ooo`030;md
000007@0_ooo00/0oooo00D0oono07@0M02o_g@0000007Boo`0:0?ooo`030000003oool0oooo0?l0
ooooB`3oool4000005L0oooo0`00001L0?ooo`030000003oool0oooo00`0oooo000F0?ooo`060?oo
g`2LB00000000018W03Oool0gia80`0000000`00B9`0gooo0?ooo`0=0?ooo`030;md000007@0_ooo
00`0oooo00@0okmd000000000000M;oo2P3oool00`000000oooo0?ooo`3o0?ooodL0oooo1000001L
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0303oool001H0oooo00/0omnL07BL
g`3oool0oooo0?oo_`1d07@0_ooo0?ooo`3OW4P0001d0;ooo`0<0?ooo`050=nLB000000000000000
M02oool0303oool0103ooml0W4P00000001d_ol:0?ooo`030000003oool0oooo0?l0oooo@`3oool4
00000600oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0<0?ooo`005P3oool01P3o
_g@0M;oo0?ooo`3oool0gia807Boo`80oooo00<0omnL04Qd_`3oool03@3oool0103ookl0M0000000
M02oool=0?ooo`030?oOW0180000M;oo00X0oooo00<000000?ooo`3oool0o`3oooln0?ooo`D00000
I03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00`0oooo000F0?ooo`060?noM000
M;l0oooo0?oog`2LM9`0gooo0P3oool00`2oM7@0_ooo0?ooo`0[0?ooo`030000003oool0oooo0?l0
oooo>P3oool4000006T0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0<0?ooo`00
5P3oool00`3ookl0M0000000000600000003001d_`3oool0oooo02X0oooo00<000000?ooo`3oool0
o`3ooolf0?ooo`@00000K@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00`0oooo
000G0?ooo`030=nLB0000000000000D0000000<0001d0;ooo`3oool0:P3oool00`000000oooo0?oo
o`3o0?oooc40oooo1@00001a0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0303o
ool001h0oooo00<0okmd001d_`3oool0:`3oool00`000000oooo0?ooo`3o0?ooobd0oooo1000001f
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0303oool001d0oooo00<0oooO09a8
M02oool0;03oool00`000000oooo0?ooo`3o0?ooobT0oooo1000001j0?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`@0
0000OP3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00`0oooo000I0?ooo`030?oo
g`2LM9`0gooo00H0oooo00<0gibL0;ooo`3oool09`3oool300000?l0oooo8@3oool400000880oooo
00<000000?ooo`3oool0F@3oool3000000h0oooo000I0?ooo`030?noM0000000000000H0000000<0
001d0;ooo`3oool09`3oool00`000000oooo0?ooo`3o0?oooad0oooo100000260?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0303oool00280oooo00<0gibL0;ooo`3oool09`3oool0
0`000000oooo0?ooo`3o0?oooaT0oooo1000002:0?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`D00000SP3oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0
oooo403oool4000009<0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0<0?ooo`00
C03oool00`000000oooo0?ooo`3o0?ooo``0oooo1000002G0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3oool80?ooo`@00000V`3o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0
oooo0?l0oooo103oool4000009l0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0<
0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooo`@00000X`3oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?/0oooo1000002W0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0
m`3oool400000:/0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0<0?ooo`00C03o
ool00`000000oooo0?ooo`3c0?ooo`@00000[`3oool00`000000oooo0?ooo`1K0?ooo`030000003o
ool0oooo00`0oooo001<0?ooo`<00000k`3oool400000;<0oooo00<000000?ooo`3oool0F@3oool3
000000h0oooo001<0?ooo`030000003oool0oooo0>/0oooo1000002g0?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0i`3oool400000;/0
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo
0?ooo`3S0?ooo`@00000_`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00`0oooo
001<0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0S@3oool400000<<0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo08T0oooo100000370?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`240?oo
o`D00000b`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00`0oooo001<0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0P03oool400000=00oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo07`0oooo1000003D0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
303oool004`0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1h0?ooo`@00000f03o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool0M03oool400000=`0oooo00<000000?ooo`3oool0F`3oool0
0`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
06l0oooo1@00003P0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0303oool004`0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1Z0?ooo`D00000i@3oool00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo00`0oooo001<0?ooo`<00000C`3oool00`000000oooo
0?ooo`1U0?ooo`D00000jP3oool00`000000oooo0?ooo`1I0?ooo`<000003P3oool004`0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`1P0?ooo`D00000k`3oool00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool0G03oool400000?l0ooooD`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo05P0oooo1000003o0?oooeL0oooo00<000000?oo
o`3oool0303oool004`0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1D0?ooo`@0
0000o`3ooomK0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool0D03oool400000?l0ooooG`3oool00`000000oooo0?ooo`0<0?ooo`00;@3o
ool00`3o_g@000000000000200000007001d_`3oool0oooo0?ooo`3OW4P0000004RLg`030?ooo`06
0?oog`2LB00000000000000007@0_ooo2P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo04`0oooo1000003o0?ooof<0oooo00<000000?ooo`3oool0303oool002l0oooo00<0_g@00000
M02oool0103oool00`3OW4P0000004RLg`020?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000
B02Lgol90?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0B03oool400000?l0oooo
I`3oool00`000000oooo0?ooo`0<0?ooo`00;`3oool00`2oM000001d0;ooo`090?ooo`030;md0000
07@0_ooo00<0oooo00<0_g@0001d_`3oool0203oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo04@0oooo1000003o0?ooof/0oooo00<000000?ooo`3oool0303oool002l0oooo00<0_g@0
0000M02oool0203oool00`3ookl0M000001d_`040?ooo`030=nLB00007@0_ooo00P0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`100?ooo`@00000o`3ooom_0?ooo`030000003oool0
oooo00`0oooo000_0?ooo`030;md000007@0_ooo00P0oooo00<0omnL04P00018W=l0103oool00`2o
M000001809cOo`080?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0?@3oool30000
0?l0ooooL`3oool00`000000oooo0?ooo`0<0?ooo`00;`3oool00`2oM000001d0;ooo`080?ooo`03
0?oOW0180000B9cO00<0oooo00@0oono07@0000007@0_ooo203oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo03T0oooo1000003o0?ooogH0oooo00<000000?ooo`3oool0303oool002l0
oooo00<0_g@00000M02oool0203oool02@3ookl0M00000000000B9`0gooo0?ooo`2oM000000004RL
g`090?ooo`D00000C@3oool00`000000oooo0?ooo`0e0?ooo`@00000o`3ooomg0?ooo`@000003P3o
ool002l0oooo00<0_g@00000M02oool0203oool01@3ooml0W4P00000M02ogi`0B0000080000000<0
B9cO0?ooo`3oool0203oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0340oooo1000
003o0?ooogh0oooo00<000000?ooo`3oool0303oool002l0oooo00<0_g@00000M02oool02@3oool0
0`3o_g@0000004RLg`0>0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0;03oool5
00000?l0ooooPP3oool00`000000oooo0?ooo`0<0?ooo`00;`3oool00`2oM000001d0;ooo`090?oo
o`040?oog`2LB000001809cOo`d0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0W
0?ooo`D00000o`3ooon70?ooo`030000003oool0oooo00`0oooo000_0?ooo`030;md000007@0_ooo
00X0oooo00@0oono07@0000007@0_ooo303oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0280oooo1@00003o0?oooh`0oooo00<000000?ooo`3oool0303oool002d0oooo00D0gia80000
00000000001d0;ooo`0;0?ooo`040?oog`2LB0000000001d_`/0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0M0?ooo`D00000o`3ooonA0?ooo`030000003oool0oooo00`0oooo000^
0?ooo`040?oo_`1d0000001d0;ooo`d0oooo00D0omnL04P00000000004RL0=ooo`080?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool06@3oool400000?l0ooooUP3oool00`000000oooo
0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo01D0oooo1000
003o0?oooiX0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0CP3oool3
00000180oooo1000003o0?oooih0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?oo
o`3oool0C@3oool5000000d0oooo1000003o0?oooj80oooo00<000000?ooo`3oool0303oool004`0
oooo00<000000?ooo`3oool0C03oool7000000P0oooo1000003o0?ooojH0oooo00<000000?ooo`3o
ool0303oool004`0oooo00<000000?ooo`3oool0C03oool7000000@0oooo1000003o0?ooojX0oooo
00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0C03oool;00000?l0oooo[P3o
ool00`000000oooo0?ooo`0<0?ooo`00C03oool3000004d0oooo1P00003o0?oook00oooo0`00000>
0?ooo`00C03oool00`000000oooo0?ooo`1;0?ooo`H00000C03oool00`000000oooo0?ooo`3o0?oo
ofD0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0A`3oool4000000@0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3o
ool0303oool004`0oooo00<000000?ooo`3oool0@`3oool4000000P0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool0303oool004`0oooo00<0
00000?ooo`3oool0?`3oool4000000`0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`3o0?ooofD0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0>`3oool4
00000100oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<00000
0?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0=`3oool4000001@0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool0303oool004`0
oooo00<000000?ooo`3oool0<P3oool5000001P0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0
;P3oool4000001d0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooofD0oooo
00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0:P3oool400000240oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool0303o
ool004`0oooo00<000000?ooo`3oool09@3oool5000002D0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?oo
o`3oool08@3oool4000002X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?oo
ofD0oooo00<000000?ooo`3oool0303oool004`0oooo0`00000M0?ooo`@00000;P3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0ooooH`3oool3000000h0oooo001<0?ooo`030000
003oool0oooo01T0oooo1000000b0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
o`3ooomU0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo01D0oooo1000
000f0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003o
ool0oooo00`0oooo001<0?ooo`030000003oool0oooo0140oooo1000000j0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo00`0oooo001<0?oo
o`030000003oool0oooo00d0oooo1000000n0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0o`3ooomU0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo00X0
oooo0`0000120?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`03
0000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool0303oool004`0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0ooooI@3o
ool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo00`0oooo001<0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?oo
ofD0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00
C03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
o`3ooomU0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool0303o
ool004`0oooo0`00001?0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooomS
0?ooo`<000003P3oool004`0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo0?l0ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`03
0000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool0303oool004`0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0ooooI@3o
ool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`2M0?ooo`030000003oool0
oooo0?l0ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00;@3oool00`3o_g@00000000000020000
0007001d_`3oool0oooo0?ooo`3OW4P0000004RLg`030?ooo`060?oOW018000000000000000004P0
W=oo2P3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0?l0ooooI@3oool00`000000
oooo0?ooo`0<0?ooo`00;`3oool00`2oM000001d0;ooo`040?ooo`030=nLB0000000B9cO0080oooo
00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B00007Boo`T0oooo00<000000?ooo`3oool0W@3oool0
0`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool0303oool002l0oooo00<0_g@00000
M02oool02@3oool00`2oM000001d0;ooo`030?ooo`030=nLB000B9`0gooo00P0oooo00<000000?oo
o`3oool0W@3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool0303oool002l0
oooo00<0_g@00000M02oool02@3oool00`2oM000001d0;ooo`030?ooo`030;md0000B9`0gooo00P0
oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3o
ool0303oool002l0oooo00<0_g@00000M02oool02@3oool00`3o_g@0001809cOo`020?ooo`030=nL
B000000007Bo00T0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`3o0?ooofD0oooo
00<000000?ooo`3oool0303oool002l0oooo00<0_g@00000M02oool02P3oool01`3OW4P007Bo0?oo
o`2oM00000000000M02oool02@3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0?l0
ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00;`3oool00`2oM000001d0;ooo`0;0?ooo`050?no
M000000000000018W03Oool02P3oool5000009/0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`@0
00003P3oool002l0oooo00<0_g@00000M02oool02P3oool01@3ogi`0B000000000000000B9cO00/0
oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3o
ool0303oool002l0oooo00<0_g@00000M02oool02@3oool01`3ogi`0B0000000B02Lgol0oooo0=nL
B000M;l02P3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0?l0ooooI@3oool00`00
0000oooo0?ooo`0<0?ooo`00;`3oool00`2oM000001d0;ooo`090?ooo`030=nLB00004P0W=oo0080
oooo00<0oooO09a8001d_ol02@3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0?l0
ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00;`3oool00`2oM000001d0;ooo`090?ooo`030=nL
B000B9`0gooo0080oooo00<0oooO09a80018W=l02@3oool00`000000oooo0?ooo`2M0?ooo`030000
003oool0oooo0?l0ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00;@3oool01@3OW4P000000000
000007@0_ooo00T0oooo00<0omnL04P00018W=l00P3oool00`3o_g@0001809cOo`090?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo00`0oooo
000^0?ooo`040?oo_`1d0000001d0;ooo`X0oooo00H0oono07@00000000000000000B02Lgol:0?oo
o`030000003oool0oooo09d0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo
00`0oooo001<0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`03
0000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0
o`3ooomU0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0
oooo09`0oooo0`00003o0?ooofH0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?oo
o`3oool0V`3oool500000?l0ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000
oooo0?ooo`2J0?ooo`L00000o`3ooomT0?ooo`030000003oool0oooo00`0oooo001<0?ooo`<00000
VP3oool700000?l0ooooHP3oool3000000h0oooo001<0?ooo`030000003oool0oooo09X0oooo1`00
003o0?ooof@0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0V`3oool5
00000?l0ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`2L0?oo
o`<00000o`3ooomV0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo09d0
oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo00`0oooo
001<0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003o
ool0oooo00`0oooo001<0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0o`3ooomU
0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo09d0oooo00<000000?oo
o`3oool0o`3ooomU0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo09d0
oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo00`0oooo
001<0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003o
ool0oooo00`0oooo001<0?ooo`<00000W@3oool00`000000oooo0?ooo`3o0?ooof<0oooo0`00000>
0?ooo`00C03oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0?l0ooooI@3oool00`00
0000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0?l0
ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`2M0?ooo`030000
003oool0oooo0?l0ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?oo
o`2M0?ooo`030000003oool0oooo0?l0ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool0
0`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0?l0ooooI@3oool00`000000oooo0?ooo`0<
0?ooo`00C03oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0?l0ooooI@3oool00`00
0000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0?l0
ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`2M0?ooo`030000
003oool0oooo0?l0ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?oo
o`2M0?ooo`030000003oool0oooo0?l0ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool0
0`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0?l0ooooI@3oool00`000000oooo0?ooo`0<
0?ooo`00C03oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0?l0ooooI@3oool00`00
0000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0?l0
ooooI@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool3000009d0oooo00<000000?ooo`3oool0
o`3ooomS0?ooo`<000003P3oool004`0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?oo
o`0M0?ooo`050?oog`2LB00000000000B02Lgol0<@3oool00`3o_g@007Bo0?ooo`3o0?ooo`l0oooo
00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?oo
o`0N0?ooo`030?oo_`1d04P0W=oo0380oooo00<0oono07@0B02Lgol0o`3oool?0?ooo`030000003o
ool0oooo00`0oooo001<0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool07P3oool0
0`3ookl0M01809cOo`0c0?ooo`030=nLB018W=l0oooo0?l0oooo3P3oool00`000000oooo0?ooo`0<
0?ooo`00C03oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo01h0oooo00H0oono07@0
0000000000000000B02Lgol20?ooo`0C0?noM0000000000004RLg`3oool0oono07@0000000000018
04Q8000004P0B4P00000000004P0W=oO09a80000000004RL0=ooo`0K0?ooo`030?oog`2LM9`0gooo
0?l0oooo3P3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`2M0?ooo`03
0000003oool0oooo01h0oooo01T0oono07@00018W=l0oooo0?noM00007@0_ooo0?oOW0180000M;oo
0?ooo`3OW7@0W=oo0=nLB000B9`0gooo0?oo_`1d04P0W=oo0?oog`2LB000M;oo0?oo_`1d0000M;oo
01d0oooo00<0oooO09a8001d_ol0o`3oool>0?ooo`030000003oool0oooo00`0oooo000j0?ooo`03
0=nLB0000000000000D0000000<0M;oo0?ooo`3oool01`3oool00`000000oooo0?ooo`2M0?ooo`03
0000003oool0oooo01h0oooo00T0oono07@0B02Lgol0oooo0?oog`2LB000M;oo0=nLB000M;l00P3o
ool03@3ookl0M7Bo0?oo_`1d000007Bo0?oo_`1d04P0W=oo0?oog`2LB000M;oo0;md0000M;l07P3o
ool0103ooml0W4Qd07AdM02ooooo0?ooo`d0oooo00<000000?ooo`3oool0303oool003/0oooo00<0
gia8000000000000100000000`00M;l0oooo0?ooo`070?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0103oool00`3o_g@000000000000200000009001d_`3oool0oooo0?ooo`3ooml0
W4P00000B02Lgml0W4P000T0000000`007Bo0?ooo`3oool0oono07@0B02Lgol0oooo0?oog`2LB000
B9cO0=nLB018W=l60?ooo`090?noM0000000001809cOo`3ooml0W4P00000000007@0_ooo00l0oooo
00<0oooO09a800000000200000002000M;l0oooo0?ooo`3oool0oooO09a8M02ogi`0M9cO3P3oool0
0`2oM000000000000002000000030000M02oool0oooo00<0oooo00H0omnL04P00000000000000000
M02oool20?ooo`050=nLB0000000000000000000M;l00P3oool01@3OW4P0000000000000000007Bo
00@0oooo00D0omnL04P0000000000000001d_`020?ooo`080?oo_`1d000000000000000004P0W=oo
0?ooo`2oM0020000000<0000B02Lgkl0M00000000000M;l0oooo0?oo_`1d000000000018W03Ookl0
M0000P0000001P0004P0W=oo0?ooo`3oool0omnL04P00080000000D0001d0;ooo`3oool0oooo0;md
00030000000607Bo_`1d000000000000000007@0_ooo203oool00`2oM00000000000000200000003
0000M02oool0oooo00<0oooo00H0omnL04P00000000000000000M02oool40?ooo`050?oOW0180000
000000000000M;l00P3oool00`3o_g@0000000000002000000030018W03O_g@0000000<0000000<0
04RL0=oo_`1d00000P0000001@0004P0W=oo0?ooo`3oool0okmd00<0000000D004RL0=ooo`3oool0
oono07@00002000000060000B02Lgol0oooo0?ooo`3ogi`0B0000P0000001000M;l0oooo0?ooo`2o
M0030000000;07Bo_`1d000000000000000007@0_ooo0?oo_`1d000000000018W03Oool00P3oool0
103ooml0W4P00000B02Lgol60?ooo`050=nLB0000000000000000000M;l04@3oool0102oM0000000
00000018W=l40?ooo`030=nLB0000000B9cO00H0oooo00<0okmd0000001d_ol01@3oool00`3ogi`0
B01d0;ooo`0;0?ooo`030000003oool0oooo00`0oooo000l0?ooo`030=nLB018W=l0oooo0080oooo
00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00H0oooo
00<0_g@00000M02oool0103oool02@3ooml0W4P00000B02Lgol0oooo0?oo_`1d000004RL0=ooo`04
0?ooo`0<0?noM00007@0_ooo0?ooo`3ookl0M01809cOo`3oool0oooO09a80018W=l0gia810000000
3000M;l0oooo0?ooo`3oool0oono07@0B02Lgol0oooO09a8001d_ml0W4P007Booa40oooo00@0oono
07@00000B9`0gooo103oool00`3o_g@0001d0;ooo`020?ooo`050?oo_`1d07@0_ooO09a8B02Lgol0
2`3oool0103o_g@000000000001d_ol30?ooo`030?oo_`1d0000M;oo0080oooo00P0okmd00000000
B9`0gooo0?ooo`3o_g@0001809cOo`80oooo00<0okmd0000001d_ol0103oool00`3o_g@0000007Bo
o`040?ooo`0Q0?noM0000000001809cOo`3oool0gia80018W03Oool0oooo0?oog`2LB00004RL0=oo
o`3oool0okmd00000000M;l0oooo0?oog`2LB000000004RLg`3o_kl0_ooo0=nLB00004P0W=oo0?oO
W02L_ol0oooo0;md000007@0_ooo0080oooo00P0okmd00000000B9`0gooo0?ooo`3o_g@0001809cO
o`80oooo00P0gia80000B02Lgol0oooo0?oog`2LB00004RL0=ooo`L0oooo00@0okmd000000000000
M;oo0`3oool00`3ookl0M00007Boo`020?ooo`080?noM000000004RL0=ooo`3oool0okmd0000B02L
gol20?ooo`0=0?noM0000000001809cOo`3oool0gia80018W03Oool0oooo0?oog`2LB000001d0;oo
o`020?ooo`040?oog`2LB000001d0;ooo`<0oooo00<0_g@00000M02oool00P3oool00`3OW4P00000
00000003000000070018W03Oool0oooo0?ooo`2oM000001d0;ooo`020?ooo`0G0?noM00000000018
09cOo`3oool0gia80018W03Oool0oooo0=nLB00004P0W=oo0?ooo`3ooml0W4P00018W03Oool0oooo
0=nLB00004P0W=oo0?oOW02L_ol00P3oool0103ooml0W4P00000B02Lgol70?ooo`030?noM0000000
M;oo0100oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l0
1P3oool00`3o_g@0000007Boo`060?ooo`030;md001d_ol0oooo00X0oooo00<000000?ooo`3oool0
303oool003d0oooo00<0gia804RLg`3oool0303oool00`000000oooo0?ooo`2M0?ooo`030000003o
ool0oooo00H0oooo00<0_g@00000M02oool02@3oool0103ookl0M0000018W03Oool50?ooo`0L0?no
M018W=l0oono07@000000000001d0;ooo`3o_g@0001809cOo`3ookl0M4RL0=ooo`3ooml0W4P007Bo
o`3ogi`0B01d0;ooo`3ogi`0B01809cOo`3ooml0W4P007Boo`3oool0_gA809cOoa00oooo00@0oono
07@00000B9`0gooo1@3oool02@3o_g@0B9bW07A8W03Oool0okmd001d_`3oool0okmd001d_`0:0?oo
o`040?oOW0180000001809cOo`H0oooo00H0_gA809cOo`3ooml0W4P00000B02Lgol30?ooo`070;md
0000B9`0gooo0?ooo`3o_g@0000007Boo`040?ooo`030?noM0000000M;oo00<0oooo00@0oono07@0
0000B9`0gooo0`3oool02`3o_g@0M;oo0?ooo`3ooml0W4P00018W03Oool0oooo0?noM0000000M;oo
0080oooo00<0omnL04P00018W=l00P3oool00`3OW4P0001809cOo`030?ooo`080;md0000B9`0gooo
0?ooo`3ooml0W4P00000B02Lgol30?ooo`0<0;md0000B9`0gooo0?ooo`3OW4P0001809cOo`3oool0
oooO09a80000B9`0gooo1P3oool0103ogi`0B0000000B02Lgol60?ooo`060;mdB02Lgol0oooO09a8
000004P0W=oo0`3oool01`2oM00004RL0=ooo`3ookl0M0000018W03Oool00`3oool01`3o_g@0M;oo
0?ooo`3oool0_g@00018W03Oool00`3oool00`2oM00004RL0=ooo`030?ooo`080;md0000B9`0gooo
0?ooo`3ookl0M00000000018W=l30?ooo`0<0=nLM02Lgol0oooo0?ooo`2oM00004RL0=ooo`3oool0
oono07@00000B9`0gooo0`3oool03`3o_g@0M;oo0?ooo`3OW4P0001809cOo`3oool0oooO09a80000
B9`0gooo0?ooo`3OW4P0001809cOo`0?0?ooo`030?noM0000000M;oo0100oooo00<0okmd0000B02L
gol00P3oool00`3ogi`0B00007Boo`0;0?ooo`030?noM0000000M;oo00H0oooo00<0okmd001d_`3o
ool02P3oool00`000000oooo0?ooo`0<0?ooo`00?P3oool00`3OW4P0M;oo0?ooo`0;0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool01P3oool00`2oM000001d0;ooo`090?ooo`040?oo
_`1d000004RL0=ooo`P0oooo00H0oono07@0B02Lgkl0M00000000018W=l20?ooo`040?oOW0180000
0000001d_`80oooo00d0_g@000000000000004RL0=ooo`3ooml0W4P007Boo`3ookl0M00000000000
B9`0gooo00h0oooo00@0oono07@00000B9`0gooo1`3oool0203ogi`0B0000000B02Lgol0oooo0?oo
_`1d07@0_ooo2@3oool00`2oM000000004RLg`090?ooo`030?oOW018000007Bo00@0oooo00L0gia8
0000B02Lgol0oooo0?noM0000000M;oo00@0oooo00<0okmd0000001d_ol00`3oool00`3ogi`0B000
07Boo`070?ooo`080?oog`2LB00004RL0=ooo`3oool0oono07@00000M;l20?ooo`030?oOW0180000
B9cO0080oooo00<0gia80000B02Lgol00`3oool01`2oM00004RL0=ooo`3oool0omnL04P00000M;l0
103oool0303OW4P0001809cOo`3oool0gia80000B02Lgol0oooo0?oog`2LB00004RL0=ooo`H0oooo
00<0_g@000000018W=l02@3oool00`3ogi`0B000001d_`040?ooo`060=nLB00004P0W=oo0?oOW018
0000M;oo203oool00`2oM00004RL0=ooo`030?ooo`030;md0000B9`0gooo00<0oooo00L0_g@00018
W03Oool0oooo0?noM000000007Bo00P0oooo00L0_g@00018W03Oool0oooo0?oOW0180000M;oo00L0
oooo00`0gia80000B02Lgol0oooo0?oog`2LB00004RL0=ooo`3oool0gia80000B02Lgol?0?ooo`03
0?noM0000000M;oo00<0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?oog`2LB00004RL
0=ooo`80oooo00<0oooO09a80000M;l01P3oool00`3OW4P0000000000005000000030000B02Lgol0
oooo00<0oooo00<0oono07@0M02oool02P3oool00`000000oooo0?ooo`0<0?ooo`00?P3oool00`3o
oml0W4Q809cOo`0;0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool01P3oool00`2o
M000001d0;ooo`090?ooo`040?oo_`1d000004RL0=ooo`<0oooo00<0oknL09cOo`3oool05@3oool0
0`3ooml0W4P007Boo`0C0?ooo`040?oo_`1d000004RL0=ooo`<0oooo00<0oknL09cOo`3oool04@3o
ool0103ookl0M0000000B02Lgol90?ooo`030?noM0000000B9cO00@0oooo00L0gia80000001d_ol0
oooo0?noM0000000M;oo00@0oooo00<0okmd0000001d_ol00`3oool00`3ogi`0B01809cOo`070?oo
o`040?oog`2LB00004RL0=ooo`80oooo00L0oooO09a800000000M;oo0?oOW0180000B9cO0080oooo
00<0gia80000B02Lgol00`3oool01`2oM00004RL0=ooo`3oool0okmd00000018W=l0103oool0303O
W4P0000007Boo`3oool0gia80000B02Lgol0oooo0?oog`2LB00004RL0=ooo`D0oooo00@0oono07@0
000004P0W=oo2@3oool00`3o_g@0000004RLg`040?ooo`060=nLB0000000M;oo0?oOW01804P0W=oo
203oool00`2oM00004RL0=ooo`030?ooo`030;md0000B9`0gooo00<0oooo00L0_g@00018W03Oool0
oooo0?noM0000000M;oo00P0oooo00L0_g@00018W03Oool0oooo0?oOW01804P0W=oo00L0oooo00`0
gia80000B02Lgol0oooo0?oog`2LB00004RL0=ooo`3oool0gia80000B02Lgol?0?ooo`030?noM000
0000M;oo00l0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`050?ooo`030?oOW018
M;l0oooo0080oooo00<0okmd0000001d_ol01`3oool00`2oM000M;oo0?ooo`090?ooo`030000003o
ool0oooo00`0oooo000o0?ooo`030?oOW01807@0_ooo00X0oooo1@00002K0?ooo`030000003oool0
oooo00H0oooo00<0_g@00000M02oool02@3oool0103ookl0M0000018W03Oool30?ooo`030;mdB02L
gol0oooo01@0oooo00@0oooO09a800000000M;oo1P3oool00`2oM0000000000000070000000704RL
g`3oool0oooo0?oo_`1d000004RL0=ooo`030?ooo`030;mdB02Lgol0oooo0140oooo00@0okmd0000
000007@0_ooo2@3oool00`3ogi`0B00004RLg`040?ooo`070;md000004P0W=oo0?ooo`3o_g@00000
07Boo`040?ooo`030?noM0000000M;oo00<0oooo00<0omnL04P0000000001@0000001P1d_ol0oooo
0?oog`2LB00004RL0=ooo`D0oooo00@0_g@0000000000000B9cO0P3oool00`3OW4P0001809cOo`03
0?ooo`070;md0000B9`0gooo0?ooo`3ogi`0B00004RLg`040?ooo`0<0;md000004P0W=oo0?ooo`3O
W4P0001809cOo`3oool0oooO09a80000B9`0gooo1@3oool0103o_g@000000000M02oool90?ooo`03
0?oOW0180000B9cO00@0oooo00D0_g@00000B02Lgol0omnL04P000060000000607Boo`3oool0oooo
0;md0000B9`0gooo0`3oool00`2oM00004RL0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3o_g@0
001809cOo`080?ooo`060;md0000B9`0gooo0?ooo`3ogi`0B0001P0000003P1d_ol0oooo0=nLB000
04P0W=oo0?ooo`3ooml0W4P00018W03Oool0oooo0=nLB00004P0W=oo3`3oool00`3o_g@0000007Bo
o`0?0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01P3oool01`3OW4P0M;oo0?oo
o`3oool0okmd0000001d_ol01`3oool00`3o_g@007Bo0?ooo`060?ooo`@000003P3oool00400oooo
00<0_g@004RLg`3oool02@3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00H0oooo
00<0_g@00000M02oool02@3oool00`3ookl0M00000000004000000030000B02Lgol0oooo01D0oooo
00<0oono07@0001d_ol04`3oool00`3ookl0M00000000004000000030000B02Lgol0oooo0140oooo
00@0okmd0000000007@0_ooo2@3oool00`3ooml0W4P0001d_`030?ooo`080?oo_`1d0000001d0;oo
o`3oool0okmd00000000M;l40?ooo`030?noM000000007Bo00<0oooo00<0oooO09a8B02Lgol00`3o
ool0302oM000001809cOo`3oool0oooO09a80000B9`0gooo0?ooo`3ooml0W4P0001d_`80oooo00<0
omnL04P00018W=l00P3oool00`3OW4P0001809cOo`020?ooo`080?oog`2LB00004RL0=ooo`3oool0
oooO09a80000M;l30?ooo`0=0?oo_`1d0000001d0;ooo`3oool0_g@00000001d_ol0oooo0?oog`2L
B00004RL0=ooo`050?ooo`040?noM0000000001d0;ooo`T0oooo00<0oooO09a80000M;l00`3oool0
1`3ookl0M0000000M02oool0oooO09a8B02Lgol00`3oool00`2oM000001809cOo`020?ooo`030;md
0000B9`0gooo00<0oooo00<0_g@00018W03Oool00P3oool0203ooml0W4P00018W03Oool0oooo0?oo
_`1d0000M;oo0P3oool03@3ooml0W4P00018W03Oool0oooo0?oog`2LB00004RL0=ooo`3oool0oooO
09a8B02Lgol00`3oool0402oM000001809cOo`3oool0_g@00000001d_ol0oooo0?oog`2LB00004RL
0=ooo`3oool0gia80000B02Lgol?0?ooo`030?noM000000007Bo00l0oooo00<0omnL04P00018W=l0
103oool00`3OW4P0001809cOo`060?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0000007Boo`070?oo
o`030?oo_`1d07@0_ooo00T0oooo00<000000?ooo`3oool0303oool00400oooo00<0gia80000M02o
ool02@3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00H0oooo00<0_g@00000M02o
ool0103oool02@3ooml0W4P00000B02Lgol0oooo0?oo_`1d000004RL0=ooo`030?ooo`030;mdB02L
gol0oooo02/0oooo00@0oono07@00000B9`0gooo0`3oool00`2oM4P0W=oo0?ooo`0A0?ooo`040?oO
W0180000001d0;ooo`X0oooo00X0omnL04P0001d_ol0oooo0?oog`2LB000000007Boo`3ooml0W4P0
0P0000001@1dM7@0B9cO0;md0000B7@0M4P00080000002H0M7Ad04RLg`2oM00004RL0=ooo`3o_g@0
001d0;ooo`3oool0omnL04P00000B9`0gooo0?ooo`3ooml0W4P00018W03Oool0oooo0?oog`2LB000
04RL0=ooo`3oool0gia80000001d_ol0oooO0=oOo`3OW4P0001809cOo`3oool0omnL04P000000000
04RL0=ooo`80oooo0140omnL04P0001d_ol0oooo0?oog`2LB000000007Boo`3ookl0M00000000000
04P0B4P004RLg`3ookl0M000001d_`060?ooo`040?oOW0180000001d0;ooo`X0oooo00P0omnL04P0
001d_ol0oooo0?oog`2LB000000007Boo`80oooo00P0okmd0000M02oool0oooo0?oOW018000004RL
0=ooo`80oooo00<0_g@00018W03Oool00`3oool02@2oM00004RL0=ooo`3oool0omnL04P000000000
04RL0=ooo`020?ooo`0=0?noM00004P0W=oo0?ooo`3o_g@000000018W03Oool0omnL04P000000000
04RL0=ooo`020?ooo`0E0?noM00007@0_ooo0?ooo`3ogi`0B0000018W03Ookl0M0000000000004P0
B4P004RLg`3ookl0M000001d_`3ooml0gmoo0=nLB00004P0W=oo00@0oooo00@0oooO09a8000004P0
W=oo1@3oool02@3ooml0W4P0000000000000M7Ad04RLg`2oM00004RL0:Md00090000000504RLg`3o
ool0omnL04P00018W=l0103oool00`3OW4P0001809cOo`070?ooo`060?noM000M;l0oooo0?noM000
0000M;oo203oool00`2oM000M;oo0?ooo`080?ooo`030000003oool0oooo00`0oooo00100?ooo`03
0?noM0000000M;oo00T0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`060?ooo`03
0;md000007@0_ooo00@0oooo00T0oooO09a8000004P0W=oo0?ooo`3ookl0M0000018W03Oool00`3o
ool00`3o_i`0W=oo0?ooo`0[0?ooo`040?oo_`1d000004RL0=ooo`<0oooo00<0oknL09cOo`3oool0
4@3oool0103ookl0M0000000B02Lgol60?ooo`030?oog`2LM9`0gooo0080oooo00H0oono07@00000
000000000000B02Lgol30?ooo`0=0=nLB0000000M;oo0=nLB000000007Bo0?ooo`3OW4P0000007Bo
o`3OW4P00000001d_`020?ooo`060?oOW0180000000000000000B9`0gooo0P3oool0103ooml0W4P0
0018W03Oool20?ooo`030?oog`2LB00000000080000000@007Bo0?ooo`3oool0_g@00`0000001P00
04P0W=oo0?oog`2LB00004RL0=ooo`<0oooo00H0oono07@00000000000000000B02Lgol30?ooo`07
0;md000004P0W=oo0=nLB0000000001809cOo`060?ooo`040?oo_`1d0000001809cOo`H0oooo00<0
oooO09adW03Oool00P3oool01P3ookl0M000000000000000001809cOo`@0oooo00P0omnL04P00000
000000000018W03Oool0oooo0=nLB0@0000000<0001807AdB00000000`0000001P0004P0W=oo0?oo
g`2LB00004RL0=ooo`<0oooo00H0omnL04P00000000000000018W03Oool20?ooo`040?oog`2LB000
04RL0=ooo`<0oooo00H0omnL04P00000000000000018W03Oool20?ooo`090;md000004P0W=oo0=nL
B0000000001809cOo`3oool0_g@000<0000000P0001809cOo`3oool0oooo0?oog`2LB000001809cO
o`L0oooo00H0gia80000001d_ol0gia800000000M;l<0?ooo`030?oo_`1d000007Bo00@0oooo00<0
_g@00000M02oool0203oool01@2oM000M;oo0?noM0000000M;oo00P0oooo00<0okmd001d_`3oool0
203oool00`000000oooo0?ooo`0<0?ooo`00>P3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md0000
0000M;oo00T0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`060?ooo`030;md0000
07@0_ooo00T0oooo00@0oono07@00000B9`0gooo<@3oool0103ookl0M0000018W03OoolH0?ooo`03
0=nLB0000000B9cO00H0oooo00<0omnL04Q8W03Oool08P3oool0103ooml0W4P00018W03Oool;0?oo
o`030=nLB00004P0W=oo0200oooo00<0gia800000018W=l01P3oool00`3ogi`0B4RL0=ooo`0E0?oo
o`030;md0000B9`0gooo00<0oooo00<0_g@00018W03Oool0:@3oool00`3OW4P0001809cOo`0R0?oo
o`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l02@3oool01@3ookl0M01d0;noM0000000
M;oo0080oooo00<0omno0;oOo`3oool00`3oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0
oooo00`0oooo000k0?ooo`080;md001d_ol0oooo0?ooo`3OW4P000000018W03Oool90?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool01P3oool00`2oM000001d0;ooo`090?ooo`040?oo
_`1d000004RL0=ooo`@0oooo00<0oono09bLg`3oool0:P3oool0103ookl0M0000018W03Oool40?oo
o`030?oo_`2LW=l0oooo0140oooo00@0oono07@0000004P0W=oo1@3oool00`2oM00007Bo0?ooo`0R
0?ooo`040?oog`2LB00004RL0=ooo`/0oooo00<0oono07@0B02Lgol0803oool0103ookl0M0000000
B02Lgol50?ooo`030;md0000M;l0oooo01D0oooo00<0_g@00018W03Oool00`3oool00`2oM00004RL
0=ooo`0Y0?ooo`030?oo_`1d04P0W=oo0280oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`0:0?ooo`040?noM0000000000007Boo`80oooo00<0oooO09a8M02oool0103oool00`2oM000
M;oo0?ooo`070?ooo`030000003oool0oooo00`0oooo000l0?ooo`050;md00000000000000000000
M;l02`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00@0oooo00D0gia800000000
0000001d0;ooo`090?ooo`040?oo_`1d000004RL0=ooo`@0oooo00<0gia804RLg`3oool0:P3oool0
103ookl0M0000018W03Oool40?ooo`030=nLB018W=l0oooo0180oooo00@0oono07@0000004P0W=oo
0P3oool0103ooml0W4P000000000M;lS0?ooo`040?oog`2LB00004RL0=ooo``0oooo00<0giad09cO
o`3oool0803oool0103ookl0M0000000B02Lgol20?ooo`040?oog`2LB0000000001d_aH0oooo00<0
gia80000M02oool00`3oool00`3OW4P0001d0;ooo`0Z0?ooo`030=nLM02Lgol0oooo0280oooo00H0
_g@00018W03Oool0oooo0;md0000M;l;0?ooo`040?oog`2LB000000007Boo`<0oooo00<0gia80000
00000000100000000`00M;l0oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo001<0?ooo`03
0000003oool0oooo09d0oooo00<000000?ooo`3oool01@3oool0103ookl0M0000000M02oool70?oo
o`030?oog`2LB000000000P0000000<0B9cO0?ooo`3oool09`3oool00`3ooml0W4P0000000080000
000304RLg`3oool0oooo01<0oooo00P0gia800000000000000000000B02Lgol0oono07Ad_b80oooo
00D0omnL04P00000000004RL0=ooo`0@0?ooo`040?oog`2LB000001d0;oooad0oooo00P0gia80000
0000000000000000B02Lgol0oono07Ad_aH0oooo00/0oono07@0B02Lgol0oooo0=nLB0000000B9bL
07@0B02Lgol0oooo0=nLB002000000030000M02oool0oooo00X0oooo00@0oooO09a8000007@0_ooo
>`3oool0102oM000000000000000M;l=0?ooo`030?oOW0180000M;oo00<0oooo00<0omnL04P00000
0000100000000`0004P0W=oo0?ooo`060?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool0T@3oool0103ookl0M0000018W03Oool@0?ooo`04
0?oog`2LB000001d0;oooc`0oooo00P0oooO09a80000000000000018W03Oool0oooO09a800800000
00@004Qd07A8000007@0_ooo2`3oool0103ooml0W4P00000M02ooomR0?ooo`030000003oool0oooo
00`0oooo001<0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`03
0000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0
o`3ooomU0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0
oooo09d0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo00`0oooo001<0?oo
o`<00000o`3ooooo0?ooo`@0oooo0`00000>0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooool0
oooo1P3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooool0oooo
1P3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00`0oooo001<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool0
04`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0303oool004`0ooooo`00003o000000X000003P3oool00001\
\>"],
  ImageRangeCache->{{{0, 609}, {376, 0}} -> {-0.904158, 0.573971, 0.0101272, \
0.00399777}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ 
        Evaluate\ \ linear\ correlation\ coefficient\ for\ each\ \
\(\(plot\)\(.\)\)\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(a1cor = {}; b1cor = {};\), "\n", 
    \(\(Do[\[IndentingNewLine]AppendTo[
          a1cor, {res[\([i, 1]\)], 
            res[\([i, 2]\)]}]; \[IndentingNewLine]AppendTo[
          b1cor, {res[\([i, 1]\)], res[\([i, 4]\)]}], {i, 1, 4}];\)\), "\n", 
    \(\(rega1 = Regress[a1cor, {1, x}, x];\)\), "\n", 
    \(ra1 = Sqrt[RSquared /. rega1]\), "\[IndentingNewLine]", 
    \(\(regb1 = Regress[b1cor, {1, x}, x];\)\), "\n", 
    \(rb1 = Sqrt[RSquared /. regb1]\)}], "Input"],

Cell[BoxData[
    \(0.30460404268075686`\)], "Output"],

Cell[BoxData[
    \(0.4763581029384675`\)], "Output"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ Export\ plots\ for\ use\ in\ Fig . \ 1\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(Export["\<fb1.eps\>", fb1, 
        ImageSize \[Rule] 800];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<fa1.eps\>", fa1, ImageSize \[Rule] 800];\)\)}], "Input"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 713}},
WindowSize->{766, 699},
WindowMargins->{{Automatic, 8}, {-3, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 552, 10, 191, "Input"],
Cell[2309, 63, 142, 3, 35, "Input"],
Cell[2454, 68, 758, 23, 130, "Input"],
Cell[3215, 93, 83, 2, 35, "Input"],
Cell[3301, 97, 298, 5, 70, "Input"],
Cell[3602, 104, 121, 2, 35, "Input"],
Cell[3726, 108, 1456, 33, 330, "Input"],
Cell[5185, 143, 271, 5, 87, "Input"],
Cell[5459, 150, 448, 8, 70, "Input"],
Cell[5910, 160, 368, 6, 110, "Input"],
Cell[6281, 168, 102, 2, 35, "Input"],

Cell[CellGroupData[{
Cell[6408, 174, 55, 1, 30, "Input"],
Cell[6466, 177, 49, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6552, 183, 4425, 80, 959, "Input"],
Cell[10980, 265, 446, 8, 25, "Print"],
Cell[11429, 275, 365, 7, 25, "Print"],
Cell[11797, 284, 446, 8, 25, "Print"],
Cell[12246, 294, 362, 7, 25, "Print"],
Cell[12611, 303, 447, 8, 25, "Print"],
Cell[13061, 313, 362, 7, 25, "Print"],
Cell[13426, 322, 448, 8, 25, "Print"],
Cell[13877, 332, 362, 7, 25, "Print"]
}, Open  ]],
Cell[14254, 342, 244, 4, 87, "Input"],
Cell[14501, 348, 317, 6, 90, "Input"],

Cell[CellGroupData[{
Cell[14843, 358, 255, 6, 50, "Input"],

Cell[CellGroupData[{
Cell[15123, 368, 80812, 1764, 412, 19221, 999, "GraphicsData", "PostScript", \
"Graphics"],
Cell[95938, 2134, 72887, 1635, 412, 18840, 963, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[168852, 3773, 193, 4, 61, "Input"],
Cell[169048, 3779, 77, 1, 30, "Input"],
Cell[169128, 3782, 231, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[169384, 3790, 988, 20, 230, "Input"],
Cell[170375, 3812, 468, 8, 25, "Print"],
Cell[170846, 3822, 407, 10, 55, "Output"],
Cell[171256, 3834, 54, 1, 29, "Output"]
}, Open  ]],
Cell[171325, 3838, 188, 4, 50, "Input"],
Cell[171516, 3844, 163, 4, 61, "Input"],

Cell[CellGroupData[{
Cell[171704, 3852, 398, 7, 90, "Input"],
Cell[172105, 3861, 98962, 2123, 385, 25638, 1213, "GraphicsData", \
"PostScript", "Graphics"],
Cell[271070, 5986, 130, 3, 29, "Output"]
}, Open  ]],
Cell[271215, 5992, 81, 1, 30, "Input"],
Cell[271299, 5995, 231, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[271555, 6003, 988, 20, 230, "Input"],
Cell[272546, 6025, 464, 8, 25, "Print"],
Cell[273013, 6035, 405, 10, 55, "Output"],
Cell[273421, 6047, 53, 1, 29, "Output"]
}, Open  ]],
Cell[273489, 6051, 188, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[273702, 6059, 395, 7, 90, "Input"],
Cell[274100, 6068, 86483, 1937, 385, 25259, 1177, "GraphicsData", \
"PostScript", "Graphics"],
Cell[360586, 8007, 130, 3, 29, "Output"]
}, Open  ]],
Cell[360731, 8013, 158, 4, 61, "Input"],

Cell[CellGroupData[{
Cell[360914, 8021, 491, 9, 170, "Input"],
Cell[361408, 8032, 54, 1, 29, "Output"],
Cell[361465, 8035, 53, 1, 29, "Output"]
}, Open  ]],
Cell[361533, 8039, 111, 2, 35, "Input"],
Cell[361647, 8043, 186, 3, 50, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

