(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    346702,       7687]*)
(*NotebookOutlinePosition[    347345,       7709]*)
(*  CellTagsIndexPosition[    347301,       7705]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    StyleBox[\( (*\ 
        This\ file\ produces\ one\ raw\ of\ Fig . \ 1\ of\ the\ paper\ ' 
          Testing\ GRBs\ as\ Standard\ Candles'\ \((E\_peak - L)\) . \ 
            The\ parameter\ a1\ corresponds\ to\ the\ parameters\ b\_j\ in\ \
the\ paper\ \[IndentingNewLine]while\ the\ parameter\ b1\ corresponds\ to\ \
the\ parameters\ a\_j . \ 
            The\ produced\ Figs\ examine\ the\ dependence\ of\ the\ \
parameters\ a\_j, \ b\_j\ on\ redshift\ \(\(z\)\(.\)\)*) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Set\ Directory\ to\ Read\ GRB\ data\ from, \ 
        Input\ Packages\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{\(SetDirectory["\<D:/mathdata/grb\>"];\), "\[IndentingNewLine]",
   
    RowBox[{\($TextStyle = {FontFamily \[Rule] "\<Times\>", 
          FontSize \[Rule] 20}\), ";", 
      StyleBox[" ",
        "MR"], 
      StyleBox[\(Off[]\),
        "MR"], 
      StyleBox[";",
        "MR"], 
      StyleBox[\(Off[General::spell]\),
        "MR"], 
      StyleBox[";",
        "MR"], 
      RowBox[{"Off", 
        StyleBox["[",
          "MR"], \(NIntegrate::"\<inum\>"\), 
        StyleBox["]",
          "MR"]}], 
      StyleBox[";",
        "MR"]}], "\[IndentingNewLine]", \(<< 
      Statistics`LinearRegression`\), "\[IndentingNewLine]", \(<< 
      Graphics`Graphics`\), "\[IndentingNewLine]", \(<< 
      Graphics`MultipleListPlot`\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Read\ Data\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(data1 = 
        ReadList["\<grbdat.txt\>", {Number, Number, Number, Number, Number, 
            Number, Number, Number, Number, Number, Number, Number, Number, 
            Number, Number, Number}];\)\), "\[IndentingNewLine]", 
    \(\(ndat = Length[data1];\)\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Rescale\ Data, \ Define\ new\ Arrays\ with\ Data\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(zz = data1[\([#, 1]\)] &;\)\), "\n", 
    \(\(pbolo = data1[\([#, 2]\)] &;\)\), "\n", 
    \(\(spbolo = data1[\([#, 3]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(sbolo = data1[\([#, 4]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(ssbolo = data1[\([#, 5]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(fbeam = data1[\([#, 6]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(sfbeam = data1[\([#, 7]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(tlag = 
        data1[\([#, 8]\)]/\((\((1 + zz[#])\) 
                0.1)\) &;\)\), "\[IndentingNewLine]", 
    \(\(stlag = 
        data1[\([#, 9]\)]/\((\((1 + zz[#])\) 
                0.1)\) &;\)\), "\[IndentingNewLine]", 
    \(\(var = 
        data1[\([#, 10]\)]\ \((1 + zz[#])\)/
              0.02 &;\)\), "\[IndentingNewLine]", 
    \(\(svar = 
        data1[\([#, 11]\)] \((1 + zz[#])\)/
              0.02 &;\)\), "\[IndentingNewLine]", 
    \(\(epeak = 
        data1[\([#, 12]\)]\ \((1 + zz[#])\)/
              300 &;\)\), "\[IndentingNewLine]", 
    \(\(sepeak1 = 
        data1[\([#, 13]\)] \((1 + zz[#])\)/
              300 &;\)\), "\[IndentingNewLine]", 
    \(\(sepeak2 = 
        data1[\([#, 14]\)] \((1 + zz[#])\)/
              300 &;\)\), "\[IndentingNewLine]", 
    \(\(trt = 
        data1[\([#, 
                15]\)]/\((\((1 + 
                    zz[#])\)\ 0.1)\) &;\)\), "\[IndentingNewLine]", 
    \(\(strt = data1[\([#, 16]\)]/\((\((1 + zz[#])\)\ 0.1)\) &;\)\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Fix\ \[CapitalOmega]\_m, \ 
        evaluate\ \(d\_L\) \((z)\)\ and\ evaluate\ L, \ 
        E\_\[Gamma]\ and\ corresponding\ errors\ \((for\ E\_\[Gamma]\ find\ \
error\ of\ Log \((E\_\[Gamma])\))\)\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(Clear[f, dl, dld]; om = 0.26; w0 = \(-1\); w1 = 0; h0 = 10^5\ h; \ 
    c = 3\ 10^8; h = 0.72; res = {};\), "\[IndentingNewLine]", 
    \(\(f[z_] := 
        1/Sqrt[om*\((1 + z)\)^3\  + \((1 - 
                    om)\)*\((1 + z)\)^\((3 \((1 + w0\  + \ w1)\))\) 
                Exp[3\ w1\ \((\((1/\((1 + z)\))\) - 1)\)]];\)\), "\n", 
    \(\(dl[zz_] := 
        c \((1 + zz)\)\ NIntegrate[f[z], {z, 0, zz}]/h0;\)\)}], "Input"],

Cell[BoxData[{
    \(\(dld = dl[zz[#]] 3\ 10^24 &;\)\), "\n", 
    \(\(ll = 4\ Pi\ dld[#]^2\ pbolo[#] &;\)\), "\n", 
    \(\(sll = 4\ Pi\ dld[#]^2\ spbolo[#] &;\)\), "\[IndentingNewLine]", 
    \(eg = 4\ Pi\ dld[#]^2\ sbolo[#]\ fbeam[#]/\((1 + zz[#])\) &; 
    seg = Sqrt[\((ssbolo[#]/sbolo[#])\)^2\  + \ \((sfbeam[#]/fbeam[#])\)^2]/
          Log[10] &;\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Define\ redshift\ bin\ ranges\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zreg = {0, 1, 2, 3, 7}\)], "Input"],

Cell[BoxData[
    \({0, 1, 2, 3, 7}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Do", "[", 
      RowBox[{
        RowBox[{\(zmin = zreg[\([i]\)]\), ";", \(zmax = zreg[\([i + 1]\)]\), 
          ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ For\ a\ given\ redshift\ bin, \ 
              construct\ arrays\ with\ \((Log \((E\_peak)\) - 
                    Log \((L)\))\)\ and\ corresponding\ errors\ *) \),
            FontSize->18], "\[IndentingNewLine]", 
          "\n", \(Clear[llepeak, sllepeak1, sllepeak2, sllepeak, zzt]\), ";", 
          "\n", \(llepeak = {}\), ";", \(sllepeak1 = {}\), 
          ";", \(sllepeak2 = {}\), ";", \(sllepeak = {}\), ";", \(zzt = {}\), 
          ";", "\n", \(Do[\[IndentingNewLine]If[
              epeak[i] > 0\ \  && \ zz[i] \[GreaterEqual] zmin\  && \ 
                zz[i] \[LessEqual] \ zmax, \[IndentingNewLine]AppendTo[zzt, 
                zz[i]]; \[IndentingNewLine]AppendTo[
                llepeak, {Log[10, epeak[i]], 
                  Log[10, ll[i]]}]; \[IndentingNewLine]AppendTo[
                sllepeak1, {sepeak1[i]/\((Log[10]\ epeak[i])\), 
                  sll[i]/\((Log[10]\ ll[i])\)}]; \[IndentingNewLine]AppendTo[
                sllepeak2, {sepeak2[i]/\((Log[10]\ epeak[i])\), 
                  sll[i]/\((Log[10]\ ll[i])\)}]; \[IndentingNewLine]AppendTo[
                sllepeak, {\((sepeak2[i] + sepeak1[i])\)/\((2)\), 
                  sll[i]/\((Log[10]\ ll[i])\)}]], \[IndentingNewLine]{i, 1, 
              ndat}]\), ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ 
              Minimize\ \[Chi]\^2\ to\ find\ best\ fit\ parameters\ \
a\_j\ \ \((b1)\), \ 
              b\_j\ \((a1)\)\ for\ the\ given\ redshift\ bin . \ 
                  Set\ proper\ value\ to\ intrinsic\ error\ s1 . \ 
                  Use\ covariance\ matrix\ cij\ to\ find\ errors\ of\ a\_j, \ \
\(\(b\_j\)\(.\)\)\ *) \),
            FontSize->18], "\[IndentingNewLine]", 
          "\n", \(llp[a1_, b1_, x_] := a1\  + \ b1\ x\), ";", 
          "\[IndentingNewLine]", \(epeakp[a1_, b1_, x_] := \((x - a1)\)/b1\), 
          ";", "\[IndentingNewLine]", \(chi2[a1_, b1_, s1_] := 
            Sum[\((\((llepeak[\([i, 2]\)] - 
                          llp[a1, b1, 
                            llepeak[\([i, 1]\)]])\)^2/\((sllepeak[\([i, 
                              2]\)]^2 + s1^2)\))\), {i, 1, 
                  Length[sllepeak]}] + 
              Sum[\((\((llepeak[\([i, 1]\)] - 
                          epeakp[a1, b1, 
                            llepeak[\([i, 2]\)]])\)^2/\((sllepeak[\([i, 
                              1]\)]^2 + s1^2)\))\), {i, 1, 
                  Length[llepeak]}]\), ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", \(s1 = 0.33\), 
          ";", \(ngrb = Length[llepeak]\), ";", "\n", \(par = {a1, b1}\), ";",
           "\n", \(akl[a1_, b1_, k_, l_] := 
            1/2  D[D[chi2[a1, b1, s1], par[\([k]\)]], par[\([l]\)]\ ]\), ";", 
          "\n", \(fmingrb = 
            FindMinimum[chi2\ [a1, b1, s1], {a1, 52}, {b1, 2}]\), ";", 
          "\n", \(a1o = fmingrb[\([2, 1, 2]\)]\), ";", 
          "\n", \(b1o = fmingrb[\([2, 2, 2]\)]\), ";", 
          "\n", \(aklo = 
            Table[If[
                k \[LessSlantEqual] 
                  l, \(akl[a1, b1, k, l] /. a1 \[Rule] a1o\) /. 
                  b1 \[Rule] b1o, \(akl[a1, b1, l, k] /. a1 \[Rule] a1o\) /. 
                  b1 \[Rule] b1o], {k, 1, 2}, {l, 1, 2}]\), 
          ";", \(cij = Inverse[aklo]\), 
          ";", \(spar = Table[Sqrt[cij[\([i, i]\)]], {i, 1, 2}]\), 
          ";", \(Print["\<a1= \>", a1o, "\<+-\>", 
            spar[\([1]\)], "\<  b1= \>", b1o, "\<+-\>", spar[\([2]\)]]\), 
          ";", \(cij // MatrixForm\), ";", 
          "\[IndentingNewLine]", \(erra1o = spar[\([1]\)]\), ";", 
          "\[IndentingNewLine]", \(errb1o = spar[\([2]\)]\), ";", 
          "\[IndentingNewLine]", \(chi2r = 
            Part[fmingrb, 1]/\((2\ Length[llepeak])\)\), ";", 
          "\[IndentingNewLine]", \(Print["\<chi2r=\>", chi2r, "\<  ngrb=\>", 
            ngrb]\), ";", "\n", "\[IndentingNewLine]", \(meanz = Mean[zzt]\), 
          ";", "  ", 
          "\[IndentingNewLine]", \(AppendTo[
            res, {meanz, a1o, erra1o, b1o, errb1o, chi2r, ngrb}]\)}], ",", 
        " ", \({i, 1, 4}\)}], "]"}]], "Input"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.07007560101627`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.07156161011197543`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5044653789832143`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.10552524670911743`\),
      SequenceForm[ 
      "a1= ", 52.070075601016271, "+-", .071561610111975427, "  b1= ", 
        1.5044653789832143, "+-", .10552524670911743],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9123283056786545`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]18\),
      SequenceForm[ "chi2r=", .91232830567865453, "  ngrb=", 18],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.25491601288546`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.07989318394159249`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.6826416872439856`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.18123172924899378`\),
      SequenceForm[ 
      "a1= ", 52.25491601288546, "+-", .079893183941592491, "  b1= ", 
        1.6826416872439856, "+-", .18123172924899378],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.1555878055770024`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]15\),
      SequenceForm[ "chi2r=", 1.1555878055770024, "  ngrb=", 15],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.26677707734362`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08615561415335594`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.7592089762888616`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.23082062832046735`\),
      SequenceForm[ 
      "a1= ", 52.266777077343619, "+-", .086155614153355944, "  b1= ", 
        1.7592089762888616, "+-", .23082062832046735],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.8526357071809278`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]14\),
      SequenceForm[ "chi2r=", .85263570718092785, "  ngrb=", 14],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.443073086946065`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.07689382048632744`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]0.9442345161035754`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.16918170782384373`\),
      SequenceForm[ 
      "a1= ", 52.443073086946065, "+-", .076893820486327438, 
        "  b1= ", .94423451610357545, "+-", .16918170782384373],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.4222964011220188`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]17\),
      SequenceForm[ "chi2r=", .42229640112201883, "  ngrb=", 17],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ Plot\ best\ fit\ parameter\ values\ b\_j\ \((a1dtpl)\), \ 
        a\_j\ \((b1dtpl)\)\ as\ function\ of\ redshift\ bin\ \((mean\ \
redshift\ of\ each\ bin)\)\ with\ errors\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(a1pl = {}; b1pl = {};\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]AppendTo[
        a1pl, {res[\([i, 1]\)], res[\([i, 2]\)], 
          res[\([i, 3]\)]}]; \[IndentingNewLine]AppendTo[
        b1pl, {res[\([i, 1]\)], res[\([i, 4]\)], res[\([i, 5]\)]}], {i, 1, 
        4}]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a1dtpl = 
        ErrorListPlot[a1pl, Frame \[Rule] True, Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<<z>\>", \*"\"\<\!\(b\_2\)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(b1dtpl = 
        ErrorListPlot[b1pl, Frame \[Rule] True, Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<<z>\>", \*"\"\<\!\(a\_2\)\>\""}];\)\)}], \
"Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.232355 -58.68 1.12878 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.25616 -0.0125 -7.03125 -24.5625 ]
[.25616 -0.0125 7.03125 0 ]
[.48852 -0.0125 -7.03125 -24.5625 ]
[.48852 -0.0125 7.03125 0 ]
[.72087 -0.0125 -7.03125 -24.5625 ]
[.72087 -0.0125 7.03125 0 ]
[.95323 -0.0125 -7.03125 -24.5625 ]
[.95323 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.375 -49.125 ]
[.5 -0.0125 19.375 -24.5625 ]
[-0.0125 .01639 -24.125 -12.2813 ]
[-0.0125 .01639 0 12.2813 ]
[-0.0125 .12927 -39.1875 -12.2813 ]
[-0.0125 .12927 0 12.2813 ]
[-0.0125 .24215 -39.1875 -12.2813 ]
[-0.0125 .24215 0 12.2813 ]
[-0.0125 .35503 -39.1875 -12.2813 ]
[-0.0125 .35503 0 12.2813 ]
[-0.0125 .4679 -39.1875 -12.2813 ]
[-0.0125 .4679 0 12.2813 ]
[-0.0125 .58078 -39.1875 -12.2813 ]
[-0.0125 .58078 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -63.75 -10.8125 ]
[-0.01875 .30902 -39.1875 10.8125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.25616 0 m
.25616 .00625 L
s
gsave
.25616 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.48852 0 m
.48852 .00625 L
s
gsave
.48852 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.72087 0 m
.72087 .00625 L
s
gsave
.72087 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.95323 0 m
.95323 .00625 L
s
gsave
.95323 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.07028 0 m
.07028 .00375 L
s
.11675 0 m
.11675 .00375 L
s
.16322 0 m
.16322 .00375 L
s
.20969 0 m
.20969 .00375 L
s
.30264 0 m
.30264 .00375 L
s
.34911 0 m
.34911 .00375 L
s
.39558 0 m
.39558 .00375 L
s
.44205 0 m
.44205 .00375 L
s
.53499 0 m
.53499 .00375 L
s
.58146 0 m
.58146 .00375 L
s
.62793 0 m
.62793 .00375 L
s
.6744 0 m
.6744 .00375 L
s
.76734 0 m
.76734 .00375 L
s
.81382 0 m
.81382 .00375 L
s
.86029 0 m
.86029 .00375 L
s
.90676 0 m
.90676 .00375 L
s
.9997 0 m
.9997 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.375 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
75.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
84.813 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
97.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01639 m
.00625 .01639 L
s
gsave
-0.0125 .01639 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52) show
1.000 setlinewidth
grestore
0 .12927 m
.00625 .12927 L
s
gsave
-0.0125 .12927 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.1) show
1.000 setlinewidth
grestore
0 .24215 m
.00625 .24215 L
s
gsave
-0.0125 .24215 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.2) show
1.000 setlinewidth
grestore
0 .35503 m
.00625 .35503 L
s
gsave
-0.0125 .35503 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.3) show
1.000 setlinewidth
grestore
0 .4679 m
.00625 .4679 L
s
gsave
-0.0125 .4679 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.4) show
1.000 setlinewidth
grestore
0 .58078 m
.00625 .58078 L
s
gsave
-0.0125 .58078 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03897 m
.00375 .03897 L
s
0 .06154 m
.00375 .06154 L
s
0 .08412 m
.00375 .08412 L
s
0 .10669 m
.00375 .10669 L
s
0 .15185 m
.00375 .15185 L
s
0 .17442 m
.00375 .17442 L
s
0 .197 m
.00375 .197 L
s
0 .21957 m
.00375 .21957 L
s
0 .26472 m
.00375 .26472 L
s
0 .2873 m
.00375 .2873 L
s
0 .30987 m
.00375 .30987 L
s
0 .33245 m
.00375 .33245 L
s
0 .3776 m
.00375 .3776 L
s
0 .40018 m
.00375 .40018 L
s
0 .42275 m
.00375 .42275 L
s
0 .44533 m
.00375 .44533 L
s
0 .49048 m
.00375 .49048 L
s
0 .51305 m
.00375 .51305 L
s
0 .53563 m
.00375 .53563 L
s
0 .55821 m
.00375 .55821 L
s
0 .60336 m
.00375 .60336 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -123.281 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.8125 16.2813 translate
90 rotate
-71.8125 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
80.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.25616 .61178 m
.25616 .61803 L
s
.48852 .61178 m
.48852 .61803 L
s
.72087 .61178 m
.72087 .61803 L
s
.95323 .61178 m
.95323 .61803 L
s
.125 Mabswid
.07028 .61428 m
.07028 .61803 L
s
.11675 .61428 m
.11675 .61803 L
s
.16322 .61428 m
.16322 .61803 L
s
.20969 .61428 m
.20969 .61803 L
s
.30264 .61428 m
.30264 .61803 L
s
.34911 .61428 m
.34911 .61803 L
s
.39558 .61428 m
.39558 .61803 L
s
.44205 .61428 m
.44205 .61803 L
s
.53499 .61428 m
.53499 .61803 L
s
.58146 .61428 m
.58146 .61803 L
s
.62793 .61428 m
.62793 .61803 L
s
.6744 .61428 m
.6744 .61803 L
s
.76734 .61428 m
.76734 .61803 L
s
.81382 .61428 m
.81382 .61803 L
s
.86029 .61428 m
.86029 .61803 L
s
.90676 .61428 m
.90676 .61803 L
s
.9997 .61428 m
.9997 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01639 m
1 .01639 L
s
.99375 .12927 m
1 .12927 L
s
.99375 .24215 m
1 .24215 L
s
.99375 .35503 m
1 .35503 L
s
.99375 .4679 m
1 .4679 L
s
.99375 .58078 m
1 .58078 L
s
.125 Mabswid
.99625 .03897 m
1 .03897 L
s
.99625 .06154 m
1 .06154 L
s
.99625 .08412 m
1 .08412 L
s
.99625 .10669 m
1 .10669 L
s
.99625 .15185 m
1 .15185 L
s
.99625 .17442 m
1 .17442 L
s
.99625 .197 m
1 .197 L
s
.99625 .21957 m
1 .21957 L
s
.99625 .26472 m
1 .26472 L
s
.99625 .2873 m
1 .2873 L
s
.99625 .30987 m
1 .30987 L
s
.99625 .33245 m
1 .33245 L
s
.99625 .3776 m
1 .3776 L
s
.99625 .40018 m
1 .40018 L
s
.99625 .42275 m
1 .42275 L
s
.99625 .44533 m
1 .44533 L
s
.99625 .49048 m
1 .49048 L
s
.99625 .51305 m
1 .51305 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55821 m
1 .55821 L
s
.99625 .60336 m
1 .60336 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.18233 .01472 m
.18233 .17627 L
s
.015 w
.18233 .09549 Mdot
.002 w
.3443 .21395 m
.3443 .39432 L
s
.015 w
.3443 .30414 Mdot
.002 w
.58843 .22027 m
.58843 .41477 L
s
.015 w
.58843 .31752 Mdot
.002 w
.97619 .42973 m
.97619 .60332 L
s
.015 w
.97619 .51652 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{525.25, 324.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008=0001A2000`400?l00000o`00003oo`3ooooo
0?ooo`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00o`3ooooo0?ooo`l0oooo
003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00o`3ooolS0?ooo`040?noM000M;l0oooo
0;md00H0000000D0B9cO0?ooo`3oool0_gA809cOo`3L0?ooo`00o`3ooolQ0?ooo`080?noM0000000
001d0;ooo`3oool0oono07@00000M;l30?ooo`080?oOW01dW=l0oooo0?ooo`3ogi`0B0000000B02L
gooJ0?ooo`00o`3ooolO0?ooo`040?noM0000000001809cOo`@0oooo00<0omnL04P0001d_ol00P3o
ool00`3ooml0_koO0?ooo`030?ooo`040?oOW0180000001809cOomP0oooo003o0?oooad0oooo00@0
omnL04P0000004P0W=oo1`3oool00`3OW4P0001809cOo`090?ooo`040?noM0000000001809cOomH0
oooo003o0?oooa/0oooo00@0omnL04P0000004P0W=oo2@3oool0103ooml0W4P00018W03Oool:0?oo
o`040?noM0000000001d0;ooom@0oooo003o0?oooaX0oooo00<0_g@00000B02Lgol0303oool00`3o
okl0M000001d_`0<0?ooo`030?noM0000000B9cO0=<0oooo003o0?oooa/0oooo00@0omnL04P00000
04P0W=oo1`3oool01`3ogi`0W;oo0?ooo`3oool0okmd0000001d_ol02@3oool0103o_g@000000000
M02ooooD0?ooo`00o`3ooolM0?ooo`040?oOW0180000001809cOo`D0oooo00<0oono09bLg`3oool0
0P3oool00`2oM000001d0;ooo`060?ooo`040?noM0000000001809cOomH0oooo003o0?oooal0oooo
00@0okmd0000000004P0W=oo0`3oool00`3ookl0M00000000004000000030018W03Oool0oooo0080
oooo00@0omnL04P0000004P0W=oof03oool00?l0oooo8@3oool0103o_g@000000000M02oool;0?oo
o`040?oOW0180000001809cOomX0oooo003o0?ooob<0oooo00<0okmd001d_`3oool02P3oool00`2o
M4P0W=oo0?ooo`3K0?ooo`00o`3ooooo0?ooo`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3o
ool?0?ooo`00o`3ooooo0?ooo`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00
o`3ooooo0?ooo`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00o`3ooooo0?oo
o`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00o`3ooooo0?ooo`l0oooo003o
0?ooool0oooo3`3oool005P0oooo00@0_g@0000000000000B9cOH03oool00`3o_g@0000000000002
00000003001d_`3oool0oooo05/0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`1K
0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0HP3oool00`3o_g@0000007Boo`0K
0?ooo`00EP3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0H@3oool00`2oM000001d0;oo
o`1O0?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool0F`3oool0203ogi`0B0000018
W03Oool0oooo0?oOW01804P0W=ooHP3oool00`3o_g@0000007Boo`0K0?ooo`00EP3oool00`3o_g@0
001809cOo`020?ooo`030?oOW0180000M;oo0600oooo00<0_g@00000M02oool0H03oool00`3OW4P0
B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo0680oooo00<0okmd0018W03Oool0H@3oool00`3o_g@0
000007Boo`0K0?ooo`00E@3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo0600
oooo00<0_g@00000M02oool0H@3oool00`3OW4P0B9cO0?ooo`1V0?ooo`030?noM00004P0W=oo05`0
oooo00<0gia80000000000001@0000000`0004P0W=oo0?ooo`0H0?ooo`00E@3oool00`3ookl0M000
001d_`040?ooo`030;md000007@0_ooo05l0oooo00<0_g@00000M02oool0HP3oool00`3OW4P0M;oo
0?ooo`1U0?ooo`030;md000004P0W=oo05`0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@00000
07Boo`0K0?ooo`00E@3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo05l0oooo00<0
_g@00000M02oool0HP3oool00`3ooml0W4Q809cOo`1T0?ooo`040;md00000000001d0;oooed0oooo
00L0gia807Boo`3oool0oooo0?noM0000000M;oo01/0oooo001E0?ooo`030?oOW0180000B9cO00@0
oooo00<0gia80000B02Lgol0G`3oool00`2oM000001d0;ooo`1S0?ooo`030?oOW01807@0_ooo0600
oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`1L0?ooo`070?oo_`1d07@0_ooo0?oo
o`3o_g@0000007Boo`0K0?ooo`00E@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo
05l0oooo00<0_g@00000M02oool0I03oool00`2oM000B9cO0?ooo`1Q0?ooo`030?noM00004P0W=oo
0600oooo00H0okmd001d_`3oool0okmd0000001d_olK0?ooo`00E@3oool00`3ookl0M000001d_`04
0?ooo`030;md000007@0_ooo05l0oooo00<0_g@00000M02oool0I03oool00`3OW4P0001d0;ooo`1R
0?ooo`030?oOW018M;l0oooo0600oooo00D0_g@007Boo`3o_g@0000007Boo`0K0?ooo`00EP3oool0
0`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo0600oooo00<0_g@00000M02oool0I03oool0
0`3o_g@0000007Boo`1R0?ooo`030?oog`2LB000B9cO0600oooo00D0oono07@0M02o_g@0000007Bo
o`0K0?ooo`00EP3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo0600oooo00<0_g@0
0000M02oool0GP3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo05d0oooo00<0oooO
09adW03Oool00P3oool00`3ooml0W4P0001d_`1Q0?ooo`040?noM0000000000007Booa/0oooo001G
0?ooo`060;md0000B9`0gooo0?ooo`2oM00007BoG`3oool01@3OW4P000000000000007@0_ooo05l0
oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=oooeh0oooo00L0omnL04Q8W03Oool0oooo
0=nLB0000000M;oo0640oooo00@0oooO09a800000000M;oo6`3oool005P0oooo00@0_g@000000000
000007BoH@3oool0103ookl0M0000000M02ooomP0?ooo`050;md00000000000000000000M;l0H@3o
ool01@3ogi`0B000000000000000B9cO06<0oooo00<0omnL04P0001d_ol06`3oool00?l0ooooo`3o
ool?0?ooo`00o`3ooooo0?ooo`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00
o`3ooooo0?ooo`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00o`3ooooo0?oo
o`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00D03ooooo00000;D000002@3o
ool00500oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`00=@3oool01P2o
M000000000000000000004RL0=ooo`<0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01`3oool003@0oooo00<0oooO
09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`030?ooo`030=nLB0000000000000@0000000<007Bo
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0680oooo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0680oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`00>P3oool00`3ogi`0B7Bo0?ooo`030?oo
o`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`3o0?oo
ok40oooo00<000000?ooo`3oool01`3oool003X0oooo00<0oono07@0B02Lgol0103oool00`3OW4P0
B9cO0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo/@3oool00`000000oooo0?ooo`070?ooo`00
>P3oool00`3ookl0M00007Boo`050?ooo`030=nLB01d_ol0oooo00/0oooo00<000000?ooo`3oool0
o`3ooona0?ooo`030000003oool0oooo00L0oooo000j0?ooo`030?noM0000000M;oo00D0oooo00<0
oooO09a8B02Lgol02`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0ooooHP3o
ool00`000000oooo0?ooo`070?ooo`00>@3oool0103ogi`0B0000000M02oool60?ooo`030?oOW018
07@0_ooo00X0oooo1000001;0?ooo`030000003oool0oooo0?l0ooooG`3oool4000000T0oooo000e
0?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool01P3oool00`2oM000B9cO0?oo
o`090?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`030000003o
ool0oooo00L0oooo000e0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool01`3oool0
0`3OW4P0001d0;ooo`090?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooomR
0?ooo`030000003oool0oooo00L0oooo000e0?ooo`050?oog`2LB00000000000M02oool02P3oool0
0`3o_g@0000007Boo`090?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooomR
0?ooo`030000003oool0oooo00L0oooo000f0?ooo`030?noM000M;l0oooo00D0oooo00<0omnL09bo
o`3oool00`3oool00`2oM000000007Boo`090?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0o`3ooomR0?ooo`030000003oool0oooo00L0oooo000f0?ooo`030?oog`2LB00000000080
000000H0001d0;ooo`3oool0oooo0;md001d_ol20?ooo`040=nLB000000004RL0=ooo`T0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool01`3o
ool003L0oooo00<0okmd0000000000000P0000001@1d_ol0oooo0?ooo`3oool0_g@000<0000000<0
07Bo0?ooo`3oool02@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0ooooHP3o
ool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0?l0ooooHP3oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0?l0ooooHP3oool00`000000oooo0?ooo`070?ooo`00D03oool2000004d0
oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`8000002@3oool00500oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool01`3oool00500oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool01`3o
ool00500oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<00000
0?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?oo
of80oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool01`3oool00500oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool01`3o
ool00500oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<00000
0?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?oo
of80oooo00<000000?ooo`3oool01`3oool00500oooo0P00001=0?ooo`030000003oool0oooo0?l0
ooooH@3oool2000000T0oooo001@0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
o`3ooomR0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool0o`3ooomR0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`030000003oool0oooo00L0oooo001@0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`030000003oool0oooo
00L0oooo001@0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`03
0000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
o`3ooomR0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool0o`3ooomR0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`030000003oool0oooo00L0oooo001@0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`030000003oool0oooo
00L0oooo001@0?ooo`800000C@3oool00`000000oooo0?ooo`3o0?ooof40oooo0P0000090?ooo`00
D03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0ooooHP3oool00`000000oooo
0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0ooooHP3o
ool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`1;0?ooo`800000o`3ooomT
0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo04X0oooo1000003o0?oo
of<0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0B@3oool600000?l0
ooooHP3oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`190?ooo`H00000
o`3ooomR0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo04X0oooo1000
003o0?ooof<0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0B`3oool2
00000?l0ooooI03oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0?l0ooooHP3oool00`000000oooo0?ooo`070?ooo`00D03oool2000004d0
oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`8000002@3oool00500oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool01`3oool00500oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool01`3o
ool00500oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<00000
0?ooo`3oool01`3oool002H0oooo00H0_g@000000000000000000018W03Oool30?ooo`030=nLB000
0000000000D0000000H0M;oo0?ooo`3oool0gia800000018W=l30?ooo`030?noM000000000000080
000000<007Bo0?ooo`3oool0203oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0
ooooHP3oool00`000000oooo0?ooo`070?ooo`009@3oool00`3ooml0W4P004RLg`020?ooo`030?oO
W018B9`0gooo00<0oooo00<0gia8000000000000100000001P00M;l0oooo0?ooo`3OW4P0000004RL
g`D0oooo00<0_g@00000M02oool02`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
0?l0ooooHP3oool00`000000oooo0?ooo`070?ooo`00:`3oool00`3ogi`0B7Bo0?ooo`030?ooo`03
0=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool02@3oool00`2oM000001d0;ooo`0;0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`030000003oool0oooo00L0
oooo000[0?ooo`030?oo_`1d04P0W=oo00@0oooo00<0gia804RLg`3oool03@3oool00`2oM000001d
0;ooo`0;0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`030000
003oool0oooo00L0oooo000[0?ooo`030?oo_`1d0000M;oo00D0oooo00<0gia807Boo`3oool0303o
ool00`2oM000001d0;ooo`0;0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3o
oomR0?ooo`030000003oool0oooo00L0oooo000[0?ooo`030?noM0000000M;oo00D0oooo00<0oooO
09a8B02Lgol0303oool00`2oM000001d0;ooo`0;0?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0o`3ooomR0?ooo`030000003oool0oooo00L0oooo000Z0?ooo`040?oOW0180000001d
0;ooo`H0oooo00<0omnL04P0M02oool02`3oool00`2oM000001d0;ooo`0;0?ooo`@00000B`3oool0
0`000000oooo0?ooo`3o0?oooel0oooo100000090?ooo`009P3oool0103Ogml0oooo0?ooo`2oM002
0000000304RLg`3oool0oooo00H0oooo00<0_g@004RLg`3oool02P3oool00`2oM000001d0;ooo`0;
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`030000003oool0
oooo00L0oooo000V0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool01`3oool00`3O
W4P0001d0;ooo`0:0?ooo`030;md000007@0_ooo00/0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool01`3oool002H0oooo00D0oooO09a80000
0000001d0;ooo`0:0?ooo`030?noM0000000M;oo00X0oooo00<0_g@00000M02oool02`3oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0ooooHP3oool00`000000oooo0?ooo`070?oo
o`009`3oool00`3o_g@007Bo0?ooo`050?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d
_ol02P3oool00`2oM000001d0;ooo`0;0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0o`3ooomR0?ooo`030000003oool0oooo00L0oooo000W0?ooo`030?oog`2LB000000000800000
00H0001d0;ooo`3oool0oooo0;md001d_ol20?ooo`040=nLB000000004RL0=ooo`P0oooo00D0gia8
000000000000001d0;ooo`0;0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3o
oomR0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030?noM000000000000080000000D0M;oo
0?ooo`3oool0oooo0;md000300000003001d_`3oool0oooo00T0oooo00@0oono07@0000007@0_ooo
2`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0ooooHP3oool00`000000oooo
0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0ooooHP3o
ool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0?l0ooooHP3oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0?l0ooooHP3oool00`000000oooo0?ooo`070?ooo`00D03oool2000004d0
oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`8000002@3oool00500oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool01`3oool00500oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool01`3o
ool00500oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<00000
0?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?oo
of80oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool01`3oool00500oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool01`3o
ool00500oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooof80oooo00<00000
0?ooo`3oool01`3oool00500oooo0P00001=0?ooo`030000003oool0oooo0?l0ooooH@3oool20000
00T0oooo001@0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`03
0000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0oooo/@3oool00`000000oooo
0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oook40oooo00<000000?ooo`3oool01`3o
ool00500oooo00<000000?ooo`3oool0o`3ooona0?ooo`030000003oool0oooo00L0oooo001@0?oo
o`030000003oool0oooo0?l0oooo/@3oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000
oooo0?ooo`3o0?oook40oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0
o`3ooona0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0oooo/@3o
ool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oook40oooo00<00000
0?ooo`3oool01`3oool00500oooo0P00003o0?oook40oooo0P0000090?ooo`00D03oool00`000000
oooo0?ooo`3o0?oook40oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0
o`3ooona0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0oooo/@3o
ool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oook40oooo00<00000
0?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3ooona0?ooo`030000003oool0oooo
00L0oooo001@0?ooo`030000003oool0oooo0?l0oooo/@3oool00`000000oooo0?ooo`070?ooo`00
D03oool00`000000oooo0?ooo`3o0?oook40oooo00<000000?ooo`3oool01`3oool00500oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool01`3o
ool00500oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<00000
0?ooo`3oool01`3oool00500oooo0P00002D0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0[`3oool2000000T0oooo001@0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2`0?ooo`030000
003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo000V0?ooo`060;md00000000
000000000000B9`0gooo0`3oool00`3OW4P00000000000050000000807Boo`3oool0oooo0=nLB000
0000B9cO0?ooo`3OW4P70000000307Boo`3oool0oooo00L0oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool01`3oool0
02D0oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`030?ooo`030=nLB00000000000
00@0000000H007Bo0?ooo`3oool0gia800000018W=l20?ooo`030=nLB0000000000000@0000000<0
07Bo0?ooo`3oool01`3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`00:`3oool00`3ogi`0B7Bo0?ooo`03
0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool01`3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?oog`2LB7@0_ooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool01`3oool002/0oooo00<0oono07@0
B02Lgol0103oool00`3OW4P0B9cO0?ooo`0<0?ooo`030=nLB018W=l0oooo00`0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0;00oooo00<000000?oo
o`3oool01`3oool002/0oooo00<0oono07@0001d_ol01@3oool00`3OW4P0M;oo0?ooo`0<0?ooo`03
0=nLB01d_ol0oooo00/0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo0;00oooo00<000000?ooo`3oool01`3oool002/0oooo00<0okmd0000001d_ol0
1@3oool00`3ooml0W4Q809cOo`0<0?ooo`030?oog`2LB4P0W=oo00/0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
1`3oool002X0oooo00@0omnL04P0000007@0_ooo1P3oool00`3ogi`0B01d0;ooo`0<0?ooo`030?oO
W01807@0_ooo00X0oooo1000002B0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0
[@3oool4000000T0oooo000V0?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool0
1P3oool00`2oM000B9cO0?ooo`0<0?ooo`030;md0018W=l0oooo00T0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
1`3oool002H0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`070?ooo`030=nLB000
07@0_ooo00`0oooo00<0gia80000M02oool02@3oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo06L0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`009P3oool0
1@3ooml0W4P00000000007@0_ooo00X0oooo00<0okmd0000001d_ol0303oool00`3o_g@0000007Bo
o`090?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`2`0?ooo`030000003oool0oooo00L0oooo000W0?ooo`030?noM000M;l0oooo00D0oooo00<0omnL
09boo`3oool00`3oool00`2oM000000007Boo`060?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@0
0000001d_ol02@3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo06L0oooo00<00000
0?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`009`3oool00`3ooml0W4P0000000020000
00060000M02oool0oooo0?ooo`2oM000M;oo0P3oool0103OW4P000000018W03Oool70?ooo`080;md
001d_ol0oooo0?ooo`3OW4P000000018W03Oool90?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo000X0?oo
o`030?noM000000000000080000000D0M;oo0?ooo`3oool0oooo0;md000300000003001d_`3oool0
oooo00P0oooo00D0_g@00000000000000000001d_`0;0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo001@
0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo001@0?ooo`03
0000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2`0?ooo`03
0000003oool0oooo00L0oooo001@0?ooo`800000U03oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo0:l0oooo0P0000090?ooo`00D03oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo06L0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`00D03oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0/03oool0
0`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0/03oool00`000000
oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo06L0oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?oo
o`2C0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?oo
o`070?ooo`00D03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo06L0oooo00<00000
0?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo06L0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`070?oo
o`00D03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool0/03oool00`000000oooo0?ooo`070?ooo`00D03oool2000009@0oooo00<000000?ooo`3oool0
I`3oool00`000000oooo0?ooo`2_0?ooo`8000002@3oool000d0oooo00<0omnL09boo`3oool0@03o
ool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0/03o
ool00`000000oooo0?ooo`070?ooo`003@3oool00`2oM000000000000009000000030000B02Lgol0
oooo03@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0
oooo0;00oooo00<000000?ooo`3oool01`3oool000`0oooo00<0oono07@0000000002`0000000`00
M;l0oooo0?ooo`0c0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo000B0?ooo`030?oOW018M;l0oooo00@0
oooo00<0omnL04P0M02oool0=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`004@3oool00`3ookl0M018
09cOo`060?ooo`030;mdM02oool0oooo03<0oooo00<000000?ooo`3oool0TP3oool2000006T0oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`004@3oool00`3o_g@0001809cO
o`050?ooo`030?oog`2LM9`0gooo03@0oooo00<000000?ooo`3oool0T@3oool4000006P0oooo00<0
00000?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`004@3oool0103ogi`0B0000000B02L
gol30?ooo`030?oog`2LB000M;oo03D0oooo00<000000?ooo`3oool0T03oool6000006L0oooo00<0
00000?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`004P3oool00`2oM000000000000004
00000003001d_`3oool0oooo03@0oooo00<000000?ooo`3oool0T03oool6000006L0oooo00<00000
0?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`004`3oool00`3OW4P00000000000020000
000307Boo`3oool0oooo03D0oooo0P00002B0?ooo`@00000J03oool00`000000oooo0?ooo`2_0?oo
o`8000002@3oool00500oooo00<000000?ooo`3oool0TP3oool2000006P0oooo0P00002b0?ooo`03
0000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
I@3oool400000;40oooo00<000000?ooo`3oool01`3oool001D0oooo00<0gia80018W03Oool0103o
ool00`3OW7@0B4Qd0;ooo`0a0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I03o
ool600000;00oooo00<000000?ooo`3oool01`3oool001@0oooo00<0okmd001d_`3oool0103oool0
102oM000B9bL07@0M02ooola0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I03o
ool600000;00oooo00<000000?ooo`3oool01`3oool001@0oooo00<0gia804RLg`3oool00P3oool0
1P3ooml0W4P007Boo`3ookl0M01d0;oooc40oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`1U0?ooo`@00000/@3oool00`000000oooo0?ooo`070?ooo`00503oool02`3o_g@0001809cO
o`3oool0okmd0000B02Lgol0oooo0?oOW01807@0_ooo0340oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`1V0?ooo`800000/P3oool00`000000oooo0?ooo`070?ooo`005@3oool0103O
W4P0000000000000M;l20?ooo`040?oog`2LB00004RL0=oooc40oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool01`3o
ool00500oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0
oooo0;00oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0T`3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool01`3oool00500
oooo0P00002D0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0[`3oool2000000T0
oooo001@0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo
0?ooo`2`0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo001@
0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo00L0oooo000V0?ooo`060;md00000000000000000000B9`0gooo0`3o
ool00`3OW4P00000000000050000000907Boo`3oool0oooo0=nLB0000000B9cO0?ooo`3ooml0W4P0
00<0000000<004RL0=ooo`3oool02P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`009@3oool00`3ooml0
W4P004RLg`020?ooo`030?oOW018B9`0gooo00<0oooo00<0gia8000000000000100000003`00M;l0
oooo0?ooo`3OW4P0000004RLg`3oool0omnL04P00000B9`0gooo0?ooo`3ogi`0B01809cOo`0:0?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2`0?oo
o`030000003oool0oooo00L0oooo000[0?ooo`030?oOW018M;l0oooo00<0oooo00<0gia804RLg`3o
ool00P3oool00`3ooml0W4Qd0;ooo`0;0?ooo`030?noM000B9`0gooo00T0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3o
ool01`3oool002/0oooo00<0oono07@0B02Lgol0103oool00`3OW4P0B9cO0?ooo`0?0?ooo`030?no
M00004P0W=oo00T0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo0;00oooo00<000000?ooo`3oool01`3oool002/0oooo00<0oono07@0001d_ol01@3o
ool00`3OW4P0M;oo0?ooo`0>0?ooo`030;md000004P0W=oo00T0oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool01`3o
ool002/0oooo00<0okmd0000001d_ol01@3oool00`3ooml0W4Q809cOo`0=0?ooo`040;md00000000
001d0;ooo`T0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1W0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool01`3oool002X0oooo00@0omnL04P0000007@0_ooo1P3o
ool00`3ogi`0B01d0;ooo`090?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0203o
ool400000980oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2]0?ooo`@000002@3o
ool002H0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`060?ooo`030;md0018
W=l0oooo00X0oooo00<0okmd0000B02Lgol02`3oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo06L0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`009P3oool0
0`3o_g@000000000000200000003001d_`3oool0oooo00L0oooo00<0gia80000M02oool02`3oool0
0`3ogi`0B7Bo0?ooo`0:0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo000V0?ooo`050?oog`2LB0000000
0000M02oool02P3oool00`3o_g@0000007Boo`0;0?ooo`030?oog`2LB000B9cO00X0oooo00<00000
0?ooo`3oool0T`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0;00oooo00<00000
0?ooo`3oool01`3oool002L0oooo00<0okmd001d_`3oool01@3oool00`3ogi`0W;oo0?ooo`030?oo
o`030;md00000000M;oo00H0oooo00<0oooO09adW03Oool00P3oool00`3ooml0W4P0001d_`0:0?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2`0?oo
o`030000003oool0oooo00L0oooo000W0?ooo`030?oog`2LB00000000080000000H0001d0;ooo`3o
ool0oooo0;md001d_ol20?ooo`040=nLB000000004RL0=ooo`L0oooo00L0omnL04Q8W03Oool0oooo
0=nLB0000000M;oo00X0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo0;00oooo00<000000?ooo`3oool01`3oool002P0oooo00<0okmd000000000000
0P0000001@1d_ol0oooo0?ooo`3oool0_g@000<0000000<007Bo0?ooo`3oool0203oool01@3ogi`0
B000000000000000B9cO00/0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo0;00oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3o
ool01`3oool00500oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo0;00oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool01`3o
ool00500oooo0P00002D0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0[`3oool2
000000T0oooo001@0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00L0
oooo001@0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo
0?ooo`2`0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo001@
0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo001@0?ooo`03
0000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2`0?ooo`03
0000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool0
/03oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3m0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool01`3oool00500oooo0P00003n0?ooo`030000003oool0
oooo0:l0oooo0P0000090?ooo`00D03oool00`000000oooo0?ooo`3m0?ooo`030000003oool0oooo
0;00oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o@3oool00`000000
oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?d0oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?oo
o`3m0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool01`3oool00500oooo00<00000
0?ooo`3oool0o@3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo001@0?oo
o`030000003oool0oooo0?d0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`070?oo
o`00D03oool00`000000oooo0?ooo`3o0?oook40oooo00<000000?ooo`3oool01`3oool00500oooo
00<000000?ooo`3oool0o`3ooona0?ooo`030000003oool0oooo00L0oooo001@0?ooo`800000o`3o
oona0?ooo`8000002@3oool00500oooo00<000000?ooo`3oool0o`3ooona0?ooo`030000003oool0
oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0oooo/@3oool00`000000oooo0?ooo`070?oo
o`00D03oool00`000000oooo0?ooo`3o0?oook40oooo00<000000?ooo`3oool01`3oool00500oooo
00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00500oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3ooonW0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3o
ool0o`3ooonW0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00500oooo
00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00500oooo0P00003o0?ooojP0oooo00<000000?ooo`3oool01P3oool2000000T0oooo001@
0?ooo`030000003oool0oooo0?l0ooooY`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0ooooY`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0ooooY`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000V0?ooo`060;md00000000000000000000
B9`0gooo0`3oool00`3OW4P00000000000050000000607Boo`3oool0oooo0=nLB0000000B9cO1P3o
ool00`3o_g@0000007Boo`0:0?ooo`030000003oool0oooo0?l0ooooY`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo000U0?ooo`030?oog`2LB000B9cO0080oooo00<0omnL
04Q8W03Oool00`3oool00`3OW4P000000000000400000006001d_`3oool0oooo0=nLB0000000B9cO
1P3oool00`3o_g@0000007Boo`0:0?ooo`030000003oool0oooo0?l0ooooY`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo000[0?ooo`030?oOW018M;l0oooo00<0oooo00<0
gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`0:0?ooo`030?noM0000000M;oo00X0oooo00<0
00000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool002/0oooo00<0oono07@0B02Lgol0103oool00`3OW4P0B9cO0?ooo`090?ooo`030=nLB0000000
000000D0000000<0001809cOo`3oool01`3oool00`000000oooo0?ooo`3o0?ooojL0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00:`3oool00`3ookl0M00007Boo`050?oo
o`030=nLB01d_ol0oooo00P0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`0:0?oo
o`030000003oool0oooo0?l0ooooY`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo000[0?ooo`030?noM0000000M;oo00D0oooo00<0oooO09a8B02Lgol02@3oool01`3OW4P0
M;oo0?ooo`3oool0okmd0000001d_ol02P3oool00`000000oooo0?ooo`3o0?ooojL0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00:P3oool0103ogi`0B0000000M02oool6
0?ooo`030?oOW01807@0_ooo00P0oooo00L0oono07@0M02oool0oooo0?noM0000000M;oo00X0oooo
1000003o0?ooojH0oooo00<000000?ooo`3oool0103oool4000000T0oooo000V0?ooo`040=oOg`3o
ool0oooo0;md0080000000<0B9cO0?ooo`3oool01P3oool00`2oM000B9cO0?ooo`080?ooo`060?no
M000M;l0oooo0?noM0000000M;oo2P3oool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`009P3oool00`3o_g@000000000000200000003
001d_`3oool0oooo00L0oooo00<0gia80000M02oool02@3oool01@2oM000M;oo0?noM0000000M;oo
00X0oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool002H0oooo00D0oooO09a800000000001d0;ooo`0:0?ooo`030?noM0000000M;oo
00T0oooo00D0oono07@0M02o_g@0000007Boo`0:0?ooo`030000003oool0oooo0?l0ooooY`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000W0?ooo`030?noM000M;l0oooo
00D0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`0:0?ooo`040?noM00000000000
07Boo`X0oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool002L0oooo00<0oooO09a8000000000P0000001P0007@0_ooo0?ooo`3oool0
_g@007Boo`80oooo00@0gia800000000B9`0gooo2P3oool0103ooml0W4P00000001d_ol:0?ooo`03
0000003oool0oooo0?l0ooooY`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo000X0?ooo`030?noM000000000000080000000D0M;oo0?ooo`3oool0oooo0;md000300000003
001d_`3oool0oooo00/0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?ooojL0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo
0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00D03o
ool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`00D03oool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`00D03oool200000?l0ooooZ03oool00`000000oooo0?ooo`060?oo
o`8000002@3oool00500oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3o
oonW0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00500oooo00<00000
0?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0500oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3o
oonW0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00500oooo00<00000
0?ooo`3oool0o`3ooonV0?ooo`8000002@3oool00`000000oooo0?ooo`070?ooo`00D03oool20000
0?l0ooooYP3oool4000000L0oooo0P0000090?ooo`00D03oool00`000000oooo0?ooo`3o0?oooj@0
oooo1P0000070?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0oooo
Y03oool6000000L0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3o
oonU0?ooo`@00000203oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o
0?ooojH0oooo0P0000090?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo
0?l0ooooY`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo001@0?ooo`03
0000003oool0oooo0?l0ooooY`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo001@0?ooo`030000003oool0oooo0?l0ooooY`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0ooooY`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0ooooY`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo001@0?ooo`800000o`3ooonX0?oo
o`030000003oool0oooo00H0oooo0P0000090?ooo`00D03oool00`000000oooo0?ooo`3o0?ooojL0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo
0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00D03o
ool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`00D03oool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?ooojL0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo
0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00D03o
ool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`00D03oool200000?l0ooooZ03oool00`000000oooo0?ooo`060?ooo`8000002@3oool0
0500oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3o
oonW0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool002H0oooo00H0_g@0
00000000000000000018W03Oool30?ooo`030=nLB0000000000000D0000000H0M;oo0?ooo`3oool0
gia800000018W=l20?ooo`060;md00000000000000000000B9`0gooo2`3oool00`000000oooo0?oo
o`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`009@3oool0
0`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00<0oooo00<0gia800000000000010000000
2P00M;l0oooo0?ooo`3OW4P0000004RLg`3oool0oooO09a80018W=l20?ooo`030?oOW018B9`0gooo
00X0oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool002/0oooo00<0omnL04Qd_`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?oog`2LB7@0_ooo00/0oooo00<0omnL04Qd_`3oool02@3oool00`000000oooo0?ooo`3o0?ooojL0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00:`3oool00`3ookl0M018
09cOo`040?ooo`030=nLB018W=l0oooo00l0oooo00<0oono07@0B02Lgol02@3oool00`000000oooo
0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00:`3o
ool00`3ookl0M00007Boo`050?ooo`030=nLB01d_ol0oooo00h0oooo00<0oono07@0001d_ol02@3o
ool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`00:`3oool00`3o_g@0000007Boo`050?ooo`030?oog`2LB4P0W=oo00h0oooo00<0okmd
0000001d_ol02@3oool400000?l0ooooYP3oool00`000000oooo0?ooo`040?ooo`@000002@3oool0
02X0oooo00@0omnL04P0000007@0_ooo1P3oool00`3ogi`0B01d0;ooo`0<0?ooo`040?oOW0180000
001d0;ooo`T0oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool002H0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?oo
o`060?ooo`030;md0018W=l0oooo00L0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo
0?ooo`080?ooo`030000003oool0oooo0?l0ooooY`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo000V0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool01`3o
ool00`3OW4P0001d0;ooo`070?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool02@3o
ool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`009P3oool01@3ooml0W4P00000000007@0_ooo00X0oooo00<0okmd0000001d_ol01`3o
ool01@3ooml0W4P00000000007@0_ooo00`0oooo00<000000?ooo`3oool0o`3ooonW0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool002L0oooo00<0okmd001d_`3oool01@3o
ool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo00P0oooo00<0okmd001d_`3oool03@3o
ool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`009`3oool00`3ooml0W4P000000002000000060000M02oool0oooo0?ooo`2oM000M;oo
0P3oool0103OW4P000000018W03Oool80?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3o
ool0203oool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`00:03oool00`3o_g@00000000000020000000507Boo`3oool0oooo0?ooo`2o
M0000`0000000`00M;l0oooo0?ooo`090?ooo`030?noM000000000000080000000<0M;oo0?ooo`3o
ool01`3oool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?ooojL0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00D03oool200000?l0ooooZ03oool0
0`000000oooo0?ooo`060?ooo`8000002@3oool00500oooo00<000000?ooo`3oool0o`3ooona0?oo
o`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0oooo/@3oool00`000000
oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oook40oooo00<000000?ooo`3oool0
1`3oool00500oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`070?ooo`00D03ooooo00000;D000002@3oool00001\
\>"],
  ImageRangeCache->{{{0, 524.25}, {323.625, 0}} -> {-0.896772, 51.8743, \
0.00988589, 0.00203497}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.232355 -0.360765 0.484457 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.25616 -0.0125 -7.03125 -24.5625 ]
[.25616 -0.0125 7.03125 0 ]
[.48852 -0.0125 -7.03125 -24.5625 ]
[.48852 -0.0125 7.03125 0 ]
[.72087 -0.0125 -7.03125 -24.5625 ]
[.72087 -0.0125 7.03125 0 ]
[.95323 -0.0125 -7.03125 -24.5625 ]
[.95323 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.375 -49.125 ]
[.5 -0.0125 19.375 -24.5625 ]
[-0.0125 .0268 -29.125 -12.2813 ]
[-0.0125 .0268 0 12.2813 ]
[-0.0125 .12369 -14.0625 -12.2813 ]
[-0.0125 .12369 0 12.2813 ]
[-0.0125 .22058 -29.125 -12.2813 ]
[-0.0125 .22058 0 12.2813 ]
[-0.0125 .31748 -29.125 -12.2813 ]
[-0.0125 .31748 0 12.2813 ]
[-0.0125 .41437 -29.125 -12.2813 ]
[-0.0125 .41437 0 12.2813 ]
[-0.0125 .51126 -29.125 -12.2813 ]
[-0.0125 .51126 0 12.2813 ]
[-0.0125 .60815 -14.0625 -12.2813 ]
[-0.0125 .60815 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -53.6875 -10.2188 ]
[-0.01875 .30902 -29.125 10.2188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.25616 0 m
.25616 .00625 L
s
gsave
.25616 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.48852 0 m
.48852 .00625 L
s
gsave
.48852 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.72087 0 m
.72087 .00625 L
s
gsave
.72087 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.95323 0 m
.95323 .00625 L
s
gsave
.95323 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.07028 0 m
.07028 .00375 L
s
.11675 0 m
.11675 .00375 L
s
.16322 0 m
.16322 .00375 L
s
.20969 0 m
.20969 .00375 L
s
.30264 0 m
.30264 .00375 L
s
.34911 0 m
.34911 .00375 L
s
.39558 0 m
.39558 .00375 L
s
.44205 0 m
.44205 .00375 L
s
.53499 0 m
.53499 .00375 L
s
.58146 0 m
.58146 .00375 L
s
.62793 0 m
.62793 .00375 L
s
.6744 0 m
.6744 .00375 L
s
.76734 0 m
.76734 .00375 L
s
.81382 0 m
.81382 .00375 L
s
.86029 0 m
.86029 .00375 L
s
.90676 0 m
.90676 .00375 L
s
.9997 0 m
.9997 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.375 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
75.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
84.813 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
97.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0268 m
.00625 .0268 L
s
gsave
-0.0125 .0268 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .12369 m
.00625 .12369 L
s
gsave
-0.0125 .12369 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .22058 m
.00625 .22058 L
s
gsave
-0.0125 .22058 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .31748 m
.00625 .31748 L
s
gsave
-0.0125 .31748 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .41437 m
.00625 .41437 L
s
gsave
-0.0125 .41437 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
0 .51126 m
.00625 .51126 L
s
gsave
-0.0125 .51126 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
0 .60815 m
.00625 .60815 L
s
gsave
-0.0125 .60815 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05102 m
.00375 .05102 L
s
0 .07525 m
.00375 .07525 L
s
0 .09947 m
.00375 .09947 L
s
0 .14792 m
.00375 .14792 L
s
0 .17214 m
.00375 .17214 L
s
0 .19636 m
.00375 .19636 L
s
0 .24481 m
.00375 .24481 L
s
0 .26903 m
.00375 .26903 L
s
0 .29325 m
.00375 .29325 L
s
0 .3417 m
.00375 .3417 L
s
0 .36592 m
.00375 .36592 L
s
0 .39014 m
.00375 .39014 L
s
0 .43859 m
.00375 .43859 L
s
0 .46281 m
.00375 .46281 L
s
0 .48703 m
.00375 .48703 L
s
0 .53548 m
.00375 .53548 L
s
0 .5597 m
.00375 .5597 L
s
0 .58393 m
.00375 .58393 L
s
0 .00258 m
.00375 .00258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -112.625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.2188 16.2813 translate
90 rotate
-71.2188 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
71.875 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
79.438 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.25616 .61178 m
.25616 .61803 L
s
.48852 .61178 m
.48852 .61803 L
s
.72087 .61178 m
.72087 .61803 L
s
.95323 .61178 m
.95323 .61803 L
s
.125 Mabswid
.07028 .61428 m
.07028 .61803 L
s
.11675 .61428 m
.11675 .61803 L
s
.16322 .61428 m
.16322 .61803 L
s
.20969 .61428 m
.20969 .61803 L
s
.30264 .61428 m
.30264 .61803 L
s
.34911 .61428 m
.34911 .61803 L
s
.39558 .61428 m
.39558 .61803 L
s
.44205 .61428 m
.44205 .61803 L
s
.53499 .61428 m
.53499 .61803 L
s
.58146 .61428 m
.58146 .61803 L
s
.62793 .61428 m
.62793 .61803 L
s
.6744 .61428 m
.6744 .61803 L
s
.76734 .61428 m
.76734 .61803 L
s
.81382 .61428 m
.81382 .61803 L
s
.86029 .61428 m
.86029 .61803 L
s
.90676 .61428 m
.90676 .61803 L
s
.9997 .61428 m
.9997 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0268 m
1 .0268 L
s
.99375 .12369 m
1 .12369 L
s
.99375 .22058 m
1 .22058 L
s
.99375 .31748 m
1 .31748 L
s
.99375 .41437 m
1 .41437 L
s
.99375 .51126 m
1 .51126 L
s
.99375 .60815 m
1 .60815 L
s
.125 Mabswid
.99625 .05102 m
1 .05102 L
s
.99625 .07525 m
1 .07525 L
s
.99625 .09947 m
1 .09947 L
s
.99625 .14792 m
1 .14792 L
s
.99625 .17214 m
1 .17214 L
s
.99625 .19636 m
1 .19636 L
s
.99625 .24481 m
1 .24481 L
s
.99625 .26903 m
1 .26903 L
s
.99625 .29325 m
1 .29325 L
s
.99625 .3417 m
1 .3417 L
s
.99625 .36592 m
1 .36592 L
s
.99625 .39014 m
1 .39014 L
s
.99625 .43859 m
1 .43859 L
s
.99625 .46281 m
1 .46281 L
s
.99625 .48703 m
1 .48703 L
s
.99625 .53548 m
1 .53548 L
s
.99625 .5597 m
1 .5597 L
s
.99625 .58393 m
1 .58393 L
s
.99625 .00258 m
1 .00258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.18233 .31696 m
.18233 .41921 L
s
.015 w
.18233 .36808 Mdot
.002 w
.3443 .3666 m
.3443 .5422 L
s
.015 w
.3443 .4544 Mdot
.002 w
.58843 .37967 m
.58843 .60332 L
s
.015 w
.58843 .4915 Mdot
.002 w
.97619 .01472 m
.97619 .17864 L
s
.015 w
.97619 .09668 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{525.25, 324.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008=0001A2000`400?l00000o`00003oo`3ooooo
0?ooo`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00o`3ooooo0?ooo`l0oooo
003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00o`3ooolN0?ooo`040?noM000M;l0oooo
0;md00H0000000D0B9cO0?ooo`3oool0_gA809cOo`3Q0?ooo`00o`3ooolL0?ooo`080?noM0000000
001d0;ooo`3oool0oono07@00000M;l30?ooo`080?oOW01dW=l0oooo0?ooo`3ogi`0B0000000B02L
gooO0?ooo`00o`3ooolJ0?ooo`040?noM0000000001809cOo`@0oooo00<0omnL04P0001d_ol00P3o
ool00`3ooml0_koO0?ooo`030?ooo`040?oOW0180000001809cOomd0oooo003o0?oooaP0oooo00@0
omnL04P0000004P0W=oo1`3oool00`3OW4P0001809cOo`090?ooo`040?noM0000000001809cOom/0
oooo003o0?oooaH0oooo00@0omnL04P0000004P0W=oo2@3oool0103ooml0W4P00018W03Oool:0?oo
o`040?noM0000000001d0;ooomT0oooo003o0?oooaD0oooo00<0_g@00000B02Lgol0303oool00`3o
okl0M000001d_`0<0?ooo`030?noM0000000B9cO0=P0oooo003o0?oooaH0oooo00@0omnL04P00000
04P0W=oo1`3oool01`3ogi`0W;oo0?ooo`3oool0okmd0000001d_ol02@3oool0103o_g@000000000
M02ooooI0?ooo`00o`3ooolH0?ooo`040?oOW0180000001809cOo`D0oooo00<0oono09bLg`3oool0
0P3oool00`2oM000001d0;ooo`060?ooo`040?noM0000000001809cOom/0oooo003o0?oooaX0oooo
00@0okmd0000000004P0W=oo0`3oool00`3ookl0M00000000004000000030018W03Oool0oooo0080
oooo00@0omnL04P0000004P0W=oog@3oool00?l0oooo703oool0103o_g@000000000M02oool;0?oo
o`040?oOW0180000001809cOoml0oooo003o0?oooah0oooo00<0okmd001d_`3oool02P3oool00`2o
M4P0W=oo0?ooo`3P0?ooo`00o`3ooooo0?ooo`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3o
ool?0?ooo`00o`3ooooo0?ooo`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00
o`3ooooo0?ooo`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00o`3ooooo0?oo
o`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00o`3ooooo0?ooo`l0oooo003o
0?ooool0oooo3`3oool005T0oooo00@0_g@0000000000000B9cOG@3oool00`3o_g@0000000000002
00000003001d_`3oool0oooo05P0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`1H
0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0G`3oool00`3o_g@0000007Boo`0V
0?ooo`00E`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0GP3oool00`2oM000001d0;oo
o`1L0?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool0F03oool0203ogi`0B0000018
W03Oool0oooo0?oOW01804P0W=ooG`3oool00`3o_g@0000007Boo`0V0?ooo`00E`3oool00`3o_g@0
001809cOo`020?ooo`030?oOW0180000M;oo05d0oooo00<0_g@00000M02oool0G@3oool00`3OW4P0
B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo05l0oooo00<0okmd0018W03Oool0GP3oool00`3o_g@0
000007Boo`0V0?ooo`00EP3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo05d0
oooo00<0_g@00000M02oool0GP3oool00`3OW4P0B9cO0?ooo`1S0?ooo`030?noM00004P0W=oo05T0
oooo00<0gia80000000000001@0000000`0004P0W=oo0?ooo`0S0?ooo`00EP3oool00`3ookl0M000
001d_`040?ooo`030;md000007@0_ooo05`0oooo00<0_g@00000M02oool0G`3oool00`3OW4P0M;oo
0?ooo`1R0?ooo`030;md000004P0W=oo05T0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@00000
07Boo`0V0?ooo`00EP3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo05`0oooo00<0
_g@00000M02oool0G`3oool00`3ooml0W4Q809cOo`1Q0?ooo`040;md00000000001d0;oooeX0oooo
00L0gia807Boo`3oool0oooo0?noM0000000M;oo02H0oooo001F0?ooo`030?oOW0180000B9cO00@0
oooo00<0gia80000B02Lgol0G03oool00`2oM000001d0;ooo`1P0?ooo`030?oOW01807@0_ooo05d0
oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`1I0?ooo`070?oo_`1d07@0_ooo0?oo
o`3o_g@0000007Boo`0V0?ooo`00EP3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo
05`0oooo00<0_g@00000M02oool0H@3oool00`2oM000B9cO0?ooo`1N0?ooo`030?noM00004P0W=oo
05d0oooo00H0okmd001d_`3oool0okmd0000001d_olV0?ooo`00EP3oool00`3ookl0M000001d_`04
0?ooo`030;md000007@0_ooo05`0oooo00<0_g@00000M02oool0H@3oool00`3OW4P0001d0;ooo`1O
0?ooo`030?oOW018M;l0oooo05d0oooo00D0_g@007Boo`3o_g@0000007Boo`0V0?ooo`00E`3oool0
0`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo05d0oooo00<0_g@00000M02oool0H@3oool0
0`3o_g@0000007Boo`1O0?ooo`030?oog`2LB000B9cO05d0oooo00D0oono07@0M02o_g@0000007Bo
o`0V0?ooo`00E`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo05d0oooo00<0_g@0
0000M02oool0F`3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo05X0oooo00<0oooO
09adW03Oool00P3oool00`3ooml0W4P0001d_`1N0?ooo`040?noM0000000000007BoobH0oooo001H
0?ooo`060;md0000B9`0gooo0?ooo`2oM00007BoG03oool01@3OW4P000000000000007@0_ooo05`0
oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=oooe/0oooo00L0omnL04Q8W03Oool0oooo
0=nLB0000000M;oo05h0oooo00@0oooO09a800000000M;oo9P3oool005T0oooo00@0_g@000000000
000007BoGP3oool0103ookl0M0000000M02ooomM0?ooo`050;md00000000000000000000M;l0GP3o
ool01@3ogi`0B000000000000000B9cO0600oooo00<0omnL04P0001d_ol09P3oool00?l0ooooo`3o
ool?0?ooo`00o`3ooooo0?ooo`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00
o`3ooooo0?ooo`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00o`3ooooo0?oo
o`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3oool?0?ooo`00D@3ooooo00000:T00000503o
ool00540oooo0`0000070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0?0?ooo`<00000503oool00540oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool20000
01@0oooo001A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0G`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0G`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?l0oooo
Y@3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<0
00000?ooo`3oool04P3oool003@0oooo00@0_g@0000000000000B9cO103oool00`3OW4P0000004RL
g`030?ooo`060?oOW018000000000000000004P0W=oo2@3oool00`000000oooo0?ooo`3o0?oooi/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`00<P3oool01`3ooml0W4P0
001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`080?oOW018000004RL
0=ooo`3oool0omnL04P0001d_ol80?ooo`030000003oool0oooo0?l0ooooV`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0180oooo000b0?ooo`030?noM00004P0W=oo0080oooo00<0
omnL04P0001d_ol01`3oool00`2oM000001d0;ooo`030?ooo`030=nLB000B9`0gooo00L0oooo00<0
00000?ooo`3oool0o`3ooonK0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3o
ool00340oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`070?ooo`030;md0000
07@0_ooo00<0oooo00<0_g@00018W03Oool01`3oool00`000000oooo0?ooo`3o0?oooi/0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`00<@3oool00`3ookl0M000001d_`04
0?ooo`030;md000007@0_ooo00H0oooo00<0okmd0000B02Lgol00P3oool00`3OW4P00000001d_`08
0?ooo`030000003oool0oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0180oooo000a0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01`3oool01`3O
W4P007Bo0?ooo`2oM00000000000M02oool0203oool00`000000oooo0?ooo`3o0?oooi/0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`00<@3oool00`3ogi`0B00004RLg`04
0?ooo`030=nLB00004P0W=oo00P0oooo00D0okmd00000000000004RL0=ooo`090?ooo`@00000o`3o
oonJ0?ooo`030000003oool0oooo00@0oooo1000000D0?ooo`00<@3oool00`3ogi`0B00004RLg`04
0?ooo`030=nLB00004P0W=oo00L0oooo00D0omnL04P000000000000004RLg`0:0?ooo`030000003o
ool0oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo000a
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool01`3ogi`0B0000000B02L
gol0oooo0=nLB000M;l02@3oool00`000000oooo0?ooo`3o0?oooi/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0B0?ooo`00<P3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2L
B00007Bo00L0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P007Boo`080?ooo`030000003o
ool0oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo000b
0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`3OW4P004RL0=ooo`02
0?ooo`030?oog`2LB000B9cO00P0oooo00<000000?ooo`3oool0o`3ooonK0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool04P3oool003<0oooo00H0_g@00018W03Oool0oooo0;md0000
M;l80?ooo`030?oOW0180000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?oo
o`3o0?oooi/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`00=03oool0
102oM000000000000000M;l:0?ooo`060?oo_`1d000000000000000004P0W=oo2@3oool00`000000
oooo0?ooo`3o0?oooi/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`00
D@3oool00`000000oooo0?ooo`3o0?oooi/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooi/0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooi/0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool300000?l0ooooV`3oool00`00
0000oooo0?ooo`050?ooo`<00000503oool00540oooo00<000000?ooo`3oool0o`3ooonK0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0
o`3ooonK0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00540oooo00<0
00000?ooo`3oool0o`3ooonK0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3o
ool00540oooo00<000000?ooo`3oool0o`3ooonK0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0o`3ooonK0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0o`3ooonK0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0
o`3ooonK0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00540oooo00<0
00000?ooo`3oool0o`3ooonK0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3o
ool00540oooo00<000000?ooo`3oool0o`3ooonK0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool04P3oool00540oooo0`00003o0?oooi/0oooo00<000000?ooo`3oool01@3oool30000
01@0oooo001A0?ooo`030000003oool0oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?l0ooooV`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?l0ooooV`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003oool0
oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo001A0?oo
o`030000003oool0oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0180oooo001A0?ooo`030000003oool0oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?l0ooooVP3oool2000000T0oooo
00<000000?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0o`3ooonI0?ooo`@00000203o
ool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooiP0oooo1P000007
0?ooo`030000003oool0oooo0180oooo001A0?ooo`<00000o`3ooonH0?ooo`H000001@3oool30000
01@0oooo001A0?ooo`030000003oool0oooo0?l0ooooV@3oool4000000P0oooo00<000000?ooo`3o
ool04P3oool00540oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`8000002@3oool00`000000oooo
0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooi/0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooi/0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`00@P3oool00`3o_g@00000000000020000
0003001d_`3oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonK0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool04P3oool004@0oooo00<0_g@00000M02oool02P3oool00`000000
oooo0?ooo`3o0?oooi/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`00
A03oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo0?l0ooooV`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0180oooo00140?ooo`030;md000007@0_ooo00X0oooo00<0
00000?ooo`3oool0o`3ooonK0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3o
ool004@0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?oooi/0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`00A03oool00`2oM000001d0;ooo`0:0?oo
o`030000003oool0oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0180oooo00140?ooo`030;md000007@0_ooo00X0oooo1000003o0?oooiX0oooo00<000000?ooo`3o
ool0103oool4000001@0oooo00140?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0
o`3ooonK0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool004@0oooo00<0
_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?oooi/0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0B0?ooo`00A03oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0
oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo00140?oo
o`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooonK0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool04P3oool00480oooo00D0gia8000000000000001d0;ooo`0:0?oo
o`030000003oool0oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0180oooo00130?ooo`040?oo_`1d0000001d0;ooo`X0oooo00<000000?ooo`3oool0o`3ooonK0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00540oooo00<000000?ooo`3o
ool0o`3ooonK0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00540oooo
00<000000?ooo`3oool0o`3ooonK0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
4P3oool00540oooo00<000000?ooo`3oool0o`3ooonK0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool04P3oool00540oooo0`00003o0?oooi/0oooo00<000000?ooo`3oool01@3oool3
000001@0oooo001A0?ooo`030000003oool0oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?l0ooooV`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?l0oooo
V`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003o
ool0oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo001A
0?ooo`030000003oool0oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0180oooo001A0?ooo`030000003oool0oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?l0ooooV`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?l0oooo
V`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003o
ool0oooo0?l0ooooV`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo001A
0?ooo`<00000o`3ooonK0?ooo`030000003oool0oooo00D0oooo0`00000D0?ooo`00D@3oool00`00
0000oooo0?ooo`3o0?oooi/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?oo
o`00D@3oool00`000000oooo0?ooo`3o0?oooi/0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooi/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<0
00000?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0
oooo0180oooo001A0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`0B0?oo
o`00D@3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool04P3oool00540oooo
00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003o
ool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool300000?l0ooooX`3oool3
000001@0oooo001A0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`0B0?oo
o`00D@3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool04P3oool00540oooo
00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003o
ool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`0B0?ooo`00<`3oool00`3o_g@0000000000002
00000009001d_`3oool0oooo0?ooo`3OW4P0000004RLg`3oool0gia800L0000000<0M;oo0?ooo`3o
ool01P3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool04P3oool003D0oooo
00<0_g@00000M02oool0103oool00`3OW4P0000004RLg`020?ooo`030=nLB0000000000000@00000
00<007Bo0?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool0
4P3oool003D0oooo00<0_g@00000M02oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2L
B7@0_ooo00L0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo0180oooo000e
0?ooo`030;md000007@0_ooo00/0oooo00<0gia804RLg`3oool02`3oool00`000000oooo0?ooo`3o
0?ooojD0oooo00<000000?ooo`3oool04P3oool003D0oooo00<0_g@00000M02oool0303oool00`3O
W4P0M;oo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`0B0?oo
o`00=@3oool00`2oM000001d0;ooo`0<0?ooo`030?oog`2LB4P0W=oo00X0oooo1000003o0?oooj40
oooo1000000D0?ooo`00=@3oool00`2oM000001d0;ooo`0=0?ooo`030?oOW01807@0_ooo00T0oooo
00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo0180oooo000e0?ooo`030;md0000
07@0_ooo00h0oooo00<0_g@004RLg`3oool0203oool00`000000oooo0?ooo`3o0?ooojD0oooo00<0
00000?ooo`3oool04P3oool003D0oooo00<0_g@00000M02oool03P3oool00`3OW4P0001d0;ooo`08
0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`0B0?ooo`00=@3oool00`2o
M000001d0;ooo`0>0?ooo`030?noM0000000M;oo00P0oooo00<000000?ooo`3oool0o`3ooonU0?oo
o`030000003oool0oooo0180oooo000e0?ooo`030;md000007@0_ooo00P0oooo00<0omnL09boo`3o
ool00`3oool00`2oM000000007Boo`080?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000
oooo0?ooo`0B0?ooo`00<`3oool01@3OW4P000000000000007@0_ooo00T0oooo00P0_g@007Boo`3o
ool0oooo0=nLB000000004RL0=ooo`P0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003o
ool0oooo0180oooo000d0?ooo`040?oo_`1d0000001d0;ooo`X0oooo00D0_g@00000000000000000
001d_`0:0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`0B0?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool04P3oool00540oooo00<00000
0?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo
0?l0ooooY@3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool300000?l0ooooX`3oool3000001@0
oooo001A0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`0B0?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool04P3oool00540oooo00<00000
0?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo
0?l0ooooY@3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooojD0
oooo00<000000?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000
003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?oo
o`0B0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool04P3oool0
0540oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo0180oooo001A0?ooo`<0
0000o`3ooonS0?ooo`<00000503oool00540oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000
003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?oo
o`0B0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool04P3oool0
0540oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0oooo0180oooo001A0?ooo`03
0000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo
0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0o`3o
oonU0?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?l0ooooY@3oool0
0`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?oo
o`3oool04P3oool00540oooo0`00003o0?oooj<0oooo0`00000D0?ooo`007P3oool01P3ogi`0B000
0018W03Oool0oooo0;md0080000000<0M;oo0?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?oo
ojD0oooo00<000000?ooo`3oool04P3oool001d0oooo00H0oooO09a80000000004RL0=ooo`3OW4P3
000000030018W03Oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooonU0?ooo`030000003oool0
oooo0180oooo000M0?ooo`0;0?oOW01dW=l0oooo0?ooo`3ookl0M01d0;ooo`3oool0gia80000M02o
ool0:@3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool04P3oool001d0oooo
00H0okmd07Boo`3oool0oooo0=nLB01d_ol20?ooo`030?oOW018M;l0oooo02T0oooo00<000000?oo
o`3oool0o`3ooonU0?ooo`030000003oool0oooo0180oooo000M0?ooo`060?noM000M;l0oooo0?oo
g`2LM9`0gooo0P3oool00`2oM7@0_ooo0?ooo`0;0?ooo`030?noM000000000000080000000L007Bo
0?ooo`3oool0oooo0=nLB0000000B9cO00H0oooo00<0okmd0000001d_ol02@3oool00`000000oooo
0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool04P3oool001d0oooo00<0oono07@0000000001P00
00000`00M;l0oooo0?ooo`0<0?ooo`030;md000007@0_ooo00@0oooo00<0gia800000018W=l01P3o
ool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?oo
o`0B0?ooo`007P3oool00`3OW4P0000000000005000000030000M02oool0oooo00`0oooo00<0_g@0
0000M02oool03@3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo0?l0ooooY@3oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`3o_g@007Bo0?ooo`0=0?ooo`030;md000007@0_ooo
00P0oooo00<0gia80000000000001@0000000`0004P0W=oo0?ooo`060?ooo`030000003oool0oooo
0?l0ooooY@3oool00`000000oooo0?ooo`0B0?ooo`008@3oool02P3OW4P004RL0=ooo`3ooml0W4Qd
0;ooo`3oool0giad04Q8M02oool:0?ooo`030;md000007@0_ooo00P0oooo00<0omnL04Qd_`3oool0
0P3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo
0?ooo`0B0?ooo`00803oool00`3o_g@007Bo0?ooo`040?ooo`040;md0018W9`0M01d0;ooo`X0oooo
00<0_g@00000M02oool02@3oool01`3OW4P0M;oo0?ooo`3oool0okmd0000001d_ol02@3oool40000
04T0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`@00000503oool00200oooo00<0gia804RLg`3o
ool00P3oool01P3ooml0W4P007Boo`3ookl0M01d0;ooo`X0oooo00<0_g@00000M02oool02@3oool0
1`3ookl0M01d0;ooo`3oool0okmd0000001d_ol02@3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo0?l0ooooF03oool00`000000oooo0?ooo`0B0?ooo`00803oool02`3o_g@0001809cO
o`3oool0okmd0000B02Lgol0oooo0?oOW01807@0_ooo00X0oooo00<0_g@00000M02oool02P3oool0
1P3o_g@007Bo0?ooo`3o_g@0000007Boo`T0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`3o0?oooeP0oooo00<000000?ooo`3oool04P3oool00240oooo00@0gia800000000000007Bo
0P3oool0103ooml0W4P00018W03Oool:0?ooo`030;md000007@0_ooo00/0oooo00D0_g@007Boo`3o
_g@0000007Boo`090?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0o`3ooomH0?oo
o`030000003oool0oooo0180oooo000e0?ooo`030;md000007@0_ooo00/0oooo00D0oono07@0M02o
_g@0000007Boo`090?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0o`3ooomH0?oo
o`030000003oool0oooo0180oooo000e0?ooo`030;md000007@0_ooo00`0oooo00@0okmd00000000
0000M;oo2@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0ooooF03oool00`00
0000oooo0?ooo`0B0?ooo`00<`3oool01@3OW4P000000000000007@0_ooo00`0oooo00@0oooO09a8
00000000M;oo2@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0ooooF03oool0
0`000000oooo0?ooo`0B0?ooo`00=03oool0103ookl0M0000000M02oool=0?ooo`030?oOW0180000
M;oo00T0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`3o0?oooeP0oooo00<00000
0?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`3o0?oo
oeP0oooo00<000000?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`3o0?oooeP0oooo00<000000?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`3o0?oooeP0oooo00<000000?ooo`3oool04P3oool00540oooo0`00
001:0?ooo`030000003oool0oooo0?l0ooooEP3oool3000001@0oooo001A0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`030000003oool0oooo0180oooo001A0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`030000003oool0oooo
0180oooo001A0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`03
0000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
o`3ooomH0?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool0o`3ooomH0?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`030000003oool0oooo0180oooo001A0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`030000003oool0oooo
0180oooo001A0?ooo`030000003oool0oooo04X0oooo0P00003o0?oooeT0oooo00<000000?ooo`3o
ool04P3oool00540oooo00<000000?ooo`3oool0B@3oool400000?l0ooooF03oool00`000000oooo
0?ooo`0B0?ooo`00D@3oool3000004P0oooo1P0000110?ooo`030000003oool0oooo0?l0oooo4@3o
ool3000001@0oooo001A0?ooo`030000003oool0oooo04P0oooo1P0000110?ooo`030000003oool0
oooo0?l0oooo4`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`190?oo
o`@00000@P3oool00`000000oooo0?ooo`3o0?oooa<0oooo00<000000?ooo`3oool04P3oool00540
oooo00<000000?ooo`3oool0BP3oool2000004<0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`03
0000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`3o0?oooa<0oooo00<000000?ooo`3oool04P3oool00540oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0oooo4`3o
ool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0
oooo0180oooo001A0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool04P3oool00540
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo06@0
oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`2[0?ooo`030000003oool0oooo0180oooo001A0?ooo`<00000BP3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0Z@3oool3000001@0oooo001A
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool04P3oool00540oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`2[0?ooo`03
0000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0
4P3oool003<0oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3oool0gia800000018
W=l00`3oool01P3ooml0W4P0000000000000001d0;ooo`T0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`0B0?ooo`00=@3oool00`2oM000001d0;ooo`040?ooo`030=nLB0000000B9cO
0080oooo00P0oono07@00000B9`0gooo0?ooo`3OW4P0001809cOo`P0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0?ooo`0B0?ooo`00=@3oool00`2oM000001d0;ooo`090?ooo`030;md0000
07@0_ooo00<0oooo00<0_g@0001d_`3oool01`3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`2[0?ooo`030000003o
ool0oooo0180oooo000e0?ooo`030;md000007@0_ooo00P0oooo00<0oono07@00000M;l0103oool0
0`3OW4P0001d0;ooo`070?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool04P3oool0
03D0oooo00<0_g@00000M02oool0203oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0W=oo
00L0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00=@3oool00`2oM000
001d0;ooo`080?ooo`030?oOW0180000B9cO00<0oooo00@0oono07@0000007@0_ooo1`3oool40000
04T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
0:P0oooo1000000D0?ooo`00=@3oool00`2oM000001d0;ooo`080?ooo`090?oo_`1d000000000018
W03Oool0oooo0;md00000000B9cO00P0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?oo
o`0B0?ooo`00=@3oool00`2oM000001d0;ooo`080?ooo`050?oog`2LB000001d0;oOW01800000P00
00000`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool04P3o
ool003D0oooo00<0_g@00000M02oool02@3oool00`3o_g@0000004RLg`0=0?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0
oooo0180oooo000e0?ooo`030;md000007@0_ooo00T0oooo00@0oooO09a8000004P0W=oo303oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`0B0?ooo`00=@3oool00`2oM000001d0;ooo`0:0?ooo`040?oo_`1d0000001d
0;ooo`/0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo0:/0oooo00<000000?ooo`3oool04P3oool003<0oooo00D0gia8000000000000001d0;ooo`0;
0?ooo`040?oog`2LB0000000001d_`X0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool04P3oool003@0oooo00@0oono
07@0000007@0_ooo3@3oool01@3ogi`0B00000000000B9`0gooo00L0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0
4P3oool00540oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo0:/0oooo00<000000?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool04P3oool0
0540oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
0:/0oooo00<000000?ooo`3oool04P3oool00540oooo0`00002?0?ooo`030000003oool0oooo06@0
oooo00<000000?ooo`3oool0Z@3oool3000001@0oooo001A0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0180oooo
001A0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`2[0?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0180oooo001A0?oo
o`030000003oool0oooo08h0oooo0P00001V0?ooo`030000003oool0oooo0:/0oooo00<000000?oo
o`3oool04P3oool00540oooo00<000000?ooo`3oool0S@3oool4000006D0oooo00<000000?ooo`3o
ool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`2<0?ooo`H00000
I03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003o
ool0oooo08`0oooo1P00001T0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool04P3o
ool00540oooo00<000000?ooo`3oool0S@3oool4000006D0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`2>0?ooo`800000IP3oool00`00
0000oooo0?ooo`2[0?ooo`030000003oool0oooo0180oooo001A0?ooo`<00000S`3oool00`000000
oooo0?ooo`1T0?ooo`030000003oool0oooo0:T0oooo0`00000D0?ooo`00D@3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo
0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B
0?ooo`00D@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00
D@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool3000008l0
oooo00<000000?ooo`3oool0H`3oool200000:/0oooo0`00000D0?ooo`00D@3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo0680oooo1000002/0?ooo`030000003oool0oooo0180oooo
001A0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0H@3oool600000:/0oooo00<0
00000?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`1Q
0?ooo`H00000Z`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo0680oooo1000002/0?ooo`030000003oool0oooo0180oooo000c0?ooo`03
0?noM000000000000080000000L007Bo0?ooo`3oool0oooo0=nLB0000000B9cO00<0oooo00H0omnL
04P00000000000000000B02Lgol90?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
H`3oool200000:d0oooo00<000000?ooo`3oool04P3oool003D0oooo00<0_g@00000M02oool0103o
ool00`3OW4P0000004RLg`020?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0001d_ol80?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`2[0?oo
o`030000003oool0oooo0180oooo000e0?ooo`030;md000007@0_ooo00T0oooo00<0_g@00000M02o
ool00`3oool00`3OW4P004RL0=ooo`070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool0I03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0180oooo000e0?ooo`030;md
000007@0_ooo00T0oooo00<0_g@00000M02oool00`3oool00`2oM00004RL0=ooo`070?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`2[0?ooo`030000
003oool0oooo0180oooo000e0?ooo`030;md000007@0_ooo00T0oooo00<0okmd0000B02Lgol00P3o
ool00`3OW4P00000001d_`080?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0180oooo000e0?ooo`030;md000007@0
_ooo00X0oooo00L0gia8001d_`3oool0_g@00000000007@0_ooo00P0oooo1000002>0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool0Z03oool4000001@0oooo000e0?ooo`030;md0000
07@0_ooo00/0oooo00D0okmd00000000000004RL0=ooo`090?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0180oooo
000e0?ooo`030;md000007@0_ooo00X0oooo00D0omnL04P000000000000004RLg`0:0?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`2[0?ooo`030000
003oool0oooo0180oooo000e0?ooo`030;md000007@0_ooo00T0oooo00L0omnL04P0000004P0W=oo
0?ooo`3OW4P007Bo00T0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo0:/0oooo00<000000?ooo`3oool04P3oool003D0oooo00<0_g@00000M02oool0
2@3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000M;oo00P0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0
4P3oool003D0oooo00<0_g@00000M02oool02@3oool00`3OW4P004RL0=ooo`020?ooo`030?oog`2L
B000B9cO00P0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo0:/0oooo00<000000?ooo`3oool04P3oool003<0oooo00D0gia8000000000000001d0;oo
o`090?ooo`030?oOW0180000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?oo
o`0B0?ooo`00=03oool0103ookl0M0000000M02oool:0?ooo`060?oo_`1d000000000000000004P0
W=oo2@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3o
ool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00D@3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0Z`3o
ool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool30000
08l0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`2Y0?ooo`<00000503oool00540
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0:/0
oooo00<000000?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool04P3oool00540oooo00<0
00000?ooo`3oool0mP3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0180oooo001A
0?ooo`030000003oool0oooo0?H0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B
0?ooo`00D@3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo0:/0oooo00<000000?oo
o`3oool04P3oool00540oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`2[0?ooo`03
0000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?H0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`3f0?ooo`030000003o
ool0oooo0:/0oooo00<000000?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0mP3oool0
0`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0180oooo001A0?ooo`<00000mP3oool00`00
0000oooo0?ooo`2Y0?ooo`<00000503oool00540oooo00<000000?ooo`3oool0mP3oool00`000000
oooo0?ooo`2[0?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?H0oooo
00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?oo
o`3f0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool04P3oool00540oooo00<00000
0?ooo`3oool0mP3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0180oooo001A0?oo
o`030000003oool0oooo0?H0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B0?oo
o`00D@3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3o
ool04P3oool00540oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`2[0?ooo`030000
003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?H0oooo00<000000?ooo`3oool0Z`3o
ool00`000000oooo0?ooo`0B0?ooo`00D@3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0
oooo0:/0oooo00<000000?ooo`3oool04P3oool00540oooo0`00003f0?ooo`030000003oool0oooo
0:T0oooo0`00000D0?ooo`00D@3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo0:/0
oooo00<000000?ooo`3oool04P3oool00540oooo00<000000?ooo`3oool0mP3oool00`000000oooo
0?ooo`2[0?ooo`030000003oool0oooo0180oooo001A0?ooo`030000003oool0oooo0?H0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00@03oool00`3OW4P0000000000005
0000000307Boo`3oool0oooo00H0oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`2[
0?ooo`030000003oool0oooo0180oooo00110?ooo`030=nLB0000000000000@0000000<007Bo0?oo
o`3oool01P3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo0:/0oooo00<000000?oo
o`3oool04P3oool00480oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`070?ooo`03
0000003oool0oooo0?H0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00
@`3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030000003oool0oooo0?H0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0?ooo`0B0?ooo`00A03oool00`3OW4P0M;oo0?ooo`0:0?ooo`030000003o
ool0oooo0?H0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0B0?ooo`00A03oool0
0`3ooml0W4Q809cOo`0:0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`0B
0?ooo`00A@3oool00`3ogi`0B01d0;ooo`090?ooo`@00000o`3ooonQ0?ooo`@00000503oool004H0
oooo00<0_g@004RLg`3oool0203oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3o
ool04P3oool004H0oooo00<0gia80000M02oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo05l0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo05l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`00AP3o
ool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo0P00000D0?ooo`00@03oool0
0`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo00P0ooooo`00002Y000001@0oooo00110?oo
o`080;md001d_ol0oooo0?ooo`3OW4P000000018W03Ooooo0?ooolD0oooo00120?ooo`050;md0000
0000000000000000M;l0o`3oooo70?ooo`00o`3ooooo0?ooo`l0oooo003o0?ooool0oooo3`3oool0
0?l0ooooo`3oool?0?ooo`00o`3ooooo0?ooo`l0oooo003o0?ooool0oooo3`3oool00?l0ooooo`3o
ool?0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 524.25}, {323.625, 0}} -> {-0.933953, 0.478858, \
0.0101867, 0.00488576}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ 
        Use\ Maximum\ Likelihood\ Method\ to\ find\ best\ fit\ straight\ \
lines\ going\ through\ the\ four\ datapoints\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    \(\(a1p[a1a1_, b1a1_, x_] := a1a1 + b1a1\ x;\)\)], "Input"],

Cell[BoxData[
    \(\(chi2a1[a1a1_, b1a1_] := 
        Sum[\((\((a1pl[\([i, 2]\)] - 
                    a1p[a1a1, b1a1, a1pl[\([i, 1]\)]])\)/\((a1pl[\([i, 
                      3]\)])\))\)^2, {i, 1, Length[a1pl]}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(par = {a1a1, b1a1};\)\), "\n", 
    \(\(akla1[a1a1_, b1a1_, k_, l_] := 
        1/2  D[D[chi2a1[a1a1, b1a1], par[\([k]\)]], 
            par[\([l]\)]\ ];\)\), "\n", 
    \(\(fmina1 = 
        FindMinimum[
          chi2a1\ [a1a1, b1a1], {a1a1, 1}, {b1a1, \(-10\)}];\)\), "\n", 
    \(\(a1a1o = fmina1[\([2, 1, 2]\)];\)\), "\n", 
    \(\(b1a1o = fmina1[\([2, 2, 2]\)];\)\), "\n", 
    \(akloa1 = 
      Table[If[k \[LessSlantEqual] 
            l, \(akla1[a1a1, b1a1, k, l] /. a1a1 \[Rule] a1a1o\) /. 
            b1a1 \[Rule] b1a1o, \(akla1[a1a1, b1a1, l, k] /. 
              a1a1 \[Rule] a1a1o\) /. b1a1 \[Rule] b1a1o], {k, 1, 2}, {l, 1, 
          2}]; cij = Inverse[akloa1]; 
    spara1 = Table[Sqrt[cij[\([i, i]\)]], {i, 1, 2}]; 
    Print["\<a1a1= \>", a1a1o, "\<+-\>", spara1[\([1]\)], "\<  b1a1= \>", 
      b1a1o, "\<+-\>", spara1[\([2]\)]]; 
    cij // MatrixForm\), "\[IndentingNewLine]", 
    \(chi2ra1 = Part[fmina1, 1]/\((Length[a1pl])\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("a1a1= "\[InvisibleSpace]52.043988892550026`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.07261668148434922`\[InvisibleSpace]"  \
b1a1= "\[InvisibleSpace]0.09902088530001407`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.029308102147016256`\),
      SequenceForm[ 
      "a1a1= ", 52.043988892550026, "+-", .072616681484349216, 
        "  b1a1= ", .099020885300014072, "+-", .029308102147016256],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.0052731824297994265`", \(-0.0017943408708789572`\)},
            {\(-0.0017943408708789572`\), "0.0008589648514599389`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    \(0.313081179980997`\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(a1pr = a1a1o + \ b1a1o\ z;\)\), "\[IndentingNewLine]", 
    \(\(a1prpl = 
        Plot[a1pr, {z, 0, 5}, 
          DisplayFunction \[Rule] Identity];\)\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ 
        Construct\ plot\ of\ best\ fit\ straight\ lines\ along\ with\ \
\(\(data\)\(.\)\)\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fb2 = 
      Show[a1prpl, a1dtpl, 
        Graphics[{Text[\*"\"\<2:\!\(E\_peak\)-L  Correlation Coefficient: \
r=0.94\>\"", {1.3, 52.4}]}], Frame \[Rule] True, Axes \[Rule] False, 
        DisplayFunction \[Rule] $DisplayFunction, PlotRange \[Rule] All, 
        FrameLabel \[Rule] {"\<<z>\>", \*"\"\<\!\(b\_2\)\>\""}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 -56.6033 1.08884 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -7.03125 -24.5625 ]
[.21429 -0.0125 7.03125 0 ]
[.40476 -0.0125 -7.03125 -24.5625 ]
[.40476 -0.0125 7.03125 0 ]
[.59524 -0.0125 -7.03125 -24.5625 ]
[.59524 -0.0125 7.03125 0 ]
[.78571 -0.0125 -7.03125 -24.5625 ]
[.78571 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.375 -49.125 ]
[.5 -0.0125 19.375 -24.5625 ]
[-0.0125 .01633 -24.125 -12.2813 ]
[-0.0125 .01633 0 12.2813 ]
[-0.0125 .12522 -39.1875 -12.2813 ]
[-0.0125 .12522 0 12.2813 ]
[-0.0125 .2341 -39.1875 -12.2813 ]
[-0.0125 .2341 0 12.2813 ]
[-0.0125 .34298 -39.1875 -12.2813 ]
[-0.0125 .34298 0 12.2813 ]
[-0.0125 .45187 -39.1875 -12.2813 ]
[-0.0125 .45187 0 12.2813 ]
[-0.0125 .56075 -39.1875 -12.2813 ]
[-0.0125 .56075 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -63.75 -10.8125 ]
[-0.01875 .30902 -39.1875 10.8125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.27143 .45187 -172.75 -13.0938 ]
[.27143 .45187 172.75 13.0938 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.375 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
75.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
84.813 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
97.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01633 m
.00625 .01633 L
s
gsave
-0.0125 .01633 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52) show
1.000 setlinewidth
grestore
0 .12522 m
.00625 .12522 L
s
gsave
-0.0125 .12522 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.1) show
1.000 setlinewidth
grestore
0 .2341 m
.00625 .2341 L
s
gsave
-0.0125 .2341 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.2) show
1.000 setlinewidth
grestore
0 .34298 m
.00625 .34298 L
s
gsave
-0.0125 .34298 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.3) show
1.000 setlinewidth
grestore
0 .45187 m
.00625 .45187 L
s
gsave
-0.0125 .45187 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.4) show
1.000 setlinewidth
grestore
0 .56075 m
.00625 .56075 L
s
gsave
-0.0125 .56075 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03811 m
.00375 .03811 L
s
0 .05989 m
.00375 .05989 L
s
0 .08166 m
.00375 .08166 L
s
0 .10344 m
.00375 .10344 L
s
0 .14699 m
.00375 .14699 L
s
0 .16877 m
.00375 .16877 L
s
0 .19055 m
.00375 .19055 L
s
0 .21232 m
.00375 .21232 L
s
0 .25588 m
.00375 .25588 L
s
0 .27765 m
.00375 .27765 L
s
0 .29943 m
.00375 .29943 L
s
0 .32121 m
.00375 .32121 L
s
0 .36476 m
.00375 .36476 L
s
0 .38654 m
.00375 .38654 L
s
0 .40832 m
.00375 .40832 L
s
0 .43009 m
.00375 .43009 L
s
0 .47365 m
.00375 .47365 L
s
0 .49542 m
.00375 .49542 L
s
0 .5172 m
.00375 .5172 L
s
0 .53898 m
.00375 .53898 L
s
0 .58253 m
.00375 .58253 L
s
0 .60431 m
.00375 .60431 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -123.281 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.8125 16.2813 translate
90 rotate
-71.8125 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
80.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01633 m
1 .01633 L
s
.99375 .12522 m
1 .12522 L
s
.99375 .2341 m
1 .2341 L
s
.99375 .34298 m
1 .34298 L
s
.99375 .45187 m
1 .45187 L
s
.99375 .56075 m
1 .56075 L
s
.125 Mabswid
.99625 .03811 m
1 .03811 L
s
.99625 .05989 m
1 .05989 L
s
.99625 .08166 m
1 .08166 L
s
.99625 .10344 m
1 .10344 L
s
.99625 .14699 m
1 .14699 L
s
.99625 .16877 m
1 .16877 L
s
.99625 .19055 m
1 .19055 L
s
.99625 .21232 m
1 .21232 L
s
.99625 .25588 m
1 .25588 L
s
.99625 .27765 m
1 .27765 L
s
.99625 .29943 m
1 .29943 L
s
.99625 .32121 m
1 .32121 L
s
.99625 .36476 m
1 .36476 L
s
.99625 .38654 m
1 .38654 L
s
.99625 .40832 m
1 .40832 L
s
.99625 .43009 m
1 .43009 L
s
.99625 .47365 m
1 .47365 L
s
.99625 .49542 m
1 .49542 L
s
.99625 .5172 m
1 .5172 L
s
.99625 .53898 m
1 .53898 L
s
.99625 .58253 m
1 .58253 L
s
.99625 .60431 m
1 .60431 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .06423 m
.06244 .0861 L
.10458 .10995 L
.14415 .13235 L
.18221 .15389 L
.22272 .17682 L
.26171 .19889 L
.30316 .22235 L
.34309 .24495 L
.3815 .2667 L
.42237 .28983 L
.46172 .3121 L
.49955 .33352 L
.53984 .35633 L
.57861 .37827 L
.61984 .40161 L
.65954 .42408 L
.69774 .4457 L
.73838 .46871 L
.77751 .49086 L
.81909 .5144 L
.85916 .53708 L
.89771 .5589 L
.93871 .58211 L
.97619 .60332 L
s
.002 w
.15376 .01472 m
.15376 .17055 L
s
.015 w
.15376 .09263 Mdot
.002 w
.28654 .2069 m
.28654 .38089 L
s
.015 w
.28654 .2939 Mdot
.002 w
.48667 .213 m
.48667 .40062 L
s
.015 w
.48667 .30681 Mdot
.002 w
.80454 .41504 m
.80454 .58249 L
s
.015 w
.80454 .49877 Mdot
gsave
.27143 .45187 -233.75 -17.0938 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
73.063 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
78.563 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
90.813 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(peak) show
117.938 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
130.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
153.125 23.000 moveto
(Correlation) show
249.250 23.000 moveto
(Coefficient) show
339.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
349.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
356.375 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
369.313 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.94) show
404.500 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{821.813, 507.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<e0001nb000`400?l00000o`00003oo`3ooooo
0?ooool0oooo>03oool00?l0ooooo`3ooooo0?ooocP0oooo003o0?ooool0ooooo`3ooolh0?ooo`00
o`3ooooo0?ooool0oooo>03oool00?l0ooooo`3ooooo0?ooocP0oooo003o0?ooool0ooooo`3ooolh
0?ooo`00o`3ooonj0?ooo`040?noM000M;l0oooo0;md00H0000000D0B9cO0?ooo`3oool0_gA809cO
o`3o0?ooofh0oooo003o0?oookP0oooo00P0okmd0000000007@0_ooo0?ooo`3ookl0M000001d_`<0
oooo00P0omnL07BLg`3oool0oooo0?oOW0180000001809cOool0ooooK03oool00?l0oooo]P3oool0
103o_g@000000000B02Lgol40?ooo`030?oOW0180000M;oo0080oooo00<0oooO0;nog`3oool00`3o
ool0103ogi`0B0000000B02Lgooo0?ooofX0oooo003o0?oook@0oooo00@0omnL04P0000004P0W=oo
1`3oool00`3OW4P0001809cOo`090?ooo`040?noM0000000001809cOool0ooooJ03oool00?l0oooo
/P3oool0103ogi`0B0000000B02Lgol90?ooo`040?oog`2LB00004RL0=ooo`X0oooo00@0okmd0000
000007@0_oooo`3ooomV0?ooo`00o`3ooona0?ooo`030;md000004P0W=oo00`0oooo00<0oono07@0
0000M;l0303oool00`3o_g@0000004RLg`3o0?ooofD0oooo003o0?oook80oooo00@0omnL04P00000
04P0W=oo1`3oool01`3ogi`0W;oo0?ooo`3oool0okmd0000001d_ol02@3oool0103o_g@000000000
M02ooooo0?ooofH0oooo003o0?oook@0oooo00@0omnL04P0000004P0W=oo1@3oool00`3ookl0W9cO
0?ooo`020?ooo`030;md000007@0_ooo00H0oooo00@0okmd0000000004P0W=ooo`3ooomX0?ooo`00
o`3ooonf0?ooo`040?noM0000000001809cOo`<0oooo00<0oono07@000000000100000000`00B9`0
gooo0?ooo`020?ooo`040?oOW0180000001809cOool0ooooJP3oool00?l0oooo^03oool0103o_g@0
00000000M02oool;0?ooo`040?oOW0180000001809cOool0ooooK03oool00?l0oooo^P3oool00`3o
_g@007Bo0?ooo`0:0?ooo`030;mdB02Lgol0oooo0?l0ooooK@3oool00?l0ooooo`3ooooo0?ooocP0
oooo003o0?ooool0ooooo`3ooolh0?ooo`00o`3ooooo0?ooool0oooo>03oool00?l0ooooo`3ooooo
0?ooocP0oooo003o0?ooool0ooooo`3ooolh0?ooo`00o`3ooooo0?ooool0oooo>03oool00?l0oooo
o`3ooooo0?ooocP0oooo003o0?ooool0ooooo`3ooolh0?ooo`00o`3ooooo0?ooool0oooo>03oool0
0?l0ooooo`3ooooo0?ooocP0oooo003o0?ooool0ooooo`3ooolh0?ooo`00o`3ooooo0?ooool0oooo
>03oool00?l0ooooo`3ooooo0?ooocP0oooo003o0?ooool0ooooo`3ooolh0?ooo`00I@3oool0102o
M000000000000018W=n50?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool0P03oool0
0`3OW4P00000000000050000000307Boo`3oool0oooo0800oooo00<0oooO09a8000000000P000000
0`00B9`0gooo0?ooo`270?ooo`030?noM0000000M;oo08<0oooo00H0_g@000000000000000000018
W03OoolI0?ooo`00H`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0QP3oool00`2oM000
001d0;ooo`240?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool0P03oool0203ogi`0
B0000018W03Oool0oooo0?oOW01804P0W=ooQ`3oool00`3o_g@0000007Boo`220?ooo`030?oog`2L
B000B9cO0080oooo00<0omnL04Q8W03Oool0603oool006<0oooo00<0okmd0000B02Lgol00P3oool0
0`3ogi`0B00007Boo`250?ooo`030;md000007@0_ooo08D0oooo00<0gia804RLg`3oool00P3oool0
0`3ooml0W4Qd0;ooo`270?ooo`030?noM000B9`0gooo08H0oooo00<0okmd0000001d_ol0R03oool0
0`3ogi`0B7Bo0?ooo`0G0?ooo`00HP3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB000
07Bo08D0oooo00<0_g@00000M02oool0QP3oool00`3OW4P0B9cO0?ooo`2;0?ooo`030?noM00004P0
W=oo0840oooo00<0gia80000000000001@0000000`0004P0W=oo0?ooo`250?ooo`030?oo_`1d04P0
W=oo01L0oooo001R0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0Q03oool00`2o
M000001d0;ooo`270?ooo`030=nLB01d_ol0oooo08X0oooo00<0_g@00000B02Lgol0P@3oool00`3o
gi`0B7Bo0?ooo`020?ooo`030?noM0000000M;oo08P0oooo00<0oono07@0001d_ol05`3oool00680
oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`240?ooo`030;md000007@0_ooo08L0
oooo00<0oooO09a8B02Lgol0R@3oool0102oM00000000000M02ooon20?ooo`070=nLB01d_ol0oooo
0?ooo`3o_g@0000007Boo`280?ooo`030?noM0000000M;oo01L0oooo001R0?ooo`030?oOW0180000
B9cO00@0oooo00<0gia80000B02Lgol0Q03oool00`2oM000001d0;ooo`280?ooo`030?oOW01807@0
_ooo08D0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`210?ooo`070?oo_`1d07@0
_ooo0?ooo`3o_g@0000007Boo`270?ooo`040?oOW0180000001d0;oooaL0oooo001R0?ooo`030?oO
W0180000B9cO00@0oooo00<0gia80000B02Lgol0Q03oool00`2oM000001d0;ooo`290?ooo`030;md
0018W=l0oooo08H0oooo00<0okmd0000B02Lgol0Q@3oool01P3o_g@007Bo0?ooo`3o_g@0000007Bo
oh<0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`0F0?ooo`00HP3oool00`3o
okl0M000001d_`040?ooo`030;md000007@0_ooo08@0oooo00<0_g@00000M02oool0R@3oool00`3O
W4P0001d0;ooo`270?ooo`030?oOW018M;l0oooo08D0oooo00D0_g@007Boo`3o_g@0000007Boo`23
0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool05`3oool006<0oooo00<0_g@00018
W03Oool00P3oool00`3ooml0W4P0001d_`250?ooo`030;md000007@0_ooo08T0oooo00<0okmd0000
001d_ol0Q`3oool00`3ooml0W4P004RLg`250?ooo`050?oo_`1d07@0_kmd0000001d_ol0P`3oool0
1@3ooml0W4P00000000007@0_ooo01X0oooo001S0?ooo`030?noM00004P0W=oo0080oooo00<0omnL
04P0001d_ol0Q@3oool00`2oM000001d0;ooo`230?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@0
0000001d_ol0PP3oool00`3ooml0W7BL0=ooo`020?ooo`030?oog`2LB00007Bo08H0oooo00@0okmd
000000000000M;ooQ03oool00`3o_g@007Bo0?ooo`0K0?ooo`00I03oool01P2oM00004RL0=ooo`3o
ool0_g@0001d_h@0oooo00D0gia8000000000000001d0;ooo`240?ooo`080;md001d_ol0oooo0?oo
o`3OW4P000000018W03Ooon30?ooo`070?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`260?ooo`04
0?oog`2LB000000007Booh@0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`0F0?oo
o`00I@3oool0102oM000000000000000M;n60?ooo`040?oo_`1d0000001d0;ooohD0oooo00D0_g@0
0000000000000000001d_`260?ooo`050?oOW0180000000000000018W=l0R03oool00`3ogi`0B000
07Boo`250?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool05@3oool00?l0ooooo`3o
oooo0?ooocP0oooo003o0?ooool0ooooo`3ooolh0?ooo`00o`3ooooo0?ooool0oooo>03oool00?l0
ooooo`3ooooo0?ooocP0oooo003o0?ooool0ooooo`3ooolh0?ooo`00o`3ooooo0?ooool0oooo>03o
ool00?l0ooooo`3ooooo0?ooocP0oooo003o0?ooool0ooooo`3ooolh0?ooo`00o`3ooooo0?ooool0
oooo>03oool00?l0ooooo`3ooooo0?ooocP0oooo003o0?ooool0ooooo`3ooolh0?ooo`00o`3ooooo
0?ooool0oooo>03oool00?l0ooooo`3ooooo0?ooocP0oooo003o0?ooool0ooooo`3ooolh0?ooo`00
E@3ooooo00000?l00000fP0000080?ooo`00E@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`00E@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00H0oooo001E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`270?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`270?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool005D0oooo
00<000000?ooo`3oool0o`3ooooo0?ooomH0oooo00<000000?ooo`3oool01P3oool003L0oooo00H0
_g@000000000000000000018W03Oool30?ooo`030=nLB0000000000000D0000000<0M;oo0?ooo`3o
ool02P3oool00`000000oooo0?ooo`3o0?ooool0ooooeP3oool00`000000oooo0?ooo`060?ooo`00
=P3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00<0oooo00<0gia8000000000000
100000000`00M;l0oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooo`3ooooF0?ooo`030000
003oool0oooo00H0oooo000l0?ooo`030?oOW018M;l0oooo00<0oooo00<0gia804RLg`3oool00P3o
ool00`3ooml0W4Qd0;ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooooF0?ooo`030000003o
ool0oooo00H0oooo000l0?ooo`030?oo_`1d04P0W=oo00@0oooo00<0gia804RLg`3oool03`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooeP3oool00`000000oooo0?ooo`060?ooo`00?03oool00`3o
okl0M00007Boo`050?ooo`030=nLB01d_ol0oooo00h0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`060?ooo`00?03oool00`3o_g@0
000007Boo`050?ooo`030?oog`2LB4P0W=oo00h0oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`060?ooo`00>`3oool0103ogi`0B000
0000M02oool60?ooo`030?oOW01807@0_ooo00d0oooo1P00001Z0?ooo`030000003oool0oooo0?l0
ooooo`3ooomQ0?ooo`H00000203oool003L0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0
oooo0?ooo`060?ooo`030;md0018W=l0oooo00`0oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`060?ooo`00=`3oool00`3o_g@00000
0000000200000003001d_`3oool0oooo00L0oooo00<0gia80000M02oool0303oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?ooo`030000003oool0oooo00H0oooo
000g0?ooo`050?oog`2LB00000000000M02oool02P3oool00`3o_g@0000007Boo`0<0?ooo`030000
003oool0oooo06d0oooo00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<000000?ooo`3oool0
1P3oool003P0oooo00<0okmd001d_`3oool01@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md0000
0000M;oo00`0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`3o0?ooool0ooooIP3o
ool00`000000oooo0?ooo`060?ooo`00>03oool00`3ooml0W4P000000002000000060000M02oool0
oooo0?ooo`2oM000M;oo0P3oool0103OW4P000000018W03Oool<0?ooo`030000003oool0oooo06d0
oooo00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<000000?ooo`3oool01P3oool003T0oooo
00<0okmd0000000000000P0000001@1d_ol0oooo0?ooo`3oool0_g@000<0000000<007Bo0?ooo`3o
ool0303oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?ooo`03
0000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
o`3ooooo0?ooofH0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`060?ooo`00E@3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?ooo`030000003oool0
oooo00H0oooo001E0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ofH0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?ooo`030000003oool0oooo00H0oooo
001E0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<0
00000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`3o
0?ooool0ooooIP3oool00`000000oooo0?ooo`060?ooo`00E@3oool4000006`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooof<0oooo100000080?ooo`00E@3oool00`000000oooo0?ooo`1]0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomV0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000
003oool0oooo06d0oooo00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<000000?ooo`3oool0
1P3oool005D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`3o0?ooool0ooooIP3o
ool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo0?l0ooooo`3ooomV0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo
06d0oooo00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<000000?ooo`3oool01P3oool005D0
oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000
oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0?l0oooo
o`3ooomV0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo06d0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooofH0oooo00<000000?ooo`3oool01P3oool005D0oooo00<00000
0?ooo`3oool0K@3oool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`06
0?ooo`00E@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?oo
o`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooofH0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`060?ooo`00E@3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?ooo`030000003o
ool0oooo00H0oooo001E0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0o`3ooooo
0?ooofH0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`060?ooo`00E@3oool4000006`0
oooo00<000000?ooo`3oool0o`3ooooo0?ooof<0oooo100000080?ooo`00E@3oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?ooo`030000003oool0oooo00H0oooo
001E0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<0
00000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?ooo`030000003oool0oooo00H0oooo001E0?oo
o`030000003oool0oooo0100oooo0P00001K0?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?oo
o`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0180oooo0P00001I0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomV0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000
003oool0oooo01@0oooo0P00001G0?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?ooo`030000
003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`060?ooo`00E@3oool0
0`000000oooo0?ooo`0G0?ooo`800000E03oool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool0
0`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`0I0?ooo`800000DP3oool00`00
0000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000
oooo0?ooo`0K0?ooo`800000D03oool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000
oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<000000?ooo`3oool01P3oool005D0oooo00<0
00000?ooo`3oool07P3oool2000004d0oooo00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<0
00000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0803oool2000004/0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooofH0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?oo
o`3oool08P3oool2000004T0oooo00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<000000?oo
o`3oool01P3oool005D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo0?l0ooooo`3ooomV0?ooo`030000003oool0oooo00H0oooo001E0?ooo`@00000
903oool2000004H0oooo00<000000?ooo`3oool0o`3ooooo0?ooof<0oooo100000080?ooo`00E@3o
ool00`000000oooo0?ooo`0W0?ooo`800000A03oool00`000000oooo0?ooo`3o0?ooool0ooooIP3o
ool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`0Y0?ooo`800000@P3oool0
0`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ofH0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0;03oool2000003h0
oooo0P00003o0?ooool0ooooJ03oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo
0?ooo`0^0?ooo`800000>P3oool600000?l0ooooo`3ooomV0?ooo`030000003oool0oooo00H0oooo
001E0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0=P3oool800000?l0ooooo`3o
oomU0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0340oooo0P00000f
0?ooo`P00000o`3ooooo0?ooofD0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?oo
o`3oool0<`3oool2000003<0oooo2P00003o0?ooool0ooooI03oool00`000000oooo0?ooo`060?oo
o`00E@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0300oooo2P00003o0?ooool0
ooooI03oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`0f0?ooo`800000
<@3oool800000?l0ooooo`3ooomU0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003o
ool0oooo03P0oooo0P00000_0?ooo`P00000o`3ooooo0?ooofD0oooo00<000000?ooo`3oool01P3o
ool005D0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0]0?ooo`H00000o`3ooooo
0?ooofH0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0>`3oool20000
02l0oooo0P00003o0?ooool0ooooJ03oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000
oooo0?ooo`0m0?ooo`800000;P3oool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000
oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<000000?ooo`3oool01P3oool005D0oooo1000
000o0?ooo`800000:`3oool00`000000oooo0?ooo`3o0?ooool0ooooH`3oool4000000P0oooo001E
0?ooo`030000003oool0oooo0480oooo0P00000Y0?ooo`030000003oool0oooo0?l0ooooo`3ooomV
0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`060?oo
o`00E@3oool00`000000oooo0?ooo`150?ooo`8000009P3oool00`000000oooo0?ooo`3o0?ooool0
ooooIP3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`170?ooo`800000
903oool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`060?ooo`00E@3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3o
oooo0?ooofH0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0BP3oool2
00000240oooo00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<000000?ooo`3oool01P3oool0
05D0oooo00<000000?ooo`3oool0C03oool2000001l0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ofH0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0CP3oool2000001d0
oooo00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<000000?ooo`3oool01P3oool005D0oooo
00<000000?ooo`3oool0D03oool2000001/0oooo00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo
00<000000?ooo`3oool01P3oool002P0oooo00H0_g@000000000000000000018W03Oool30?ooo`03
0=nLB0000000000000D0000000H0M;oo0?ooo`3oool0gia800000018W=l30?ooo`030?noM0000000
00000080000000<007Bo0?ooo`3oool02`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<000000?ooo`3oool01P3oool0
02L0oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`030?ooo`030=nLB00000000000
00@0000000H007Bo0?ooo`3oool0gia800000018W=l50?ooo`030;md000007@0_ooo00h0oooo00<0
00000?ooo`3oool0D`3oool2000001P0oooo00<000000?ooo`3oool0o`3ooooo0?ooofH0oooo00<0
00000?ooo`3oool01P3oool002d0oooo00<0omnL04Qd_`3oool00`3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?oog`2LB7@0_ooo00T0oooo00<0_g@00000M02oool03P3oool00`000000oooo0?ooo`1E
0?ooo`8000005P3oool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`06
0?ooo`00;@3oool00`3ookl0M01809cOo`040?ooo`030=nLB018W=l0oooo00d0oooo00<0_g@00000
M02oool03P3oool00`000000oooo0?ooo`1G0?ooo`800000503oool00`000000oooo0?ooo`3o0?oo
ool0ooooIP3oool00`000000oooo0?ooo`060?ooo`00;@3oool00`3ookl0M00007Boo`050?ooo`03
0=nLB01d_ol0oooo00`0oooo00<0_g@00000M02oool03P3oool00`000000oooo0?ooo`1I0?ooo`80
00004P3oool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`060?ooo`00
;@3oool00`3o_g@0000007Boo`050?ooo`030?oog`2LB4P0W=oo00`0oooo00<0_g@00000M02oool0
3P3oool00`000000oooo0?ooo`1K0?ooo`800000403oool00`000000oooo0?ooo`3o0?ooool0oooo
IP3oool00`000000oooo0?ooo`060?ooo`00;03oool0103ogi`0B0000000M02oool60?ooo`030?oO
W01807@0_ooo00/0oooo00<0_g@00000M02oool03P3oool6000005X0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3o0?ooool0ooooH@3oool6000000P0oooo000X0?ooo`040=oOg`3o
ool0oooo0;md0080000000<0B9cO0?ooo`3oool01P3oool00`2oM000B9cO0?ooo`0:0?ooo`030;md
000007@0_ooo00h0oooo00<000000?ooo`3oool0GP3oool2000000d0oooo00<000000?ooo`3oool0
o`3ooooo0?ooofH0oooo00<000000?ooo`3oool01P3oool002P0oooo00<0okmd0000000000000P00
00000`00M;l0oooo0?ooo`070?ooo`030=nLB00007@0_ooo00X0oooo00<0_g@00000M02oool03P3o
ool00`000000oooo0?ooo`1P0?ooo`8000002`3oool00`000000oooo0?ooo`3o0?ooool0ooooIP3o
ool00`000000oooo0?ooo`060?ooo`00:03oool01@3ooml0W4P00000000007@0_ooo00X0oooo00<0
okmd0000001d_ol02P3oool00`2oM000001d0;ooo`0>0?ooo`030000003oool0oooo0680oooo0P00
00090?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?ooo`030000003oool0oooo00H0oooo000Y
0?ooo`030?noM000M;l0oooo00D0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`0:
0?ooo`030;md000007@0_ooo00h0oooo00<000000?ooo`3oool0I03oool2000000L0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooofH0oooo00<000000?ooo`3oool01P3oool002T0oooo00<0oooO09a8
000000000P0000001P0007@0_ooo0?ooo`3oool0_g@007Boo`80oooo00@0gia800000000B9`0gooo
203oool01@3OW4P000000000000007@0_ooo00h0oooo00<000000?ooo`3oool0IP3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?ooo`030000003oool0oooo00H0
oooo000Z0?ooo`030?noM000000000000080000000D0M;oo0?ooo`3oool0oooo0;md000300000003
001d_`3oool0oooo00T0oooo00@0oono07@0000007@0_ooo3P3oool00`000000oooo0?ooo`1W0?oo
o`800000103oool00`000000oooo0?ooo`3o0?ooool0ooooIP3oool00`000000oooo0?ooo`060?oo
o`00E@3oool00`000000oooo0?ooo`1Y0?ooo`8000000P3oool00`000000oooo0?ooo`3o0?ooool0
ooooIP3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`1[0?ooo`<00000
o`3ooooo0?ooofP0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0K@3o
ool200000?l0ooooo`3ooomW0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0
oooo06d0oooo00@000000?ooo`0000000000o`3ooooo0?ooofD0oooo00<000000?ooo`3oool01P3o
ool005D0oooo00<000000?ooo`3oool0K@3oool010000000oooo0?ooo`3oool200000?l0ooooo`3o
oomS0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo06d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooool0ooooH03oool00`000000oooo0?ooo`06
0?ooo`00E@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00@0oooo0P00003o0?oo
ool0ooooH03oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`1]0?ooo`03
0000003oool0oooo00H0oooo0P00003o0?ooool0ooooGP3oool00`000000oooo0?ooo`060?ooo`00
E@3oool4000006`0oooo00<000000?ooo`3oool0203oool200000?l0ooooo`3ooomI0?ooo`@00000
203oool005D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0:0?ooo`800000o`3o
oooo0?oooeX0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0K@3oool0
0`000000oooo0?ooo`0<0?ooo`800000o`3ooooo0?oooeP0oooo00<000000?ooo`3oool01P3oool0
05D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0>0?ooo`800000o`3ooooo0?oo
oeH0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`0@0?ooo`800000o`3ooooo0?oooe@0oooo00<000000?ooo`3oool01P3oool005D0oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo
o`3ooomA0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo06d0oooo00<0
00000?ooo`3oool04`3oool200000?l0ooooo`3ooomA0?ooo`030000003oool0oooo00H0oooo001E
0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool05@3oool200000?l0ooooo`3ooom?
0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`3o0?ooool0ooooC03oool00`000000oooo0?ooo`060?oo
o`00E@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo01P0oooo0P00003o0?ooool0
ooooC03oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo01X0oooo0P00003o0?ooool0ooooBP3oool00`000000oooo0?ooo`060?ooo`00E@3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo01`0oooo0P00003o0?ooool0ooooB03o
ool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0o`3ooooo0?ooodD0oooo00<000000?ooo`3oool01P3oool0
05D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0O0?ooo`800000o`3ooooo0?oo
odD0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`0Q0?ooo`800000o`3ooooo0?oood<0oooo00<000000?ooo`3oool01P3oool005D0oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0oooo
o`3ooom00?ooo`030000003oool0oooo00H0oooo001E0?ooo`@00000K03oool00`000000oooo0?oo
o`0T0?ooo`800000o`3ooooo0?ooocd0oooo100000080?ooo`00E@3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo02H0oooo0P00003o0?ooool0oooo?P3oool00`000000oooo0?ooo`06
0?ooo`00E@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo02P0oooo0P00003o0?oo
ool0oooo?03oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`2J0?ooo`03
0000003oool0oooo0?l0ooooo`3oooli0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000
003oool0oooo09/0oooo0P00003o0?ooool0oooo>@3oool00`000000oooo0?ooo`060?ooo`00E@3o
ool00`000000oooo0?ooo`2M0?ooo`800000o`3ooooo0?ooocL0oooo00<000000?ooo`3oool01P3o
ool005D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`3o0?ooool0oooo=03oool0
0`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`2P0?ooo`800000o`3ooooo0?oo
oc@0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0XP3oool200000?l0
ooooo`3ooolb0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0:@0oooo
0P00003o0?ooool0oooo<03oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?oo
o`2V0?ooo`800000o`3ooooo0?ooobh0oooo00<000000?ooo`3oool01P3oool005D0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`3o0?ooool0oooo:`3oool00`000000oooo0?ooo`06
0?ooo`00E@3oool00`000000oooo0?ooo`2Y0?ooo`800000o`3ooooo0?ooob/0oooo00<000000?oo
o`3oool01P3oool005D0oooo00<000000?ooo`3oool0Z`3oool200000?l0ooooo`3ooolY0?ooo`03
0000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0:d0oooo0P00003o0?ooool0oooo
9`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`2_0?ooo`800000o`3o
oooo0?ooobD0oooo00<000000?ooo`3oool01P3oool005D0oooo1000002`0?ooo`800000o`3ooooo
0?ooob00oooo100000080?ooo`00E@3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo
0?l0ooooo`3ooolP0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0;@0
oooo0P00003o0?ooool0oooo803oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo
0?ooo`2f0?ooo`800000o`3ooooo0?oooah0oooo00<000000?ooo`3oool01P3oool005D0oooo00<0
00000?ooo`3oool0^03oool200000?l0ooooo`3ooolL0?ooo`030000003oool0oooo00H0oooo001E
0?ooo`030000003oool0oooo0;X0oooo0P00003o0?ooool0oooo6P3oool00`000000oooo0?ooo`06
0?ooo`00E@3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?oo
o`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0;d0oooo0P00003o0?ooool0
oooo5`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`2o0?ooo`800000
o`3ooooo0?oooaD0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0`@3o
ool200000?l0ooooo`3ooolC0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0
oooo0<<0oooo00<000000?ooo`3oool0o`3ooooo0?oooa00oooo00<000000?ooo`3oool01P3oool0
05D0oooo00<000000?ooo`3oool0a03oool200000?l0ooooo`3oool@0?ooo`030000003oool0oooo
00H0oooo001E0?ooo`030000003oool0oooo0<H0oooo0P0000060?ooo`030000003oool0oooo0?l0
ooooo`3oool50?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0<P0oooo
0P0000040?ooo`030000003oool0oooo0?l0ooooo`3oool50?ooo`030000003oool0oooo00H0oooo
001E0?ooo`030000003oool0oooo0<X0oooo00D000000?ooo`3oool0oooo0000003o0?ooool0oooo
1`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3;0?ooo`80000000<0
oooo0000003oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool01P3oool005D0oooo1000003<
0?ooo`800000T03oool00`000000oooo0?ooo`3o0?ooog00oooo100000080?ooo`00E@3oool00`00
0000oooo0?ooo`3>0?ooo`<00000SP3oool00`000000oooo0?ooo`3o0?ooog<0oooo00<000000?oo
o`3oool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`02000008`0
oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000
003oool0oooo0<h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`290?ooo`030000
003oool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo00<0oooo0P0000290?ooo`030000003oool0oooo0?l0ooooL`3o
ool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0
oooo00D0oooo0P0000270?ooo`030000003oool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`06
0?ooo`00E@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00L0oooo0P0000250?oo
o`030000003oool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000
oooo0?ooo`3>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0PP3oool00`000000
oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0
cP3oool00`000000oooo0?ooo`0:0?ooo`800000PP3oool00`000000oooo0?ooo`3o0?ooog<0oooo
00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?oo
o`0<0?ooo`800000P03oool00`000000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3oool01P3o
ool002P0oooo00H0_g@000000000000000000018W03Oool30?ooo`030=nLB0000000000000D00000
00P0M;oo0?ooo`3oool0gia800000018W=l0oooo0=nLB0L0000000<0M;oo0?ooo`3oool02P3oool0
0`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3oool01P3oool002L0oooo00<0oooO09a8
0018W=l00P3oool00`3ogi`0B4RL0=ooo`030?ooo`030=nLB0000000000000@0000000H007Bo0?oo
o`3oool0gia800000018W=l20?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool02P3o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00l0oooo0P00001m0?ooo`030000003o
ool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`060?ooo`00;@3oool00`3ogi`0B7Bo0?ooo`03
0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool01`3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?oog`2LB7@0_ooo00/0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A
0?ooo`800000N`3oool00`000000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3oool01P3oool0
02d0oooo00<0oono07@0B02Lgol0103oool00`3OW4P0B9cO0?ooo`0<0?ooo`030=nLB018W=l0oooo
00l0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0C0?ooo`800000N@3oool00`00
0000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3oool01P3oool002d0oooo00<0oono07@0001d
_ol01@3oool00`3OW4P0M;oo0?ooo`0<0?ooo`030=nLB01d_ol0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool0o`3ooomc0?ooo`030000003oool0oooo00H0oooo000]0?ooo`030?noM0000000M;oo00D0oooo
00<0oooO09a8B02Lgol0303oool00`3ooml0W4Q809cOo`0>0?ooo`030000003oool0oooo0<h0oooo
00<000000?ooo`3oool05P3oool2000007H0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000
003oool0oooo00H0oooo000/0?ooo`040?oOW0180000001d0;ooo`H0oooo00<0omnL04P0M02oool0
303oool00`3ogi`0B01d0;ooo`0=0?ooo`H00000b`3oool00`000000oooo0?ooo`0H0?ooo`800000
M03oool00`000000oooo0?ooo`3o0?ooofh0oooo1P0000080?ooo`00:03oool0103Ogml0oooo0?oo
o`2oM0020000000304RLg`3oool0oooo00H0oooo00<0_g@004RLg`3oool0303oool00`2oM000B9cO
0?ooo`0<0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`060?ooo`00:03o
ool00`3o_g@000000000000200000003001d_`3oool0oooo00L0oooo00<0gia80000M02oool0303o
ool00`3OW4P0001d0;ooo`0<0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool06`3o
ool200000740oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003oool0oooo00H0oooo000X
0?ooo`050?oog`2LB00000000000M02oool02P3oool00`3o_g@0000007Boo`0<0?ooo`030?noM000
0000M;oo00`0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0M0?ooo`800000K`3o
ool00`000000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3oool01P3oool002T0oooo00<0okmd
001d_`3oool01@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo00H0oooo00<0omnL
09boo`3oool00`3oool00`2oM000000007Boo`0<0?ooo`030000003oool0oooo0<h0oooo00<00000
0?ooo`3oool07`3oool2000006d0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003oool0
oooo00H0oooo000Y0?ooo`030?oog`2LB00000000080000000H0001d0;ooo`3oool0oooo0;md001d
_ol20?ooo`040=nLB000000004RL0=ooo`L0oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL
0=ooo``0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003oool0oooo00H0oooo000Z0?oo
o`030?noM000000000000080000000D0M;oo0?ooo`3oool0oooo0;md000300000003001d_`3oool0
oooo00P0oooo00D0_g@00000000000000000001d_`0>0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool08P3oool2000006X0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003o
ool0oooo00H0oooo001E0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0903oool2
000006P0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003oool0oooo00H0oooo001E0?oo
o`030000003oool0oooo0<h0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000
oooo0?ooo`3>0?ooo`030000003oool0oooo02L0oooo0P00001U0?ooo`030000003oool0oooo0?l0
ooooL`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3>0?ooo`030000
003oool0oooo02T0oooo0P00001S0?ooo`030000003oool0oooo0?l0ooooL`3oool00`000000oooo
0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo02/0oooo0P00
001Q0?ooo`030000003oool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`060?ooo`00E@3oool0
0`000000oooo0?ooo`3>0?ooo`030000003oool0oooo02d0oooo0P00001O0?ooo`030000003oool0
oooo0?l0ooooL`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3>0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3o0?oo
og<0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool00`000000
oooo0?ooo`0`0?ooo`800000G03oool00`000000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3o
ool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0b0?ooo`800000
FP3oool00`000000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3oool01P3oool005D0oooo1000
003=0?ooo`030000003oool0oooo03@0oooo0P00001H0?ooo`030000003oool0oooo0?l0ooooL03o
ool4000000P0oooo001E0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0=P3oool2
000005H0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003oool0oooo00H0oooo001E0?oo
o`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000
oooo0?ooo`3>0?ooo`030000003oool0oooo03T0oooo0P00001C0?ooo`030000003oool0oooo0?l0
ooooL`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3>0?ooo`030000
003oool0oooo03/0oooo0P00001A0?ooo`030000003oool0oooo0?l0ooooL`3oool00`000000oooo
0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo03d0oooo0P00
001?0?ooo`030000003oool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`060?ooo`00E@3oool0
0`000000oooo0?ooo`3>0?ooo`030000003oool0oooo03l0oooo0P00001=0?ooo`030000003oool0
oooo0?l0ooooL`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3>0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`3o0?oo
og<0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool00`000000
oooo0?ooo`120?ooo`800000BP3oool00`000000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3o
ool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`140?ooo`800000
B03oool00`000000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3oool01P3oool005D0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`160?ooo`800000AP3oool00`000000oooo0?oo
o`3o0?ooog<0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0o`3ooomc
0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0<h0oooo00<000000?oo
o`3oool0B@3oool2000004<0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003oool0oooo
00H0oooo001E0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0B`3oool200000440
oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000
003oool0oooo0<h0oooo00<000000?ooo`3oool0C@3oool2000003l0oooo00<000000?ooo`3oool0
o`3ooomc0?ooo`030000003oool0oooo00H0oooo001E0?ooo`@00000c@3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0o`3ooom`0?ooo`@00000203o
ool005D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`1@0?ooo`800000?03oool0
0`000000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?oo
o`3oool0cP3oool00`000000oooo0?ooo`1B0?ooo`800000>P3oool00`000000oooo0?ooo`3o0?oo
og<0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool00`000000
oooo0?ooo`1D0?ooo`800000>03oool00`000000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3o
ool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`1F0?ooo`800000
=P3oool00`000000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3oool01P3oool005D0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0o`3ooomc0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0
oooo0<h0oooo00<000000?ooo`3oool0F@3oool2000003<0oooo00<000000?ooo`3oool0o`3ooomc
0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0<h0oooo00<000000?oo
o`3oool0F`3oool200000340oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003oool0oooo
00H0oooo001E0?ooo`030000003oool0oooo0<d0oooo0P00001O0?ooo`800000;`3oool00`000000
oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0
b`3oool6000005l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?ooog<0oooo
00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0bP3oool8000005l0oooo0P00
000/0?ooo`030000003oool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`060?ooo`00E@3oool0
0`000000oooo0?ooo`3:0?ooo`P00000H@3oool2000002X0oooo00<000000?ooo`3oool0o`3ooomc
0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0<T0oooo2P00001R0?oo
o`800000:03oool00`000000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3oool01P3oool005D0
oooo00<000000?ooo`3oool0b@3oool:000006@0oooo0P00000V0?ooo`030000003oool0oooo0?l0
ooooL`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3:0?ooo`P00000
I`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0ooooL`3oool00`000000oooo
0?ooo`060?ooo`003@3oool00`3ogi`0W;oo0?ooo`150?ooo`030000003oool0oooo0<X0oooo2000
001X0?ooo`8000008`3oool00`000000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3oool01P3o
ool000d0oooo00<0_g@00000000000002@0000000`0004P0W=oo0?ooo`0i0?ooo`@00000bP3oool6
000006/0oooo0P00000Q0?ooo`030000003oool0oooo0?l0ooooL03oool4000000P0oooo000<0?oo
o`030?oo_`1d0000000000/0000000<007Bo0?ooo`3oool0>03oool00`000000oooo0?ooo`3=0?oo
o`800000K`3oool2000001h0oooo0P00003o0?ooogD0oooo00<000000?ooo`3oool01P3oool00180
oooo00<0omnL04Qd_`3oool0103oool00`3ogi`0B01d0;ooo`0i0?ooo`030000003oool0oooo0<h0
oooo00<000000?ooo`3oool0K`3oool2000001X0oooo1P00003o0?ooog<0oooo00<000000?ooo`3o
ool01P3oool00140oooo00<0oono07@0B02Lgol01P3oool00`2oM7@0_ooo0?ooo`0h0?ooo`030000
003oool0oooo0<h0oooo00<000000?ooo`3oool0L@3oool2000001L0oooo2000003o0?ooog80oooo
00<000000?ooo`3oool01P3oool00140oooo00<0okmd0000B02Lgol01@3oool00`3ooml0W7BL0=oo
o`0i0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`0D0?ooo`P00000o`3ooomb0?ooo`030000003oool0oooo00H0oooo000A0?ooo`040?oOW0180000
001809cOo`<0oooo00<0oooO09a8001d_ol0>P3oool00`000000oooo0?ooo`3>0?ooo`030000003o
ool0oooo07@0oooo0P00000C0?ooo`X00000o`3oooma0?ooo`030000003oool0oooo00H0oooo000B
0?ooo`030;md00000000000000@0000000<007Bo0?ooo`3oool0>@3oool00`000000oooo0?ooo`3>
0?ooo`030000003oool0oooo07H0oooo0P00000A0?ooo`X00000o`3oooma0?ooo`030000003oool0
oooo00H0oooo000C0?ooo`030=nLB000000000000080000000<0M;oo0?ooo`3oool0>P3oool00`00
0000oooo0?ooo`3>0?ooo`030000003oool0oooo07P0oooo0P00000@0?ooo`P00000o`3ooomb0?oo
o`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3o
ool0NP3oool2000000h0oooo2000003o0?ooog80oooo00<000000?ooo`3oool01P3oool005D0oooo
00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00`0oooo
1P00003o0?ooog<0oooo00<000000?ooo`3oool01P3oool001D0oooo00<0gia80018W03Oool0103o
ool00`3OW7@0B4Qd0;ooo`0f0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0O@3o
ool2000000h0oooo0P00003o0?ooogD0oooo00<000000?ooo`3oool01P3oool001@0oooo00<0okmd
001d_`3oool0103oool0102oM000B9bL07@0M02ooolf0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool0O`3oool2000000d0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003o
ool0oooo00H0oooo000D0?ooo`030=nLB018W=l0oooo0080oooo00H0oooO09a8001d_ol0oono07@0
M02ooolf0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0P@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`060?ooo`00503o
ool02`3o_g@0001809cOo`3oool0okmd0000B02Lgol0oooo0?oOW01807@0_ooo03H0oooo00<00000
0?ooo`3oool0cP3oool00`000000oooo0?ooo`220?ooo`8000002P3oool00`000000oooo0?ooo`3o
0?ooog<0oooo00<000000?ooo`3oool01P3oool001D0oooo00@0gia800000000000007Bo0P3oool0
103ooml0W4P00018W03Ooolf0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0Q03o
ool2000000P0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003oool0oooo00H0oooo001E
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`060?ooo`00E@3oool40000
0<d0oooo00<000000?ooo`3oool0Q`3oool2000000D0oooo00<000000?ooo`3oool0o`3ooom`0?oo
o`@00000203oool005D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`290?ooo`80
00000`3oool00`000000oooo0?ooo`3o0?ooog<0oooo00<000000?ooo`3oool01P3oool005D0oooo
00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`2;0?ooo`80000000<0oooo0000003oool0
o`3ooomd0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool0S@3oool200000?l0ooooM@3oool00`000000oooo0?ooo`060?ooo`00E@3oool0
0`000000oooo0?ooo`3>0?ooo`030000003oool0oooo08h0oooo0P00003o0?ooog@0oooo00<00000
0?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`2>0?oo
o`040000003oool0000000000?l0ooooLP3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`00
0000oooo0?ooo`3>0?ooo`030000003oool0oooo08h0oooo00D000000?ooo`3oool0oooo0000003o
0?ooog40oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo0080oooo0P00003o0?ooofl0oooo00<000000?oo
o`3oool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo00@0oooo0P00003o0?ooofd0oooo00<000000?ooo`3oool01P3oool005D0oooo
00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0o`3ooomZ0?ooo`030000003oool0oooo00H0oooo000X0?ooo`060;md0000
0000000000000000B9`0gooo0`3oool00`3OW4P00000000000050000000907Boo`3oool0oooo0=nL
B0000000B9cO0?ooo`3ooml0W4P000<0000000<004RL0=ooo`3oool03@3oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool01`3oool200000?l0ooooJP3o
ool00`000000oooo0?ooo`060?ooo`009`3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0
gooo00<0oooo00<0gia8000000000000100000003`00M;l0oooo0?ooo`3OW4P0000004RLg`3oool0
omnL04P00000B9`0gooo0?ooo`3ogi`0B01809cOo`0=0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`090?ooo`800000o`3ooomX0?ooo`030000003o
ool0oooo00H0oooo000]0?ooo`030?oOW018M;l0oooo00<0oooo00<0gia804RLg`3oool00P3oool0
0`3ooml0W4Qd0;ooo`0;0?ooo`030?noM000B9`0gooo00`0oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00/0oooo0P00003o0?ooofH0oooo00<00000
0?ooo`3oool01P3oool002d0oooo00<0oono07@0B02Lgol0103oool00`3OW4P0B9cO0?ooo`0?0?oo
o`030?noM00004P0W=oo00`0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo00d0oooo0P00003o0?ooof@0oooo00<000000?ooo`3oool01P3oool002d0
oooo00<0oono07@0001d_ol01@3oool00`3OW4P0M;oo0?ooo`0>0?ooo`030;md000004P0W=oo00`0
oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`030000003oool0oooo00H0oooo000]0?ooo`030?no
M0000000M;oo00D0oooo00<0oooO09a8B02Lgol03@3oool0102oM00000000000M02oool<0?ooo`03
0000003oool0oooo0<h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0@0?ooo`80
0000o`3ooomQ0?ooo`030000003oool0oooo00H0oooo000/0?ooo`040?oOW0180000001d0;ooo`H0
oooo00<0omnL04P0M02oool02@3oool00`3ookl0M000000000020000000304RLg`3oool0oooo00/0
oooo1P00003;0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool04P3oool200000?l0
ooooFP3oool6000000P0oooo000X0?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3o
ool01P3oool00`2oM000B9cO0?ooo`0:0?ooo`030?noM00004P0W=oo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01@0oooo0P00003o0?oooed0
oooo00<000000?ooo`3oool01P3oool002P0oooo00<0okmd0000000000000P0000000`00M;l0oooo
0?ooo`070?ooo`030=nLB00007@0_ooo00/0oooo00<0omnL04Qd_`3oool03@3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool05P3oool200000?l0oooo
F`3oool00`000000oooo0?ooo`060?ooo`00:03oool01@3ooml0W4P00000000007@0_ooo00X0oooo
00<0okmd0000001d_ol02`3oool00`3ooml0W4P004RLg`0=0?ooo`030000003oool0oooo0<h0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0H0?ooo`800000o`3ooomI0?ooo`030000
003oool0oooo00H0oooo000Y0?ooo`030?noM000M;l0oooo00D0oooo00<0omnL09boo`3oool00`3o
ool00`2oM000000007Boo`060?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO09a80000M;l03@3o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`3o0?oooeH0oooo00<000000?ooo`3oool01P3oool002T0oooo00<0oooO
09a8000000000P0000001P0007@0_ooo0?ooo`3oool0_g@007Boo`80oooo00@0gia800000000B9`0
gooo1`3oool01`3ogi`0B4RL0=ooo`3oool0gia80000001d_ol03@3oool00`000000oooo0?ooo`3>
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool06`3oool200000?l0ooooEP3oool0
0`000000oooo0?ooo`060?ooo`00:P3oool00`3o_g@00000000000020000000507Boo`3oool0oooo
0?ooo`2oM0000`0000000`00M;l0oooo0?ooo`080?ooo`050?oOW0180000000000000018W=l03P3o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool07@3o
ool200000?l0ooooE03oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3>
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool07`3oool200000?l0ooooDP3oool0
0`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool08@3oool200000?l0ooooD03oool00`000000oooo0?ooo`060?oo
o`00E@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool01P3oool005D0oooo
00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02@0oooo
0P00003o0?ooodd0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02H0oooo0P00003o0?oood/0oooo00<0
00000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo02P0oooo0P00003o0?ooodT0oooo00<000000?ooo`3oool01P3oool0
05D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02X0oooo0P00003o0?ooodL0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0o`3ooom40?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0<h0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0]0?ooo`800000o`3ooom40?ooo`030000
003oool0oooo00H0oooo001E0?ooo`@00000c@3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02l0oooo0P00003o0?ooocl0oooo100000080?ooo`00E@3oool00`000000oooo0?ooo`3>
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool200000?l0oooo@03oool0
0`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0<`3oool200000?l0oooo?P3oool00`000000oooo0?ooo`060?oo
o`00E@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0=@3oool200000?l0oooo?03oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03P0oooo0P00003o0?ooocT0oooo00<0
00000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo03X0oooo0P00003o0?ooocL0oooo00<000000?ooo`3oool01P3oool0
05D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
03`0oooo0P00003o0?ooocD0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03h0oooo0P00003o0?oooc<0
oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0o`3oool`0?ooo`030000
003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`110?ooo`800000o`3oool`0?ooo`030000003oool0oooo00H0oooo001E
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`13
0?ooo`800000o`3oool^0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo
0?l0ooooH03oool00`000000oooo0?ooo`150?ooo`800000o`3oool/0?ooo`030000003oool0oooo
00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooH03oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0?l0oooo:@3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo
0?ooo`3o0?ooof00oooo00<000000?ooo`3oool0B03oool200000?l0oooo:@3oool00`000000oooo
0?ooo`060?ooo`00E@3oool400000?l0ooooG`3oool00`000000oooo0?ooo`1:0?ooo`800000o`3o
oolT0?ooo`@00000203oool005D0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`030000003oool0
oooo04`0oooo0P00003o0?ooobD0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?oo
o`3oool0o`3ooomP0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0o`3ooolR0?oo
o`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooH03oool00`000000
oooo0?ooo`1?0?ooo`800000o`3ooolR0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000
003oool0oooo0?l0ooooH03oool00`000000oooo0?ooo`1A0?ooo`800000o`3ooolP0?ooo`030000
003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooH03oool00`000000oooo0?oo
o`1C0?ooo`800000o`3ooolN0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0
oooo0?l0ooooH03oool00`000000oooo0?ooo`1E0?ooo`800000o`3ooolL0?ooo`030000003oool0
oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooH03oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000
oooo0?ooo`3o0?ooof00oooo00<000000?ooo`3oool0F03oool200000?l0oooo6@3oool00`000000
oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooof00oooo00<000000?ooo`3oool0
FP3oool200000?l0oooo5`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?oo
o`3o0?ooof00oooo00<000000?ooo`3oool0G03oool200000?l0oooo5@3oool00`000000oooo0?oo
o`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooof00oooo00<000000?ooo`3oool0GP3oool0
0`000000oooo0?ooo`3o0?oooa80oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?oo
o`3oool0o`3oooo20?ooo`800000o`3ooolB0?ooo`030000003oool0oooo00H0oooo001E0?ooo`03
0000003oool0oooo0?l0ooooa03oool200000?l0oooo403oool00`000000oooo0?ooo`060?ooo`00
E@3oool00`000000oooo0?ooo`3o0?ooolH0oooo00<000000?ooo`3oool0o`3oool=0?ooo`030000
003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooa`3oool200000?l0oooo3@3o
ool00`000000oooo0?ooo`060?ooo`00E@3oool400000?l0oooob03oool200000?l0oooo203oool4
000000P0oooo001E0?ooo`030000003oool0oooo0?l0oooob`3oool00`000000oooo0?ooo`3o0?oo
o`P0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3oooo<0?ooo`80
0000o`3oool80?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0oooo
cP3oool00`000000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool01P3oool005D0oooo00<0
00000?ooo`3oool0o`3oooo?0?ooo`800000o`3oool50?ooo`030000003oool0oooo00H0oooo001E
0?ooo`030000003oool0oooo0?l0ooood@3oool2000007@0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooom<0oooo00<000000?oo
o`3oool0L@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00H0oooo001E0?ooo`03
0000003oool0oooo0?l0ooooe03oool200000740oooo00<000000?ooo`3oool0R`3oool00`000000
oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooomH0oooo0P00001_0?ooo`030000
003oool0oooo08/0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3o
oooH0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooomT0oooo0P00001/0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooK0?oo
o`800000JP3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00H0oooo001E0?ooo`03
0000003oool0oooo0?l0oooog@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooN0?ooo`800000
I`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003o
ool0oooo0?l0ooooh03oool2000006D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooon80oooo0P00001S0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool01P3oool005D0oooo1000003o0?ooon<0oooo0P00001Q0?oo
o`030000003oool0oooo08P0oooo100000080?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooonH0
oooo0P00001O0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool01P3oool005D0oooo
00<000000?ooo`3oool0o`3ooooX0?ooo`800000G@3oool00`000000oooo0?ooo`2;0?ooo`030000
003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0oooojP3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool01P3oool005D0oooo00<00000
0?ooo`3oool0o`3oooo[0?ooo`800000FP3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo00H0oooo001E0?ooo`030000003oool0oooo03<0oooo00D0oooO09a800000000001809cOo`3o
0?oookD0oooo0P00001H0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool01P3oool0
05D0oooo00<000000?ooo`3oool0=03oool00`3ookl0M01809cOo`3o0?oookP0oooo0P00001F0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3o
ool0=03oool00`3ookl0M01809cOo`3o0?oookX0oooo0P00001D0?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0=03oool01P3ookl0M000
000000000000001809cOo`80oooo01<0okmd000000000000B9cO0?ooo`3ookl0M0000000000004P0
B4P00000B018B00000000000B02Lgml0W4P000000000B9`0gooo0?l0ooooY03oool200000580oooo
00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?oo
o`0d0?ooo`0I0?oo_`1d0000B9cO0?ooo`3o_g@0001d0;ooo`3ogi`0B00007Boo`3oool0giad09cO
o`3OW4P004RL0=ooo`3ookl0M01809cOo`3ooml0W4P007Boo`3ookl0M00007Boo`3o0?ooojP0oooo
0P00001@0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool01P3oool002P0oooo00H0
_g@000000000000000000018W03Oool30?ooo`030=nLB0000000000000D0000000H0M;oo0?ooo`3o
ool0gia800000018W=l60?ooo`030?noM0000000M;oo00d0oooo00<000000?ooo`3oool0=03oool0
2@3ookl0M01809cOo`3oool0oooO09a8001d_ol0gia8001d_`020?ooo`0=0?oo_`1dM;l0oono07@0
0000M;l0oono07@0B02Lgol0oooO09a8001d_ol0_g@0001d_`3o0?oooj/0oooo0P00001>0?ooo`03
0000003oool0oooo08/0oooo00<000000?ooo`3oool01P3oool002L0oooo00<0oooO09a80018W=l0
0P3oool00`3ogi`0B4RL0=ooo`030?ooo`030=nLB0000000000000@0000000H007Bo0?ooo`3oool0
gia800000018W=l60?ooo`030?noM0000000M;oo00d0oooo00<000000?ooo`3oool0603oool00`3O
W4P00000000000050000000807Boo`3oool0oooo0?oog`2LB000001809cOg`2LB0090000000<001d
_`3oool0oooo0?oo_`1d04P0W=oo0?ooo`3ooml0W4P004RLg`3OW4P0B9cO1P3oool02@3o_g@00000
0000B02Lgol0oooO09a800000000001d0;ooo`0?0?ooo`030?oog`2LB000000000L0000000<0M;oo
0?ooo`3oool03P3oool00`2oM000000000000002000000030000M02oool0oooo00<0oooo00H0omnL
04P00000000000000000M02oool20?ooo`050=nLB0000000000000000000M;l00P3oool01@3OW4P0
000000000000000007Bo00@0oooo00D0omnL04P0000000000000001d_`020?ooo`080?oo_`1d0000
00000000000004P0W=oo0?ooo`2oM0020000000<0000B02Lgkl0M00000000000M;l0oooo0?oo_`1d
000000000018W03Ookl0M0000P0000001P0004P0W=oo0?ooo`3oool0omnL04P00080000000D0001d
0;ooo`3oool0oooo0;md00030000000607Bo_`1d000000000000000007@0_ooo203oool00`2oM000
000000000002000000030000M02oool0oooo00<0oooo00H0omnL04P00000000000000000M02oool4
0?ooo`050?oOW0180000000000000000M;l00P3oool00`3o_g@0000000000002000000030018W03O
_g@0000000<0000000<004RL0=oo_`1d00000P0000001@0004P0W=oo0?ooo`3oool0okmd00<00000
00D004RL0=ooo`3oool0oono07@00002000000060000B02Lgol0oooo0?ooo`3ogi`0B0000P000000
1000M;l0oooo0?ooo`2oM0030000000;07Bo_`1d000000000000000007@0_ooo0?oo_`1d00000000
0018W03Oool00P3oool0103ooml0W4P00000B02Lgol60?ooo`050=nLB0000000000000000000M;l0
4@3oool0102oM000000000000018W=l40?ooo`090=nLB0000000B9cO0?ooo`3ooml0W4P000000000
04P0W=oo00X0oooo00<0okmd0000001d_ol0S@3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool01P3oool002d0oooo00<0omnL04Qd_`3oool00`3oool0
0`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo00X0oooo00<0okmd0000001d_ol03@3oool0
0`000000oooo0?ooo`0I0?ooo`030=nLB0000000000000@0000000`007Bo0?ooo`3oool0oooO09a8
000004P0W=oo0?ooo`3ookl0M0000018W03Oool40?ooo`0<0?noM00007@0_ooo0?ooo`3ookl0M018
09cOo`3oool0oooO09a80018W=l0gia8100000003000M;l0oooo0?ooo`3oool0oono07@0B02Lgol0
oooO09a8001d_ml0W4P007Booa40oooo00<0omnL04P00000M;l0103oool00`2oM00007Bo0?ooo`0=
0?ooo`040?noM0000000000007Boo`<0oooo00<0oono07@0001d_ol00P3oool0203o_g@000000018
W03Oool0oooo0?noM00004P0W=oo0P3oool00`3o_g@0000007Boo`040?ooo`030?noM0000000M;oo
00@0oooo0240okmd0000000004P0W=oo0?ooo`3OW4P004RL0=ooo`3oool0oooO09a80000B9`0gooo
0?ooo`3o_g@00000001d_`3oool0oooO09a800000000B9cO0?no_`2oool0gia80000B02Lgol0omnL
09boo`3oool0_g@00000M02oool00P3oool0203o_g@000000018W03Oool0oooo0?noM00004P0W=oo
0P3oool0203OW4P0001809cOo`3oool0oooO09a80000B9`0gooo1`3oool0103o_g@000000000001d
_ol30?ooo`030?oo_`1d0000M;oo0080oooo00P0okmd00000000B9`0gooo0?ooo`3o_g@0001809cO
o`80oooo00d0okmd0000000004P0W=oo0?ooo`3OW4P004RL0=ooo`3oool0oooO09a8000007@0_ooo
0080oooo00@0oooO09a8000007@0_ooo0`3oool00`2oM000001d0;ooo`020?ooo`030=nLB0000000
000000<0000000L004RL0=ooo`3oool0oooo0;md000007@0_ooo0080oooo01L0okmd0000000004P0
W=oo0?ooo`3OW4P004RL0=ooo`3oool0gia80000B02Lgol0oooo0?oog`2LB00004RL0=ooo`3oool0
gia80000B02Lgol0omnL09boo`020?ooo`040?oog`2LB000001809cOo`L0oooo00<0okmd0000001d
_ol0403oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`04
0?ooo`040=nLB000000004RL0=ooo`P0oooo00<0okmd0000001d_ol0SP3oool2000004/0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`060?ooo`00;@3oool00`3ookl0M01809cOo`04
0?ooo`030=nLB018W=l0oooo00T0oooo00<0gia80000000000001@0000000`0004P0W=oo0?ooo`0:
0?ooo`030000003oool0oooo01X0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`06
0?ooo`040?oo_`1d000004RL0=ooo`D0oooo01`0okmd04RLg`3ookl0M0000000000007@0_ooo0?no
M00004P0W=oo0?oo_`1dB9`0gooo0?oog`2LB000M;oo0?oOW01807@0_ooo0?oOW01804P0W=oo0?oo
g`2LB000M;oo0?ooo`2oM4P0W=oo403oool00`3ogi`0B00004RLg`040?ooo`030?oog`2LM9`0gooo
00`0oooo00@0omnL04P0000004P0W=oo1P3oool01P2oM4P0W=oo0?oog`2LB000001809cOo`<0oooo
00L0_g@00018W03Oool0oooo0?noM0000000M;oo00@0oooo00<0okmd0000001d_ol00`3oool0103o
okl0M0000018W03Oool30?ooo`0;0?noM01d_ol0oooo0?oog`2LB00004RL0=ooo`3oool0okmd0000
001d_ol00P3oool00`3ogi`0B00004RLg`020?ooo`030=nLB00004P0W=oo00<0oooo00P0_g@00018
W03Oool0oooo0?oog`2LB000001809cOo`<0oooo00`0_g@00018W03Oool0oooo0=nLB00004P0W=oo
0?ooo`3ooml0W4P00018W03Oool60?ooo`040?oOW0180000001809cOo`H0oooo00H0_gA809cOo`3o
oml0W4P00000B02Lgol30?ooo`070;md0000B9`0gooo0?oo_`1d000004RL0=ooo`030?ooo`070?no
M01d_ol0oooo0?ooo`2oM00004RL0=ooo`030?ooo`030;md0000B9`0gooo00<0oooo00P0_g@00018
W03Oool0oooo0?oo_`1d0000000004RLg`<0oooo00`0giad09cOo`3oool0oooo0;md0000B9`0gooo
0?ooo`3ookl0M0000018W03Oool30?ooo`0?0?noM01d_ol0oooo0=nLB00004P0W=oo0?ooo`3ooml0
W4P00018W03Oool0oooo0=nLB00004P0W=oo00l0oooo00<0okmd0000001d_ol0403oool00`3o_g@0
001809cOo`020?ooo`030?oOW0180000M;oo00X0oooo00@0oono07@0000007@0_ooo1`3oool00`3o
_g@0000007Boo`2@0?ooo`800000B@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
00H0oooo000]0?ooo`030?oo_`1d0000M;oo00D0oooo00<0gia807Boo`3oool0203oool00`3ogi`0
B7Bo0?ooo`020?ooo`030?noM0000000M;oo00d0oooo00<000000?ooo`3oool06`3oool00`3OW4P0
B9cO0?ooo`0:0?ooo`040?oo_`1d000004RL0=ooo`P0oooo00H0oono07@0B02Lgkl0M00000000018
W=l20?ooo`040?oOW01800000000001d_`80oooo00d0_g@000000000000004RL0=ooo`3ooml0W4P0
07Boo`3ookl0M00000000000B9`0gooo00h0oooo00<0omnL04P00018W=l01@3oool00`3o_i`0W=oo
0?ooo`0;0?ooo`030;md00000000B9cO00T0oooo00<0omnL04P00000M;l0103oool01`3OW4P00018
09cOo`3oool0okmd0000001d_ol0103oool00`3o_g@0000007Boo`030?ooo`030?oOW0180000M;oo
00L0oooo00P0oooO09a80000B9`0gooo0?ooo`3ookl0M000001d_`80oooo00<0omnL04P00018W=l0
0P3oool00`3OW4P0001809cOo`030?ooo`070;md0000B9`0gooo0?ooo`3ogi`0B000001d_`040?oo
o`0<0=nLB00004P0W=oo0?ooo`3OW4P0001809cOo`3oool0oooO09a80000B9`0gooo1P3oool00`2o
M000000004RLg`090?ooo`030?oOW018000007Bo00@0oooo00H0gia80000B02Lgol0omnL04P0001d
_ol80?ooo`030;md0000B9`0gooo00<0oooo00<0_g@00018W03Oool00`3oool01`2oM00004RL0=oo
o`3oool0okmd00000000M;l0203oool01`2oM00004RL0=ooo`3oool0omnL04P0001d_ol01`3oool0
303OW4P0001809cOo`3oool0oooO09a80000B9`0gooo0?ooo`3OW4P0001809cOo`l0oooo00<0okmd
0000001d_ol00`3oool00`2oM0000000000000070000000604RLg`3oool0oooO09a80000B9`0gooo
0P3oool00`3ooml0W4P0001d_`0;0?ooo`060?oo_`1d000004RL0=ooo`3oool0gia81`0000000`00
04P0W=oo0?ooo`2?0?ooo`800000A`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
00H0oooo000]0?ooo`030?noM0000000M;oo00D0oooo00<0oooO09a8B02Lgol02@3oool01`3OW4P0
M;oo0?ooo`3oool0okmd0000001d_ol03@3oool00`000000oooo0?ooo`0L0?ooo`030=nLB01d_ol0
oooo00T0oooo00@0oono07@00000B9`0gooo0`3oool00`3o_i`0W=oo0?ooo`0E0?ooo`030?oog`2L
B000M;oo01<0oooo00<0omnL04P00018W=l04P3oool0103ookl0M0000000B02Lgol90?ooo`030?no
M0000000B9cO00@0oooo00L0gia80000001d_ol0oooo0?noM0000000M;oo00@0oooo00<0okmd0000
001d_ol00`3oool00`3ogi`0B01809cOo`070?ooo`040?oog`2LB00004RL0=ooo`80oooo00L0oooO
09a800000000M;oo0?oOW0180000B9cO0080oooo00<0gia80000B02Lgol00`3oool01`2oM00004RL
0=ooo`3oool0okmd00000018W=l0103oool0303OW4P0000007Boo`3oool0gia80000B02Lgol0oooo
0?oog`2LB00004RL0=ooo`D0oooo00@0oono07@0000004P0W=oo2@3oool00`3o_g@0000004RLg`04
0?ooo`060=nLB0000000M;oo0?oOW01804P0W=oo203oool00`2oM00004RL0=ooo`030?ooo`030;md
0000B9`0gooo00<0oooo00L0_g@00018W03Oool0oooo0?noM0000000M;oo00P0oooo00L0_g@00018
W03Oool0oooo0?oOW01804P0W=oo00L0oooo00`0gia80000B02Lgol0oooo0?oog`2LB00004RL0=oo
o`3oool0gia80000B02Lgol?0?ooo`030?noM0000000M;oo00l0oooo00<0oono07@00000M;l0103o
ool00`2oM000001d0;ooo`0;0?ooo`060=nLB0000000M;oo0?ooo`3ogi`0B7Bo0`3oool00`3o_g@0
000007Boo`2D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0R`3oool00`000000
oooo0?ooo`060?ooo`00;03oool0103ogi`0B0000000M02oool60?ooo`030?oOW01807@0_ooo00P0
oooo00L0oono07@0M02oool0oooo0?noM0000000M;oo00d0oooo1P00000I0?ooo`030?oog`2LB4P0
W=oo00T0oooo00@0oono07@00000B9`0gooo0`3oool00`2oM4P0W=oo0?ooo`0D0?ooo`040?oog`2L
B000000007Boo`H0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3ogi`0B00004RL
ga80oooo00@0okmd0000000007@0_ooo2@3oool00`3ogi`0B00004RLg`040?ooo`070;md000004P0
W=oo0?ooo`3o_g@0000007Boo`040?ooo`030?noM0000000M;oo00<0oooo00<0omnL04P000000000
1@0000001P1d_ol0oooo0?oog`2LB00004RL0=ooo`D0oooo00@0_g@0000000000000B9cO0P3oool0
0`3OW4P0001809cOo`030?ooo`070;md0000B9`0gooo0?ooo`3ogi`0B00004RLg`040?ooo`0<0;md
000004P0W=oo0?ooo`3OW4P0001809cOo`3oool0oooO09a80000B9`0gooo1@3oool0103o_g@00000
0000M02oool90?ooo`030?oOW0180000B9cO00@0oooo00D0_g@00000B02Lgol0omnL04P000060000
000607Boo`3oool0oooo0;md0000B9`0gooo0`3oool00`2oM00004RL0=ooo`030?ooo`070;md0000
B9`0gooo0?ooo`3o_g@0001809cOo`080?ooo`060;md0000B9`0gooo0?ooo`3ogi`0B0001P000000
3P1d_ol0oooo0=nLB00004P0W=oo0?ooo`3ooml0W4P00018W03Oool0oooo0=nLB00004P0W=oo3`3o
ool00`3o_g@0000007Boo`0?0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01`3o
ool00`3OW4P0000000000003000000050018W03Oool0oooo0=nLB01d_ol00P3oool00`3o_g@00000
07Boo`2E0?ooo`800000A03oool00`000000oooo0?ooo`260?ooo`H00000203oool002P0oooo00@0
gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`060?ooo`030;md0018W=l0oooo00P0oooo
00H0okmd001d_`3oool0okmd0000001d_ol=0?ooo`030000003oool0oooo01d0oooo00<0omnL04P0
M02oool0203oool00`3ookl0M00000000004000000030000B02Lgol0oooo01D0oooo00<0oono07@0
001d_ol04`3oool00`3ogi`0B00004RLg`0B0?ooo`040?noM0000000001d0;ooo`T0oooo00<0oooO
09a80000M;l00`3oool0203ookl0M0000000M02oool0oooo0?noM000000007Bo103oool00`3o_g@0
0000001d_`030?ooo`030?oog`2LB4P0W=oo00<0oooo00`0_g@00000B02Lgol0oooo0?oog`2LB000
04RL0=ooo`3oool0oooO09a80000M;l20?ooo`030?oOW0180000B9cO0080oooo00<0gia80000B02L
gol00P3oool0203ooml0W4P00018W03Oool0oooo0?oog`2LB00007Bo0`3oool03@3ookl0M0000000
M02oool0oooo0;md00000000M;oo0?ooo`3ooml0W4P00018W03Oool01@3oool0103o_g@000000000
M02oool90?ooo`030?oog`2LB00007Bo00<0oooo00L0oono07@0000007@0_ooo0?oog`2LB4P0W=oo
00<0oooo00<0_g@00000B02Lgol00P3oool00`2oM00004RL0=ooo`030?ooo`030;md0000B9`0gooo
0080oooo00P0oooO09a80000B9`0gooo0?ooo`3ookl0M00007Boo`80oooo00d0oooO09a80000B9`0
gooo0?ooo`3ooml0W4P00018W03Oool0oooo0?oog`2LB4P0W=oo00<0oooo0100_g@00000B02Lgol0
oooo0;md00000000M;oo0?ooo`3ooml0W4P00018W03Oool0oooo0=nLB00004P0W=oo3`3oool00`3o
_g@00000001d_`0?0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01P3oool00`2o
M0000000001d_`020?ooo`0<0?oo_`1d0000001d0;ooo`3oool0oono07@0M02oool0oooo0?noM000
0000M;ooU`3oool200000480oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`060?oo
o`00:03oool00`3o_g@000000000000200000003001d_`3oool0oooo00L0oooo00<0gia80000M02o
ool02@3oool01@2oM000M;oo0?noM0000000M;oo00d0oooo00<000000?ooo`3oool07P3oool00`2o
M000B9cO0?ooo`020?ooo`090?oog`2LB000001809cOo`3oool0oono07@00000B9`0gooo00<0oooo
00<0_gA809cOo`3oool0:`3oool00`3ogi`0B00004RLg`0B0?ooo`040?oOW0180000001d0;ooo`X0
oooo00X0omnL04P0001d_ol0oooo0?oog`2LB000000007Boo`3ooml0W4P00P0000001@1dM7@0B9cO
0;md0000B7@0M4P00080000002H0M7Ad04RLg`2oM00004RL0=ooo`3o_g@0001d0;ooo`3oool0omnL
04P00000B9`0gooo0?ooo`3ooml0W4P00018W03Oool0oooo0?oog`2LB00004RL0=ooo`3oool0gia8
0000001d_ol0oooO0=oOo`3OW4P0001809cOo`3oool0omnL04P00000000004RL0=ooo`80oooo0140
omnL04P0001d_ol0oooo0?oog`2LB000000007Boo`3ookl0M0000000000004P0B4P004RLg`3ookl0
M000001d_`060?ooo`040?oOW0180000001d0;ooo`X0oooo00P0omnL04P0001d_ol0oooo0?oog`2L
B000000007Boo`80oooo00P0okmd0000M02oool0oooo0?oOW018000004RL0=ooo`80oooo00<0_g@0
0018W03Oool00`3oool02@2oM00004RL0=ooo`3oool0omnL04P00000000004RL0=ooo`020?ooo`0=
0?noM00004P0W=oo0?ooo`3o_g@000000018W03Oool0omnL04P00000000004RL0=ooo`020?ooo`0E
0?noM00007@0_ooo0?ooo`3ogi`0B0000018W03Ookl0M0000000000004P0B4P004RLg`3ookl0M000
001d_`3ooml0gmoo0=nLB00004P0W=oo00@0oooo00@0oooO09a8000004P0W=oo1@3oool02@3ooml0
W4P0000000000000M7Ad04RLg`2oM00004RL0:Md00090000000504RLg`3oool0omnL04P00018W=l0
103oool00`3OW4P0001809cOo`050?ooo`040?oo_`1d000004RL0=ooo`<0oooo00<0_g@00000B02L
gol00P3oool01P3o_g@007Bo0?ooo`3o_g@0000007BooiT0oooo0P0000100?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool01P3oool002P0oooo00D0oooO09a800000000001d0;ooo`0:
0?ooo`030?noM0000000M;oo00T0oooo00D0oono07@0M02o_g@0000007Boo`0=0?ooo`030000003o
ool0oooo01h0oooo00<0gia80000M02oool00P3oool02@3ooml0W4P00000B02Lgol0oooo0?oo_`1d
000004RL0=ooo`030?ooo`030?noW02Lgol0oooo02/0oooo00<0omnL04P00018W=l04P3oool0103o
okl0M0000000B02Lgol60?ooo`030?oog`2LM9`0gooo0080oooo00H0oono07@00000000000000000
B02Lgol30?ooo`0=0=nLB0000000M;oo0=nLB000000007Bo0?ooo`3OW4P0000007Boo`3OW4P00000
001d_`020?ooo`060?oOW0180000000000000000B9`0gooo0P3oool0103ooml0W4P00018W03Oool2
0?ooo`030?oog`2LB00000000080000000@007Bo0?ooo`3oool0_g@00`0000001P0004P0W=oo0?oo
g`2LB00004RL0=ooo`<0oooo00H0oono07@00000000000000000B02Lgol30?ooo`070;md000004P0
W=oo0=nLB0000000001809cOo`060?ooo`040?oo_`1d0000001809cOo`H0oooo00<0oooO09adW03O
ool00P3oool01P3ookl0M000000000000000001809cOo`@0oooo00P0omnL04P00000000000000018
W03Oool0oooo0=nLB0@0000000<0001807AdB00000000`0000001P0004P0W=oo0?oog`2LB00004RL
0=ooo`<0oooo00H0omnL04P00000000000000018W03Oool20?ooo`040?oog`2LB00004RL0=ooo`<0
oooo00H0omnL04P00000000000000018W03Oool20?ooo`090;md000004P0W=oo0=nLB00000000018
09cOo`3oool0_g@000<0000000P0001809cOo`3oool0oooo0?oog`2LB000001809cOo`L0oooo00H0
gia80000001d_ol0gia800000000M;l<0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02o
ool01@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00<0oooo00D0_g@007Boo`3o
_g@0000007Boo`2K0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0R`3oool00`00
0000oooo0?ooo`060?ooo`00:@3oool00`3o_g@007Bo0?ooo`050?ooo`030?oOW02L_ol0oooo00<0
oooo00<0_g@00000001d_ol02P3oool0103o_g@000000000001d_ol=0?ooo`030000003oool0oooo
01h0oooo00<0okmd0000001d_ol01`3oool0103ookl0M0000018W03Ooola0?ooo`030?oOW0180000
B9cO01<0oooo00<0gia800000018W=l01P3oool00`3ogi`0B4RL0=ooo`0R0?ooo`040?oog`2LB000
04RL0=ooo`/0oooo00<0gia80000B02Lgol0803oool00`3OW4P0000004RLg`060?ooo`030?oOW018
B9`0gooo01D0oooo00<0_g@00018W03Oool00`3oool00`2oM00004RL0=ooo`0Y0?ooo`030=nLB000
04P0W=oo0280oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`060?ooo`030?oOW018
0000B9cO00@0oooo00<0_g@00000M02oool00`3oool01@3ookl0M01d0;noM0000000M;oo09`0oooo
0P00000m0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool01P3oool002T0oooo00<0
oooO09a8000000000P0000001P0007@0_ooo0?ooo`3oool0_g@007Boo`80oooo00@0gia800000000
B9`0gooo2P3oool0103ooml0W4P00000001d_ol=0?ooo`030000003oool0oooo01P0oooo00<0omnL
09boo`3oool00`3oool00`2oM000000007Boo`070?ooo`040?oo_`1d000004RL0=ooo`@0oooo00<0
oono09bLg`3oool0:P3oool00`3ogi`0B00004RLg`0C0?ooo`040?oo_`1d0000001809cOo`D0oooo
00<0_g@0001d_`3oool08P3oool0103ooml0W4P00018W03Oool;0?ooo`030?oo_`1d04P0W=oo0200
oooo00@0oono07@0000004P0W=oo1@3oool00`2oM00007Bo0?ooo`0E0?ooo`030;md0000B9`0gooo
00<0oooo00<0_g@00018W03Oool0:@3oool00`3ookl0M01809cOo`0R0?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol01P3oool00`3ooml0W4P0001d_`030?ooo`030?oo_`1d0000B9cO
00D0oooo00@0okmd000000000000M;ooWP3oool2000003/0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`060?ooo`00:P3oool00`3o_g@00000000000020000000507Boo`3oool0oooo
0?ooo`2oM0000`0000000`00M;l0oooo0?ooo`0;0?ooo`030?oOW0180000M;oo00d0oooo00<00000
0?ooo`3oool06@3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo1`3oool0103ookl0
M0000018W03Oool40?ooo`030=nLB018W=l0oooo02X0oooo00<0omnL04P00018W=l0503oool0103o
okl0M0000000B02Lgol20?ooo`040?oog`2LB0000000001d_b<0oooo00@0oooO09a80000B9`0gooo
303oool00`3OW7@0W=oo0?ooo`0P0?ooo`040?oo_`1d0000001809cOo`80oooo00@0oooO09a80000
000007Bo5P3oool00`3OW4P0001d0;ooo`030?ooo`030=nLB00007@0_ooo02X0oooo00<0giad09cO
o`3oool08P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00P0omnL04P0001d_ol0oooo
0?oog`2LB00004RL0=ooo`D0oooo00@0oooO09a800000000M;ooX03oool2000003T0oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`0J0?oo
o`050;md00000000000000000000M;l01`3oool00`3ooml0W4P0000000080000000304RLg`3oool0
oooo02L0oooo00<0oooO09a8000000000`0000000`1d_ol0oooo0?ooo`0B0?ooo`080=nLB0000000
00000000000004P0W=oo0?oo_`1dM;lR0?ooo`050?oOW018000000000018W03Oool0403oool0103o
oml0W4P00000M02ooolM0?ooo`080=nLB000000000000000000004P0W=oo0?oo_`1dM;lF0?ooo`0;
0?oo_`1d04P0W=oo0?ooo`3OW4P0000004RLW01d04P0W=oo0?ooo`3OW4P00P0000000`0007@0_ooo
0?ooo`0:0?ooo`040?oog`2LB000001d0;oooc/0oooo00@0_g@000000000000007Bo2P3oool01P3o
okl0M00000000000000004RL0=ooo`L0oooo00<0omnL04P0001d_ol0XP3oool2000003L0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`2Q
0?ooo`040?oo_`1d000004RL0=oooa00oooo00@0oooO09a8000007@0_ooo?03oool0203ooml0W4P0
00000000000004RL0=ooo`3ooml0W4P00P0000001000B7@0M4P00000M02oool;0?ooo`040?oog`2L
B000001d0;ooood0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2;0?ooo`030000
003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3ooolB0?ooo`800000=03o
ool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0
oooo0?l0ooooo`3ooolD0?ooo`800000<P3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3ooolF0?ooo`800000<03oool00`00
0000oooo0?ooo`2;0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0
ooooo`3ooolH0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0R`3oool00`000000
oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0oooo6@3oool2000002d0oooo
00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?oo
o`3o0?ooool0oooo6`3oool2000002/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0oooo7@3oool2000002T0oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`060?ooo`00E@3oool400000?l0ooooo`3ooolN0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0R03oool4000000P0oooo001E0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolP0?ooo`8000009P3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3ooolR0?ooo`800000
903oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolT0?ooo`8000008P3oool00`000000oooo0?ooo`2;0?ooo`030000003o
ool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3ooolV0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`00
0000oooo0?ooo`3o0?ooool0oooo9`3oool2000001l0oooo00<000000?ooo`3oool0R`3oool00`00
0000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0oooo:@3oool2000001d0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo
0?ooo`3o0?ooool0oooo:`3oool2000001/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0oooo;@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool01P3oool005D0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooobh0oooo0P00000H0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?oooc00oooo0P00000F0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooc80oooo0P00000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3o
ool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?oooc@0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003o
ool0oooo0?l0ooooo`3ooole0?ooo`8000004@3oool00`000000oooo0?ooo`2;0?ooo`030000003o
ool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3ooolg0?ooo`8000003P3oool2
000008d0oooo00<000000?ooo`3oool01P3oool005D0oooo1000003o0?ooool0oooo>03oool20000
00X0oooo1P0000280?ooo`@00000203oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?oooc/0
oooo00<000000?ooo`3oool01P3oool8000008X0oooo00<000000?ooo`3oool01P3oool005D0oooo
00<000000?ooo`3oool0o`3ooooo0?oooc`0oooo0P0000060?ooo`P00000RP3oool00`000000oooo
0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0oooo?P3oool2000000<0oooo2P00
00290?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3ooom0
0?ooo`80000000<0oooo000000000000200000290?ooo`030000003oool0oooo00H0oooo001E0?oo
o`030000003oool0oooo0?l0ooooo`3ooom20?ooo`030000003oool0000000L00000RP3oool00`00
0000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0oooo@`3oool9000008X0
oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooodD0oooo
1P00002;0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3o
oom70?ooo`800000S@3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o
0?ooool0ooooB03oool3000008/0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?oo
o`3oool0o`3ooooo0?ooodP0oooo00@000000?ooo`3oool00000RP3oool00`000000oooo0?ooo`06
0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool010000000oooo0?ooo`3oool2
000008P0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
odP0oooo00<000000?ooo`3oool00`3oool2000008H0oooo00<000000?ooo`3oool01P3oool005D0
oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool01@3oool2000008@0
oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00H0oooo
001E0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo00P0oooo0P00
00210?ooo`030000003oool0oooo00H0oooo001E0?ooo`@00000o`3ooooo0?ooodL0oooo00<00000
0?ooo`3oool02P3oool2000007`0oooo100000080?ooo`00E@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooB03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07`0oooo00<000000?oo
o`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3o
ool03@3oool2000007`0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0
o`3ooooo0?ooodP0oooo00<000000?ooo`3oool03`3oool2000007X0oooo00<000000?ooo`3oool0
1P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool04@3o
ool2000007P0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo
0?ooodP0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0
oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo
01@0oooo0P00001e0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0
ooooo`3ooom80?ooo`030000003oool0oooo01H0oooo0P00001c0?ooo`030000003oool0oooo00H0
oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?oo
o`3o0?ooool0ooooB03oool00`000000oooo0?ooo`0I0?ooo`800000L03oool00`000000oooo0?oo
o`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?ooo`0K
0?ooo`800000KP3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooB03oool00`000000oooo0?ooo`0M0?ooo`800000K03oool00`000000oooo0?ooo`060?oo
o`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo06T0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0
o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0803oool2000006T0oooo00<000000?ooo`3oool0
1P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool08P3o
ool2000006L0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo
0?ooodP0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo00H0oooo001E0?ooo`@00000o`3ooooo0?ooodL0oooo00<000000?ooo`3oool09@3oool20000
0640oooo100000080?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000
oooo0?ooo`0W0?ooo`800000HP3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo
0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?ooo`0Y0?ooo`800000H03oool00`000000oooo
0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool01P3oool005D0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0;03oool2000005d0oooo00<00000
0?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?oo
o`3oool0;P3oool2000005/0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0<03oool2000005T0oooo00<000000?ooo`3o
ool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo03<0oooo0P00001F0?ooo`030000003o
ool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0
oooo03D0oooo0P00001D0?ooo`030000003oool0oooo00H0oooo000X0?ooo`060;md000000000000
00000000B9`0gooo0`3oool00`3OW4P00000000000050000000607Boo`3oool0oooo0=nLB0000000
B9cO0P3oool01P2oM000000000000000000004RL0=ooo`h0oooo00<000000?ooo`3oool0o`3ooooo
0?ooodP0oooo00<000000?ooo`3oool0=`3oool200000580oooo00<000000?ooo`3oool01P3oool0
02L0oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`030?ooo`030=nLB00000000000
00@0000000X007Bo0?ooo`3oool0gia800000018W=l0oooo0?oog`2LB000B9cO0P3oool00`3ogi`0
B4RL0=ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`060?ooo`00;@3oool00`3ogi`0B7Bo
0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool02`3oool00`3ogi`0B7Bo
0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo03X0oooo
0P00001?0?ooo`030000003oool0oooo00H0oooo000]0?ooo`030?oo_`1d04P0W=oo00@0oooo00<0
gia804RLg`3oool03`3oool00`3ookl0M01809cOo`0<0?ooo`030000003oool0oooo0?l0ooooo`3o
oom80?ooo`030000003oool0oooo03`0oooo0P00001=0?ooo`030000003oool0oooo00H0oooo000]
0?ooo`030?oo_`1d0000M;oo00D0oooo00<0gia807Boo`3oool03P3oool00`3ookl0M00007Boo`0<
0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo03h0oooo0P00001;
0?ooo`030000003oool0oooo00H0oooo000]0?ooo`030?noM0000000M;oo00D0oooo00<0oooO09a8
B02Lgol03P3oool00`3o_g@0000007Boo`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`060?oo
o`00;03oool0103ogi`0B0000000M02oool60?ooo`030?oOW01807@0_ooo00`0oooo00@0omnL04P0
000007@0_ooo303oool600000?l0ooooo`3ooom50?ooo`030000003oool0oooo0440oooo0P000013
0?ooo`H00000203oool002P0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`06
0?ooo`030;md0018W=l0oooo00L0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?oo
o`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`030000003oool0oooo04<0oooo0P00
00160?ooo`030000003oool0oooo00H0oooo000X0?ooo`030?noM000000000000080000000<007Bo
0?ooo`3oool01`3oool00`3OW4P0001d0;ooo`070?ooo`030?noM000000000000080000000<007Bo
0?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?ooo`15
0?ooo`800000A03oool00`000000oooo0?ooo`060?ooo`00:03oool01@3ooml0W4P00000000007@0
_ooo00X0oooo00<0okmd0000001d_ol01`3oool01@3ooml0W4P00000000007@0_ooo00l0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0A`3oool200000480oooo00<0
00000?ooo`3oool01P3oool002T0oooo00<0okmd001d_`3oool01@3oool00`3ogi`0W;oo0?ooo`03
0?ooo`030;md00000000M;oo00P0oooo00<0okmd001d_`3oool0403oool00`000000oooo0?ooo`3o
0?ooool0ooooB03oool00`000000oooo0?ooo`190?ooo`800000@03oool00`000000oooo0?ooo`06
0?ooo`00:@3oool00`3ooml0W4P000000002000000060000M02oool0oooo0?ooo`2oM000M;oo0P3o
ool0103OW4P000000018W03Oool80?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool0
2`3oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?ooo`1;0?ooo`800000
?P3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`3o_g@00000000000020000000507Boo`3o
ool0oooo0?ooo`2oM0000`0000000`00M;l0oooo0?ooo`090?ooo`030?noM0000000000000800000
00<0M;oo0?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo
0?ooo`1=0?ooo`800000?03oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?oo
o`3o0?ooool0ooooB03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<00000
0?ooo`3oool0D03oool2000003T0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?oo
o`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0DP3oool2000003L0oooo00<000000?oo
o`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3o
ool0E03oool2000003D0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0
o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0EP3oool2000003<0oooo00<000000?ooo`3oool0
1P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0F03o
ool200000340oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo
0?ooodP0oooo00<000000?ooo`3oool0FP3oool2000002l0oooo00<000000?ooo`3oool01P3oool0
05D0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo00<000000?ooo`3oool0G03oool20000
02d0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00H0
oooo001E0?ooo`@00000o`3ooooo0?ooodL0oooo00<000000?ooo`3oool0G`3oool2000002L0oooo
100000080?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0oooo[03oool2000002P0oooo00<0
00000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooojh0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?oo
ool0oooo[`3oool2000002D0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3o
ool0o`3ooooo0?oook40oooo0P00000S0?ooo`030000003oool0oooo00H0oooo001E0?ooo`030000
003oool0oooo0?l0ooooo`3ooonc0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
1P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?oook@0oooo0P00000P0?ooo`030000003o
ool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3ooonf0?ooo`8000007P3oool0
0`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0oooo^03oool20000
01`0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?oookX0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo
0?ooo`3o0?ooool0oooo^`3oool2000001T0oooo00<000000?ooo`3oool01P3oool005D0oooo00<0
00000?ooo`3oool0o`3ooooo0?oookd0oooo0P00000G0?ooo`030000003oool0oooo00H0oooo001E
0?ooo`030000003oool0oooo0?l0ooooo`3ooono0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool01P3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?oool00oooo0P00000D0?oo
o`030000003oool0oooo00H0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo20?ooo`80
00004P3oool00`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0oooo
a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo001E0?ooo`@00000o`3o
oooo0?ooom80oooo100000080?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooooeP3oool0
0`000000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooooeP3oool00`00
0000oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooooeP3oool00`000000
oooo0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooooeP3oool00`000000oooo
0?ooo`060?ooo`00E@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo08L0oooo00<0
00000?ooo`3oool0Q`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo08L0oooo00<0
00000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo001E
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool005D0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool01P3oool005D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool005D0ooooo`00003o00000=X00000
203oool00001\
\>"],
  ImageRangeCache->{{{0, 820.813}, {506.938, 0}} -> {-0.746781, 51.9113, \
0.00723073, 0.00126491}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(b1p[a1b1_, b1b1_, x_] := a1b1\  + \ b1b1\ x;\)\)], "Input"],

Cell[BoxData[
    \(\(chi2b1[a1b1_, b1b1_] := 
        Sum[\((\((b1pl[\([i, 2]\)] - 
                    b1p[a1b1, b1b1, b1pl[\([i, 1]\)]])\)/\((b1pl[\([i, 
                      3]\)])\))\)^2, {i, 1, Length[b1pl]}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(par = {a1b1, b1b1};\)\), "\n", 
    \(\(aklb1[a1b1_, b1b1_, k_, l_] := 
        1/2  D[D[chi2b1[a1b1, b1b1], par[\([k]\)]], 
            par[\([l]\)]\ ];\)\), "\n", 
    \(\(fminb1 = 
        FindMinimum[
          chi2b1\ [a1b1, b1b1], {a1b1, 1}, {b1b1, \(-10\)}];\)\), "\n", 
    \(\(a1b1o = fminb1[\([2, 1, 2]\)];\)\), "\n", 
    \(\(b1b1o = fminb1[\([2, 2, 2]\)];\)\), "\n", 
    \(aklob1 = 
      Table[If[k \[LessSlantEqual] 
            l, \(aklb1[a1b1, b1b1, k, l] /. a1b1 \[Rule] a1b1o\) /. 
            b1b1 \[Rule] b1b1o, \(aklb1[a1b1, b1b1, l, k] /. 
              a1b1 \[Rule] a1b1o\) /. b1b1 \[Rule] b1b1o], {k, 1, 2}, {l, 1, 
          2}]; cij = Inverse[aklob1]; 
    sparb1 = Table[Sqrt[cij[\([i, i]\)]], {i, 1, 2}]; 
    Print["\<a1b1= \>", a1b1o, "\<+-\>", sparb1[\([1]\)], "\<  b1b1= \>", 
      b1b1o, "\<+-\>", sparb1[\([2]\)]]; 
    cij // MatrixForm\), "\[IndentingNewLine]", 
    \(chi2rb1 = Part[fminb1, 1]/\((Length[b1pl])\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("a1b1= "\[InvisibleSpace]1.6988058369538175`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.12217852412890917`\[InvisibleSpace]"  \
b1b1= "\[InvisibleSpace]\(-0.14781752107254498`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.05706155942303592`\),
      SequenceForm[ 
      "a1b1= ", 1.6988058369538175, "+-", .12217852412890917, 
        "  b1b1= ", -.14781752107254498, "+-", .057061559423035917],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.014927591758318441`", \(-0.005466899702624034`\)},
            {\(-0.005466899702624034`\), "0.003256021563788659`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    \(1.4837579585725928`\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(b1pr = a1b1o + \ b1b1o\ z;\)\), "\[IndentingNewLine]", 
    \(\(b1prpl = 
        Plot[b1pr, {z, 0, 5}, 
          DisplayFunction \[Rule] Identity];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fa2 = 
      Show[b1prpl, b1dtpl, 
        Graphics[{Text[\*"\"\<2:\!\(E\_peak\)-L  Correlation Coefficient: \
r=0.70\>\"", {3.7, 1.44}]}], Frame \[Rule] True, Axes \[Rule] False, 
        DisplayFunction \[Rule] $DisplayFunction, PlotRange \[Rule] All, 
        FrameLabel \[Rule] {"\<<z>\>", \*"\"\<\!\(a\_2\)\>\""}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 -0.360765 0.484457 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -7.03125 -24.5625 ]
[.21429 -0.0125 7.03125 0 ]
[.40476 -0.0125 -7.03125 -24.5625 ]
[.40476 -0.0125 7.03125 0 ]
[.59524 -0.0125 -7.03125 -24.5625 ]
[.59524 -0.0125 7.03125 0 ]
[.78571 -0.0125 -7.03125 -24.5625 ]
[.78571 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.375 -49.125 ]
[.5 -0.0125 19.375 -24.5625 ]
[-0.0125 .0268 -29.125 -12.2813 ]
[-0.0125 .0268 0 12.2813 ]
[-0.0125 .12369 -14.0625 -12.2813 ]
[-0.0125 .12369 0 12.2813 ]
[-0.0125 .22058 -29.125 -12.2813 ]
[-0.0125 .22058 0 12.2813 ]
[-0.0125 .31748 -29.125 -12.2813 ]
[-0.0125 .31748 0 12.2813 ]
[-0.0125 .41437 -29.125 -12.2813 ]
[-0.0125 .41437 0 12.2813 ]
[-0.0125 .51126 -29.125 -12.2813 ]
[-0.0125 .51126 0 12.2813 ]
[-0.0125 .60815 -14.0625 -12.2813 ]
[-0.0125 .60815 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -53.6875 -10.2188 ]
[-0.01875 .30902 -29.125 10.2188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.72857 .33685 -172.75 -13.0938 ]
[.72857 .33685 172.75 13.0938 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.375 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
75.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
84.813 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
97.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0268 m
.00625 .0268 L
s
gsave
-0.0125 .0268 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .12369 m
.00625 .12369 L
s
gsave
-0.0125 .12369 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .22058 m
.00625 .22058 L
s
gsave
-0.0125 .22058 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .31748 m
.00625 .31748 L
s
gsave
-0.0125 .31748 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .41437 m
.00625 .41437 L
s
gsave
-0.0125 .41437 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
0 .51126 m
.00625 .51126 L
s
gsave
-0.0125 .51126 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
0 .60815 m
.00625 .60815 L
s
gsave
-0.0125 .60815 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05102 m
.00375 .05102 L
s
0 .07525 m
.00375 .07525 L
s
0 .09947 m
.00375 .09947 L
s
0 .14792 m
.00375 .14792 L
s
0 .17214 m
.00375 .17214 L
s
0 .19636 m
.00375 .19636 L
s
0 .24481 m
.00375 .24481 L
s
0 .26903 m
.00375 .26903 L
s
0 .29325 m
.00375 .29325 L
s
0 .3417 m
.00375 .3417 L
s
0 .36592 m
.00375 .36592 L
s
0 .39014 m
.00375 .39014 L
s
0 .43859 m
.00375 .43859 L
s
0 .46281 m
.00375 .46281 L
s
0 .48703 m
.00375 .48703 L
s
0 .53548 m
.00375 .53548 L
s
0 .5597 m
.00375 .5597 L
s
0 .58393 m
.00375 .58393 L
s
0 .00258 m
.00375 .00258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -112.625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.2188 16.2813 translate
90 rotate
-71.2188 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
71.875 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
79.438 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0268 m
1 .0268 L
s
.99375 .12369 m
1 .12369 L
s
.99375 .22058 m
1 .22058 L
s
.99375 .31748 m
1 .31748 L
s
.99375 .41437 m
1 .41437 L
s
.99375 .51126 m
1 .51126 L
s
.99375 .60815 m
1 .60815 L
s
.125 Mabswid
.99625 .05102 m
1 .05102 L
s
.99625 .07525 m
1 .07525 L
s
.99625 .09947 m
1 .09947 L
s
.99625 .14792 m
1 .14792 L
s
.99625 .17214 m
1 .17214 L
s
.99625 .19636 m
1 .19636 L
s
.99625 .24481 m
1 .24481 L
s
.99625 .26903 m
1 .26903 L
s
.99625 .29325 m
1 .29325 L
s
.99625 .3417 m
1 .3417 L
s
.99625 .36592 m
1 .36592 L
s
.99625 .39014 m
1 .39014 L
s
.99625 .43859 m
1 .43859 L
s
.99625 .46281 m
1 .46281 L
s
.99625 .48703 m
1 .48703 L
s
.99625 .53548 m
1 .53548 L
s
.99625 .5597 m
1 .5597 L
s
.99625 .58393 m
1 .58393 L
s
.99625 .00258 m
1 .00258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .46223 m
.06244 .44771 L
.10458 .43187 L
.14415 .41699 L
.18221 .40268 L
.22272 .38745 L
.26171 .37279 L
.30316 .35721 L
.34309 .3422 L
.3815 .32776 L
.42237 .31239 L
.46172 .2976 L
.49955 .28337 L
.53984 .26823 L
.57861 .25365 L
.61984 .23815 L
.65954 .22322 L
.69774 .20886 L
.73838 .19358 L
.77751 .17887 L
.81909 .16324 L
.85916 .14818 L
.89771 .13368 L
.93871 .11827 L
.97619 .10418 L
s
.002 w
.15376 .31696 m
.15376 .41921 L
s
.015 w
.15376 .36808 Mdot
.002 w
.28654 .3666 m
.28654 .5422 L
s
.015 w
.28654 .4544 Mdot
.002 w
.48667 .37967 m
.48667 .60332 L
s
.015 w
.48667 .4915 Mdot
.002 w
.80454 .01472 m
.80454 .17864 L
s
.015 w
.80454 .09668 Mdot
gsave
.72857 .33685 -233.75 -17.0938 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
73.063 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
78.563 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
90.813 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(peak) show
117.938 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
130.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
153.125 23.000 moveto
(Correlation) show
249.250 23.000 moveto
(Coefficient) show
339.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
349.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
356.375 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
369.313 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.70) show
404.500 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{749.125, 463},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;]0001cb000`400?l00000o`00003oo`3ooooo
0?ooonl0oooo003o0?ooool0ooook`3oool00?l0ooooo`3oooo_0?ooo`00o`3ooooo0?ooonl0oooo
003o0?ooool0ooook`3oool00?l0ooooo`3oooo_0?ooo`00o`3ooooo0?ooonl0oooo003o0?oooi00
oooo00@0okmd001d_`3oool0_g@01P0000001@18W=l0oooo0?ooo`2oM4P0W=oo0?l0ooooD03oool0
0?l0ooooSP3oool0203o_g@000000000M02oool0oooo0?oo_`1d000007Bo0`3oool0203ogi`0M9cO
0?ooo`3oool0omnL04P0000004P0W=ooo`3ooom>0?ooo`00o`3ooon<0?ooo`040?noM00000000018
09cOo`@0oooo00<0omnL04P0001d_ol00P3oool00`3ooml0_koO0?ooo`030?ooo`040?oOW0180000
001809cOool0ooooC03oool00?l0ooooRP3oool0103ogi`0B0000000B02Lgol70?ooo`030=nLB000
04P0W=oo00T0oooo00@0okmd0000000004P0W=ooo`3ooom:0?ooo`00o`3ooon80?ooo`040?oOW018
0000001809cOo`T0oooo00@0oooO09a80000B9`0gooo2P3oool0103o_g@000000000M02ooooo0?oo
odP0oooo003o0?ooohL0oooo00<0_g@00000B02Lgol0303oool00`3ookl0M000001d_`0<0?ooo`03
0?noM0000000B9cO0?l0ooooA`3oool00?l0ooooR03oool0103ogi`0B0000000B02Lgol70?ooo`07
0?oOW02L_ol0oooo0?ooo`3o_g@0000007Boo`090?ooo`040?noM0000000001d0;ooool0ooooB03o
ool00?l0ooooRP3oool0103ogi`0B0000000B02Lgol50?ooo`030?oo_`2LW=l0oooo0080oooo00<0
_g@00000M02oool01P3oool0103o_g@000000000B02Lgooo0?ooodX0oooo003o0?oooh`0oooo00@0
okmd0000000004P0W=oo0`3oool00`3ookl0M00000000004000000030018W03Oool0oooo0080oooo
00@0omnL04P0000004P0W=ooo`3ooom<0?ooo`00o`3ooon>0?ooo`040?noM0000000001d0;ooo`/0
oooo00@0omnL04P0000004P0W=ooo`3ooom>0?ooo`00o`3ooon@0?ooo`030?noM000M;l0oooo00X0
oooo00<0_gA809cOo`3oool0o`3ooom?0?ooo`00o`3ooooo0?ooonl0oooo003o0?ooool0ooook`3o
ool00?l0ooooo`3oooo_0?ooo`00o`3ooooo0?ooonl0oooo003o0?ooool0ooook`3oool00?l0oooo
o`3oooo_0?ooo`00o`3ooooo0?ooonl0oooo003o0?ooool0ooook`3oool00?l0ooooo`3oooo_0?oo
o`00o`3ooooo0?ooonl0oooo003o0?ooool0ooook`3oool00?l0ooooo`3oooo_0?ooo`00o`3ooooo
0?ooonl0oooo003o0?ooool0ooook`3oool00640oooo00@0_g@0000000000000B9cOMP3oool00`3o
_g@000000000000200000003001d_`3oool0oooo0740oooo00<0gia80000000000001@0000000`1d
_ol0oooo0?ooo`1`0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0N03oool00`3o
_g@0000007Boo`1d0?ooo`060;md00000000000000000000B9`0gooo8@3oool005l0oooo00L0oooO
09a80000M;l0oooo0?oog`2LB00007Bo07L0oooo00<0_g@00000M02oool0M@3oool00`3OW4P00000
0000000400000003001d_`3oool0oooo0700oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B018
09cOogP0oooo00<0okmd0000001d_ol0L`3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0
gooo0200oooo001O0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0MP3oool00`2o
M000001d0;ooo`1f0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool0M`3oool00`3o
_g@004RL0=ooo`1g0?ooo`030?noM0000000M;oo07T0oooo00<0omnL04Qd_`3oool07`3oool005h0
oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`1f0?ooo`030;md000007@0_ooo
07L0oooo00<0gia804RLg`3oool0N`3oool00`3o_g@0001809cOo`1b0?ooo`030=nLB00000000000
00D0000000<0001809cOo`3oool0MP3oool00`3ookl0M01809cOo`0O0?ooo`00GP3oool00`3ookl0
M000001d_`040?ooo`030;md000007@0_ooo07D0oooo00<0_g@00000M02oool0N03oool00`3OW4P0
M;oo0?ooo`1j0?ooo`030;md000004P0W=oo0780oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0
000007Boo`1i0?ooo`030?oo_`1d0000M;oo01l0oooo001N0?ooo`030?oOW0180000B9cO00@0oooo
00<0_g@00000M02oool0M@3oool00`2oM000001d0;ooo`1h0?ooo`030?oog`2LB4P0W=oo07T0oooo
00@0_g@00000000007@0_oooL`3oool01`3OW4P0M;oo0?ooo`3oool0okmd0000001d_ol0N@3oool0
0`3o_g@0000007Boo`0O0?ooo`00GP3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo
07D0oooo00<0_g@00000M02oool0N@3oool00`3ogi`0B01d0;ooo`1e0?ooo`030?oo_`1d00000000
0080000000<0B9cO0?ooo`3oool0LP3oool01`3ookl0M01d0;ooo`3oool0okmd0000001d_ol0N03o
ool0103ogi`0B0000000M02ooolO0?ooo`00GP3oool00`3ogi`0B00004RLg`040?ooo`030=nLB000
04P0W=oo07D0oooo00<0_g@00000M02oool0NP3oool00`2oM000B9cO0?ooo`1f0?ooo`030?noM000
04P0W=oo07H0oooo00H0okmd001d_`3oool0okmd0000001d_omd0?ooo`040=oOg`3oool0oooo0;md
0080000000<0B9cO0?ooo`3oool07P3oool005h0oooo00<0oono07@00000M;l0103oool00`2oM000
001d0;ooo`1e0?ooo`030;md000007@0_ooo07X0oooo00<0gia80000M02oool0M`3oool00`3ogi`0
B7Bo0?ooo`1f0?ooo`050;md001d_ol0okmd0000001d_ol0M03oool00`3o_g@00000000000020000
0003001d_`3oool0oooo01l0oooo001O0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000
M;l0MP3oool00`2oM000001d0;ooo`1j0?ooo`030?noM0000000M;oo07L0oooo00<0oooO09a80018
W=l0MP3oool01@3ookl0M01d0;noM0000000M;oo07@0oooo00D0oooO09a800000000001d0;ooo`0R
0?ooo`00G`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo07H0oooo00<0_g@00000
M02oool0M03oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo0780oooo00<0oooO09ad
W03Oool00P3oool00`3ooml0W4P0001d_`1g0?ooo`040?noM0000000000007BoogD0oooo00<0okmd
001d_`3oool08`3oool00600oooo00H0_g@00018W03Oool0oooo0;md0000M;me0?ooo`050=nLB000
000000000000M02oool0M@3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0goooL`3oool0
1`3ogi`0B4RL0=ooo`3oool0gia80000001d_ol0M`3oool0103ooml0W4P00000001d_ome0?ooo`03
0?oog`2LB00000000080000000<0001d0;ooo`3oool07P3oool00640oooo00@0_g@0000000000000
07BoM`3oool0103ookl0M0000000M02ooomf0?ooo`050;md00000000000000000000M;l0MP3oool0
1@3ogi`0B000000000000000B9cO07T0oooo00<0omnL04P0001d_ol0MP3oool00`3o_g@000000000
00020000000307Boo`3oool0oooo01d0oooo003o0?ooool0ooook`3oool00?l0ooooo`3oooo_0?oo
o`00o`3ooooo0?ooonl0oooo003o0?ooool0ooook`3oool00?l0ooooo`3oooo_0?ooo`00o`3ooooo
0?ooonl0oooo003o0?ooool0ooook`3oool00?l0ooooo`3oooo_0?ooo`00o`3ooooo0?ooonl0oooo
003o0?ooool0ooook`3oool00?l0ooooo`3oooo_0?ooo`00o`3ooooo0?ooonl0oooo003o0?ooool0
ooook`3oool005@0ooooo`00003o000008P000004`3oool005@0oooo0`00000<0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool02P3oool3000001<0oooo001D0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0140oooo001D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool005@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo
0?ooo`3o0?ooool0ooooQ03oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?oo
o`3o0?ooool0ooooQ03oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o
0?ooool0ooooQ03oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?oo
ool0ooooQ03oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0
oooo1P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000
003oool0oooo0?l0ooooo`3oool60?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
4@3oool003@0oooo00@0_g@0000000000000B9cO103oool00`3OW4P0000004RLg`030?ooo`060?oO
W018000000000000000004P0W=oo303oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`00
0000oooo0?ooo`1k0?ooo`030000003oool0oooo0140oooo000b0?ooo`070?oog`2LB00007Bo0?oo
o`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00P0omnL04P00000B9`0gooo0?oo
o`3ogi`0B00007Boo`/0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`0A0?ooo`00<P3oool00`3o_g@0001809cOo`020?ooo`030?oO
W0180000M;oo00L0oooo00<0_g@00000M02oool00`3oool00`3OW4P004RL0=ooo`0:0?ooo`030000
003oool0oooo0?l0ooooo`3oool60?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
4@3oool00340oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`070?ooo`030;md
000007@0_ooo00<0oooo00<0_g@00018W03Oool02P3oool00`000000oooo0?ooo`3o0?ooool0oooo
1P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0140oooo000a0?ooo`030?oo_`1d
000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@0001809cOo`020?ooo`030=nLB000
000007Bo00/0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0N`3o
ool00`000000oooo0?ooo`0A0?ooo`00<@3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0
_ooo00L0oooo00L0gia8001d_`3oool0_g@00000000007@0_ooo00/0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0A0?ooo`00<@3o
ool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00P0oooo00D0okmd00000000000004RL
0=ooo`0<0?ooo`D00000o`3ooooo0?ooo`@0oooo00<000000?ooo`3oool0M`3oool5000001<0oooo
000a0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01`3oool01@3ogi`0B0000000
00000000B9cO00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`0A0?ooo`00<@3oool00`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo00H0oooo00L0omnL04P0000004P0W=oo0?ooo`3OW4P007Bo00`0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0A0?ooo`00
<P3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00<0gia80000B02Lgol0
0P3oool00`3ooml0W4P007Boo`0;0?ooo`030000003oool0oooo0?l0ooooo`3oool60?ooo`030000
003oool0oooo07/0oooo00<000000?ooo`3oool04@3oool00380oooo00<0okmd0000B02Lgol00P3o
ool00`3ogi`0B00007Boo`070?ooo`030=nLB000B9`0gooo0080oooo00<0oooO09a80018W=l02`3o
ool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo0140oooo000c0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203oool00`3ogi`0B000
04RLg`020?ooo`030?noM00004P0W=oo00/0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo
00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0A0?ooo`00=03oool0102oM00000000000
0000M;l:0?ooo`060?oo_`1d000000000000000004P0W=oo303oool00`000000oooo0?ooo`3o0?oo
ool0oooo1P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0140oooo001D0?ooo`03
0000003oool0oooo0?l0ooooo`3oool60?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3o
ool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo1P3o
ool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0
oooo0?l0ooooo`3oool60?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool04@3oool0
05@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0oooo
o`3oool60?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool04@3oool005@0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`1k
0?ooo`030000003oool0oooo0140oooo001D0?ooo`<00000o`3ooooo0?ooo`H0oooo00<000000?oo
o`3oool0N@3oool3000001<0oooo001D0?ooo`030000003oool0oooo0?l0ooooo`3oool60?ooo`03
0000003oool0oooo07/0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0A0?ooo`00E03o
ool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooo`3oool60?ooo`030000003oool0
oooo07/0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`H0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000
oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0140
oooo001D0?ooo`030000003oool0oooo0?l0ooooo`3oool60?ooo`030000003oool0oooo07/0oooo
00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o
0?ooool0oooo1P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0140oooo001D0?oo
o`030000003oool0oooo0?l0ooooo`3oool60?ooo`030000003oool0oooo07/0oooo00<000000?oo
o`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo
1P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003o
ool0oooo0?l0ooooo`3oool60?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool04@3o
ool005@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`0A0?ooo`00E03oool300000?l0ooooo`3oool60?ooo`030000003oool0oooo
07T0oooo0`00000C0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0oooo
o`3oool60?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool04@3oool005@0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`1k
0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooo`3oool60?oo
o`030000003oool0oooo07/0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0A0?ooo`00
E03oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`1k0?ooo`030000
003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooo`3oool60?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`H0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`00
0000oooo0?ooo`3o0?ooool0oooo1@3oool3000007`0oooo00<000000?ooo`3oool04@3oool005@0
oooo00<000000?ooo`3oool0o`3ooooo0?ooo`<0oooo1`00001j0?ooo`030000003oool0oooo0140
oooo001D0?ooo`030000003oool0oooo0?l0ooooo`3oool30?ooo`L00000NP3oool00`000000oooo
0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo0P3oool9000007T0oooo00<0
00000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo2@00001i
0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooo`3oool20?oo
o`T00000N@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool300000?l0ooooo`3oool30?ooo`L0
0000N03oool3000001<0oooo001D0?ooo`030000003oool0oooo0?l0ooooo`3oool30?ooo`L00000
NP3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo1@3o
ool3000007`0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`H0oooo00<000000?ooo`3oool0J`3oool2000000h0oooo00<000000?ooo`3oool04@3oool0
05@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0J@3oool20000
0100oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0
oooo00<000000?ooo`3oool0IP3oool300000180oooo00<000000?ooo`3oool04@3oool005@0oooo
00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0H`3oool3000001D0oooo
00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<0
00000?ooo`3oool0H@3oool2000001P0oooo00<000000?ooo`3oool04@3oool005@0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0GP3oool3000001X0oooo00<00000
0?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?oo
o`3oool0F`3oool3000001d0oooo00<000000?ooo`3oool04@3oool00480oooo00<0okmd00000000
00000P0000000`00M;l0oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooo`3oool60?ooo`03
0000003oool0oooo05T0oooo0P00000P0?ooo`030000003oool0oooo0140oooo00140?ooo`030;md
000007@0_ooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0
EP3oool300000280oooo00<000000?ooo`3oool04@3oool004@0oooo00<0_g@00000M02oool03@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`1C0?ooo`<000009@3o
ool00`000000oooo0?ooo`0A0?ooo`00A03oool00`2oM000001d0;ooo`0=0?ooo`030000003oool0
oooo0?l0ooooo`3oool60?ooo`030000003oool0oooo0500oooo0`00000X0?ooo`030000003oool0
oooo0140oooo00140?ooo`030;md000007@0_ooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`H0oooo00<000000?ooo`3oool0CP3oool2000002/0oooo00<000000?ooo`3oool04@3oool004@0
oooo00<0_g@00000M02oool03@3oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000
oooo0?ooo`1;0?ooo`<00000;@3oool00`000000oooo0?ooo`0A0?ooo`00A03oool00`2oM000001d
0;ooo`0=0?ooo`D00000o`3ooooo0?ooo`@0oooo00<000000?ooo`3oool0B03oool3000002`0oooo
1@00000C0?ooo`00A03oool00`2oM000001d0;ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3o
ool60?ooo`030000003oool0oooo04H0oooo0P00000c0?ooo`030000003oool0oooo0140oooo0014
0?ooo`030;md000007@0_ooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo00<00000
0?ooo`3oool0@`3oool3000003D0oooo00<000000?ooo`3oool04@3oool004@0oooo00<0_g@00000
M02oool03@3oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`100?oo
o`<00000>03oool00`000000oooo0?ooo`0A0?ooo`00A03oool00`2oM000001d0;ooo`0=0?ooo`03
0000003oool0oooo0?l0ooooo`3oool60?ooo`030000003oool0oooo03h0oooo0P00000k0?ooo`03
0000003oool0oooo0140oooo00120?ooo`050=nLB000000000000000M02oool03@3oool00`000000
oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`0k0?ooo`<00000?@3oool00`000000
oooo0?ooo`0A0?ooo`00@`3oool0103ookl0M0000000M02oool=0?ooo`030000003oool0oooo0?l0
ooooo`3oool60?ooo`030000003oool0oooo03P0oooo0`0000100?ooo`030000003oool0oooo0140
oooo001D0?ooo`030000003oool0oooo0?l0ooooo`3oool60?ooo`030000003oool0oooo03D0oooo
0`0000130?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooo`3o
ool60?ooo`030000003oool0oooo03<0oooo0P0000160?ooo`030000003oool0oooo0140oooo001D
0?ooo`030000003oool0oooo0?l0ooooo`3oool60?ooo`030000003oool0oooo0300oooo0`000018
0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooo`3oool60?oo
o`030000003oool0oooo02d0oooo0`00001;0?ooo`030000003oool0oooo0140oooo001D0?ooo`03
0000003oool0oooo0?l0ooooo`3oool60?ooo`030000003oool0oooo02X0oooo0`00001>0?ooo`03
0000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooo`3oool60?ooo`030000
003oool0oooo02L0oooo0`00001A0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003o
ool0oooo0?l0ooooo`3oool60?ooo`030000003oool0oooo02D0oooo0P00001D0?ooo`030000003o
ool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooo`3oool60?ooo`030000003oool0
oooo0280oooo0`00001F0?ooo`030000003oool0oooo0140oooo001D0?ooo`<00000o`3ooooo0?oo
o`H0oooo00<000000?ooo`3oool07`3oool3000005L0oooo0`00000C0?ooo`00E03oool00`000000
oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`0M0?ooo`800000G03oool00`000000
oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo
0?ooo`0J0?ooo`<00000GP3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?oo
o`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`0G0?ooo`<00000H@3oool00`000000oooo0?oo
o`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`0E
0?ooo`800000I03oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?oo
ool0oooo1P3oool00`000000oooo0?ooo`0B0?ooo`<00000IP3oool00`000000oooo0?ooo`0A0?oo
o`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`0@0?ooo`80
0000J@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo
1P3oool00`000000oooo0?ooo`0=0?ooo`<00000J`3oool00`000000oooo0?ooo`0A0?ooo`00E03o
ool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`0:0?ooo`<00000KP3o
ool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool0
0`000000oooo0?ooo`080?ooo`800000L@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`00
0000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`050?ooo`<00000L`3oool00`00
0000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo1P3oool00`000000
oooo0?ooo`030?ooo`800000MP3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo
0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`03000007P0oooo00<000000?ooo`3oool0
4@3oool005@0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo0`00001k0?ooo`030000003o
ool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooo`3oool40?ooo`<00000O@3oool0
0`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooool0oooo0@3oool30000
0080oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0A0?ooo`00E03oool300000?l0
oooooP3oool2000000D0oooo00<000000?ooo`3oool0N@3oool3000001<0oooo001D0?ooo`030000
003oool0oooo0?l0oooon`3oool3000000L0oooo00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooooP0oooo0`00000:0?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3oooof
0?ooo`8000003@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0140oooo001D0?oo
o`030000003oool0oooo0?l0ooool`3oool3000000l0oooo00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?oooo40oooo0P00002@0?ooo`03
0000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooookP3oool300000980oooo
00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3oooo[0?ooo`<00000U@3o
ool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooonT0oooo0P00002H
0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooiP3oool30000
09X0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooooT0?ooo`80
0000W@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooon40oooo
0`00002O0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0oooogP3o
ool300000:80oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooooL
0?ooo`800000Y@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?oo
omT0oooo0`00002W0?ooo`030000003oool0oooo0140oooo001D0?ooo`<00000o`3ooooF0?ooo`<0
0000Z03oool3000001<0oooo001D0?ooo`030000003oool0oooo0?l0ooood`3oool300000:d0oooo
00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3oooo@0?ooo`<00000/03o
ool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooolh0oooo0P00002c
0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0oooob`3oool30000
0;D0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3oooo80?ooo`<0
0000^03oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooolD0oooo
0`00002k0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0oooo`P3o
ool300000;h0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooono
0?ooo`<00000`@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?oo
okd0oooo0P0000340?ooo`030000003oool0oooo0140oooo000c0?ooo`030?noM000000000000080
000000T007Bo0?ooo`3oool0oooo0=nLB0000000B9cO0?ooo`3OW4P01`0000000`1d_ol0oooo0?oo
o`090?ooo`030000003oool0oooo0?l0oooo^P3oool300000<H0oooo00<000000?ooo`3oool04@3o
ool003D0oooo00<0_g@00000M02oool0103oool00`3OW4P0000004RLg`020?ooo`030=nLB0000000
000000@0000000<007Bo0?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oookP0oooo0P000039
0?ooo`030000003oool0oooo0140oooo000e0?ooo`030;md000007@0_ooo00X0oooo00<0gia804RL
g`3oool00P3oool00`3ooml0W4Qd0;ooo`0:0?ooo`030000003oool0oooo0?l0oooo]@3oool30000
0</0oooo00<000000?ooo`3oool04@3oool003D0oooo00<0_g@00000M02oool02`3oool00`3OW4P0
B9cO0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo/`3oool200000<h0oooo00<000000?ooo`3o
ool04@3oool003D0oooo00<0_g@00000M02oool0303oool00`3OW4P0M;oo0?ooo`0=0?ooo`030000
003oool0oooo0?l0oooo/03oool300000=00oooo00<000000?ooo`3oool04@3oool003D0oooo00<0
_g@00000M02oool0303oool00`3ooml0W4Q809cOo`0=0?ooo`030000003oool0oooo0?l0oooo[P3o
ool200000=<0oooo00<000000?ooo`3oool04@3oool003D0oooo00<0_g@00000M02oool03@3oool0
0`3ogi`0B01d0;ooo`0<0?ooo`D00000o`3ooonY0?ooo`<00000d@3oool5000001<0oooo000e0?oo
o`030;md000007@0_ooo00h0oooo00<0_g@004RLg`3oool02`3oool00`000000oooo0?ooo`3o0?oo
ojT0oooo0P00003H0?ooo`030000003oool0oooo0140oooo000e0?ooo`030;md000007@0_ooo00h0
oooo00<0gia80000M02oool02`3oool00`000000oooo0?ooo`3o0?ooojH0oooo0`00003J0?ooo`03
0000003oool0oooo0140oooo000e0?ooo`030;md000007@0_ooo00h0oooo00<0okmd0000001d_ol0
2`3oool00`000000oooo0?ooo`3o0?oooj<0oooo0`00003M0?ooo`030000003oool0oooo0140oooo
000e0?ooo`030;md000007@0_ooo00P0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Bo
o`0;0?ooo`030000003oool0oooo0?l0ooooX@3oool200000>00oooo00<000000?ooo`3oool04@3o
ool003<0oooo00D0gia8000000000000001d0;ooo`090?ooo`080;md001d_ol0oooo0?ooo`3OW4P0
00000018W03Oool;0?ooo`030000003oool0oooo0?l0ooooWP3oool300000>80oooo00<000000?oo
o`3oool04@3oool003@0oooo00@0oono07@0000007@0_ooo2P3oool01@2oM0000000000000000000
07Bo00d0oooo00<000000?ooo`3oool0o`3ooonK0?ooo`<00000i@3oool00`000000oooo0?ooo`0A
0?ooo`00E03oool00`000000oooo0?ooo`3o0?oooiP0oooo0`00003X0?ooo`030000003oool0oooo
0140oooo001D0?ooo`030000003oool0oooo0?l0ooooU@3oool300000>/0oooo00<000000?ooo`3o
ool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooonC0?ooo`800000kP3oool00`000000oooo
0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?oooi00oooo0`00003`0?ooo`030000003o
ool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooS@3oool300000?<0oooo00<00000
0?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`<00000mP3oool00`00
0000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooohP0oooo0P00003i0?ooo`03
0000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooQ@3oool300000?/0oooo
00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooon20?ooo`<00000oP3o
ool00`000000oooo0?ooo`0A0?ooo`00E03oool300000?l0ooooP03oool200000?l0oooo0`00000C
0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooogd0oooo0`00003o0?ooo`@0oooo00<000000?oo
o`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`<00000o`3oool70?ooo`03
0000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooN03oool200000?l0oooo
2P3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooogD0oooo0`00
003o0?ooo``0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooomb
0?ooo`<00000o`3oool?0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo
0?l0ooooL03oool200000?l0oooo4P3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000
oooo0?ooo`3o0?ooofd0oooo0`00003o0?oooa@0oooo00<000000?ooo`3oool04@3oool005@0oooo
00<000000?ooo`3oool0o`3ooom[0?ooo`800000o`3ooolG0?ooo`030000003oool0oooo0140oooo
001D0?ooo`030000003oool0oooo0?l0ooooJ03oool300000?l0oooo6@3oool00`000000oooo0?oo
o`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooofH0oooo0P00003o0?oooa`0oooo00<00000
0?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`<00000o`3ooolN0?oo
o`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooH@3oool200000?l0
oooo8@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?oooeh0oooo
0`00003o0?ooob<0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3o
oomL0?ooo`800000o`3ooolV0?ooo`030000003oool0oooo0140oooo001D0?ooo`<00000o`3ooomI
0?ooo`<00000o`3ooolV0?ooo`<000004`3oool005@0oooo00<000000?ooo`3oool0o`3ooomG0?oo
o`800000o`3oool[0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0
ooooE03oool300000?l0oooo;@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo
0?ooo`3o0?oooe40oooo0`00003o0?oooc00oooo00<000000?ooo`3oool04@3oool005@0oooo00<0
00000?ooo`3oool0o`3ooom?0?ooo`800000o`3ooolc0?ooo`030000003oool0oooo0140oooo001D
0?ooo`030000003oool0oooo0?l0ooooC03oool300000?l0oooo=@3oool00`000000oooo0?ooo`0A
0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooodX0oooo0P00003o0?ooocP0oooo00<000000?oo
o`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooom70?ooo`<00000o`3ooolj0?ooo`03
0000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0ooooA03oool300000?l0oooo
?@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?oood80oooo0P00
003o0?oood00oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooolo
0?ooo`<00000o`3ooom20?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo
0?l0oooo?@3oool200000?l0ooooA@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000
oooo0?ooo`3o0?ooocX0oooo0`00003o0?ooodL0oooo00<000000?ooo`3oool04@3oool005@0oooo
00<000000?ooo`3oool0o`3ooolg0?ooo`<00000o`3ooom:0?ooo`030000003oool0oooo0140oooo
001D0?ooo`030000003oool0oooo0?l0oooo=@3oool200000?l0ooooC@3oool00`000000oooo0?oo
o`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?oooc80oooo0`00003o0?ooodl0oooo00<00000
0?ooo`3oool04@3oool005@0oooo0`00003o0?ooobl0oooo0`00003o0?oooe00oooo0`00000C0?oo
o`00E03oool00`000000oooo0?ooo`3o0?ooobd0oooo0P00003o0?oooeD0oooo00<000000?ooo`3o
ool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`<00000o`3ooomG0?ooo`030000
003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0oooo9`3oool300000?l0ooooFP3o
ool00`000000oooo0?ooo`0A0?ooo`00703oool01P3ogi`0B0000018W03Oool0oooo0;md00800000
00<0M;oo0?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?ooob@0oooo0`00003o0?oooed0oooo
00<000000?ooo`3oool04@3oool001/0oooo00H0oooO09a80000000004RL0=ooo`3OW4P300000003
0018W03Oool0oooo02d0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`<00000o`3ooomP0?ooo`03
0000003oool0oooo0140oooo000K0?ooo`0;0?oOW01dW=l0oooo0?ooo`3ookl0M01d0;ooo`3oool0
gia80000M02oool0;P3oool00`000000oooo0?ooo`3o0?oooah0oooo0`00003o0?ooof<0oooo00<0
00000?ooo`3oool04@3oool001/0oooo00H0okmd07Boo`3oool0oooo0=nLB01d_ol20?ooo`030?oO
W018M;l0oooo02h0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`800000o`3ooomV0?ooo`030000
003oool0oooo0140oooo000K0?ooo`060?noM000M;l0oooo0?oog`2LM9`0gooo0P3oool00`2oM7@0
_ooo0?ooo`0^0?ooo`030000003oool0oooo0?l0oooo6@3oool300000?l0ooooJ03oool00`000000
oooo0?ooo`0A0?ooo`006`3oool00`3ookl0M0000000000600000003001d_`3oool0oooo02d0oooo
00<000000?ooo`3oool0o`3ooolF0?ooo`<00000o`3ooom[0?ooo`030000003oool0oooo0140oooo
000L0?ooo`030=nLB0000000000000D0000000<0001d0;ooo`3oool0303oool00`3o_g@000000000
000200000007001d_`3oool0oooo0?ooo`3OW4P0000004RLg`060?ooo`030?noM0000000M;oo00`0
oooo00<000000?ooo`3oool0o`3ooolC0?ooo`<00000o`3ooom^0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030?noM000M;l0oooo00l0oooo00<0_g@00000M02oool0103oool00`3OW4P00000
04RLg`060?ooo`030?noM0000000M;oo00`0oooo00<000000?ooo`3oool0o`3oool@0?ooo`<00000
o`3oooma0?ooo`030000003oool0oooo0140oooo000R0?ooo`030?oog`2LB7@0_ooo0100oooo00<0
_g@00000M02oool03@3oool00`3o_g@0000007Boo`0<0?ooo`030000003oool0oooo0?l0oooo3@3o
ool300000?l0ooooM03oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`3OW4P004RL0=ooo`04
0?ooo`030=nLM018B7@0_ooo00`0oooo00<0_g@00000M02oool0203oool00`3OW4P0000000000005
000000030000B02Lgol0oooo00T0oooo00<000000?ooo`3oool0o`3oool;0?ooo`800000o`3ooomg
0?ooo`030000003oool0oooo0140oooo000N0?ooo`030?noM000M;l0oooo00@0oooo00@0_g@004RL
W01d07@0_ooo303oool00`2oM000001d0;ooo`080?ooo`030?oOW018M;l0oooo0080oooo00<0okmd
0000001d_ol0303oool00`000000oooo0?ooo`3o0?ooo`P0oooo0`00003o0?ooogT0oooo00<00000
0?ooo`3oool04@3oool001h0oooo00<0gia804RLg`3oool00P3oool01P3ooml0W4P007Boo`3ookl0
M01d0;ooo``0oooo00<0_g@00000M02oool02@3oool01`3OW4P0M;oo0?ooo`3oool0okmd0000001d
_ol0303oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0:40oooo0`00003o0?ooog`0
oooo00<000000?ooo`3oool04@3oool001h0oooo00/0okmd0000B02Lgol0oooo0?noM00004P0W=oo
0?ooo`3ogi`0B01d0;ooo`0<0?ooo`030;md000007@0_ooo00T0oooo00L0oono07@0M02oool0oooo
0?noM0000000M;oo00`0oooo1@00001N0?ooo`030000003oool0oooo09l0oooo0P00003o0?ooog/0
oooo1@00000C0?ooo`007`3oool0103OW4P0000000000000M;l20?ooo`040?oog`2LB00004RL0=oo
o``0oooo00<0_g@00000M02oool02P3oool01P3o_g@007Bo0?ooo`3o_g@0000007Boo``0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`2L0?ooo`<00000@@3oool01@3ooml0W4P00000
000004P0W=oo0?l0oooo>`3oool00`000000oooo0?ooo`0A0?ooo`00=@3oool00`2oM000001d0;oo
o`0;0?ooo`050;md001d_ol0okmd0000001d_ol0303oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo09X0oooo0P0000150?ooo`030?oo_`1d04P0W=oo0?l0oooo?03oool00`000000oooo
0?ooo`0A0?ooo`00=@3oool00`2oM000001d0;ooo`0;0?ooo`050?oo_`1d07@0_kmd0000001d_ol0
303oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo09L0oooo0`0000170?ooo`030?oo
_`1d04P0W=oo0?l0oooo?03oool00`000000oooo0?ooo`0A0?ooo`00=@3oool00`2oM000001d0;oo
o`0<0?ooo`040?noM0000000000007Boo``0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`2D0?ooo`<00000BP3oool01P3ookl0M000000000000000001809cOo`80oooo01<0okmd0000
00000000B9cO0?ooo`3ookl0M0000000000004P0B4P00000B018B00000000000B02Lgml0W4P00000
0000B9`0gooo0?l0oooo903oool00`000000oooo0?ooo`0A0?ooo`00<`3oool01@3OW4P000000000
000007@0_ooo00`0oooo00@0oooO09a800000000M;oo303oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo0980oooo0P00001=0?ooo`0I0?oo_`1d0000B9cO0?ooo`3o_g@0001d0;ooo`3o
gi`0B00007Boo`3oool0giad09cOo`3OW4P004RL0=ooo`3ookl0M01809cOo`3ooml0W4P007Boo`3o
okl0M00007Boo`3o0?ooobH0oooo00<000000?ooo`3oool04@3oool003@0oooo00@0oono07@00000
07@0_ooo3@3oool00`3ogi`0B00007Boo`0<0?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool0S`3oool3000004l0oooo00T0oono07@0B02Lgol0oooo0?oog`2LB000M;oo0=nLB000M;l0
0P3oool03@3ookl0M7Bo0?oo_`1d000007Bo0?oo_`1d04P0W=oo0?oog`2LB000M;oo0;md0000M;l0
o`3ooolW0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool0S@3oool2000003H0oooo00<0gia80000000000001@0000002@1d_ol0oooo0?oo
o`3ooml0W4P00000B02Lgol0oooO09a800090000000;001d_`3oool0oono07@0B02Lgol0oooo0?oo
g`2LB000B9cO0=nLB018W=l01P3oool02@3o_g@000000000B02Lgol0oooO09a800000000001d0;oo
o`0?0?ooo`030?oog`2LB000000000L0000000<0M;oo0?ooo`3oool03P3oool00`2oM00000000000
0002000000030000M02oool0oooo00<0oooo00H0omnL04P00000000000000000M02oool20?ooo`05
0=nLB0000000000000000000M;l00P3oool01@3OW4P0000000000000000007Bo00@0oooo00D0omnL
04P0000000000000001d_`020?ooo`080?oo_`1d000000000000000004P0W=oo0?ooo`2oM0020000
000<0000B02Lgkl0M00000000000M;l0oooo0?oo_`1d000000000018W03Ookl0M0000P0000001P00
04P0W=oo0?ooo`3oool0omnL04P00080000000D0001d0;ooo`3oool0oooo0;md00030000000607Bo
_`1d000000000000000007@0_ooo203oool00`2oM000000000000002000000030000M02oool0oooo
00<0oooo00H0omnL04P00000000000000000M02oool40?ooo`050?oOW0180000000000000000M;l0
0P3oool00`3o_g@0000000000002000000030018W03O_g@0000000<0000000<004RL0=oo_`1d0000
0P0000001@0004P0W=oo0?ooo`3oool0okmd00<0000000D004RL0=ooo`3oool0oono07@000020000
00060000B02Lgol0oooo0?ooo`3ogi`0B0000P0000001000M;l0oooo0?ooo`2oM0030000000;07Bo
_`1d000000000000000007@0_ooo0?oo_`1d000000000018W03Oool00P3oool0103ooml0W4P00000
B02Lgol60?ooo`050=nLB0000000000000000000M;l04@3oool0102oM000000000000018W=l40?oo
o`030=nLB0000000B9cO00@0oooo00<0omnL04P0M02oool01`3oool0102oM000000000000018W=l8
0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool0RP3oool3000003T0oooo00<0gia8000000000000100000001`00M;l0oooo0?ooo`3ooml0
W4P00000B02Lgol00P3oool0103ookl0M0000018W03Oool40?ooo`0;0?noM00007@0_ooo0?oo_`1d
04P0W=oo0?ooo`3ooml0W4P004RLg`3OW4P0100000003000M;l0oooo0?ooo`3oool0oono07@0B02L
gol0oooO09a8001d_ml0W4P007Booa40oooo00<0omnL04P00000M;l0103oool00`2oM00007Bo0?oo
o`0=0?ooo`040?noM0000000000007Boo`<0oooo00<0oono07@0001d_ol00P3oool0203o_g@00000
0018W03Oool0oooo0?noM00004P0W=oo0P3oool00`3o_g@0000007Boo`040?ooo`030?noM0000000
M;oo00@0oooo0240okmd0000000004P0W=oo0?ooo`3OW4P004RL0=ooo`3oool0oooO09a80000B9`0
gooo0?ooo`3o_g@00000001d_`3oool0oooO09a800000000B9cO0?no_`2oool0gia80000B02Lgol0
omnL09boo`3oool0_g@00000M02oool00P3oool0203o_g@000000018W03Oool0oooo0?noM00004P0
W=oo0P3oool0203OW4P0001809cOo`3oool0oooO09a80000B9`0gooo1`3oool0103o_g@000000000
001d_ol30?ooo`030?oo_`1d0000M;oo0080oooo00P0okmd00000000B9`0gooo0?ooo`3o_g@00018
09cOo`80oooo00d0okmd0000000004P0W=oo0?ooo`3OW4P004RL0=ooo`3oool0oooO09a8000007@0
_ooo0080oooo00@0oooO09a8000007@0_ooo0`3oool00`2oM000001d0;ooo`020?ooo`030=nLB000
0000000000<0000000L004RL0=ooo`3oool0oooo0;md000007@0_ooo0080oooo01L0okmd00000000
04P0W=oo0?ooo`3OW4P004RL0=ooo`3oool0gia80000B02Lgol0oooo0?oog`2LB00004RL0=ooo`3o
ool0gia80000B02Lgol0omnL09boo`020?ooo`040?oog`2LB000001809cOo`L0oooo00<0okmd0000
001d_ol0403oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RL
g`050?ooo`030;md001d_ol0oooo00@0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00L0
oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`280?ooo`800000?@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo00L0oooo
00@0oono07@00000B9`0gooo1@3oool06`3o_g@0B9bW07@000000000001d0;ooo`3o_g@0001809cO
o`3ookl0M4RL0=ooo`3ooml0W4P007Boo`3ogi`0B01d0;ooo`3ogi`0B01809cOo`3ooml0W4P007Bo
o`3oool0_gA809cOo`0@0?ooo`030?oOW0180000B9cO00@0oooo00<0oooO09adW03Oool0303oool0
103ogi`0B0000000B02Lgol60?ooo`060;mdB02Lgol0oooO09a8000004P0W=oo0`3oool01`2oM000
04RL0=ooo`3oool0okmd0000001d_ol0103oool00`3o_g@0000007Boo`030?ooo`040?oo_`1d0000
04RL0=ooo`<0oooo00/0okmd07Boo`3oool0oooO09a80000B9`0gooo0?ooo`3o_g@0000007Boo`02
0?ooo`030?oOW0180000B9cO0080oooo00<0gia80000B02Lgol00`3oool0202oM00004RL0=ooo`3o
ool0oooO09a8000004P0W=oo0`3oool0302oM00004RL0=ooo`3oool0gia80000B02Lgol0oooo0?oo
g`2LB00004RL0=ooo`H0oooo00@0omnL04P0000004P0W=oo1P3oool01P2oM4P0W=oo0?oog`2LB000
001809cOo`<0oooo00L0_g@00018W03Oool0oono07@00000B9`0gooo00<0oooo00L0okmd07Boo`3o
ool0oooo0;md0000B9`0gooo00<0oooo00<0_g@00018W03Oool00`3oool0202oM00004RL0=ooo`3o
ool0oono07@000000000B9cO0`3oool0303OW7@0W=oo0?ooo`3oool0_g@00018W03Oool0oooo0?oo
_`1d000004RL0=ooo`<0oooo00l0okmd07Boo`3oool0gia80000B02Lgol0oooo0?oog`2LB00004RL
0=ooo`3oool0gia80000B02Lgol03`3oool00`3o_g@0000007Boo`0@0?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol02P3oool00`3o_g@007Bo0?ooo`040?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08D0oooo0`0000100?ooo`030=nLB018W=l0oooo00/0
oooo00@0oono07@00000B9`0gooo1`3oool01P3ookl0M01809cO_`1d0000000004RLg`80oooo00@0
omnL04P00000000007Bo0P3oool03@2oM000000000000000B9`0gooo0?oog`2LB000M;oo0?oo_`1d
000000000018W03Oool03P3oool00`3ogi`0B00004RLg`050?ooo`030?noW02Lgol0oooo00/0oooo
00<0_g@000000018W=l02@3oool00`3ogi`0B000001d_`040?ooo`070=nLB00004P0W=oo0?ooo`3o
_g@0000007Boo`040?ooo`030?noM0000000M;oo00<0oooo00<0omnL04P0001d_ol01`3oool0203o
oml0W4P00018W03Oool0oooo0?oo_`1d000007Bo0P3oool00`3ogi`0B00004RLg`020?ooo`030=nL
B00004P0W=oo00<0oooo00L0_g@00018W03Oool0oooo0?oOW018000007Bo00@0oooo00`0gia80000
B02Lgol0oooo0=nLB00004P0W=oo0?ooo`3ooml0W4P00018W03Oool60?ooo`030;md00000000B9cO
00T0oooo00<0omnL04P00000M;l0103oool01P3OW4P0001809cOo`3ogi`0B00007Boo`P0oooo00<0
_g@00018W03Oool00`3oool00`2oM00004RL0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3o_g@0
0000001d_`080?ooo`070;md0000B9`0gooo0?ooo`3ogi`0B00007Boo`070?ooo`0<0=nLB00004P0
W=oo0?ooo`3ooml0W4P00018W03Oool0oooo0=nLB00004P0W=oo3`3oool00`3o_g@0000007Boo`04
0?ooo`030;md00000000000000L0000000D0B9cO0?oog`2LB00004RL0=ooo`020?ooo`030?oog`2L
B00007Bo00X0oooo00<0oono07@0M02oool00`3oool0103ooml0W4P00018W03Oool20?ooo`030?oo
g`2LB00007Bo00H0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`230?ooo`800000A03oool00`3OW4P0M;oo0?ooo`0:0?ooo`040?oo_`1d
000004RL0=ooo`<0oooo00<0oknL09cOo`3oool0503oool00`3ooml0W4P007Boo`0C0?ooo`030?oO
W0180000B9cO0180oooo00@0oono07@0000004P0W=oo2@3oool00`3o_g@0000004RLg`040?ooo`07
0=nLB0000000M;oo0?ooo`3o_g@0000007Boo`040?ooo`030?noM0000000M;oo00<0oooo00<0omnL
04P0B02Lgol01`3oool0103ooml0W4P00018W03Oool20?ooo`070?oog`2LB000000007Boo`3ogi`0
B00004RLg`020?ooo`030=nLB00004P0W=oo00<0oooo00L0_g@00018W03Oool0oooo0?noM0000000
B9cO00@0oooo00`0gia80000001d_ol0oooo0=nLB00004P0W=oo0?ooo`3ooml0W4P00018W03Oool5
0?ooo`040?oo_`1d0000001809cOo`T0oooo00<0okmd00000018W=l0103oool01P3OW4P0000007Bo
o`3ogi`0B01809cOo`P0oooo00<0_g@00018W03Oool00`3oool00`2oM00004RL0=ooo`030?ooo`07
0;md0000B9`0gooo0?ooo`3o_g@0000007Boo`080?ooo`070;md0000B9`0gooo0?ooo`3ogi`0B018
09cOo`070?ooo`0<0=nLB00004P0W=oo0?ooo`3ooml0W4P00018W03Oool0oooo0=nLB00004P0W=oo
3`3oool00`3o_g@0000007Boo`0?0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0
2P3oool00`2oM000M;oo0?ooo`020?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0
1@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo0800oooo0`0000160?ooo`030?oog`2LB4P0W=oo00X0oooo00@0oono07@00000B9`0gooo
0`3oool00`2oM4P0W=oo0?ooo`0C0?ooo`040?oog`2LB000000007Boo`H0oooo00<0_g@000000000
00001`0000001P18W=l0oooo0?ooo`3ogi`0B00004RLga80oooo00@0okmd0000000007@0_ooo2@3o
ool00`3ogi`0B00004RLg`040?ooo`070;md000004P0W=oo0?ooo`3o_g@0000007Boo`040?ooo`03
0?noM0000000M;oo00<0oooo00<0omnL04P0000000001@0000001P1d_ol0oooo0?oog`2LB00004RL
0=ooo`D0oooo00@0_g@0000000000000B9cO0P3oool00`3OW4P0001809cOo`030?ooo`070;md0000
B9`0gooo0?ooo`3ogi`0B00004RLg`040?ooo`0<0;md000004P0W=oo0?ooo`3OW4P0001809cOo`3o
ool0oooO09a80000B9`0gooo1@3oool0103o_g@000000000M02oool90?ooo`030?oOW0180000B9cO
00@0oooo00D0_g@00000B02Lgol0omnL04P000060000000607Boo`3oool0oooo0;md0000B9`0gooo
0`3oool00`2oM00004RL0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3o_g@0001809cOo`080?oo
o`060;md0000B9`0gooo0?ooo`3ogi`0B0001P0000003P1d_ol0oooo0=nLB00004P0W=oo0?ooo`3o
oml0W4P00018W03Oool0oooo0=nLB00004P0W=oo3`3oool00`3o_g@0000007Boo`0?0?ooo`030?oO
W0180000B9cO00@0oooo00<0_g@00000M02oool02P3oool00`3o_g@007Bo0?ooo`020?ooo`030?oO
W0180000B9cO00@0oooo00<0_g@00000M02oool01@3oool00`000000oooo0?ooo`0A0?ooo`00E03o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo07h0oooo0P00001:0?ooo`030?oOW018
07@0_ooo00T0oooo00<0oono07@000000000100000000`0004P0W=oo0?ooo`0D0?ooo`030?oo_`1d
0000M;oo01<0oooo00<0omnL04P00018W=l04P3oool0103o_g@000000000M02oool90?ooo`030?oo
g`2LB00007Bo00<0oooo00P0oono07@0000007@0_ooo0?ooo`3o_g@00000001d_`@0oooo00<0okmd
00000000M;l00`3oool00`3ooml0W4Q809cOo`030?ooo`0<0;md000004P0W=oo0?ooo`3ooml0W4P0
0018W03Oool0oooo0?oog`2LB00007Bo0P3oool00`3ogi`0B00004RLg`020?ooo`030=nLB00004P0
W=oo0080oooo00P0oooO09a80000B9`0gooo0?ooo`3ooml0W4P0001d_`<0oooo00d0oono07@00000
07@0_ooo0?ooo`2oM000000007Boo`3oool0oooO09a80000B9`0gooo00D0oooo00@0okmd00000000
07@0_ooo2@3oool00`3ooml0W4P0001d_`030?ooo`070?oo_`1d0000001d0;ooo`3ooml0W4Q809cO
o`030?ooo`030;md000004P0W=oo0080oooo00<0_g@00018W03Oool00`3oool00`2oM00004RL0=oo
o`020?ooo`080?oog`2LB00004RL0=ooo`3oool0oono07@0001d_ol20?ooo`0=0?oog`2LB00004RL
0=ooo`3oool0oooO09a80000B9`0gooo0?ooo`3ooml0W4Q809cOo`030?ooo`0@0;md000004P0W=oo
0?ooo`2oM000000007Boo`3oool0oooO09a80000B9`0gooo0?ooo`3OW4P0001809cOo`l0oooo00<0
okmd00000000M;l03`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00X0oooo00<0
oono07@0M02oool00P3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00D0oooo00<0
00000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1k
0?ooo`<00000C@3oool00`2oM000B9cO0?ooo`020?ooo`040?oog`2LB000001809cOo`80oooo00@0
oono07@00000B9`0gooo0`3oool00`2oM4P0W=oo0?ooo`0Z0?ooo`030?oOW0180000B9cO0180oooo
00@0omnL04P0000007@0_ooo2P3oool02P3ogi`0B00007Boo`3oool0oooO09a800000000M;oo0?oo
g`2LB0020000000507AdM018W=l0_g@00018M01dB0000P0000009P1dM7@0B9cO0;md0000B9`0gooo
0?noM00007@0_ooo0?ooo`3ogi`0B0000018W03Oool0oooo0?oog`2LB00004RL0=ooo`3oool0oooO
09a80000B9`0gooo0?ooo`3OW4P0000007Boo`3ooml0gmoo0=nLB00004P0W=oo0?ooo`3ogi`0B000
00000000B9`0gooo0P3oool04@3ogi`0B00007Boo`3oool0oooO09a800000000M;oo0?oo_`1d0000
00000000B018B000B9cO0?oo_`1d000007Bo00H0oooo00@0omnL04P0000007@0_ooo2P3oool0203o
gi`0B00007Boo`3oool0oooO09a800000000M;oo0P3oool0203o_g@0001d0;ooo`3oool0omnL04P0
0000B9`0gooo0P3oool00`2oM00004RL0=ooo`030?ooo`090;md0000B9`0gooo0?ooo`3ogi`0B000
00000000B9`0gooo0080oooo00d0okmd0000B02Lgol0oooo0?noM000000004RL0=ooo`3ogi`0B000
00000000B9`0gooo0080oooo01D0okmd0000M02oool0oooo0?oOW018000004RL0=oo_`1d00000000
0000B018B000B9cO0?oo_`1d000007Bo0?oog`3Ogol0gia80000B02Lgol0103oool0103ooml0W4P0
0000B02Lgol50?ooo`0:0?oog`2LB00000000000001dM7@0B9cO0;md0000B9`0gooo0;md00T00000
00@0B9cO0?oOW0180000B9cO103oool00`3OW4P0001809cOo`0;0?ooo`070;md001d_ol0oooo0?oo
o`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00D0oooo00<000000?ooo`3oool04@3oool0
05@0oooo0`00001P0?ooo`030000003oool0oooo07T0oooo0P00001@0?ooo`030=nLB00007@0_ooo
0080oooo00@0oooO09a8000004P0W=oo0P3oool0103ookl0M0000018W03Oool30?ooo`030?noW02L
gol0oooo02X0oooo00<0omnL04P00018W=l04P3oool0103ookl0M0000000B02Lgol60?ooo`030?oo
g`2LM9`0gooo0080oooo00H0oono07@00000000000000000B02Lgol30?ooo`0=0=nLB0000000M;oo
0=nLB000000007Bo0?ooo`3OW4P0000007Boo`3OW4P00000001d_`020?ooo`060?oOW01800000000
00000000B9`0gooo0P3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB000000000800000
00@007Bo0?ooo`3oool0_g@00`0000001P0004P0W=oo0?oog`2LB00004RL0=ooo`<0oooo00H0oono
07@00000000000000000B02Lgol30?ooo`070;md000004P0W=oo0=nLB0000000001809cOo`060?oo
o`040?oo_`1d0000001809cOo`H0oooo00<0oooO09adW03Oool00P3oool01P3ookl0M00000000000
0000001809cOo`@0oooo00P0omnL04P00000000000000018W03Oool0oooo0=nLB0@0000000<00018
07AdB00000000`0000001P0004P0W=oo0?oog`2LB00004RL0=ooo`<0oooo00H0omnL04P000000000
00000018W03Oool20?ooo`040?oog`2LB00004RL0=ooo`<0oooo00H0omnL04P00000000000000018
W03Oool20?ooo`090;md000004P0W=oo0=nLB0000000001809cOo`3oool0_g@000<0000000P00018
09cOo`3oool0oooo0?oog`2LB000001809cOo`L0oooo00H0gia80000001d_ol0gia800000000M;l<
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02`3oool01`3o_g@007Bo0?ooo`3o
ool0oono07@00000M;l0103oool00`2oM000001d0;ooo`030?ooo`<000004`3oool005@0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`1f0?ooo`<00000DP3oool00`3o_g@0000007Bo
o`080?ooo`040?oo_`1d000004RL0=oooc00oooo00<0omnL04P00018W=l04`3oool00`3OW4P00000
04RLg`060?ooo`030?oOW018B9`0gooo0280oooo00@0oooO09a80000B9`0gooo2`3oool00`3OW4P0
001809cOo`0P0?ooo`030=nLB0000000B9cO00H0oooo00<0omnL04Q8W03Oool05@3oool00`2oM000
04RL0=ooo`030?ooo`030;md0000B9`0gooo02T0oooo00<0gia80000B02Lgol08P3oool00`2oM000
04RL0=ooo`020?ooo`030?oog`2LB00007Bo00H0oooo00<0omno0;oOo`3oool00`3oool00`3ookl0
M01d0;ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l01P3oool00`000000
oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo07<0oooo
0`00001?0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0203oool0103ookl0M000
0018W03Oool40?ooo`030?oo_`2LW=l0oooo02T0oooo00<0omnL04P00018W=l04`3oool0103ookl0
M0000000B02Lgol50?ooo`030;md0000M;l0oooo0280oooo00@0oooO09a80000B9`0gooo2`3oool0
0`3ookl0M01809cOo`0P0?ooo`040?oo_`1d0000001809cOo`D0oooo00<0_g@0001d_`3oool05@3o
ool00`2oM00004RL0=ooo`030?ooo`030;md0000B9`0gooo02T0oooo00<0oono07@0B02Lgol08P3o
ool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00H0oooo00<0oooO09a8M02oool0103o
ool01`2oM000M;oo0?ooo`3oool0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`060?ooo`03
0000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
L03oool3000005<0oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=ooo`P0oooo00@0oono
07@00000B9`0gooo103oool00`3OW4P0B9cO0?ooo`0Y0?ooo`030?oOW0180000B9cO01@0oooo00@0
oono07@0000004P0W=oo0P3oool0103ooml0W4P000000000M;lS0?ooo`040?oog`2LB00004RL0=oo
o``0oooo00<0giad09cOo`3oool0803oool0103ookl0M0000000B02Lgol20?ooo`040?oog`2LB000
0000001d_aH0oooo00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`0Z0?ooo`030=nLM02L
gol0oooo0280oooo00H0_g@00018W03Oool0oooo0;md0000M;l80?ooo`030=nLB0000000000000@0
000000X007Bo0?ooo`3oool0oooo0;md0000B9`0gooo0?ooo`2oM00007Bo1`3oool00`000000oooo
0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo06d0oooo0`00
001G0?ooo`050;md00000000000000000000M;l0203oool00`3ooml0W4P0000000080000000304RL
g`3oool0oooo02H0oooo00<0oooO09a8000000000`0000000`1d_ol0oooo0?ooo`0B0?ooo`080=nL
B000000000000000000004P0W=oo0?oo_`1dM;lR0?ooo`050?oOW018000000000018W03Oool0403o
ool0103ooml0W4P00000M02ooolM0?ooo`080=nLB000000000000000000004P0W=oo0?oo_`1dM;lF
0?ooo`0;0?oo_`1d04P0W=oo0?ooo`3OW4P0000004RLW01d04P0W=oo0?ooo`3OW4P00P0000000`00
07@0_ooo0?ooo`0:0?ooo`040?oog`2LB000001d0;oooc/0oooo00@0_g@000000000000007Bo2@3o
ool00`3ogi`0B00000000004000000030000B02Lgol0oooo0080oooo00@0_g@000000000000007Bo
203oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo06/0oooo0P00003Q0?ooo`040?oo_`1d000004RL0=oooa00oooo00@0oooO09a8000007@0
_ooo?03oool0203ooml0W4P000000000000004RL0=ooo`3ooml0W4P00P0000001000B7@0M4P00000
M02oool;0?ooo`040?oog`2LB000001d0;ooof00oooo00<000000?ooo`3oool04@3oool005@0oooo
00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1X0?ooo`<00000o`3ooone0?ooo`030000
003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0I@3o
ool300000?l0oooo^03oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo0680oooo0`00003o0?oook/0oooo00<000000?ooo`3oool04@3oool0
05@0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1O0?ooo`<00000o`3ooonn0?oo
o`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool0G03oool300000?l0oooo`@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo05X0oooo0P00003o0?oool@0oooo00<000000?ooo`3oool0
4@3oool005@0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1G0?ooo`<00000o`3o
ooo60?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool0E03oool300000?l0oooob@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`00
0000oooo0?ooo`1O0?ooo`<00000D`3oool200000?l0ooooc03oool00`000000oooo0?ooo`0A0?oo
o`00E03oool00`000000oooo0?ooo`1M0?ooo`L00000CP3oool300000?l0oooocP3oool00`000000
oooo0?ooo`0A0?ooo`00E03oool3000005d0oooo1`00001<0?ooo`800000103oool00`000000oooo
0?ooo`3o0?ooolP0oooo0`00000C0?ooo`00E03oool00`000000oooo0?ooo`1L0?ooo`T00000B03o
ool3000000H0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo0140oooo001D
0?ooo`030000003oool0oooo05`0oooo2@0000150?ooo`<000002@3oool00`000000oooo0?ooo`3o
0?ooolX0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0G03oool90000
04<0oooo0P00000<0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0A0?oo
o`00E03oool00`000000oooo0?ooo`1M0?ooo`L00000@@3oool3000000h0oooo00<000000?ooo`3o
ool0o`3oooo:0?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo05d0oooo
1`00000o0?ooo`8000004@3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool0
4@3oool005@0oooo00<000000?ooo`3oool0G`3oool3000003h0oooo0`00000C0?ooo`030000003o
ool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo03X0oooo0`00000F0?ooo`030000003oool0oooo0?l0oooobP3oool0
0`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
03P0oooo0P00000I0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0A0?oo
o`00E03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo03D0oooo0`00000K0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140
oooo001D0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0<`3oool2000001h0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool0
4@3oool005@0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0`0?ooo`<00000803o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?oo
o`0A0?ooo`00E03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo02d0oooo0`00000S
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0
oooo0140oooo001D0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0:`3oool20000
02H0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?oo
o`3oool04@3oool005@0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0X0?ooo`<0
0000:03oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000
oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo02H0oooo
0P00000[0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000
003oool0oooo0140oooo001D0?ooo`<00000H03oool00`000000oooo0?ooo`0S0?ooo`<00000;@3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooA`3oool3000001<0oooo001D
0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0803oool300000300oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool0
05@0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0N0?ooo`800000<`3oool00`00
0000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?oo
o`00E03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01/0oooo0`00000e0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140
oooo001D0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool06@3oool2000003P0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool0
4@3oool005@0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0F0?ooo`<00000>P3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?oo
o`0A0?ooo`00E03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01<0oooo0`00000m
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0
oooo0140oooo001D0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool04@3oool20000
0400oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?oo
o`3oool04@3oool005@0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0>0?ooo`<0
0000@P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000
oooo0?ooo`0A0?ooo`00<`3oool00`3o_g@000000000000200000007001d_`3oool0oooo0?ooo`3O
W4P0000004RLg`030?ooo`060?oog`2LB00000000000000007@0_ooo303oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo00`0oooo0P0000150?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo000e0?ooo`030;md000007@0
_ooo00@0oooo00<0gia800000018W=l00P3oool0203ookl0M0000018W03Oool0oooo0=nLB00004P0
W=oo2`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00T0oooo0`0000170?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140
oooo000e0?ooo`030;md000007@0_ooo00T0oooo00<0_g@00000M02oool00`3oool00`2oM00007Bo
0?ooo`0:0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01P3oool3000004X0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool0
4@3oool003D0oooo00<0_g@00000M02oool0203oool00`3ookl0M000001d_`040?ooo`030=nLB000
07@0_ooo00X0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`040?ooo`800000C@3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?oo
o`0A0?ooo`00=@3oool00`2oM000001d0;ooo`080?ooo`030?oOW0180000B9cO00@0oooo00<0_g@0
0000B02Lgol02P3oool00`000000oooo0?ooo`1P0?ooo`040000003oool0oooo0?ooo`<00000C`3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?oo
o`0A0?ooo`00=@3oool00`2oM000001d0;ooo`080?ooo`030?oOW0180000B9cO00<0oooo00@0oono
07@0000007@0_ooo2P3oool00`000000oooo0?ooo`1P0?ooo`@00000DP3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00=@3oool0
0`2oM000001d0;ooo`080?ooo`090?oo_`1d000000000018W03Oool0oooo0;md00000000B9cO00/0
oooo1@00001M0?ooo`800000E@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0
ooooA@3oool5000001<0oooo000e0?ooo`030;md000007@0_ooo00P0oooo00D0oooO09a8000007@0
_mnL04P000020000000304RLg`3oool0oooo00X0oooo00<000000?ooo`3oool0G03oool300000003
0?ooo`000000oooo05@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0
oooo00<000000?ooo`3oool04@3oool003D0oooo00<0_g@00000M02oool02@3oool00`3o_g@00000
04RLg`0@0?ooo`030000003oool0oooo05T0oooo0`0000040?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool0
4@3oool003D0oooo00<0_g@00000M02oool02@3oool0103ooml0W4P00000B02Lgol?0?ooo`030000
003oool0oooo05H0oooo0`0000070?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool003D0oooo00<0
_g@00000M02oool02P3oool0103ookl0M0000000M02oool>0?ooo`030000003oool0oooo05<0oooo
0`00001P0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000
003oool0oooo0140oooo000c0?ooo`050=nLB000000000000000M02oool02`3oool0103ooml0W4P0
00000000M;l=0?ooo`030000003oool0oooo0500oooo0`00001S0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo000d0?ooo`040?oo
_`1d0000001d0;ooo`d0oooo00D0omnL04P00000000004RL0=ooo`0:0?ooo`030000003oool0oooo
04h0oooo0P00001V0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?oo
o`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo04/0oooo0`00001X0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140
oooo001D0?ooo`030000003oool0oooo04P0oooo0`00001[0?ooo`030000003oool0oooo07h0oooo
00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003o
ool0oooo04D0oooo0`00001^0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3o
oom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0480oooo0`00001a
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0
oooo0140oooo001D0?ooo`030000003oool0oooo03l0oooo0`00001d0?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`03
0000003oool0oooo03d0oooo0P00001g0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo03X0oooo
0`00001i0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000
003oool0oooo0140oooo001D0?ooo`030000003oool0oooo03P0oooo0P00001l0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D
0?ooo`030000003oool0oooo03D0oooo0`00001n0?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`<00000<`3oool20000
0840oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodL0oooo0`00000C0?oo
o`00E03oool00`000000oooo0?ooo`0a0?ooo`800000P`3oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo
0?ooo`0^0?ooo`<00000Q@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo
B@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`0/0?ooo`800000R03o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?oo
o`0A0?ooo`00E03oool00`000000oooo0?ooo`0Y0?ooo`<00000RP3oool00`000000oooo0?ooo`1n
0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`00
0000oooo0?ooo`0W0?ooo`800000S@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo
0?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`0T0?ooo`<0
0000S@3oool300000800oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140
oooo001D0?ooo`030000003oool0oooo0240oooo0`00002>0?ooo`L00000OP3oool00`000000oooo
0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool07`3o
ool200000940oooo1`00001n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?oo
o`0A0?ooo`00E03oool00`000000oooo0?ooo`0L0?ooo`<00000TP3oool9000007d0oooo00<00000
0?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo
01T0oooo0`00002E0?ooo`T00000O@3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?oo
o`3oool04@3oool005@0oooo00<000000?ooo`3oool05P3oool3000009P0oooo2@00001m0?ooo`03
0000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo
0?ooo`0C0?ooo`<00000W03oool7000007h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000
003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0140oooo0P00002O0?ooo`L00000OP3o
ool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool005@0oooo00<00000
0?ooo`3oool03P3oool300000:<0oooo0`0000200?ooo`030000003oool0oooo0?l0ooooB@3oool0
0`000000oooo0?ooo`0A0?ooo`00E03oool3000000`0oooo0P00002X0?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool0o`3ooom70?ooo`<000004`3oool005@0oooo00<000000?ooo`3o
ool0]P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000
oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo07h0oooo
00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003o
ool0oooo0;H0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<0
00000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`1n
0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`00
0000oooo0?ooo`2f0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?oo
o`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool005@0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo
B@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D
0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o
0?ooodT0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0]P3oool00`00
0000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?oo
o`00E03oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0;H0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool0
4@3oool005@0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`2f
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0
oooo0140oooo001D0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0O03oool30000
0?l0ooooB`3oool00`000000oooo0?ooo`0A0?ooo`00E03oool300000;H0oooo00<000000?ooo`3o
ool0NP3oool700000?l0ooooA`3oool3000001<0oooo001D0?ooo`030000003oool0oooo0;H0oooo
00<000000?ooo`3oool0NP3oool700000?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00E03o
ool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo07T0oooo2@00003o0?ooodP0oooo00<0
00000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`1i
0?ooo`T00000o`3ooom80?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo
0;H0oooo00<000000?ooo`3oool0N@3oool900000?l0ooooB03oool00`000000oooo0?ooo`0A0?oo
o`00E03oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo07X0oooo1`00003o0?ooodT0
oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0]P3oool00`000000oooo
0?ooo`1j0?ooo`L00000o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003o
ool0oooo0;H0oooo00<000000?ooo`3oool0O03oool300000?l0ooooB`3oool00`000000oooo0?oo
o`0A0?ooo`00E03oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo
0;H0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?oo
o`3oool04@3oool003<0oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3oool0gia8
00000018W=l00`3oool01P3ogi`0B000000000000000001809cOo``0oooo00<000000?ooo`3oool0
]P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo
0?ooo`0A0?ooo`00=@3oool00`2oM000001d0;ooo`040?ooo`030=nLB0000000B9cO0080oooo00P0
omnL04P00000B9`0gooo0?ooo`3ogi`0B00007Boo`/0oooo00<000000?ooo`3oool0]P3oool00`00
0000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?oo
o`00=@3oool00`2oM000001d0;ooo`090?ooo`030;md000007@0_ooo00<0oooo00<0gia80018W03O
ool02P3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool0o`3ooom90?ooo`030000003oool0oooo0140oooo000e0?ooo`030;md000007@0_ooo00T0oooo
00<0_g@00000M02oool00`3oool00`2oM00004RL0=ooo`0:0?ooo`030000003oool0oooo0;H0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool0
4@3oool003D0oooo00<0_g@00000M02oool02@3oool00`3o_g@0001809cOo`020?ooo`030=nLB000
000007Bo00/0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00=@3oool00`2oM000001d0;ooo`0:
0?ooo`070=nLB000M;l0oooo0;md00000000001d0;ooo`0;0?ooo`030000003oool0oooo0;H0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool0
4@3oool003D0oooo00<0_g@00000M02oool02`3oool01@3o_g@0000000000000B9`0gooo00`0oooo
1@00002d0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom50?ooo`D00000
4`3oool003D0oooo00<0_g@00000M02oool02P3oool01@3ogi`0B000000000000000B9cO00d0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo
B@3oool00`000000oooo0?ooo`0A0?ooo`00=@3oool00`2oM000001d0;ooo`090?ooo`070?oOW018
0000001809cOo`3oool0gia8001d_`0<0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool003D0oooo
00<0_g@00000M02oool02@3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000M;oo00/0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo
B@3oool00`000000oooo0?ooo`0A0?ooo`00=@3oool00`2oM000001d0;ooo`090?ooo`030=nLB000
B9`0gooo0080oooo00<0oooO09a80018W=l02`3oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo000c
0?ooo`050=nLB000000000000000M02oool02@3oool00`3ogi`0B00004RLg`020?ooo`030?noM000
04P0W=oo00/0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00=03oool0103ookl0M0000000M02o
ool:0?ooo`060?oo_`1d000000000000000004P0W=oo303oool00`000000oooo0?ooo`2f0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140
oooo001D0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0]P3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?oo
o`0A0?ooo`00E03oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo
0;H0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?oo
o`3oool04@3oool005@0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo
0?ooo`2f0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000
003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool005@0oooo00<00000
0?ooo`3oool0]P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool0
0`000000oooo0?ooo`0A0?ooo`00E03oool300000;H0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`3o0?ooodL0oooo0`00000C0?ooo`00E03oool00`000000oooo0?ooo`2f0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140
oooo001D0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0]P3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?oo
o`0A0?ooo`00E03oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo
0;H0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?oo
o`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo0?l0
ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooocP0oooo
00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003o
ool0oooo0?l0oooo>03oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3o
ool005@0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo0?l0ooooB@3oool0
0`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?oo
o`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0
oooo>03oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool005@0oooo
00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo
0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool0o`3o
oom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0oooo>03oool0
0`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?oo
o`3oool0o`3ooolh0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?oo
o`00E03oool300000?l0oooo>03oool00`000000oooo0?ooo`3o0?ooodL0oooo0`00000C0?ooo`00
E03oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000
003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?oo
o`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooolh
0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`00
0000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo
0140oooo001D0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`3o0?ooodT0
oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000
003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?oo
o`3o0?ooocP0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D
0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`3o0?ooodT0oooo00<00000
0?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo
0?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooocP0
oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000
003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool0
4@3oool005@0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo0?l0ooooB@3o
ool00`000000oooo0?ooo`0A0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooocP0oooo00<00000
0?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo
0?l0oooo>03oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool005@0
oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000
oooo0?ooo`0A0?ooo`00E03oool300000?l0oooo>03oool00`000000oooo0?ooo`3o0?ooodL0oooo
0`00000C0?ooo`00E03oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool0o`3o
oom90?ooo`030000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0oooo>03oool0
0`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?oo
o`3oool0o`3ooolh0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?oo
o`00E03oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool0o`3ooom90?ooo`03
0000003oool0oooo0140oooo001D0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo
0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04@3oool005@0oooo00<000000?ooo`3oool0o`3o
oolh0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0A0?ooo`00E03oool0
0`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0
oooo0140oooo001D0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`3o0?oo
odT0oooo00<000000?ooo`3oool04@3oool00400oooo00<0gia80000000000001@0000000`1d_ol0
oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`3o0?ooodT0
oooo00<000000?ooo`3oool04@3oool00440oooo00<0gia8000000000000100000000`00M;l0oooo
0?ooo`090?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`3o0?ooodT0oooo
00<000000?ooo`3oool04@3oool00480oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;oo
o`0:0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`3o0?ooodT0oooo00<0
00000?ooo`3oool04@3oool004<0oooo00<0gia804RLg`3oool03P3oool00`000000oooo0?ooo`3o
0?ooocP0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0140oooo00140?oo
o`030=nLB01d_ol0oooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?oooh@0oooo00<000000?oo
o`3oool04@3oool004@0oooo00<0oooO09a8B02Lgol03@3oool00`000000oooo0?ooo`3o0?ooool0
ooooQ03oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`3ogi`0B01d0;ooo`0<0?ooo`D00000
o`3ooooo0?ooogh0oooo1@00000C0?ooo`00AP3oool00`2oM000B9cO0?ooo`0;0?ooo`030000003o
ool0oooo0?l0ooooo`3ooon40?ooo`030000003oool0oooo0140oooo00160?ooo`030=nLB00007@0
_ooo00/0oooo00<000000?ooo`3oool0o`3ooooo0?oooh@0oooo00<000000?ooo`3oool04@3oool0
04H0oooo00<0okmd0000001d_ol02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
07P0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
07P0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0140oooo00100?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol02`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0A0?ooo`00@@3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo2`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0A0?ooo`00@P3oool01@2oM000000000000000000007Bo00d0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool04@3oool005@0ooooo`00003o000008P000004`3oool00?l0ooooo`3oooo_0?ooo`00
o`3ooooo0?ooonl0oooo003o0?ooool0ooook`3oool00?l0ooooo`3oooo_0?ooo`00o`3ooooo0?oo
onl0oooo0000\
\>"],
  ImageRangeCache->{{{0, 748.125}, {462, 0}} -> {-0.809698, 0.561764, \
0.00813405, 0.0031981}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ 
        Evaluate\ \ linear\ correlation\ coefficient\ for\ each\ \
\(\(plot\)\(.\)\)\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(a1cor = {}; b1cor = {};\), "\n", 
    \(\(Do[\[IndentingNewLine]AppendTo[
          a1cor, {res[\([i, 1]\)], 
            res[\([i, 2]\)]}]; \[IndentingNewLine]AppendTo[
          b1cor, {res[\([i, 1]\)], res[\([i, 4]\)]}], {i, 1, 4}];\)\), "\n", 
    \(\(rega1 = Regress[a1cor, {1, x}, x];\)\), "\n", 
    \(ra1 = Sqrt[RSquared /. rega1]\), "\[IndentingNewLine]", 
    \(\(regb1 = Regress[b1cor, {1, x}, x];\)\), "\n", 
    \(rb1 = Sqrt[RSquared /. regb1]\)}], "Input"],

Cell[BoxData[
    \(0.9441618535048157`\)], "Output"],

Cell[BoxData[
    \(0.7057617707556675`\)], "Output"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ Export\ plots\ for\ use\ in\ Fig . \ 1\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(Export["\<fb2.eps\>", fb2, 
        ImageSize \[Rule] 800];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<fa2.eps\>", fa2, ImageSize \[Rule] 800];\)\)}], "Input"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 713}},
WindowSize->{676, 684},
WindowMargins->{{Automatic, 1}, {2, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 524, 9, 217, "Input"],
Cell[2281, 62, 142, 3, 61, "Input"],
Cell[2426, 67, 758, 23, 130, "Input"],
Cell[3187, 92, 83, 2, 35, "Input"],
Cell[3273, 96, 298, 5, 90, "Input"],
Cell[3574, 103, 121, 2, 35, "Input"],
Cell[3698, 107, 1456, 33, 330, "Input"],
Cell[5157, 142, 271, 5, 87, "Input"],
Cell[5431, 149, 448, 8, 110, "Input"],
Cell[5882, 159, 368, 6, 110, "Input"],
Cell[6253, 167, 102, 2, 35, "Input"],

Cell[CellGroupData[{
Cell[6380, 173, 55, 1, 30, "Input"],
Cell[6438, 176, 49, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6524, 182, 4326, 76, 1018, "Input"],
Cell[10853, 260, 447, 8, 25, "Print"],
Cell[11303, 270, 232, 4, 25, "Print"],
Cell[11538, 276, 446, 8, 25, "Print"],
Cell[11987, 286, 232, 4, 25, "Print"],
Cell[12222, 292, 447, 8, 25, "Print"],
Cell[12672, 302, 232, 4, 25, "Print"],
Cell[12907, 308, 448, 8, 25, "Print"],
Cell[13358, 318, 232, 4, 25, "Print"]
}, Open  ]],
Cell[13605, 325, 244, 4, 87, "Input"],
Cell[13852, 331, 317, 6, 90, "Input"],

Cell[CellGroupData[{
Cell[14194, 341, 371, 8, 90, "Input"],

Cell[CellGroupData[{
Cell[14590, 353, 60573, 1436, 333, 18791, 916, "GraphicsData", "PostScript", \
"Graphics"],
Cell[75166, 1791, 57976, 1423, 333, 19725, 946, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[133169, 3218, 193, 4, 87, "Input"],
Cell[133365, 3224, 77, 1, 30, "Input"],
Cell[133445, 3227, 231, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[133701, 3235, 988, 20, 270, "Input"],
Cell[134692, 3257, 460, 8, 25, "Print"],
Cell[135155, 3267, 408, 10, 41, "Output"],
Cell[135566, 3279, 52, 1, 29, "Output"]
}, Open  ]],
Cell[135633, 3283, 188, 4, 50, "Input"],
Cell[135824, 3289, 163, 4, 61, "Input"],

Cell[CellGroupData[{
Cell[136012, 3297, 351, 6, 90, "Input"],
Cell[136366, 3305, 108044, 2183, 516, 24026, 1141, "GraphicsData", \
"PostScript", "Graphics"],
Cell[244413, 5490, 130, 3, 29, "Output"]
}, Open  ]],
Cell[244558, 5496, 81, 1, 30, "Input"],
Cell[244642, 5499, 231, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[244898, 5507, 988, 20, 270, "Input"],
Cell[245889, 5529, 463, 8, 25, "Print"],
Cell[246355, 5539, 404, 10, 41, "Output"],
Cell[246762, 5551, 53, 1, 29, "Output"]
}, Open  ]],
Cell[246830, 5555, 188, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[247043, 5563, 351, 6, 90, "Input"],
Cell[247397, 5571, 98052, 2073, 471, 24896, 1165, "GraphicsData", \
"PostScript", "Graphics"],
Cell[345452, 7646, 130, 3, 29, "Output"]
}, Open  ]],
Cell[345597, 7652, 158, 4, 61, "Input"],

Cell[CellGroupData[{
Cell[345780, 7660, 491, 9, 170, "Input"],
Cell[346274, 7671, 53, 1, 29, "Output"],
Cell[346330, 7674, 53, 1, 29, "Output"]
}, Open  ]],
Cell[346398, 7678, 111, 2, 35, "Input"],
Cell[346512, 7682, 186, 3, 50, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

