(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    710758,      17282]*)
(*NotebookOutlinePosition[    711592,      17311]*)
(*  CellTagsIndexPosition[    711501,      17305]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ 
          This\ file\ produces\ Fig . \ 2\ of\ the\ paper\ ' 
            Testing\ GRB\ as\ Standard\ Candles' . \ 
              The\ parameter\ a1\ corresponds\ to\ the\ parameters\ b_j\ in\ \
the\ paper\ \[IndentingNewLine]while\ the\ parameter\ b1\ corresponds\ to\ \
the\ parameters\ a_j\ *) \),
        FontSize->18], "\[IndentingNewLine]"}]], "Input",
  TextAlignment->Center],

Cell[BoxData[
    StyleBox[\( (*\ Set\ Directory\ to\ Read\ GRB\ data\ from, \ 
        Input\ Packages\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{\(SetDirectory["\<D:/mathdata/grb\>"];\), "\[IndentingNewLine]",
   
    RowBox[{\($TextStyle = {FontFamily \[Rule] "\<Times\>", 
          FontSize \[Rule] 20}\), ";", 
      RowBox[{"Off", 
        StyleBox["[",
          "MR"], \(NIntegrate::"\<inum\>"\), 
        StyleBox["]",
          "MR"]}], 
      StyleBox[";",
        "MR"], 
      StyleBox[\(Off[]\),
        "MR"], 
      StyleBox[";",
        "MR"], 
      StyleBox[\(Off[General::spell]\),
        "MR"], 
      StyleBox[";",
        "MR"]}], "\[IndentingNewLine]", \(<< 
        Graphics`MultipleListPlot`;\), "\[IndentingNewLine]", \(<< 
        Statistics`LinearRegression`;\)}], "Input",
  TextAlignment->Left],

Cell[BoxData[
    StyleBox[\( (*\ Read\ Data\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(data1 = 
        ReadList["\<grbdat.txt\>", {Number, Number, Number, Number, Number, 
            Number, Number, Number, Number, Number, Number, Number, Number, 
            Number, Number, Number}];\)\), "\[IndentingNewLine]", 
    \(\(ndat = Length[data1];\)\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Rescale\ Data, \ Define\ new\ Arrays\ with\ Data\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(zz = data1[\([#, 1]\)] &;\)\), "\n", 
    \(\(pbolo = data1[\([#, 2]\)] &;\)\), "\n", 
    \(\(spbolo = data1[\([#, 3]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(sbolo = data1[\([#, 4]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(ssbolo = data1[\([#, 5]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(fbeam = data1[\([#, 6]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(sfbeam = data1[\([#, 7]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(tlag = 
        data1[\([#, 8]\)]/\((\((1 + zz[#])\) 
                0.1)\) &;\)\), "\[IndentingNewLine]", 
    \(\(stlag = 
        data1[\([#, 9]\)]/\((\((1 + zz[#])\) 
                0.1)\) &;\)\), "\[IndentingNewLine]", 
    \(\(var = 
        data1[\([#, 10]\)]\ \((1 + zz[#])\)/
              0.02 &;\)\), "\[IndentingNewLine]", 
    \(\(svar = 
        data1[\([#, 11]\)] \((1 + zz[#])\)/
              0.02 &;\)\), "\[IndentingNewLine]", 
    \(\(epeak = 
        data1[\([#, 12]\)]\ \((1 + zz[#])\)/
              300 &;\)\), "\[IndentingNewLine]", 
    \(\(sepeak1 = 
        data1[\([#, 13]\)] \((1 + zz[#])\)/
              300 &;\)\), "\[IndentingNewLine]", 
    \(\(sepeak2 = 
        data1[\([#, 14]\)] \((1 + zz[#])\)/
              300 &;\)\), "\[IndentingNewLine]", 
    \(\(trt = 
        data1[\([#, 
                15]\)]/\((\((1 + 
                    zz[#])\)\ 0.1)\) &;\)\), "\[IndentingNewLine]", 
    \(\(strt = data1[\([#, 16]\)]/\((\((1 + zz[#])\)\ 0.1)\) &;\)\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Values\ of\ \[CapitalOmega]\_m\ to\ be\ considered\ *) \),
      
      FontSize->18]], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(omv = {0.01, 0.03, 0.05, 0.07, 0.1, 0.15, 0.2, 0.25, 0.3, 
        0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1}; valsom = Length[omv]; \ 
    r1om = {};\)\)\)], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ 
        Construct\ arrays\ with\ \((Log \((E\_peak)\) - 
              Log \((L)\))\)\ and\ corresponding\ errors\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Do", "[", 
      RowBox[{
        RowBox[{\(om = omv[\([q]\)]\), ";", 
          "\[IndentingNewLine]", \(Clear[f, dl, dld]\), ";", \(w0 = \(-1\)\), 
          ";", \(w1 = 0\), ";", \(h0 = 10^5\ h\), ";", " ", \(c = 3\ 10^8\), 
          ";", \(h = 0.72\), ";", 
          "\[IndentingNewLine]", \(f[z_] := 
            1/Sqrt[om*\((1 + z)\)^3\  + \((1 - 
                        om)\)*\((1 + z)\)^\((3 \((1 + w0\  + \ w1)\))\) 
                    Exp[3\ w1\ \((\((1/\((1 + z)\))\) - 1)\)]]\), ";", 
          "\n", \(dl[zz_] := 
            c \((1 + zz)\)\ NIntegrate[f[z], {z, 0, zz}]/h0\), ";", 
          "\n", \(dld = dl[zz[#]] 3\ 10^24 &\), ";", 
          "\n", \(ll = 4\ Pi\ dld[#]^2\ pbolo[#] &\), ";", 
          "\n", \(sll = 4\ Pi\ dld[#]^2\ spbolo[#] &\), ";", 
          "\n", \(eg = 
            4\ Pi\ dld[#]^2\ sbolo[#]\ fbeam[#]/\((1 + zz[#])\) &\), 
          ";", \(seg = 
            Sqrt[\((ssbolo[#]/sbolo[#])\)^2\  + \ \((sfbeam[#]/fbeam[#])\)^2]/
                Log[10] &\), ";", "\n", \(zmin = 0\), ";", \(zmax = 7\), ";", 
          "\n", \(Clear[llepeak, sllepeak1, sllepeak2, sllepeak]\), ";", 
          "\n", \(llepeak = {}\), ";", \(sllepeak1 = {}\), 
          ";", \(sllepeak2 = {}\), ";", \(sllepeak = {}\), ";", 
          "\n", \(Do[\[IndentingNewLine]If[
              epeak[i] > 0\  && \ zz[i] \[GreaterEqual] zmin\  && \ 
                zz[i] \[LessEqual] \ zmax, \[IndentingNewLine]AppendTo[
                llepeak, {Log[10, epeak[i]], 
                  Log[10, ll[i]]}]; \[IndentingNewLine]AppendTo[
                sllepeak1, {sepeak1[i]/\((Log[10]\ epeak[i])\), 
                  sll[i]/\((Log[10]\ ll[i])\)}]; \[IndentingNewLine]AppendTo[
                sllepeak2, {sepeak2[i]/\((Log[10]\ epeak[i])\), 
                  sll[i]/\((Log[10]\ ll[i])\)}]; \[IndentingNewLine]AppendTo[
                sllepeak, {\((sepeak2[i] + sepeak1[i])\)/\((2)\), 
                  sll[i]/\((Log[10]\ ll[i])\)}]], \[IndentingNewLine]{i, 1, 
              ndat}]\), ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ 
              Minimize\ \[Chi]\^2\ to\ find\ best\ fit\ parameters\ \
a\_j\ \ \((b1)\), \ 
              b\_j\ \((a1)\) . \ 
                  Set\ proper\ value\ to\ intrinsic\ error\ s1 . \ 
                  Use\ covariance\ matrix\ cij\ to\ find\ errors\ of\ a\_j, \ \
\(\(b\_j\)\(.\)\)\ *) \),
            FontSize->18], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", \(llp[a1_, b1_, x_] := a1\  + \ b1\ x\), ";",
           "\[IndentingNewLine]", \(epeakp[a1_, b1_, x_] := \((x - a1)\)/b1\),
           ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", \(chi2[a1_, b1_, s1_] := 
            Sum[\((\((llepeak[\([i, 2]\)] - 
                          llp[a1, b1, 
                            llepeak[\([i, 1]\)]])\)^2/\((sllepeak[\([i, 
                              2]\)]^2 + s1^2)\))\), {i, 1, 
                  Length[sllepeak]}] + 
              Sum[\((\((llepeak[\([i, 1]\)] - 
                          epeakp[a1, b1, 
                            llepeak[\([i, 2]\)]])\)^2/\((sllepeak[\([i, 
                              1]\)]^2 + s1^2)\))\), {i, 1, 
                  Length[llepeak]}]\), ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", \(s1 = 0.33\), ";", 
          "\n", \(par = {a1, b1}\), ";", 
          "\n", \(akl[a1_, b1_, k_, l_] := 
            1/2  D[D[chi2[a1, b1, 0.5], par[\([k]\)]], par[\([l]\)]\ ]\), ";",
           "\n", \(fmingrb = 
            FindMinimum[chi2\ [a1, b1, s1], {a1, 52}, {b1, 1}]\), ";", 
          "\n", \(a1o = fmingrb[\([2, 1, 2]\)]\), ";", 
          "\n", \(b1o = fmingrb[\([2, 2, 2]\)]\), ";", 
          "\n", \(aklo = 
            Table[If[
                k \[LessSlantEqual] 
                  l, \(akl[a1, b1, k, l] /. a1 \[Rule] a1o\) /. 
                  b1 \[Rule] b1o, \(akl[a1, b1, l, k] /. a1 \[Rule] a1o\) /. 
                  b1 \[Rule] b1o], {k, 1, 2}, {l, 1, 2}]\), 
          ";", \(cij = Inverse[aklo]\), 
          ";", \(spar = Table[Sqrt[cij[\([i, i]\)]], {i, 1, 2}]\), 
          ";", \(Print["\<a1= \>", a1o, "\<+-\>", 
            spar[\([1]\)], "\<  b1= \>", b1o, "\<+-\>", spar[\([2]\)]]\), 
          ";", \(cij // MatrixForm\), ";", 
          "\[IndentingNewLine]", \(erra1o = spar[\([1]\)]\), ";", 
          "\[IndentingNewLine]", \(errb1o = spar[\([2]\)]\), ";", 
          "\[IndentingNewLine]", \(ngrb = Length[llepeak]\), ";", 
          "\[IndentingNewLine]", \(chi2r = 
            Part[fmingrb, 1]/\((2\ Length[llepeak])\)\), ";", 
          "\[IndentingNewLine]", \(Print["\<chi2r=\>", chi2r, "\<  ngrb=\>", 
            ngrb, "\<  om=\>", om]\), ";", 
          "\[IndentingNewLine]", \(AppendTo[r1om, {om, chi2r}]\)}], ",", 
        "\[IndentingNewLine]", \({q, 1, valsom}\)}], "]"}]], "Input"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.557016593613625`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.056999385806539016`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]1.7352809664833329`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.11086850225984718`\),
      SequenceForm[ 
      "a1= ", 52.557016593613625, "+-", .056999385806539016, "  b1= ", 
        1.7352809664833329, "+-", .11086850225984718],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.2416020803185008`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.01`\),
      SequenceForm[ 
      "chi2r=", 1.2416020803185008, "  ngrb=", 64, "  om=", .01],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.49711942803706`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.0567401380865192`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.6952952783188282`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.11015537469750648`\),
      SequenceForm[ 
      "a1= ", 52.49711942803706, "+-", .056740138086519197, "  b1= ", 
        1.6952952783188282, "+-", .11015537469750648],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.1481180671551108`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.03`\),
      SequenceForm[ 
      "chi2r=", 1.1481180671551108, "  ngrb=", 64, 
        "  om=", .029999999999999999],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.45378395466199`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05657354196234614`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.6707352319903044`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.10971218940493649`\),
      SequenceForm[ 
      "a1= ", 52.453783954661994, "+-", .056573541962346138, "  b1= ", 
        1.6707352319903044, "+-", .10971218940493649],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0976758813482226`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.05`\),
      SequenceForm[ 
      "chi2r=", 1.0976758813482226, "  ngrb=", 64, 
        "  om=", .050000000000000003],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.41869652094481`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05644776864716609`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.6527446815394147`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.10937415346234808`\),
      SequenceForm[ 
      "a1= ", 52.418696520944813, "+-", .056447768647166087, "  b1= ", 
        1.6527446815394147, "+-", .10937415346234808],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0648434518179704`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.07`\),
      SequenceForm[ 
      "chi2r=", 1.0648434518179704, "  ngrb=", 64, 
        "  om=", .070000000000000007],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.375264529047016`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05630143908039888`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.6323812285541224`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.10897269716829136`\),
      SequenceForm[ 
      "a1= ", 52.375264529047016, "+-", .056301439080398877, "  b1= ", 
        1.6323812285541224, "+-", .10897269716829136],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0320401464585907`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.1`\),
      SequenceForm[ 
      "chi2r=", 1.0320401464585907, "  ngrb=", 64, 
        "  om=", .10000000000000001],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.317544774375435`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05612080654951769`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.6080437453687864`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.10846173155260096`\),
      SequenceForm[ 
      "a1= ", 52.317544774375435, "+-", .056120806549517691, "  b1= ", 
        1.6080437453687864, "+-", .10846173155260096],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9988610321626967`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.15`\),
      SequenceForm[ 
      "chi2r=", .99886103216269673, "  ngrb=", 64, 
        "  om=", .14999999999999999],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.270934620710115`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05598517731728819`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5903212496340107`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.1080658637117567`\),
      SequenceForm[ 
      "a1= ", 52.270934620710115, "+-", .055985177317288193, "  b1= ", 
        1.5903212496340107, "+-", .10806586371175669],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9786989240337944`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.2`\),
      SequenceForm[ 
      "chi2r=", .97869892403379444, "  ngrb=", 64, 
        "  om=", .20000000000000001],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.23144960750314`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.055876819404877306`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]1.5764865872037128`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.10774194037776966`\),
      SequenceForm[ 
      "a1= ", 52.231449607503137, "+-", .055876819404877306, "  b1= ", 
        1.5764865872037128, "+-", .10774194037776966],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9652073217498004`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.25`\),
      SequenceForm[ "chi2r=", .9652073217498004, "  ngrb=", 64, "  om=", .25],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.19699800490304`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05578687463721341`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5652138111981195`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.10746794324875089`\),
      SequenceForm[ 
      "a1= ", 52.196998004903037, "+-", .055786874637213407, "  b1= ", 
        1.5652138111981195, "+-", .10746794324875089],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9556196771223462`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.3`\),
      SequenceForm[ 
      "chi2r=", .95561967712234619, "  ngrb=", 64, 
        "  om=", .29999999999999999],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.13860997296639`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05564365250596086`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5476445256545335`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.10702223882203517`\),
      SequenceForm[ 
      "a1= ", 52.138609972966393, "+-", .055643652505960858, "  b1= ", 
        1.5476445256545335, "+-", .10702223882203517],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9431038996448491`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.4`\),
      SequenceForm[ 
      "chi2r=", .94310389964484909, "  ngrb=", 64, 
        "  om=", .40000000000000002],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.08993265527939`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.055532601063593125`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]1.5343320003339327`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.10666884658346427`\),
      SequenceForm[ 
      "a1= ", 52.089932655279391, "+-", .055532601063593125, "  b1= ", 
        1.5343320003339327, "+-", .10666884658346427],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9355251191597778`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.5`\),
      SequenceForm[ "chi2r=", .93552511915977776, "  ngrb=", 64, "  om=", .5],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.04798331202453`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05544264198975553`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.523739578635748`\[InvisibleSpace]"+-"\[InvisibleSpace]\
0.10637765559698976`\),
      SequenceForm[ 
      "a1= ", 52.047983312024527, "+-", .055442641989755528, "  b1= ", 
        1.5237395786357479, "+-", .10637765559698976],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9306356283628004`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.6`\),
      SequenceForm[ 
      "chi2r=", .93063562836280045, "  ngrb=", 64, 
        "  om=", .59999999999999998],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.01100767624006`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05536754739327944`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5150249910632891`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.10613122832818309`\),
      SequenceForm[ 
      "a1= ", 52.011007676240062, "+-", .05536754739327944, "  b1= ", 
        1.5150249910632891, "+-", .10613122832818309],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9273586060040009`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.7`\),
      SequenceForm[ 
      "chi2r=", .92735860600400088, "  ngrb=", 64, 
        "  om=", .69999999999999996],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]51.97787702676502`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.055303464026591524`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]1.507677876126647`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.10591852168466731`\),
      SequenceForm[ 
      "a1= ", 51.977877026765022, "+-", .055303464026591524, "  b1= ", 
        1.5076778761266469, "+-", .10591852168466731],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9251143088017755`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.8`\),
      SequenceForm[ 
      "chi2r=", .92511430880177548, "  ngrb=", 64, 
        "  om=", .80000000000000004],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]51.947818006798016`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05524784264007127`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5013665004866699`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.10573209089440355`\),
      SequenceForm[ 
      "a1= ", 51.947818006798016, "+-", .055247842640071272, "  b1= ", 
        1.5013665004866699, "+-", .10573209089440355],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9235639396391365`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.9`\),
      SequenceForm[ 
      "chi2r=", .92356393963913652, "  ngrb=", 64, 
        "  om=", .90000000000000002],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]51.920275423632475`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05519891066254218`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.4958636940892465`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.10556667794782461`\),
      SequenceForm[ 
      "a1= ", 51.920275423632475, "+-", .055198910662542178, "  b1= ", 
        1.4958636940892465, "+-", .10556667794782461],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9224970637597081`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]64\[InvisibleSpace]"  om="\
\[InvisibleSpace]1\),
      SequenceForm[ "chi2r=", .92249706375970808, "  ngrb=", 64, "  om=", 1],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ 
        Plot\ the\ minimum\ value\ of\ \[Chi]\^2\ as\ a\ function\ of\ \
\[CapitalOmega]\_m . \ 
            Determine\ the\ quality\ of\ the\ correlation\ relations\ as\ a\ \
function\ of\ \(\(\[CapitalOmega]\_m\)\(.\)\)\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"f21", "=", 
      RowBox[{"ListPlot", "[", 
        RowBox[{
        "r1om", ",", \(Frame \[Rule] True\), ",", \(Axes \[Rule] False\), 
          ",", \(PlotJoined \[Rule] True\), 
          ",", \(FrameLabel \[Rule] {\*"\"\<\!\(\[Omega]\_\(0  m\)\)\>\"", \
\*"\"\<\!\(\[Chi]\^2\)\>\""}\), ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{\(Hue[0.8]\), ",", \(Thickness[0.005]\), ",", 
                RowBox[{
                  StyleBox["Dashing",
                    "MR"], 
                  StyleBox["[",
                    "MR"], 
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    RowBox[{
                      StyleBox["0.01",
                        "MR"], 
                      StyleBox[",",
                        "MR"], " ", 
                      StyleBox["0.01",
                        "MR"]}], 
                    StyleBox["}",
                      "MR"]}], 
                  StyleBox["]",
                    "MR"]}]}], "}"}]}]}], "]"}]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -1.68687 1.84455 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -14.5625 -24.5625 ]
[.21429 -0.0125 14.5625 0 ]
[.40476 -0.0125 -14.5625 -24.5625 ]
[.40476 -0.0125 14.5625 0 ]
[.59524 -0.0125 -14.5625 -24.5625 ]
[.59524 -0.0125 14.5625 0 ]
[.78571 -0.0125 -14.5625 -24.5625 ]
[.78571 -0.0125 14.5625 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.4063 -49.125 ]
[.5 -0.0125 19.4063 -24.5625 ]
[-0.0125 .06545 -39.1875 -12.2813 ]
[-0.0125 .06545 0 12.2813 ]
[-0.0125 .15767 -14.0625 -12.2813 ]
[-0.0125 .15767 0 12.2813 ]
[-0.0125 .2499 -39.1875 -12.2813 ]
[-0.0125 .2499 0 12.2813 ]
[-0.0125 .34213 -29.125 -12.2813 ]
[-0.0125 .34213 0 12.2813 ]
[-0.0125 .43435 -39.1875 -12.2813 ]
[-0.0125 .43435 0 12.2813 ]
[-0.0125 .52658 -29.125 -12.2813 ]
[-0.0125 .52658 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -63.75 -12.5625 ]
[-0.01875 .30902 -39.1875 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.4063 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
76.813 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
83.875 26.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
86.500 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
97.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .06545 m
.00625 .06545 L
s
gsave
-0.0125 .06545 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
1.000 setlinewidth
grestore
0 .15767 m
.00625 .15767 L
s
gsave
-0.0125 .15767 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .2499 m
.00625 .2499 L
s
gsave
-0.0125 .2499 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
1.000 setlinewidth
grestore
0 .34213 m
.00625 .34213 L
s
gsave
-0.0125 .34213 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
0 .43435 m
.00625 .43435 L
s
gsave
-0.0125 .43435 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
1.000 setlinewidth
grestore
0 .52658 m
.00625 .52658 L
s
gsave
-0.0125 .52658 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08389 m
.00375 .08389 L
s
0 .10234 m
.00375 .10234 L
s
0 .12078 m
.00375 .12078 L
s
0 .13923 m
.00375 .13923 L
s
0 .17612 m
.00375 .17612 L
s
0 .19456 m
.00375 .19456 L
s
0 .21301 m
.00375 .21301 L
s
0 .23145 m
.00375 .23145 L
s
0 .26835 m
.00375 .26835 L
s
0 .28679 m
.00375 .28679 L
s
0 .30524 m
.00375 .30524 L
s
0 .32368 m
.00375 .32368 L
s
0 .36057 m
.00375 .36057 L
s
0 .37902 m
.00375 .37902 L
s
0 .39746 m
.00375 .39746 L
s
0 .41591 m
.00375 .41591 L
s
0 .4528 m
.00375 .4528 L
s
0 .47125 m
.00375 .47125 L
s
0 .48969 m
.00375 .48969 L
s
0 .50814 m
.00375 .50814 L
s
0 .54503 m
.00375 .54503 L
s
0 .56347 m
.00375 .56347 L
s
0 .58192 m
.00375 .58192 L
s
0 .60036 m
.00375 .60036 L
s
0 .047 m
.00375 .047 L
s
0 .02855 m
.00375 .02855 L
s
0 .01011 m
.00375 .01011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -125.031 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
73.5625 16.2813 translate
90 rotate
-73.5625 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.375 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
76.563 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06545 m
1 .06545 L
s
.99375 .15767 m
1 .15767 L
s
.99375 .2499 m
1 .2499 L
s
.99375 .34213 m
1 .34213 L
s
.99375 .43435 m
1 .43435 L
s
.99375 .52658 m
1 .52658 L
s
.125 Mabswid
.99625 .08389 m
1 .08389 L
s
.99625 .10234 m
1 .10234 L
s
.99625 .12078 m
1 .12078 L
s
.99625 .13923 m
1 .13923 L
s
.99625 .17612 m
1 .17612 L
s
.99625 .19456 m
1 .19456 L
s
.99625 .21301 m
1 .21301 L
s
.99625 .23145 m
1 .23145 L
s
.99625 .26835 m
1 .26835 L
s
.99625 .28679 m
1 .28679 L
s
.99625 .30524 m
1 .30524 L
s
.99625 .32368 m
1 .32368 L
s
.99625 .36057 m
1 .36057 L
s
.99625 .37902 m
1 .37902 L
s
.99625 .39746 m
1 .39746 L
s
.99625 .41591 m
1 .41591 L
s
.99625 .4528 m
1 .4528 L
s
.99625 .47125 m
1 .47125 L
s
.99625 .48969 m
1 .48969 L
s
.99625 .50814 m
1 .50814 L
s
.99625 .54503 m
1 .54503 L
s
.99625 .56347 m
1 .56347 L
s
.99625 .58192 m
1 .58192 L
s
.99625 .60036 m
1 .60036 L
s
.99625 .047 m
1 .047 L
s
.99625 .02855 m
1 .02855 L
s
.99625 .01011 m
1 .01011 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.8 0 1 r
.005 w
[ .01 .01 ] 0 setdash
.03333 .60332 m
.05238 .43088 L
.07143 .33784 L
.09048 .27728 L
.11905 .21677 L
.16667 .15557 L
.21429 .11838 L
.2619 .0935 L
.30952 .07581 L
.40476 .05273 L
.5 .03875 L
.59524 .02973 L
.69048 .02368 L
.78571 .01954 L
.88095 .01668 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{816.25, 504.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<`0001n2000`400?l00000o`00003oo`3ooooo
0?ooool0oooo<`3oool00?l0ooooo`3ooooo0?oooc<0oooo003o0?ooool0ooooo`3ooolc0?ooo`00
o`3ooonl0?ooo`040?oog`2LB0000000001d_`D0oooo00/0_g@00000000004P0W=oO09a800000000
001d0;oo_`1d00000000001d_`3o0?ooof80oooo003o0?oook`0oooo00D0_g@004RLg`3oool0gia8
04RLg`040?ooo`0;0?oog`2LB000M;oo0?ooo`3ookl0M01809cOo`3oool0omnL04P0M02oool0o`3o
oomR0?ooo`00o`3ooonk0?ooo`070?oOW01807@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`0;0?oo
g`2LB000M;oo0?ooo`3ookl0M01809cOo`3oool0omnL04P0M02oool0o`3ooomR0?ooo`00o`3ooonk
0?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4P007Boo`030?ooo`0;0?oog`2LB000M;oo0?ooo`3o
okl0M01809cOo`3oool0omnL04P0M02oool0o`3ooomR0?ooo`00o`3ooon^0?ooo`070=nLB0000000
00000000001d_ol0omnL04P000020000000604RLg`3oool0oooo0?ooo`3OW4P007Bo0P3oool00`3o
oml0W4P007Boo`030?ooo`0;0?oog`2LB000M;oo0?ooo`3ookl0M01809cOo`3oool0omnL04P0M02o
ool0o`3ooomR0?ooo`00o`3ooon]0?ooo`030?noM000000007Bo0080oooo00/0_gA804Q8B02Lgol0
oooo0?oOW018000004RL0=ooo`3oool0gia8001d_`020?ooo`030?oog`2LB000M;oo0080oooo00`0
oooO09a800000000001809cOo`3ogi`0B0000000M02oool0okmd0018W03Ooooo0?ooof80oooo003o
0?ooojd0oooo00<0gia80000001d_ol00P3oool00`3ookl0M01809cOo`020?ooo`0;0?noM0000000
07Bo0?ooo`3o_g@004RL0=ooo`3oool0oooO09a8001d_ol00`3oool02P3ookl0M00007Bog`2LB000
0000001d_`3ookl0M00000000018W=oo0?ooof<0oooo003o0?ooojd0oooo00<0gia80000001d_ol0
0`3oool00`2oM000M;oo0?ooo`020?ooo`0:0;md000004P0W=oo0?oOW01807@0_ooo0?ooo`3ookl0
M01d0;ooool0ooooL03oool00?l0oooo[@3oool00`3o_g@0000004RLg`030?ooo`030?noM000M;l0
oooo0080oooo00T0okmd00000018W=l0oooo0;md0018W=l0oooo0=nLB000M;l0o`3oooma0?ooo`00
o`3ooon]0?ooo`030?oog`2LB00007Bo00<0oooo00<0omnL04P0M02oool00P3oool02@3ogi`0B000
04RLg`3oool0oooO09a80000000004RL0=ooo`3o0?ooog40oooo003o0?ooojh0oooo00<0omnL04P0
B02Lgol01`3oool00`3ookl0M00007Boo`3o0?ooogL0oooo003o0?ooojl0oooo00<0gia80018W03O
ool01P3oool00`3ogi`0B01d0;ooo`3o0?ooogL0oooo003o0?oook00oooo00<0okmd0018W03Oool0
1@3oool00`3OW4P0M;oo0?ooo`3o0?ooogL0oooo003o0?ooool0ooooo`3ooolc0?ooo`00o`3ooooo
0?ooool0oooo<`3oool00?l0ooooo`3ooooo0?oooc<0oooo003o0?ooool0ooooo`3ooolc0?ooo`00
o`3ooooo0?ooool0oooo<`3oool00?l0ooooo`3ooooo0?oooc<0oooo003o0?ooool0ooooo`3ooolc
0?ooo`00o`3ooooo0?ooool0oooo<`3oool00?l0ooooo`3ooooo0?oooc<0oooo003o0?ooool0oooo
o`3ooolc0?ooo`00o`3ooooo0?ooool0oooo<`3oool00?l0ooooo`3ooooo0?oooc<0oooo003o0?oo
ool0ooooo`3ooolc0?ooo`00o`3ooooo0?ooool0oooo<`3oool00?l0ooooo`3ooooo0?oooc<0oooo
001U0?ooo`040;md00000000000004RLggd0oooo00@0_g@0000000000000B9cO103oool01@3OW4P0
000004RLg`3oool0gia800L0000000<0M;oo0?ooo`3oool0L`3oool0102oM000000000000018W=l4
0?ooo`030=nLB0000000B9cO00H0oooo00<0okmd0000001d_ol0M@3oool0102oM000000000000018
W=l40?ooo`030=nLB0000000B9cO00<0oooo00H0oooO09a80000000000000000M02ooome0?ooo`04
0;md00000000000004RLg`@0oooo00<0gia800000018W=l00`3oool01P3ogi`0B000000000000000
001809cOog`0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0F0?ooo`00H`3oool0
1`3ooml0W4P0001d_`3oool0oooO09a80000M;l0NP3oool01`3ooml0W4P0001d_`3oool0oooO09a8
0000M;l00`3oool00`3OW4P0000004RLg`020?ooo`030=nLB0000000000000@0000000<007Bo0?oo
o`3oool0L@3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RL
g`060?ooo`030?noM0000000M;oo07<0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0
oooo00<0gia800000018W=l00P3oool0203ookl0M0000018W03Oool0oooo0=nLB00004P0W=ooLP3o
ool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`08
0?oOW018000004RL0=ooo`3oool0omnL04P0001d_omm0?ooo`030;md000007@0_ooo01T0oooo001S
0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0N@3oool00`3o_g@0001809cOo`02
0?ooo`030?oOW0180000M;oo00P0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`1b
0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol02`3oool00`3o_g@0000007Boo`1c
0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`2oM000001d0;ooo`03
0?ooo`030;md0000M;l0oooo0740oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`07
0?ooo`030;md000007@0_ooo00<0oooo00<0gia80018W03Oool0O03oool00`2oM000001d0;ooo`0I
0?ooo`00HP3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo07P0oooo00@0oooO
09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`090?ooo`030=nLB018W=l0oooo07D0oooo00@0
oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`060?ooo`030=nLB0000000000000D00000
00<0001809cOo`3oool0K`3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00H0
oooo00<0oono07@00000M;l0103oool00`3OW4P0001d0;ooo`1`0?ooo`040?oog`2LB00004RL0=oo
o`80oooo00<0oooO09a80000M;l01`3oool00`2oM000001d0;ooo`030?ooo`030;md0000B9`0gooo
07`0oooo00<0_g@00000M02oool06@3oool00680oooo00<0oono07@00000M;l0103oool00`2oM000
001d0;ooo`1g0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02@3oool00`3OW4P0
M;oo0?ooo`1d0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01@3oool00`3ogi`0
B7Bo0?ooo`020?ooo`030?noM0000000M;oo0780oooo00<0oono07@00000M;l0103oool00`2oM000
001d0;ooo`050?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000B02Lgol0L03oool00`3ookl0
M000001d_`040?ooo`030;md000007@0_ooo00H0oooo00<0okmd0000B02Lgol00P3oool00`3OW4P0
0000001d_`1m0?ooo`030;md000007@0_ooo01T0oooo001R0?ooo`030?oOW0180000B9cO00@0oooo
00<0_g@00000M02oool0M`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00T0oooo
00<0oooO09a8B02Lgol0M03oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00H0oooo
00L0gia807Boo`3oool0oooo0?noM0000000M;oo0780oooo00<0omnL04P00018W=l0103oool00`2o
M000001d0;ooo`050?ooo`030?oOW0180000B9cO00<0oooo00@0oono07@0000007@0_oooL03oool0
0`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00L0oooo00L0gia8001d_`3oool0_g@00000
000007@0_ooo07d0oooo00<0_g@00000M02oool06@3oool00680oooo00<0omnL04P00018W=l0103o
ool00`3OW4P0001809cOo`1g0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol02P3o
ool00`3ogi`0B01d0;ooo`1c0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01P3o
ool01`3ookl0M01d0;ooo`3oool0okmd0000001d_ol0LP3oool00`3ogi`0B00004RLg`040?ooo`03
0=nLB00004P0W=oo00D0oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l0L@3o
ool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00P0oooo00D0okmd00000000000004RL
0=ooo`1n0?ooo`030;md000007@0_ooo01T0oooo001R0?ooo`030?oOW0180000B9cO00@0oooo00<0
gia80000B02Lgol0M`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00/0oooo00<0
_g@004RLg`3oool0LP3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0oooo00H0
okmd001d_`3oool0okmd0000001d_omb0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02L
gol01@3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool0L03oool00`3o
gi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0oooo00D0omnL04P000000000000004RLg`1o
0?ooo`030;md000007@0_ooo01T0oooo001R0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000
M02oool0M`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0gia80000
M02oool0LP3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00P0oooo00D0_g@007Bo
o`3o_g@0000007Boo`1b0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool0
0`3o_g@0000004RLg`1f0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool0
1`3ogi`0B0000000B02Lgol0oooo0=nLB000M;l0OP3oool00`2oM000001d0;ooo`0I0?ooo`00H`3o
ool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo07T0oooo00<0_g@00018W03Oool00P3o
ool00`3ooml0W4P0001d_`0<0?ooo`030?noM0000000M;oo07<0oooo00<0_g@00018W03Oool00P3o
ool00`3ooml0W4P0001d_`090?ooo`050?oo_`1d07@0_kmd0000001d_ol0L`3oool00`2oM00004RL
0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00@0oooO09a8000004P0W=ooMP3oool00`2oM000
04RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00<0gia80000B02Lgol00P3oool00`3ooml0
W4P007Boo`1m0?ooo`030;md000007@0_ooo01T0oooo001S0?ooo`030?noM00004P0W=oo0080oooo
00<0omnL04P0001d_ol0N@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00H0oooo
00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`1c0?ooo`030?noM00004P0W=oo0080oooo
00<0omnL04P0001d_ol02P3oool0103o_g@000000000001d_omc0?ooo`030?noM00004P0W=oo0080
oooo00<0omnL04P0001d_ol0203oool0103ookl0M0000000M02ooome0?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol01`3oool00`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO
07d0oooo00<0_g@00000M02oool06@3oool006@0oooo00H0_g@00018W03Oool0oooo0;md0000M;mk
0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203oool0202oM000M;oo0?ooo`3oool0gia80000
0000B9`0goooM03oool01P2oM00004RL0=ooo`3oool0_g@0001d_`/0oooo00@0oooO09a800000000
M;ooM03oool01P2oM00004RL0=ooo`3oool0_g@0001d_`X0oooo00@0oooO09a80000000007BoM@3o
ool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00<0omnL04P00018W=l00P3oool00`3o_g@0
001809cOo`1k0?ooo`050=nLB000000000000000M02oool06@3oool006D0oooo00@0_g@000000000
000007BoO@3oool0102oM000000000000000M;l:0?ooo`050;md00000000000000000000M;l0M`3o
ool0102oM000000000000000M;l=0?ooo`030?oOW0180000M;oo07D0oooo00@0_g@0000000000000
07Bo3@3oool01@3ogi`0B00000000000B9`0gooo07<0oooo00@0_g@000000000000007Bo2P3oool0
1P3ookl0M000000000000000001809cOogd0oooo00@0oono07@0000007@0_ooo6@3oool00?l0oooo
o`3ooooo0?oooc<0oooo003o0?ooool0ooooo`3ooolc0?ooo`00o`3ooooo0?ooool0oooo<`3oool0
0?l0ooooo`3ooooo0?oooc<0oooo003o0?ooool0ooooo`3ooolc0?ooo`00o`3ooooo0?ooool0oooo
<`3oool00?l0ooooo`3ooooo0?oooc<0oooo003o0?ooool0ooooo`3ooolc0?ooo`00o`3ooooo0?oo
ool0oooo<`3oool00?l0ooooo`3ooooo0?oooc<0oooo003o0?ooool0ooooo`3ooolc0?ooo`00o`3o
oooo0?ooool0oooo<`3oool00?l0ooooo`3ooooo0?oooc<0oooo003o0?ooool0ooooo`3ooolc0?oo
o`00E@3ooooo00000?l00000e00000090?ooo`00E@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool005D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooom00oooo
00<000000?ooo`3oool01`3oool005D0oooo1000003o0?ooool0ooooc03oool4000000T0oooo001E
0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000003oool0oooo00L0oooo001E0?oo
o`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000003oool0oooo00L0oooo001E0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonM0?ooo`D0c03o103oool;0<`0o`@0oooo2P3<0?lA0?ooo`03
0000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3ooomb0?ooo`D0c03o
103oool:0<`0o`D0oooo2P3<0?l40?ooo`X0c03o103oool;0<`0o`@0oooo2P3<0?lA0?ooo`030000
003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3ooom@0?ooo`X0c03o103o
ool;0<`0o`@0oooo2P3<0?l40?ooo`X0c03o1@3oool:0<`0o`@0oooo2P3<0?l40?ooo`/0c03o103o
ool:0<`0oa40oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0o`3ooooo
0?oooc<0oooo2P3<0?l40?ooo`/0c03o103oool:0<`0o`@0oooo2`3<0?l40?ooo`X0c03o103oool:
0<`0o`D0oooo2P3<0?l40?ooo`D0c03o<`3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`00
0000oooo0?ooo`3o0?ooool0oooo6`3oool50<`0o`D0oooo2P3<0?l40?ooo`X0c03o103oool;0<`0
o`@0oooo2P3<0?l40?ooo`/0c03o103oool50<`0oeh0oooo00<000000?ooo`3oool01`3oool005D0
oooo00<000000?ooo`3oool0o`3ooooo0?ooo`P0oooo2P3<0?l40?ooo`X0c03o1@3oool:0<`0o`@0
oooo2P3<0?l40?ooo`/0c03oQ03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo
0?ooo`3o0?ooonh0oooo1P3<0?l40?ooo`/0c03o103oool:0<`0o`@0oooo2P3<0?l50?ooo`X0c03o
X@3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooom`0oooo2P3<
0?l40?ooo`X0c03o103oool;0<`0o`@0oooo2P3<0?l40?ooo`D0c03o]@3oool00`000000oooo0?oo
o`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooold0oooo2`3<0?l40?ooo`X0c03o103oool:
0<`0o`@0oooo2`3<0?o<0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo
0?l0oooo_`3oool:0<`0o`@0oooo2`3<0?l40?ooo`X0c03o103oool40<`0on40oooo00<000000?oo
o`3oool01`3oool005D0oooo00<000000?ooo`3oool0o`3ooona0?ooo`X0c03o103oool:0<`0o`@0
oooo2`3<0?og0?ooo`030000003oool0oooo00L0oooo001E0?ooo`@00000o`3ooonQ0?ooo`X0c03o
1@3oool:0<`0o`@0oooo2P3<0?oo0?ooo`@0oooo100000090?ooo`00E@3oool00`000000oooo0?oo
o`3o0?oooiT0oooo1@3<0?l40?ooo`X0c03o1@3oool:0<`0ool0oooo5@3oool00`000000oooo0?oo
o`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?oooh/0oooo1@3<0?l40?ooo`X0c03o103oool:
0<`0ool0oooo903oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?oo
ohH0oooo2P3<0?l40?ooo`X0c03oo`3ooolb0?ooo`030000003oool0oooo00L0oooo001E0?ooo`03
0000003oool0oooo0?l0ooooM`3oool:0<`0o`D0oooo2P3<0?l40?ooo`D0c03oo`3ooolg0?ooo`03
0000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooKP3oool50<`0o`@0oooo
2P3<0?l50?ooo`D0c03oo`3ooom50?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003o
ool0oooo0?l0ooooJ@3oool:0<`0o`@0oooo2P3<0?oo0?ooodl0oooo00<000000?ooo`3oool01`3o
ool005D0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`D0c03o103oool:0<`0ool0ooooG@3oool0
0`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?oooe/0oooo2P3<0?l40?oo
o`D0c03oo`3ooomR0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0
ooooD@3oool50<`0o`D0oooo2P3<0?oo0?ooof/0oooo00<000000?ooo`3oool01`3oool005D0oooo
00<000000?ooo`3oool0o`3ooom<0?ooo`X0c03o1@3oool50<`0ool0ooooL03oool00`000000oooo
0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?oood<0oooo1@3<0?l40?ooo`X0c03oo`3o
oomj0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0oooo?P3oool:
0<`0o`@0oooo1@3<0?oo0?ooogl0oooo00<000000?ooo`3oool01`3oool005D0oooo1000003o0?oo
oc@0oooo1@3<0?l40?ooo`X0c03oo`3ooon50?ooo`@000002@3oool005D0oooo00<000000?ooo`3o
ool0o`3oool`0?ooo`X0c03o103oool50<`0ool0ooooS@3oool00`000000oooo0?ooo`070?ooo`00
E@3oool00`000000oooo0?ooo`3o0?ooobH0oooo1P3<0?l40?ooo`X0c03oo`3ooonF0?ooo`030000
003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0oooo8@3oool;0<`0o`@0oooo1@3<
0?oo0?oooi/0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0o`3ooolQ
0?ooo`/0c03oo`3ooonT0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo
0?l0oooo603oool50<`0o`@0oooo1@3<0?oo0?ooojX0oooo00<000000?ooo`3oool01`3oool005D0
oooo00<000000?ooo`3oool0o`3ooolC0?ooo`X0c03oo`3ooonc0?ooo`030000003oool0oooo00L0
oooo001E0?ooo`030000003oool0oooo0?l0oooo4`3oool:0<`0ool0oooo/`3oool00`000000oooo
0?ooo`070?ooo`00:P3oool0102oM000000000000018W=l40?ooo`090=nLB0000000B9cO0?ooo`3o
oml0W4P00000000004P0W=oo00H0oooo00H0_g@000000000000000000018W03Oool>0?ooo`030000
003oool0oooo0?l0oooo2`3oool40<`0o`@0oooo1@3<0?oo0?oookP0oooo00<000000?ooo`3oool0
1`3oool002P0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018
W=l0103oool0103OW4P000000018W03Oool30?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8
W03Oool03@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo1`3<0?oo0?oool40oooo00<000000?oo
o`3oool01`3oool002P0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0:0?ooo`04
0?oo_`1d0000001d0;ooo`P0oooo00<0omnL04Qd_`3oool0303oool00`000000oooo0?ooo`3o0?oo
o`D0oooo2P3<0?oo0?oool40oooo00<000000?ooo`3oool01`3oool002L0oooo00@0oooO09a80000
B9`0gooo0P3oool00`3ooml0W4P0001d_`0;0?ooo`040?oo_`1d000004RL0=ooo`L0oooo00<0oono
07@0B02Lgol0303oool00`000000oooo0?ooo`3o0?ooo`D0oooo1`3<0?oo0?oool@0oooo00<00000
0?ooo`3oool01`3oool002L0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0;0?oo
o`030=nLB0000000M;oo00L0oooo00<0oono07@0001d_ol0303oool00`000000oooo0?ooo`3k0?oo
o`D0c03o103oool40<`0ool0ooooa`3oool00`000000oooo0?ooo`070?ooo`009`3oool00`3ogi`0
B00004RLg`040?ooo`030;md000007@0_ooo00L0oooo00<0gia80000000000000`0000000`00B9`0
gooo0?ooo`050?ooo`030?noM0000000M;oo00`0oooo1P00003c0?ooo`X0c03oo`3oooo:0?ooo`H0
00002@3oool002L0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`060?ooo`030;md
0000000007Bo0080oooo00@0oono07@0000007@0_ooo1@3oool0103ogi`0B0000000M02oool<0?oo
o`030000003oool0oooo0?H0oooo2P3<0?oo0?oooll0oooo00<000000?ooo`3oool01`3oool002L0
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`050?ooo`040?oo_`1d000004RL0=oo
o`<0oooo00D0_g@00000B02Lgol0oooo0=oOg`020?ooo`040;md00000000000004RLg`d0oooo00<0
00000?ooo`3oool0kP3oool40<`0o`@0oooo1@3<0?oo0?ooom@0oooo00<000000?ooo`3oool01`3o
ool002L0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`050?ooo`030?oOW0180000
B9cO00@0oooo00D0gia80000B02Lgol0oooo0?noM00400000003001d_`3oool0oooo00`0oooo00<0
00000?ooo`3oool0j`3oool70<`0ool0oooog@3oool00`000000oooo0?ooo`070?ooo`00:03oool0
0`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00H0oooo00<0omnL04P00018W=l0103oool0
2@2oM000001d0;ooo`3oool0oooO09a800000000001d0;ooo`0?0?ooo`030000003oool0oooo0>P0
oooo2P3<0?oo0?ooomd0oooo00<000000?ooo`3oool01`3oool002P0oooo00<0okmd0000B02Lgol0
0P3oool00`3ogi`0B00007Boo`060?ooo`030?oog`2LB00007Bo00<0oooo00<0oono07@00018W=l0
0`3oool00`3o_g@007Bo0?ooo`0@0?ooo`030000003oool0oooo0>00oooo103<0?l40?ooo`L0c03o
o`3ooooP0?ooo`030000003oool0oooo00L0oooo000Y0?ooo`060;md0000B9`0gooo0?ooo`2oM000
07Bo203oool0203ogi`0B00007Boo`3oool0oooO09a80000B9`0gooo0`3oool00`3ooml0W4P00000
0002000000030000M02oool0oooo00/0oooo00<000000?ooo`3oool0gP3oool60<`0o`@0oooo103<
0?oo0?ooon<0oooo00<000000?ooo`3oool01`3oool002X0oooo00@0_g@000000000000007Bo2P3o
ool01P3ookl0M00000000000000004RL0=ooo`D0oooo00<0okmd0000000000000P0000000`1d_ol0
oooo0?ooo`0:0?ooo`030000003oool0oooo0=X0oooo2P3<0?oo0?ooon/0oooo00<000000?ooo`3o
ool01`3oool005D0oooo00<000000?ooo`3oool0fP3oool70<`0ool0ooookP3oool00`000000oooo
0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3J0?ooo`D0c03oo`3oooo`0?ooo`030000003o
ool0oooo00L0oooo001E0?ooo`030000003oool0oooo0=<0oooo103<0?oo0?ooooP0oooo00<00000
0?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0d03oool70<`0ool0oooon03oool00`00
0000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3=0?ooo`X0c03oo`3ooooh0?ooo`03
0000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0<d0oooo1`3<0?oo0?oooo/0oooo
00<000000?ooo`3oool01`3oool005D0oooo1000003<0?ooo`@0c03oo`3ooook0?ooo`@000002@3o
ool005D0oooo00<000000?ooo`3oool0a@3oool40<`0ool0ooooo`3oool70?ooo`030000003oool0
oooo00L0oooo001E0?ooo`030000003oool0oooo0<80oooo1`3<0?oo0?ooool0oooo1`3oool00`00
0000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`2o0?ooo`X0c03oo`3ooooo0?ooo`L0
oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0_`3oool70<`0ool0oooo
o`3oool:0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0;l0oooo103<
0?oo0?ooool0oooo3@3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`2i
0?ooo`<0c03oo`3ooooo0?oooa@0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?oo
o`3oool0]P3oool60<`0ool0ooooo`3ooolD0?ooo`030000003oool0oooo00L0oooo001E0?ooo`03
0000003oool0oooo0;@0oooo203<0?oo0?ooool0oooo503oool00`000000oooo0?ooo`070?ooo`00
E@3oool00`000000oooo0?ooo`2b0?ooo`P0c03oo`3ooooo0?oooaH0oooo00<000000?ooo`3oool0
1`3oool005D0oooo00<000000?ooo`3oool0/P3oool50<`0ool0ooooo`3ooolI0?ooo`030000003o
ool0oooo00L0oooo001E0?ooo`030000003oool0oooo0;80oooo0`3<0?oo0?ooool0oooo6`3oool0
0`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`2/0?ooo`<0c03oo`3ooooo0?oo
ob40oooo00<000000?ooo`3oool01`3oool005D0oooo1000002Z0?ooo`@0c03oo`3ooooo0?oooah0
oooo100000090?ooo`00E@3oool00`000000oooo0?ooo`2Y0?ooo`H0c03oo`3ooooo0?ooob40oooo
00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0Z03oool50<`0ool0ooooo`3o
oolS0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0:H0oooo1P3<0?oo
0?ooool0oooo903oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`2V0?oo
o`@0c03oo`3ooooo0?ooobH0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3o
ool0YP3oool30<`0ool0ooooo`3ooolW0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000
003oool0oooo09l0oooo0`3<0?oo0?ooool0oooo;P3oool00`000000oooo0?ooo`070?ooo`00E@3o
ool00`000000oooo0?ooo`2M0?ooo`D0c03oo`3ooooo0?ooobh0oooo00<000000?ooo`3oool01`3o
ool005D0oooo00<000000?ooo`3oool0V`3oool70<`0ool0ooooo`3oool^0?ooo`030000003oool0
oooo00L0oooo001E0?ooo`030000003oool0oooo09T0oooo1`3<0?oo0?ooool0oooo<03oool00`00
0000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`2I0?ooo`D0c03oo`3ooooo0?oooc80
oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0V@3oool30<`0ool0oooo
o`3ooold0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3o
ooo@0?ooo`030000003oool0oooo00L0oooo001E0?ooo`@00000o`3ooooo0?oool`0oooo10000009
0?ooo`00E@3oool00`000000oooo0?ooo`2C0?ooo`<0c03oo`3ooooo0?ooocX0oooo00<000000?oo
o`3oool01`3oool005D0oooo00<000000?ooo`3oool0TP3oool40<`0ool0ooooo`3ooolj0?ooo`03
0000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0900oooo1P3<0?oo0?ooool0oooo
>P3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`2?0?ooo`D0c03oo`3o
oooo0?oooc`0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0S@3oool6
0<`0ool0ooooo`3ooolm0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo
08d0oooo103<0?oo0?ooool0oooo?`3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000
oooo0?ooo`2=0?ooo`<0c03oo`3ooooo0?oood00oooo00<000000?ooo`3oool01`3oool005D0oooo
00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo00<0
00000?ooo`3oool0R03oool30<`0ool0ooooo`3ooom50?ooo`030000003oool0oooo00L0oooo001E
0?ooo`030000003oool0oooo08L0oooo1@3<0?oo0?ooool0ooooA03oool00`000000oooo0?ooo`07
0?ooo`00E@3oool00`000000oooo0?ooo`260?ooo`@0c03oo`3ooooo0?ooodH0oooo00<000000?oo
o`3oool01`3oool005D0oooo00<000000?ooo`3oool0Q@3oool40<`0ool0ooooo`3ooom70?ooo`03
0000003oool0oooo00L0oooo001E0?ooo`@00000P`3oool40<`0ool0ooooo`3ooom50?ooo`@00000
2@3oool005D0oooo00<000000?ooo`3oool0PP3oool50<`0ool0ooooo`3ooom90?ooo`030000003o
ool0oooo00L0oooo001E0?ooo`030000003oool0oooo0840oooo1@3<0?oo0?ooool0ooooBP3oool0
0`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`220?ooo`80c03oo`3ooooo0?oo
od`0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooom00
oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0O03oool30<`0ool0oooo
o`3ooomA0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo07/0oooo1@3<
0?oo0?ooool0ooooD03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`1j
0?ooo`@0c03oo`3ooooo0?oooe80oooo00<000000?ooo`3oool01`3oool00480oooo00<0okmd0000
000000000P0000000`00M;l0oooo0?ooo`0;0?ooo`030000003oool0oooo07T0oooo103<0?oo0?oo
ool0ooooD`3oool00`000000oooo0?ooo`070?ooo`00A03oool00`2oM000001d0;ooo`0>0?ooo`03
0000003oool0oooo07P0oooo103<0?oo0?ooool0ooooE03oool00`000000oooo0?ooo`070?ooo`00
A03oool00`2oM000001d0;ooo`0>0?ooo`030000003oool0oooo07H0oooo1@3<0?oo0?ooool0oooo
E@3oool00`000000oooo0?ooo`070?ooo`00A03oool00`2oM000001d0;ooo`0>0?ooo`030000003o
ool0oooo07D0oooo1@3<0?oo0?ooool0ooooEP3oool00`000000oooo0?ooo`070?ooo`00A03oool0
0`2oM000001d0;ooo`0>0?ooo`030000003oool0oooo07H0oooo0P3<0?oo0?ooool0ooooF03oool0
0`000000oooo0?ooo`070?ooo`00A03oool00`2oM000001d0;ooo`0>0?ooo`030000003oool0oooo
0?l0ooooo`3oooo@0?ooo`030000003oool0oooo00L0oooo00140?ooo`030;md000007@0_ooo00h0
oooo1P00001`0?ooo`030<`0o`3oool0oooo0?l0ooooo`3ooomE0?ooo`H000002@3oool004@0oooo
00<0_g@00000M02oool03P3oool00`000000oooo0?ooo`1b0?ooo`<0c03oo`3ooooo0?oooe/0oooo
00<000000?ooo`3oool01`3oool004@0oooo00<0_g@00000M02oool03P3oool00`000000oooo0?oo
o`1b0?ooo`<0c03oo`3ooooo0?oooe/0oooo00<000000?ooo`3oool01`3oool004@0oooo00<0_g@0
0000M02oool03P3oool00`000000oooo0?ooo`1a0?ooo`<0c03oo`3ooooo0?oooe`0oooo00<00000
0?ooo`3oool01`3oool004@0oooo00<0_g@00000M02oool03P3oool00`000000oooo0?ooo`1`0?oo
o`@0c03oo`3ooooo0?oooe`0oooo00<000000?ooo`3oool01`3oool00480oooo00D0gia800000000
0000001d0;ooo`0>0?ooo`030000003oool0oooo06l0oooo103<0?oo0?ooool0ooooG@3oool00`00
0000oooo0?ooo`070?ooo`00@`3oool0103ookl0M0000000M02oool>0?ooo`030000003oool0oooo
06h0oooo103<0?oo0?ooool0ooooGP3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000
oooo0?ooo`1]0?ooo`@0c03oo`3ooooo0?oooel0oooo00<000000?ooo`3oool01`3oool005D0oooo
00<000000?ooo`3oool0K@3oool30<`0ool0ooooo`3ooomP0?ooo`030000003oool0oooo00L0oooo
001E0?ooo`030000003oool0oooo06d0oooo0P3<0?oo0?ooool0ooooH@3oool00`000000oooo0?oo
o`070?ooo`00E@3oool00`000000oooo0?ooo`1^0?ooo`030<`0o`3oool0oooo0?l0ooooo`3ooomO
0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo06X0oooo00<0c03o0?oo
o`3oool0o`3ooooo0?ooof<0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3o
ool0J@3oool30<`0ool0ooooo`3ooomT0?ooo`030000003oool0oooo00L0oooo001E0?ooo`@00000
J03oool30<`0ool0ooooo`3ooomQ0?ooo`@000002@3oool005D0oooo00<000000?ooo`3oool0J03o
ool30<`0ool0ooooo`3ooomU0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0
oooo06L0oooo103<0?oo0?ooool0ooooI@3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`00
0000oooo0?ooo`1V0?ooo`@0c03oo`3ooooo0?ooofH0oooo00<000000?ooo`3oool01`3oool005D0
oooo00<000000?ooo`3oool0I@3oool40<`0ool0ooooo`3ooomW0?ooo`030000003oool0oooo00L0
oooo001E0?ooo`030000003oool0oooo06@0oooo103<0?oo0?ooool0ooooJ03oool00`000000oooo
0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`1T0?ooo`<0c03oo`3ooooo0?ooofT0oooo00<0
00000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0I03oool20<`0ool0ooooo`3ooomZ
0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo06D0oooo00<0c03o0?oo
o`3oool0o`3ooooo0?ooofP0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0
H@3oool00`3<0?l0oooo0?ooo`3o0?ooool0ooooK03oool00`000000oooo0?ooo`070?ooo`00E@3o
ool00`000000oooo0?ooo`1P0?ooo`<0c03oo`3ooooo0?ooofd0oooo00<000000?ooo`3oool01`3o
ool005D0oooo00<000000?ooo`3oool0G`3oool40<`0ool0ooooo`3ooom]0?ooo`030000003oool0
oooo00L0oooo001E0?ooo`@00000G@3oool40<`0ool0ooooo`3ooom[0?ooo`@000002@3oool005D0
oooo00<000000?ooo`3oool0G@3oool40<`0ool0ooooo`3ooom_0?ooo`030000003oool0oooo00L0
oooo001E0?ooo`030000003oool0oooo05`0oooo103<0?oo0?ooool0ooooL03oool00`000000oooo
0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`1K0?ooo`@0c03oo`3ooooo0?ooog40oooo00<0
00000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0FP3oool40<`0ool0ooooo`3ooomb
0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo05/0oooo0P3<0?oo0?oo
ool0ooooL`3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0
ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0oooo
d03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooood03o
ool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`1G0?ooo`<0c03oo`3ooooo
0?ooogH0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0E`3oool30<`0
ool0ooooo`3ooomf0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo05H0
oooo103<0?oo0?ooool0ooooMP3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo
0?ooo`1E0?ooo`@0c03oo`3ooooo0?ooogL0oooo00<000000?ooo`3oool01`3oool005D0oooo00<0
00000?ooo`3oool0E@3oool30<`0ool0ooooo`3ooomh0?ooo`030000003oool0oooo00L0oooo001E
0?ooo`@00000D`3oool40<`0ool0ooooo`3ooome0?ooo`@000002@3oool005D0oooo00<000000?oo
o`3oool0D`3oool40<`0ool0ooooo`3ooomi0?ooo`030000003oool0oooo00L0oooo001E0?ooo`03
0000003oool0oooo05<0oooo0`3<0?oo0?ooool0ooooNP3oool00`000000oooo0?ooo`070?ooo`00
E@3oool00`000000oooo0?ooo`1C0?ooo`<0c03oo`3ooooo0?ooogX0oooo00<000000?ooo`3oool0
1`3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3o
ool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool0
05D0oooo00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0
oooo00<000000?ooo`3oool0C`3oool30<`0ool0ooooo`3ooomn0?ooo`030000003oool0oooo00L0
oooo001E0?ooo`030000003oool0oooo04l0oooo0`3<0?oo0?ooool0ooooOP3oool00`000000oooo
0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`1>0?ooo`@0c03oo`3ooooo0?ooogh0oooo00<0
00000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0CP3oool30<`0ool0ooooo`3ooomo
0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo04d0oooo103<0?oo0?oo
ool0ooooO`3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`1=0?ooo`<0
c03oo`3ooooo0?oooh00oooo00<000000?ooo`3oool01`3oool005D0oooo1000001<0?ooo`<0c03o
o`3ooooo0?ooogd0oooo100000090?ooo`00E@3oool00`000000oooo0?ooo`1<0?ooo`@0c03oo`3o
oooo0?oooh00oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0C03oool3
0<`0ool0ooooo`3ooon10?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo
04`0oooo0`3<0?oo0?ooool0ooooP@3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000
oooo0?ooo`3o0?ooool0ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo
0?ooo`3o0?ooool0ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?oo
o`3o0?ooool0ooood03oool00`000000oooo0?ooo`070?ooo`00:@3oool00`3o_g@0000000000002
00000007001d_`3oool0oooo0?ooo`3OW4P0000004RLg`040?ooo`040;md00000000000004RLg`@0
oooo00H0_g@000000000000000000018W03Oool>0?ooo`030000003oool0oooo04T0oooo0`3<0?oo
0?ooool0ooooQ03oool00`000000oooo0?ooo`070?ooo`00:`3oool00`2oM000001d0;ooo`040?oo
o`030=nLB0000000B9cO0080oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo0080oooo00<0
oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0=0?ooo`030000003oool0oooo04T0oooo0`3<
0?oo0?ooool0ooooQ03oool00`000000oooo0?ooo`070?ooo`00:`3oool00`2oM000001d0;ooo`09
0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`3ogi`0B7Bo0?ooo`0<
0?ooo`030000003oool0oooo04P0oooo103<0?oo0?ooool0ooooQ03oool00`000000oooo0?ooo`07
0?ooo`00:`3oool00`2oM000001d0;ooo`080?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO
09a80000M;l01`3oool00`3ookl0M01809cOo`0<0?ooo`030000003oool0oooo04P0oooo0`3<0?oo
0?ooool0ooooQ@3oool00`000000oooo0?ooo`070?ooo`00:`3oool00`2oM000001d0;ooo`080?oo
o`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3ookl0M00007Boo`0<0?oo
o`030000003oool0oooo04L0oooo103<0?oo0?ooool0ooooQ@3oool00`000000oooo0?ooo`070?oo
o`00:`3oool00`2oM000001d0;ooo`080?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02o
ool01P3oool00`3o_g@0000007Boo`0<0?ooo`030000003oool0oooo04L0oooo0`3<0?oo0?ooool0
ooooQP3oool00`000000oooo0?ooo`070?ooo`00:`3oool00`2oM000001d0;ooo`080?ooo`030?oO
W0180000B9cO00@0oooo00<0gia80000B02Lgol01@3oool0103ogi`0B0000000M02oool<0?ooo`H0
0000A03oool30<`0ool0ooooo`3ooon10?ooo`H000002@3oool002/0oooo00<0_g@00000M02oool0
203oool00`3ogi`0B00004RLg`040?ooo`050=nLB00004P0W=oo0?ooo`3Ogml00P3oool0102oM000
000000000018W=l=0?ooo`030000003oool0oooo04H0oooo103<0?oo0?ooool0ooooQP3oool00`00
0000oooo0?ooo`070?ooo`00:`3oool00`2oM000001d0;ooo`080?ooo`030?oo_`1d000007Bo00@0
oooo00D0_g@00000M02oool0oooo0?noM00400000003001d_`3oool0oooo00`0oooo00<000000?oo
o`3oool0AP3oool30<`0ool0ooooo`3ooon70?ooo`030000003oool0oooo00L0oooo000[0?ooo`03
0;md000007@0_ooo00T0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`020?ooo`05
0?oog`2LB00000000000M02oool03`3oool00`000000oooo0?ooo`160?ooo`<0c03oo`3ooooo0?oo
ohL0oooo00<000000?ooo`3oool01`3oool002/0oooo00<0_g@00000M02oool02@3oool00`3o_g@0
001809cOo`020?ooo`030?oOW0180000M;oo00<0oooo00<0okmd001d_`3oool0403oool00`000000
oooo0?ooo`3o0?ooool0ooood03oool00`000000oooo0?ooo`070?ooo`00:@3oool01@3OW4P00000
0000000007@0_ooo00X0oooo00H0_g@00018W03Oool0oooo0;md0000M;l40?ooo`030?oog`2LB000
00000080000000<0001d0;ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooool0ooood03oool0
0`000000oooo0?ooo`070?ooo`00:P3oool0103ookl0M0000000M02oool;0?ooo`040;md00000000
0000001d_`H0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0:0?ooo`030000003o
ool0oooo0?l0ooooo`3oooo@0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0
oooo04<0oooo0`3<0?oo0?ooool0ooooRP3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`00
0000oooo0?ooo`130?ooo`<0c03oo`3ooooo0?ooohX0oooo00<000000?ooo`3oool01`3oool005D0
oooo00<000000?ooo`3oool0@P3oool40<`0ool0ooooo`3ooon:0?ooo`030000003oool0oooo00L0
oooo001E0?ooo`030000003oool0oooo0480oooo0`3<0?oo0?ooool0ooooR`3oool00`000000oooo
0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`110?ooo`@0c03oo`3ooooo0?oooh/0oooo00<0
00000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0@@3oool30<`0ool0ooooo`3ooon<
0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0440oooo0`3<0?oo0?oo
ool0ooooS03oool00`000000oooo0?ooo`070?ooo`00E@3oool4000003l0oooo103<0?oo0?ooool0
ooooR@3oool4000000T0oooo001E0?ooo`030000003oool0oooo0400oooo0`3<0?oo0?ooool0oooo
S@3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`100?ooo`<0c03oo`3o
oooo0?ooohd0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0o`3ooooo
0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
om00oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0o`3ooooo0?ooom00
oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0?@3oool30<`0ool0oooo
o`3ooon@0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo03d0oooo0`3<
0?oo0?ooool0ooooT03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0m
0?ooo`<0c03oo`3ooooo0?oooi00oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?oo
o`3oool0?03oool40<`0ool0ooooo`3ooon@0?ooo`030000003oool0oooo00L0oooo001E0?ooo`03
0000003oool0oooo03`0oooo0`3<0?oo0?ooool0ooooT@3oool00`000000oooo0?ooo`070?ooo`00
E@3oool00`000000oooo0?ooo`0l0?ooo`<0c03oo`3ooooo0?oooi40oooo00<000000?ooo`3oool0
1`3oool005D0oooo00<000000?ooo`3oool0>`3oool40<`0ool0ooooo`3ooonA0?ooo`030000003o
ool0oooo00L0oooo001E0?ooo`@00000>P3oool30<`0ool0ooooo`3ooon?0?ooo`@000002@3oool0
05D0oooo00<000000?ooo`3oool0>`3oool30<`0ool0ooooo`3ooonB0?ooo`030000003oool0oooo
00L0oooo001E0?ooo`030000003oool0oooo03/0oooo0`3<0?oo0?ooool0ooooTP3oool00`000000
oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooood03oool00`000000oooo
0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooood03oool00`000000oooo0?oo
o`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooood03oool00`000000oooo0?ooo`07
0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooood03oool00`000000oooo0?ooo`070?oo
o`007@3oool00`3ooml0W4Q809cOo`0e0?ooo`030000003oool0oooo03T0oooo0`3<0?oo0?ooool0
ooooU03oool00`000000oooo0?ooo`070?ooo`00703oool00`3ookl0M01809cOo`0f0?ooo`030000
003oool0oooo03T0oooo0`3<0?oo0?ooool0ooooU03oool00`000000oooo0?ooo`070?ooo`006`3o
ool00`3ogi`0B01d0;ooo`0g0?ooo`030000003oool0oooo03T0oooo0`3<0?oo0?ooool0ooooU03o
ool00`000000oooo0?ooo`070?ooo`004P3oool00`3OW9`0_ooo0?ooo`050?ooo`030?oOW018B9`0
gooo03P0oooo00<000000?ooo`3oool0>03oool40<`0ool0ooooo`3ooonD0?ooo`030000003oool0
oooo00L0oooo000A0?ooo`030?oog`2LB7@0_ooo00D0oooo00<0omnL04Q8W03Oool0>@3oool00`00
0000oooo0?ooo`0h0?ooo`<0c03oo`3ooooo0?oooiD0oooo00<000000?ooo`3oool01`3oool00140
oooo00<0oono07@000000000100000000`00B4P0B01d0;ooo`0j0?ooo`030000003oool0oooo03P0
oooo0`3<0?oo0?ooool0ooooU@3oool00`000000oooo0?ooo`070?ooo`00503oool00`3o_g@00000
000000070000000304RLg`3oool0oooo03@0oooo1000000f0?ooo`@0c03oo`3ooooo0?oooi80oooo
100000090?ooo`005P3oool00`3ooml0W4Q809cOo`020?ooo`050;md0000000000000000B02Lgol0
=@3oool00`000000oooo0?ooo`0g0?ooo`<0c03oo`3ooooo0?oooiH0oooo00<000000?ooo`3oool0
1`3oool001D0oooo00<0oooO09a8B02Lgol01@3oool00`3ogi`0B4RL0=ooo`0e0?ooo`030000003o
ool0oooo03L0oooo0`3<0?oo0?ooool0ooooUP3oool00`000000oooo0?ooo`070?ooo`00503oool0
0`3ooml0W4Q809cOo`050?ooo`030?oo_`1d07@0_ooo03H0oooo00<000000?ooo`3oool0=`3oool3
0<`0ool0ooooo`3ooonF0?ooo`030000003oool0oooo00L0oooo000C0?ooo`030?oo_`1d04P0W=oo
03l0oooo00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool00180
oooo00<0okmd0000M02oool0@03oool00`000000oooo0?ooo`3o0?ooool0ooood03oool00`000000
oooo0?ooo`070?ooo`004@3oool00`3ookl0M7Bo0?ooo`110?ooo`030000003oool0oooo0?l0oooo
o`3oooo@0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3o
ooo@0?ooo`030000003oool0oooo00L0oooo000:0?ooo`030=nLB000B9`0gooo00@0oooo00<0giad
04Q8M02oool0@@3oool00`000000oooo0?ooo`0d0?ooo`<0c03oo`3ooooo0?oooiT0oooo00<00000
0?ooo`3oool01`3oool000T0oooo00<0okmd001d_`3oool0103oool0102oM000B9bL07@0M02ooom1
0?ooo`030000003oool0oooo03@0oooo0`3<0?oo0?ooool0ooooV@3oool00`000000oooo0?ooo`07
0?ooo`002@3oool00`3OW4P0B9cO0?ooo`020?ooo`060?oog`2LB000M;oo0?oo_`1d07@0_ooo@@3o
ool00`000000oooo0?ooo`0d0?ooo`<0c03oo`3ooooo0?oooiT0oooo00<000000?ooo`3oool01`3o
ool000T0oooo00/0okmd0000B02Lgol0oooo0?noM00004P0W=oo0?ooo`3ogi`0B01d0;ooo`110?oo
o`030000003oool0oooo03<0oooo103<0?oo0?ooool0ooooV@3oool00`000000oooo0?ooo`070?oo
o`002P3oool0103OW4P0000000000000M;l20?ooo`040?oog`2LB00004RL0=oood40oooo00<00000
0?ooo`3oool0<`3oool30<`0ool0ooooo`3ooonJ0?ooo`030000003oool0oooo00L0oooo001E0?oo
o`@00000<P3oool30<`0ool0ooooo`3ooonG0?ooo`@000002@3oool005D0oooo00<000000?ooo`3o
ool0<P3oool40<`0ool0ooooo`3ooonJ0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000
003oool0oooo0380oooo0`3<0?oo0?ooool0ooooV`3oool00`000000oooo0?ooo`070?ooo`00E@3o
ool00`000000oooo0?ooo`0b0?ooo`<0c03oo`3ooooo0?oooi/0oooo00<000000?ooo`3oool01`3o
ool005D0oooo00<000000?ooo`3oool0<P3oool30<`0ool0ooooo`3ooonK0?ooo`030000003oool0
oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000003oool0oooo
00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000003oool0oooo00L0
oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000003oool0oooo00L0oooo
000c0?ooo`030?noM000000000000080000000L007Bo0?ooo`3oool0oooo0=nLB0000000B9cO00<0
oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0
ooooo`3oooo@0?ooo`030000003oool0oooo00L0oooo000e0?ooo`030;md000007@0_ooo00@0oooo
00<0gia800000018W=l01@3oool00`2oM000001d0;ooo`0>0?ooo`030000003oool0oooo0300oooo
0`3<0?oo0?ooool0ooooW@3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`2oM000001d0;oo
o`0<0?ooo`030;md000007@0_ooo00h0oooo00<000000?ooo`3oool0<03oool30<`0ool0ooooo`3o
oonM0?ooo`030000003oool0oooo00L0oooo000e0?ooo`030;md000007@0_ooo00`0oooo00<0_g@0
0000M02oool03P3oool00`000000oooo0?ooo`0`0?ooo`<0c03oo`3ooooo0?oooid0oooo00<00000
0?ooo`3oool01`3oool003D0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`0>0?oo
o`030000003oool0oooo0300oooo0`3<0?oo0?ooool0ooooW@3oool00`000000oooo0?ooo`070?oo
o`00=@3oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00h0oooo00<000000?ooo`3o
ool0<03oool30<`0ool0ooooo`3ooonM0?ooo`030000003oool0oooo00L0oooo000e0?ooo`030;md
000007@0_ooo00`0oooo00<0_g@00000M02oool03P3oool6000002`0oooo0`3<0?oo0?ooool0oooo
V@3oool6000000T0oooo000e0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool03P3o
ool00`000000oooo0?ooo`0_0?ooo`<0c03oo`3ooooo0?oooih0oooo00<000000?ooo`3oool01`3o
ool003D0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`0>0?ooo`030000003oool0
oooo02l0oooo0`3<0?oo0?ooool0ooooWP3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`2o
M000001d0;ooo`0<0?ooo`030;md000007@0_ooo00h0oooo00<000000?ooo`3oool0;`3oool30<`0
ool0ooooo`3ooonN0?ooo`030000003oool0oooo00L0oooo000e0?ooo`030;md000007@0_ooo00`0
oooo00<0_g@00000M02oool03P3oool00`000000oooo0?ooo`0_0?ooo`<0c03oo`3ooooo0?oooih0
oooo00<000000?ooo`3oool01`3oool003<0oooo00D0gia8000000000000001d0;ooo`0:0?ooo`05
0=nLB000000000000000M02oool03P3oool00`000000oooo0?ooo`3o0?ooool0ooood03oool00`00
0000oooo0?ooo`070?ooo`00=03oool0103ookl0M0000000M02oool;0?ooo`040?oo_`1d0000001d
0;ooo`h0oooo00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool0
05D0oooo00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0
oooo00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo
00<000000?ooo`3oool0;@3oool30<`0ool0ooooo`3ooonP0?ooo`030000003oool0oooo00L0oooo
001E0?ooo`030000003oool0oooo02d0oooo0`3<0?oo0?ooool0ooooX03oool00`000000oooo0?oo
o`070?ooo`00E@3oool00`000000oooo0?ooo`0]0?ooo`<0c03oo`3ooooo0?oooj00oooo00<00000
0?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0;@3oool30<`0ool0ooooo`3ooonP0?oo
o`030000003oool0oooo00L0oooo001E0?ooo`@00000;03oool30<`0ool0ooooo`3ooonM0?ooo`@0
00002@3oool005D0oooo00<000000?ooo`3oool0;03oool30<`0ool0ooooo`3ooonQ0?ooo`030000
003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo02`0oooo0`3<0?oo0?ooool0ooooX@3o
ool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0/0?ooo`<0c03oo`3ooooo
0?oooj40oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0;03oool30<`0
ool0ooooo`3ooonQ0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo02`0
oooo0`3<0?oo0?ooool0ooooX@3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo
0?ooo`3o0?ooool0ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?oo
o`3o0?ooool0ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o
0?ooool0ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?oo
ool0ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0Z0?ooo`<0
c03oo`3ooooo0?oooj<0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0
:P3oool30<`0ool0ooooo`3ooonS0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003o
ool0oooo02X0oooo0`3<0?oo0?ooool0ooooX`3oool00`000000oooo0?ooo`070?ooo`00E@3oool4
000002T0oooo0`3<0?oo0?ooool0ooooX03oool4000000T0oooo001E0?ooo`030000003oool0oooo
02X0oooo0`3<0?oo0?ooool0ooooX`3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000
oooo0?ooo`0Y0?ooo`<0c03oo`3ooooo0?oooj@0oooo00<000000?ooo`3oool01`3oool005D0oooo
00<000000?ooo`3oool0:@3oool30<`0ool0ooooo`3ooonT0?ooo`030000003oool0oooo00L0oooo
001E0?ooo`030000003oool0oooo02T0oooo0`3<0?oo0?ooool0ooooY03oool00`000000oooo0?oo
o`070?ooo`00E@3oool00`000000oooo0?ooo`0Y0?ooo`<0c03oo`3ooooo0?oooj@0oooo00<00000
0?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0:@3oool30<`0ool0ooooo`3ooonT0?oo
o`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`03
0000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000
003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000003o
ool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000003oool0
oooo00L0oooo001E0?ooo`030000003oool0oooo02L0oooo0`3<0?oo0?ooool0ooooYP3oool00`00
0000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0W0?ooo`<0c03oo`3ooooo0?ooojH0
oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool09`3oool30<`0ool0oooo
o`3ooonV0?ooo`030000003oool0oooo00L0oooo001E0?ooo`@000009P3oool30<`0ool0ooooo`3o
oonS0?ooo`@000002@3oool005D0oooo00<000000?ooo`3oool09`3oool30<`0ool0ooooo`3ooonV
0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo02H0oooo0`3<0?oo0?oo
ool0ooooY`3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0V0?ooo`<0
c03oo`3ooooo0?ooojL0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0
9P3oool30<`0ool0ooooo`3ooonW0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003o
ool0oooo02H0oooo0`3<0?oo0?ooool0ooooY`3oool00`000000oooo0?ooo`070?ooo`00E@3oool0
0`000000oooo0?ooo`0V0?ooo`<0c03oo`3ooooo0?ooojL0oooo00<000000?ooo`3oool01`3oool0
05D0oooo00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0
oooo00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo
00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo00<00000
0?ooo`3oool09@3oool30<`0ool0ooooo`3ooonX0?ooo`030000003oool0oooo00L0oooo001E0?oo
o`030000003oool0oooo02D0oooo0`3<0?oo0?ooool0ooooZ03oool00`000000oooo0?ooo`070?oo
o`00E@3oool4000002@0oooo0`3<0?oo0?ooool0ooooY@3oool4000000T0oooo001E0?ooo`030000
003oool0oooo02@0oooo103<0?oo0?ooool0ooooZ03oool00`000000oooo0?ooo`070?ooo`00E@3o
ool00`000000oooo0?ooo`0T0?ooo`<0c03oo`3ooooo0?ooojT0oooo00<000000?ooo`3oool01`3o
ool005D0oooo00<000000?ooo`3oool0903oool30<`0ool0ooooo`3ooonY0?ooo`030000003oool0
oooo00L0oooo001E0?ooo`030000003oool0oooo02<0oooo103<0?oo0?ooool0ooooZ@3oool00`00
0000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0S0?ooo`<0c03oo`3ooooo0?ooojX0
oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool08`3oool30<`0ool0oooo
o`3ooonZ0?ooo`030000003oool0oooo00L0oooo000Y0?ooo`030?noM000000000000080000000L0
07Bo0?ooo`3oool0oooo0=nLB0000000B9cO00<0oooo00<0okmd0000000000000P0000001@00M;l0
oooo0?ooo`3oool0_g@000<0000000<004RL0=ooo`3oool03@3oool00`000000oooo0?ooo`0S0?oo
o`<0c03oo`3ooooo0?ooojX0oooo00<000000?ooo`3oool01`3oool002/0oooo00<0_g@00000M02o
ool0103oool00`3OW4P0000004RLg`050?ooo`030;md000007@0_ooo00<0oooo00<0oooO09a80018
W=l00P3oool00`3ogi`0B4RL0=ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`03
0000003oool0oooo00L0oooo000[0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0
2@3oool00`3ogi`0B7Bo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000
003oool0oooo00L0oooo000[0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool02@3o
ool00`3ookl0M01809cOo`0<0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000003o
ool0oooo00L0oooo000[0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool02@3oool0
0`3ookl0M00007Boo`0<0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000003oool0
oooo00L0oooo000[0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool02@3oool00`3o
_g@0000007Boo`0<0?ooo`030000003oool0oooo0280oooo0`3<0?oo0?ooool0ooooZ`3oool00`00
0000oooo0?ooo`070?ooo`00:`3oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00P0
oooo00@0omnL04P0000007@0_ooo303oool6000001l0oooo0`3<0?oo0?ooool0ooooYP3oool60000
00T0oooo000[0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0103oool0103Ogml0
oooo0?ooo`2oM0020000000304RLg`3oool0oooo00/0oooo00<000000?ooo`3oool08P3oool30<`0
ool0ooooo`3ooon[0?ooo`030000003oool0oooo00L0oooo000[0?ooo`030;md000007@0_ooo00`0
oooo00<0_g@00000M02oool0103oool00`3o_g@000000000000200000003001d_`3oool0oooo00`0
oooo00<000000?ooo`3oool08P3oool30<`0ool0ooooo`3ooon[0?ooo`030000003oool0oooo00L0
oooo000[0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0103oool01@3ooml0W4P0
0000000007@0_ooo00l0oooo00<000000?ooo`3oool08P3oool30<`0ool0ooooo`3ooon[0?ooo`03
0000003oool0oooo00L0oooo000[0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0
1@3oool00`3o_g@007Bo0?ooo`0@0?ooo`030000003oool0oooo0240oooo0`3<0?oo0?ooool0oooo
[03oool00`000000oooo0?ooo`070?ooo`00:@3oool01@3OW4P000000000000007@0_ooo00X0oooo
00D0gia8000000000000001d0;ooo`050?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3o
ool02`3oool00`000000oooo0?ooo`0Q0?ooo`<0c03oo`3ooooo0?oooj`0oooo00<000000?ooo`3o
ool01`3oool002X0oooo00@0oono07@0000007@0_ooo2`3oool0103ookl0M0000000M02oool60?oo
o`030?noM000000000000080000000<0M;oo0?ooo`3oool02P3oool00`000000oooo0?ooo`0Q0?oo
o`<0c03oo`3ooooo0?oooj`0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3o
ool08@3oool30<`0ool0ooooo`3ooon/0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000
003oool0oooo0240oooo0`3<0?oo0?ooool0oooo[03oool00`000000oooo0?ooo`070?ooo`00E@3o
ool00`000000oooo0?ooo`3o0?ooool0ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool0
0`000000oooo0?ooo`3o0?ooool0ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`00
0000oooo0?ooo`3o0?ooool0ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000
oooo0?ooo`3o0?ooool0ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool4000001l0oooo
0`3<0?oo0?ooool0ooooZP3oool4000000T0oooo001E0?ooo`030000003oool0oooo0200oooo0`3<
0?oo0?ooool0oooo[@3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0P
0?ooo`<0c03oo`3ooooo0?ooojd0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?oo
o`3oool0803oool30<`0ool0ooooo`3ooon]0?ooo`030000003oool0oooo00L0oooo001E0?ooo`03
0000003oool0oooo0200oooo0`3<0?oo0?ooool0oooo[@3oool00`000000oooo0?ooo`070?ooo`00
E@3oool00`000000oooo0?ooo`0O0?ooo`<0c03oo`3ooooo0?ooojh0oooo00<000000?ooo`3oool0
1`3oool005D0oooo00<000000?ooo`3oool07`3oool30<`0ool0ooooo`3ooon^0?ooo`030000003o
ool0oooo00L0oooo001E0?ooo`030000003oool0oooo01l0oooo0`3<0?oo0?ooool0oooo[P3oool0
0`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0O0?ooo`<0c03oo`3ooooo0?oo
ojh0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool07`3oool30<`0ool0
ooooo`3ooon^0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo01l0oooo
0`3<0?oo0?ooool0oooo[P3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?oo
o`3o0?ooool0ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o
0?ooool0ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?oo
ool0ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool400000?l0ooooo`3oooo<0?ooo`@0
00002@3oool005D0oooo00<000000?ooo`3oool07`3oool30<`0ool0ooooo`3ooon^0?ooo`030000
003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo01l0oooo0`3<0?oo0?ooool0oooo[P3o
ool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0O0?ooo`<0c03oo`3ooooo
0?ooojh0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool07`3oool30<`0
ool0ooooo`3ooon^0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo01l0
oooo0`3<0?oo0?ooool0oooo[P3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo
0?ooo`0N0?ooo`<0c03oo`3ooooo0?ooojl0oooo00<000000?ooo`3oool01`3oool005D0oooo00<0
00000?ooo`3oool07P3oool30<`0ool0ooooo`3ooon_0?ooo`030000003oool0oooo00L0oooo001E
0?ooo`030000003oool0oooo01h0oooo0`3<0?oo0?ooool0oooo[`3oool00`000000oooo0?ooo`07
0?ooo`00E@3oool00`000000oooo0?ooo`0N0?ooo`<0c03oo`3ooooo0?ooojl0oooo00<000000?oo
o`3oool01`3oool005D0oooo00<000000?ooo`3oool07P3oool30<`0ool0ooooo`3ooon_0?ooo`03
0000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000
003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000003o
ool0oooo00L0oooo001E0?ooo`@00000o`3ooooo0?oool`0oooo100000090?ooo`00E@3oool00`00
0000oooo0?ooo`3o0?ooool0ooood03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000
oooo0?ooo`0M0?ooo`<0c03oo`3ooooo0?oook00oooo00<000000?ooo`3oool01`3oool005D0oooo
00<000000?ooo`3oool07@3oool30<`0ool0ooooo`3ooon`0?ooo`030000003oool0oooo00L0oooo
001E0?ooo`030000003oool0oooo01d0oooo0`3<0?oo0?ooool0oooo/03oool00`000000oooo0?oo
o`070?ooo`00E@3oool00`000000oooo0?ooo`0M0?ooo`<0c03oo`3ooooo0?oook00oooo00<00000
0?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool07@3oool30<`0ool0ooooo`3ooon`0?oo
o`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo01`0oooo0`3<0?oo0?ooool0
oooo/@3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0L0?ooo`<0c03o
o`3ooooo0?oook40oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0703o
ool30<`0ool0ooooo`3ooona0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0
oooo01`0oooo0`3<0?oo0?ooool0oooo/@3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`00
0000oooo0?ooo`0L0?ooo`<0c03oo`3ooooo0?oook40oooo00<000000?ooo`3oool01`3oool005D0
oooo00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo
1000003o0?ooool0ooooc03oool4000000T0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3o
ooo@0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo@
0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo01`0oooo0`3<0?oo0?oo
ool0oooo/@3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0L0?ooo`<0
c03oo`3ooooo0?oook40oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0
703oool30<`0ool0ooooo`3ooona0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003o
ool0oooo01`0oooo0`3<0?oo0?ooool0oooo/@3oool00`000000oooo0?ooo`070?ooo`00E@3oool0
0`000000oooo0?ooo`0L0?ooo`<0c03oo`3ooooo0?oook40oooo00<000000?ooo`3oool01`3oool0
03<0oooo00<0okmd0000000000000P0000002@00M;l0oooo0?ooo`3oool0gia800000018W=l0oooo
0=nLB0070000000307Boo`3oool0oooo00X0oooo00<000000?ooo`3oool06`3oool30<`0ool0oooo
o`3ooonb0?ooo`030000003oool0oooo00L0oooo000e0?ooo`030;md000007@0_ooo00@0oooo00<0
gia800000018W=l00P3oool00`3OW4P000000000000400000003001d_`3oool0oooo00X0oooo00<0
00000?ooo`3oool06`3oool30<`0ool0ooooo`3ooonb0?ooo`030000003oool0oooo00L0oooo000e
0?ooo`030;md000007@0_ooo00X0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`0;
0?ooo`030000003oool0oooo01/0oooo0`3<0?oo0?ooool0oooo/P3oool00`000000oooo0?ooo`07
0?ooo`00=@3oool00`2oM000001d0;ooo`0;0?ooo`030=nLB018W=l0oooo00l0oooo00<000000?oo
o`3oool06`3oool30<`0ool0ooooo`3ooonb0?ooo`030000003oool0oooo00L0oooo000e0?ooo`03
0;md000007@0_ooo00`0oooo00<0gia807Boo`3oool03P3oool00`000000oooo0?ooo`0K0?ooo`<0
c03oo`3ooooo0?oook80oooo00<000000?ooo`3oool01`3oool003D0oooo00<0_g@00000M02oool0
303oool00`3ooml0W4Q809cOo`0>0?ooo`030000003oool0oooo01/0oooo0`3<0?oo0?ooool0oooo
/P3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`2oM000001d0;ooo`0=0?ooo`030?oOW018
07@0_ooo00d0oooo1P00003o0?ooool0oooob03oool6000000T0oooo000e0?ooo`030;md000007@0
_ooo00h0oooo00<0_g@004RLg`3oool0303oool00`000000oooo0?ooo`3o0?ooool0ooood03oool0
0`000000oooo0?ooo`070?ooo`00=@3oool00`2oM000001d0;ooo`0>0?ooo`030=nLB00007@0_ooo
00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool003D0
oooo00<0_g@00000M02oool03P3oool00`3o_g@0000007Boo`0<0?ooo`030000003oool0oooo0?l0
ooooo`3oooo@0?ooo`030000003oool0oooo00L0oooo000e0?ooo`030;md000007@0_ooo00P0oooo
00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`0<0?ooo`030000003oool0oooo01X0oooo
0`3<0?oo0?ooool0oooo/`3oool00`000000oooo0?ooo`070?ooo`00<`3oool01@3OW4P000000000
000007@0_ooo00T0oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=ooo``0oooo00<00000
0?ooo`3oool06P3oool30<`0ool0ooooo`3ooonc0?ooo`030000003oool0oooo00L0oooo000d0?oo
o`040?oo_`1d0000001d0;ooo`X0oooo00D0_g@00000000000000000001d_`0>0?ooo`030000003o
ool0oooo01X0oooo0`3<0?oo0?ooool0oooo/`3oool00`000000oooo0?ooo`070?ooo`00E@3oool0
0`000000oooo0?ooo`0J0?ooo`<0c03oo`3ooooo0?oook<0oooo00<000000?ooo`3oool01`3oool0
05D0oooo00<000000?ooo`3oool06P3oool30<`0ool0ooooo`3ooonc0?ooo`030000003oool0oooo
00L0oooo001E0?ooo`030000003oool0oooo01T0oooo0`3<0?oo0?ooool0oooo]03oool00`000000
oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0I0?ooo`<0c03oo`3ooooo0?oook@0oooo
00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool06@3oool30<`0ool0ooooo`3o
oond0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo01T0oooo0`3<0?oo
0?ooool0oooo]03oool00`000000oooo0?ooo`070?ooo`00E@3oool4000001P0oooo0`3<0?oo0?oo
ool0oooo/@3oool4000000T0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`03
0000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000
003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000003o
ool0oooo00L0oooo001E0?ooo`030000003oool0oooo0?l0ooooo`3oooo@0?ooo`030000003oool0
oooo00L0oooo001E0?ooo`030000003oool0oooo01P0oooo0`3<0?oo0?ooool0oooo]@3oool00`00
0000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0H0?ooo`<0c03oo`3ooooo0?oookD0
oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0603oool30<`0ool0oooo
o`3ooone0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo01P0oooo0`3<
0?oo0?ooool0oooo]@3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0H
0?ooo`<0c03oo`3ooooo0?oookD0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?oo
o`3oool0603oool30<`0ool0ooooo`3ooone0?ooo`030000003oool0oooo00L0oooo001E0?ooo`03
0000003oool0oooo01P0oooo0`3<0?oo0?ooool0oooo]@3oool00`000000oooo0?ooo`070?ooo`00
E@3oool00`000000oooo0?ooo`0H0?ooo`<0c03oo`3ooooo0?oookD0oooo00<000000?ooo`3oool0
1`3oool005D0oooo1000000G0?ooo`<0c03oo`3ooooo0?oook80oooo100000090?ooo`00E@3oool0
0`000000oooo0?ooo`0H0?ooo`<0c03oo`3ooooo0?oookD0oooo00<000000?ooo`3oool01`3oool0
05D0oooo00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0
oooo00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo
00<000000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo00<00000
0?ooo`3oool05`3oool30<`0ool0ooooo`3ooonf0?ooo`030000003oool0oooo00L0oooo001E0?oo
o`030000003oool0oooo01L0oooo0`3<0?oo0?ooool0oooo]P3oool00`000000oooo0?ooo`070?oo
o`00E@3oool00`000000oooo0?ooo`0G0?ooo`<0c03oo`3ooooo0?oookH0oooo00<000000?ooo`3o
ool01`3oool005D0oooo00<000000?ooo`3oool05`3oool30<`0ool0ooooo`3ooonf0?ooo`030000
003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo01L0oooo0`3<0?oo0?ooool0oooo]P3o
ool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0F0?ooo`<0c03oo`3ooooo
0?oookL0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool05P3oool30<`0
ool0ooooo`3ooong0?ooo`030000003oool0oooo00L0oooo001E0?ooo`@000005@3oool30<`0ool0
ooooo`3ooond0?ooo`@000002@3oool005D0oooo00<000000?ooo`3oool05P3oool30<`0ool0oooo
o`3ooong0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo01H0oooo0`3<
0?oo0?ooool0oooo]`3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0F
0?ooo`<0c03oo`3ooooo0?oookL0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?oo
o`3oool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0
o`3ooooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool0o`3o
oooo0?ooom00oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?ooo`3oool05@3oool3
0<`0ool0ooooo`3ooonh0?ooo`030000003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo
01D0oooo0`3<0?oo0?ooool0oooo^03oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000
oooo0?ooo`0E0?ooo`<0c03oo`3ooooo0?oookP0oooo00<000000?ooo`3oool01`3oool005D0oooo
00<000000?ooo`3oool05@3oool30<`0ool0ooooo`3ooonh0?ooo`030000003oool0oooo00L0oooo
001E0?ooo`030000003oool0oooo01D0oooo0`3<0?oo0?ooool0oooo^03oool00`000000oooo0?oo
o`070?ooo`00E@3oool00`000000oooo0?ooo`0D0?ooo`<0c03oo`3ooooo0?oookT0oooo00<00000
0?ooo`3oool01`3oool005D0oooo1000000C0?ooo`<0c03oo`3ooooo0?oookH0oooo100000090?oo
o`00E@3oool00`000000oooo0?ooo`0D0?ooo`<0c03oo`3ooooo0?oookT0oooo00<000000?ooo`3o
ool01`3oool005D0oooo00<000000?ooo`3oool0503oool30<`0ool0ooooo`3oooni0?ooo`030000
003oool0oooo00L0oooo001E0?ooo`030000003oool0oooo01@0oooo0`3<0?oo0?ooool0oooo^@3o
ool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooood03oool0
0`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooood03oool00`00
0000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooood03oool00`000000
oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooool0ooood03oool00`000000oooo
0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08L0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo001E
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool005D0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`070?ooo`00E@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00L0oooo001E0?ooool00000o`00003D000000T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 815.25}, {503.5, 0}} -> {-0.150142, 0.870779, \
0.00145709, 0.000752325}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ 
        Repeat\ above\ calculation\ for\ \((Log \((E\_\[Gamma])\) - 
              Log \((E\_peak)\))\)\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(omv = {0.01, 0.03, 0.05, 0.07, 0.1, 0.13, 0.15, 0.16, 0.18, 
        0.19, 0.2, 0.22, 0.25, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1}; 
    valsom = Length[omv]; \ r1om = {};\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[om = omv[\([q]\)]; \[IndentingNewLine]Clear[f, dl, dld]; 
      w0 = \(-1\); w1 = 0; h0 = 10^5\ h; \ c = 3\ 10^8; 
      h = 0.72; \[IndentingNewLine]f[z_] := 
        1/Sqrt[om*\((1 + z)\)^3\  + \((1 - 
                    om)\)*\((1 + z)\)^\((3 \((1 + w0\  + \ w1)\))\) 
                Exp[3\ w1\ \((\((1/\((1 + z)\))\) - 1)\)]]; \n
      dl[zz_] := c \((1 + zz)\)\ NIntegrate[f[z], {z, 0, zz}]/h0; \n
      dld = dl[zz[#]] 3\ 10^24 &; \nll = 4\ Pi\ dld[#]^2\ pbolo[#] &; \n
      sll = 4\ Pi\ dld[#]^2\ spbolo[#] &; \n
      eg = 4\ Pi\ dld[#]^2\ sbolo[#]\ fbeam[#]/\((1 + zz[#])\) &; 
      seg = Sqrt[\((ssbolo[#]/sbolo[#])\)^2\  + \ \((sfbeam[#]/fbeam[#])\)^2]/
            Log[10] &; \nzmin = 0; zmax = 7; \n
      Clear[egepeak, segepeak1, segepeak2, segepeak]; \negepeak = {}; 
      segepeak1 = {}; segepeak2 = {}; segepeak = {}; \n
      Do[\[IndentingNewLine]If[
          epeak[i] > 0\  && \ sbolo[i] > 0\  && \ 
            zz[i] \[GreaterEqual] zmin\  && \ 
            zz[i] \[LessEqual] \ zmax, \[IndentingNewLine]AppendTo[
            egepeak, {Log[10, epeak[i]], 
              Log[10, eg[i]]}]; \[IndentingNewLine]AppendTo[
            segepeak1, {sepeak1[i]/\((Log[10]\ epeak[i])\), 
              seg[i]}]; \[IndentingNewLine]AppendTo[
            segepeak2, {sepeak2[i]/\((Log[10]\ epeak[i])\), 
              seg[i]}]; \[IndentingNewLine]AppendTo[
            segepeak, {\((sepeak2[i] + 
                    sepeak1[i])\)/\((2\ Log[10]\ epeak[i])\), 
              seg[i]}]], \[IndentingNewLine]{i, 1, 
          ndat}]; \[IndentingNewLine]\[IndentingNewLine]egp[a1_, b1_, x_] := 
        a1\  + \ b1\ x; \[IndentingNewLine]epeakp[a1_, b1_, 
          x_] := \((x - a1)\)/b1; \[IndentingNewLine]\[IndentingNewLine]chi2[
          a1_, b1_, s1_] := 
        Sum[\((\((egepeak[\([i, 2]\)] - 
                      egp[a1, b1, 
                        egepeak[\([i, 1]\)]])\)^2/\((segepeak[\([i, 2]\)]^2 + 
                    s1^2)\))\), {i, 1, Length[segepeak]}] + 
          Sum[\((\((egepeak[\([i, 1]\)] - 
                      epeakp[a1, b1, 
                        egepeak[\([i, 2]\)]])\)^2/\((segepeak[\([i, 1]\)]^2 + 
                    s1^2)\))\), {i, 1, 
              Length[egepeak]}]; \[IndentingNewLine]\[IndentingNewLine]s1 = 
        0.17; \npar = {a1, b1}; \n
      akl[a1_, b1_, k_, l_] := 
        1/2  D[D[chi2[a1, b1, 0.5], par[\([k]\)]], par[\([l]\)]\ ]; \n
      fmingrb = FindMinimum[chi2\ [a1, b1, s1], {a1, 1}, {b1, \(-10\)}]; \n
      a1o = fmingrb[\([2, 1, 2]\)]; \nb1o = fmingrb[\([2, 2, 2]\)]; \n
      aklo = Table[
          If[k \[LessSlantEqual] l, \(akl[a1, b1, k, l] /. a1 \[Rule] a1o\) /. 
              b1 \[Rule] b1o, \(akl[a1, b1, l, k] /. a1 \[Rule] a1o\) /. 
              b1 \[Rule] b1o], {k, 1, 2}, {l, 1, 2}]; cij = Inverse[aklo]; 
      spar = Table[Sqrt[cij[\([i, i]\)]], {i, 1, 2}]; 
      Print["\<a1= \>", a1o, "\<+-\>", spar[\([1]\)], "\<  b1= \>", 
        b1o, "\<+-\>", spar[\([2]\)]]; 
      cij // MatrixForm; \[IndentingNewLine]erra1o = 
        spar[\([1]\)]; \[IndentingNewLine]errb1o = 
        spar[\([2]\)]; \[IndentingNewLine]ngrb = 
        Length[egepeak]; \[IndentingNewLine]chi2r = 
        Part[fmingrb, 
            1]/\((2\ Length[
                egepeak])\); \[IndentingNewLine]Print["\<chi2r=\>", 
        chi2r, "\<  ngrb=\>", ngrb, "\<  om=\>", 
        om]; \[IndentingNewLine]AppendTo[
        r1om, {om, chi2r}], \[IndentingNewLine]{q, 1, valsom}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.830252234232105`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08740639266640025`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.7208118831107124`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.20923271067235927`\),
      SequenceForm[ 
      "a1= ", 50.830252234232105, "+-", .087406392666400254, "  b1= ", 
        1.7208118831107124, "+-", .20923271067235927],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.241769209154778`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.01`\),
      SequenceForm[ 
      "chi2r=", 1.2417692091547781, "  ngrb=", 27, "  om=", .01],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.786883856676454`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08680335310598541`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.6762265167980575`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.20795032473921274`\),
      SequenceForm[ 
      "a1= ", 50.786883856676454, "+-", .086803353105985415, "  b1= ", 
        1.6762265167980575, "+-", .20795032473921274],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.130892273051068`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.03`\),
      SequenceForm[ 
      "chi2r=", 1.130892273051068, "  ngrb=", 27, 
        "  om=", .029999999999999999],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.75340364541982`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08644271782195796`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.6510400294155458`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.20707586993032576`\),
      SequenceForm[ 
      "a1= ", 50.753403645419823, "+-", .086442717821957962, "  b1= ", 
        1.6510400294155458, "+-", .20707586993032576],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0803888187901554`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.05`\),
      SequenceForm[ 
      "chi2r=", 1.0803888187901554, "  ngrb=", 27, 
        "  om=", .050000000000000003],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.72529370575502`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.0861782824827504`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.633220830931837`\[InvisibleSpace]"+-"\[InvisibleSpace]\
0.20636686684178493`\),
      SequenceForm[ 
      "a1= ", 50.725293705755021, "+-", .086178282482750404, "  b1= ", 
        1.633220830931837, "+-", .20636686684178493],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0528049531709351`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.07`\),
      SequenceForm[ 
      "chi2r=", 1.0528049531709351, "  ngrb=", 27, 
        "  om=", .070000000000000007],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.68948529817767`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.0858763994244684`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.61350729823865`\[InvisibleSpace]"+-"\[InvisibleSpace]\
0.20547956158298006`\),
      SequenceForm[ 
      "a1= ", 50.689485298177672, "+-", .085876399424468397, "  b1= ", 
        1.61350729823865, "+-", .20547956158298006],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0317849918135513`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.1`\),
      SequenceForm[ 
      "chi2r=", 1.0317849918135513, "  ngrb=", 27, 
        "  om=", .10000000000000001],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.65883636076351`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.0856417609424426`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5986230542094753`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.20472984756324766`\),
      SequenceForm[ 
      "a1= ", 50.658836360763509, "+-", .085641760942442594, "  b1= ", 
        1.5986230542094753, "+-", .20472984756324766],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0233018939232992`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.13`\),
      SequenceForm[ 
      "chi2r=", 1.0233018939232992, "  ngrb=", 27, "  om=", .13],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.640489367556846`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08550992613073308`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5904207225194096`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.20428513098982837`\),
      SequenceForm[ 
      "a1= ", 50.640489367556846, "+-", .085509926130733077, "  b1= ", 
        1.5904207225194096, "+-", .20428513098982837],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.021545771449188`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.15`\),
      SequenceForm[ 
      "chi2r=", 1.021545771449188, "  ngrb=", 27, 
        "  om=", .14999999999999999],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.63182699818132`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08544969057215783`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5867104277258128`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.20407628782115356`\),
      SequenceForm[ 
      "a1= ", 50.631826998181317, "+-", .08544969057215783, "  b1= ", 
        1.5867104277258128, "+-", .20407628782115356],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0214599109373492`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.16`\),
      SequenceForm[ 
      "chi2r=", 1.0214599109373492, "  ngrb=", 27, "  om=", .16],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.61538540923118`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08533865662326917`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5799313374500492`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.2036820198559227`\),
      SequenceForm[ 
      "a1= ", 50.61538540923118, "+-", .085338656623269171, "  b1= ", 
        1.5799313374500492, "+-", .20368201985592271],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0224727449531172`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.18`\),
      SequenceForm[ 
      "chi2r=", 1.0224727449531172, "  ngrb=", 27, 
        "  om=", .17999999999999999],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.607561077220886`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08528725845088961`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5768193140194111`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.2034954269963966`\),
      SequenceForm[ 
      "a1= ", 50.607561077220886, "+-", .085287258450889608, "  b1= ", 
        1.5768193140194111, "+-", .20349542699639661],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.023453466861121`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.19`\),
      SequenceForm[ "chi2r=", 1.023453466861121, "  ngrb=", 27, "  om=", .19],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.59997545243352`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08523827584520001`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.573868682916119`\[InvisibleSpace]"+-"\[InvisibleSpace]\
0.2033151985850114`\),
      SequenceForm[ 
      "a1= ", 50.599975452433519, "+-", .085238275845200009, "  b1= ", 
        1.573868682916119, "+-", .2033151985850114],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0246883043429116`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.2`\),
      SequenceForm[ 
      "chi2r=", 1.0246883043429116, "  ngrb=", 27, 
        "  om=", .20000000000000001],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.5854561569765`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.0851467558572469`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5683947779013772`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.20297217003025134`\),
      SequenceForm[ 
      "a1= ", 50.585456156976498, "+-", .085146755857246903, "  b1= ", 
        1.5683947779013772, "+-", .20297217003025134],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0277777594478836`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.22`\),
      SequenceForm[ 
      "chi2r=", 1.0277777594478836, "  ngrb=", 27, "  om=", .22],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.565108022457814`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08502318133698142`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5610831816220274`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.20249601175072807`\),
      SequenceForm[ 
      "a1= ", 50.565108022457814, "+-", .085023181336981418, "  b1= ", 
        1.5610831816220274, "+-", .20249601175072807],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0335590513763693`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.25`\),
      SequenceForm[ 
      "chi2r=", 1.0335590513763693, "  ngrb=", 27, "  om=", .25],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.53433290635214`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08484593098700274`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5507514973724408`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.20178700172569095`\),
      SequenceForm[ 
      "a1= ", 50.534332906352141, "+-", .084845930987002743, "  b1= ", 
        1.5507514973724408, "+-", .20178700172569095],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0450646907810297`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.3`\),
      SequenceForm[ 
      "chi2r=", 1.0450646907810297, "  ngrb=", 27, 
        "  om=", .29999999999999999],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.481532148952574`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08456624350128687`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5348098511610322`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.20060579431882627`\),
      SequenceForm[ 
      "a1= ", 50.481532148952574, "+-", .084566243501286872, "  b1= ", 
        1.5348098511610322, "+-", .20060579431882627],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0709075354401327`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.4`\),
      SequenceForm[ 
      "chi2r=", 1.0709075354401327, "  ngrb=", 27, 
        "  om=", .40000000000000002],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.43698234014932`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08435175409993788`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.522872854835656`\[InvisibleSpace]"+-"\[InvisibleSpace]\
0.19964780136238452`\),
      SequenceForm[ 
      "a1= ", 50.436982340149321, "+-", .084351754099937878, "  b1= ", 
        1.522872854835656, "+-", .19964780136238452],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0971573865586361`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.5`\),
      SequenceForm[ "chi2r=", 1.0971573865586361, "  ngrb=", 27, "  om=", .5],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.39825808036711`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08417971360186972`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5134731395556582`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.19884619274776208`\),
      SequenceForm[ 
      "a1= ", 50.398258080367107, "+-", .084179713601869724, "  b1= ", 
        1.5134731395556582, "+-", .19884619274776208],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.1223394489514815`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.6`\),
      SequenceForm[ 
      "chi2r=", 1.1223394489514815, "  ngrb=", 27, 
        "  om=", .59999999999999998],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.36389995676645`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08403740107808251`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.505812376453201`\[InvisibleSpace]"+-"\[InvisibleSpace]\
0.19816029639364086`\),
      SequenceForm[ 
      "a1= ", 50.363899956766453, "+-", .08403740107808251, "  b1= ", 
        1.505812376453201, "+-", .19816029639364086],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.1460332620524385`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.7`\),
      SequenceForm[ 
      "chi2r=", 1.1460332620524385, "  ngrb=", 27, 
        "  om=", .69999999999999996],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.3329529823156`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08391697929798217`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.499409598069241`\[InvisibleSpace]"+-"\[InvisibleSpace]\
0.19756339467780243`\),
      SequenceForm[ 
      "a1= ", 50.332952982315597, "+-", .083916979297982169, "  b1= ", 
        1.499409598069241, "+-", .19756339467780243],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.1681787969310207`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.8`\),
      SequenceForm[ 
      "chi2r=", 1.1681787969310207, "  ngrb=", 27, 
        "  om=", .80000000000000004],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.30475419231256`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08381328347823853`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.493953734240891`\[InvisibleSpace]"+-"\[InvisibleSpace]\
0.19703696236559065`\),
      SequenceForm[ 
      "a1= ", 50.304754192312558, "+-", .083813283478238534, "  b1= ", 
        1.4939537342408911, "+-", .19703696236559065],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.1888452627378576`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]0.9`\),
      SequenceForm[ 
      "chi2r=", 1.1888452627378576, "  ngrb=", 27, 
        "  om=", .90000000000000002],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]50.27882258268629`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.08372273596943136`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.4892327411268143`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.19656762064302993`\),
      SequenceForm[ 
      "a1= ", 50.278822582686288, "+-", .083722735969431361, "  b1= ", 
        1.4892327411268143, "+-", .19656762064302993],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.208144888704265`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\[InvisibleSpace]"  om="\
\[InvisibleSpace]1\),
      SequenceForm[ "chi2r=", 1.208144888704265, "  ngrb=", 27, "  om=", 1],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[r1om, Frame \[Rule] True, Axes \[Rule] False, 
      PlotJoined \[Rule] True]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -2.71434 2.67172 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -14.5625 -24.5625 ]
[.21429 -0.0125 14.5625 0 ]
[.40476 -0.0125 -14.5625 -24.5625 ]
[.40476 -0.0125 14.5625 0 ]
[.59524 -0.0125 -14.5625 -24.5625 ]
[.59524 -0.0125 14.5625 0 ]
[.78571 -0.0125 -14.5625 -24.5625 ]
[.78571 -0.0125 14.5625 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09097 -39.1875 -12.2813 ]
[-0.0125 .09097 0 12.2813 ]
[-0.0125 .22455 -29.125 -12.2813 ]
[-0.0125 .22455 0 12.2813 ]
[-0.0125 .35814 -39.1875 -12.2813 ]
[-0.0125 .35814 0 12.2813 ]
[-0.0125 .49172 -29.125 -12.2813 ]
[-0.0125 .49172 0 12.2813 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09097 m
.00625 .09097 L
s
gsave
-0.0125 .09097 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
1.000 setlinewidth
grestore
0 .22455 m
.00625 .22455 L
s
gsave
-0.0125 .22455 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
0 .35814 m
.00625 .35814 L
s
gsave
-0.0125 .35814 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
1.000 setlinewidth
grestore
0 .49172 m
.00625 .49172 L
s
gsave
-0.0125 .49172 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11768 m
.00375 .11768 L
s
0 .1444 m
.00375 .1444 L
s
0 .17112 m
.00375 .17112 L
s
0 .19783 m
.00375 .19783 L
s
0 .25127 m
.00375 .25127 L
s
0 .27799 m
.00375 .27799 L
s
0 .3047 m
.00375 .3047 L
s
0 .33142 m
.00375 .33142 L
s
0 .38485 m
.00375 .38485 L
s
0 .41157 m
.00375 .41157 L
s
0 .43829 m
.00375 .43829 L
s
0 .46501 m
.00375 .46501 L
s
0 .06425 m
.00375 .06425 L
s
0 .03753 m
.00375 .03753 L
s
0 .01081 m
.00375 .01081 L
s
0 .51844 m
.00375 .51844 L
s
0 .54516 m
.00375 .54516 L
s
0 .57187 m
.00375 .57187 L
s
0 .59859 m
.00375 .59859 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09097 m
1 .09097 L
s
.99375 .22455 m
1 .22455 L
s
.99375 .35814 m
1 .35814 L
s
.99375 .49172 m
1 .49172 L
s
.125 Mabswid
.99625 .11768 m
1 .11768 L
s
.99625 .1444 m
1 .1444 L
s
.99625 .17112 m
1 .17112 L
s
.99625 .19783 m
1 .19783 L
s
.99625 .25127 m
1 .25127 L
s
.99625 .27799 m
1 .27799 L
s
.99625 .3047 m
1 .3047 L
s
.99625 .33142 m
1 .33142 L
s
.99625 .38485 m
1 .38485 L
s
.99625 .41157 m
1 .41157 L
s
.99625 .43829 m
1 .43829 L
s
.99625 .46501 m
1 .46501 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .03753 m
1 .03753 L
s
.99625 .01081 m
1 .01081 L
s
.99625 .51844 m
1 .51844 L
s
.99625 .54516 m
1 .54516 L
s
.99625 .57187 m
1 .57187 L
s
.99625 .59859 m
1 .59859 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .60332 m
.05238 .30709 L
.07143 .17216 L
.09048 .09846 L
.11905 .0423 L
.14762 .01964 L
.16667 .01494 L
.17619 .01472 L
.19524 .01742 L
.20476 .02004 L
.21429 .02334 L
.23333 .03159 L
.2619 .04704 L
.30952 .07778 L
.40476 .14683 L
.5 .21696 L
.59524 .28424 L
.69048 .34754 L
.78571 .40671 L
.88095 .46192 L
.97619 .51348 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{513.625, 317.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000810001?B000`400?l00000o`00003oo`3ooooo
0?ooo`<0oooo003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0oooo
003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0oooo000h0?ooo`04
0;md00000000000004RLgd`0oooo00@0_g@0000000000000B9cO103oool01@3OW4P0000004RLg`3o
ool0gia800L0000000<0M;oo0?ooo`3oool0@P3oool0102oM000000000000018W=l40?ooo`030=nL
B0000000B9cO00H0oooo00<0okmd0000001d_ol0A03oool0102oM000000000000018W=l40?ooo`03
0=nLB0000000B9cO00<0oooo00H0oooO09a80000000000000000M02ooom40?ooo`040;md00000000
000004RLg`@0oooo00<0gia800000018W=l00`3oool01P3ogi`0B000000000000000001809cOod/0
oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`090?ooo`00=P3oool01`3ooml0W4P0
001d_`3oool0oooO09a80000M;l0B@3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3o
ool00`3OW4P0000004RLg`020?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool0@03o
ool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`060?ooo`03
0?noM0000000M;oo0480oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia8
00000018W=l00P3oool0203ookl0M0000018W03Oool0oooo0=nLB00004P0W=oo@@3oool01`3ooml0
W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`080?oOW0180000
04RL0=ooo`3oool0omnL04P0001d_om<0?ooo`030;md000007@0_ooo00`0oooo000f0?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol0B03oool00`3o_g@0001809cOo`020?ooo`030?oO
W0180000M;oo00P0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`110?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol02`3oool00`3o_g@0000007Boo`120?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`2oM000001d0;ooo`030?ooo`030;md
0000M;l0oooo0400oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030;md
000007@0_ooo00<0oooo00<0gia80018W03Oool0B`3oool00`2oM000001d0;ooo`0<0?ooo`00=@3o
ool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo04L0oooo00@0oooO09a80000B9`0
gooo0P3oool00`3ooml0W4P0001d_`090?ooo`030=nLB018W=l0oooo04@0oooo00@0oooO09a80000
B9`0gooo0P3oool00`3ooml0W4P0001d_`060?ooo`030=nLB0000000000000D0000000<0001809cO
o`3oool0?P3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00H0oooo00<0oono
07@00000M;l0103oool00`3OW4P0001d0;ooo`0o0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
oooO09a80000M;l01`3oool00`2oM000001d0;ooo`030?ooo`030;md0000B9`0gooo04/0oooo00<0
_g@00000M02oool0303oool003D0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`16
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02@3oool00`3OW4P0M;oo0?ooo`13
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01@3oool00`3ogi`0B7Bo0?ooo`02
0?ooo`030?noM0000000M;oo0440oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`05
0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000B02Lgol0?`3oool00`3ookl0M000001d_`04
0?ooo`030;md000007@0_ooo00H0oooo00<0okmd0000B02Lgol00P3oool00`3OW4P00000001d_`1<
0?ooo`030;md000007@0_ooo00`0oooo000e0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000
M02oool0AP3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00T0oooo00<0oooO09a8
B02Lgol0@`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00H0oooo00L0gia807Bo
o`3oool0oooo0?noM0000000M;oo0440oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;oo
o`050?ooo`030?oOW0180000B9cO00<0oooo00@0oono07@0000007@0_ooo?`3oool00`3ogi`0B000
04RLg`040?ooo`030;md000007@0_ooo00L0oooo00L0gia8001d_`3oool0_g@00000000007@0_ooo
04`0oooo00<0_g@00000M02oool0303oool003D0oooo00<0omnL04P00018W=l0103oool00`3OW4P0
001809cOo`160?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol02P3oool00`3ogi`0
B01d0;ooo`120?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01P3oool01`3ookl0
M01d0;ooo`3oool0okmd0000001d_ol0@@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0
W=oo00D0oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l0@03oool00`3ogi`0
B00004RLg`040?ooo`030=nLB00004P0W=oo00P0oooo00D0okmd00000000000004RL0=ooo`1=0?oo
o`030;md000007@0_ooo00`0oooo000e0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02L
gol0AP3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00/0oooo00<0_g@004RLg`3o
ool0@@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0oooo00H0okmd001d_`3o
ool0okmd0000001d_om10?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01@3oool0
1@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool0?`3oool00`3ogi`0B00004RL
g`040?ooo`030=nLB00004P0W=oo00L0oooo00D0omnL04P000000000000004RLg`1>0?ooo`030;md
000007@0_ooo00`0oooo000e0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0AP3o
ool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0gia80000M02oool0@@3o
ool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00P0oooo00D0_g@007Boo`3o_g@00000
07Boo`110?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@00000
04RLg`150?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool01`3ogi`0B000
0000B02Lgol0oooo0=nLB000M;l0C@3oool00`2oM000001d0;ooo`0<0?ooo`00=P3oool00`2oM000
04RL0=ooo`020?ooo`030?oog`2LB00007Bo04P0oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`0<0?ooo`030?noM0000000M;oo0480oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`090?ooo`050?oo_`1d07@0_kmd0000001d_ol0@P3oool00`2oM00004RL0=ooo`020?oo
o`030?oog`2LB00007Bo00L0oooo00@0oooO09a8000004P0W=ooA@3oool00`2oM00004RL0=ooo`02
0?ooo`030?oog`2LB00007Bo00L0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P007Boo`1<
0?ooo`030;md000007@0_ooo00`0oooo000f0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0
001d_ol0B03oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00H0oooo00<0omnL09bo
o`3oool00`3oool00`2oM000000007Boo`120?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0
001d_ol02P3oool0103o_g@000000000001d_om20?ooo`030?noM00004P0W=oo0080oooo00<0omnL
04P0001d_ol0203oool0103ookl0M0000000M02ooom40?ooo`030?noM00004P0W=oo0080oooo00<0
omnL04P0001d_ol01`3oool00`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO04`0oooo00<0
_g@00000M02oool0303oool003L0oooo00H0_g@00018W03Oool0oooo0;md0000M;m:0?ooo`060;md
0000B9`0gooo0?ooo`2oM00007Bo203oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo
@`3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`/0oooo00@0oooO09a800000000M;oo@`3oool0
1P2oM00004RL0=ooo`3oool0_g@0001d_`X0oooo00@0oooO09a80000000007BoA03oool01P2oM000
04RL0=ooo`3oool0_g@0001d_`P0oooo00<0omnL04P00018W=l00P3oool00`3o_g@0001809cOo`1:
0?ooo`050=nLB000000000000000M02oool0303oool003P0oooo00@0_g@000000000000007BoC03o
ool0102oM000000000000000M;l:0?ooo`050;md00000000000000000000M;l0AP3oool0102oM000
000000000000M;l=0?ooo`030?oOW0180000M;oo04@0oooo00@0_g@000000000000007Bo3@3oool0
1@3ogi`0B00000000000B9`0gooo0480oooo00@0_g@000000000000007Bo2P3oool01P3ookl0M000
000000000000001809cOod`0oooo00@0oono07@0000007@0_ooo303oool00?l0ooooo`3oool30?oo
o`00o`3ooooo0?ooo`<0oooo003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo
0?ooo`<0oooo003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0oooo
003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00;`3ooooo00000=4000000P3oool002l0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0203oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
203oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0203oool100000040oooo0@3o
ool002l0oooo00<000000?ooo`3oool0o`3oooo=0?ooo`4000000@3oool10?ooo`00;`3oool30000
0?l0oooob`3oool300000080oooo000_0?ooo`030000003oool0oooo0?l0ooooc@3oool100000040
oooo0@3oool002l0oooo00<000000?ooo`3oool0B@3oool:00000?l0ooooNP3oool100000040oooo
0@3oool002l0oooo00<000000?ooo`3oool0AP3oool3000000X0oooo1P00003o0?ooog@0oooo0@00
00010?ooo`40oooo000_0?ooo`030000003oool0oooo04<0oooo0`00000C0?ooo`800000o`3ooomb
0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`110?ooo`800000603oool30000
0?l0ooooK`3oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0K0?ooo`@00000o`3ooom[0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo
0?ooo`0n0?ooo`8000008P3oool200000?l0ooooJ@3oool100000040oooo0@3oool002l0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`0T0?ooo`800000o`3ooomW0?ooo`4000000@3o
ool10?ooo`00;`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02L0oooo0P00003o
0?ooofD0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo03X0oooo0P00000/0?oo
o`800000o`3ooomS0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo02h0oooo0P00003o0?ooof40oooo0@0000010?ooo`40oooo000_0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0<@3oool200000?l0ooooG`3oool100000040oooo
0@3oool002l0oooo0`00000f0?ooo`800000=P3oool200000?l0ooooF`3oool300000080oooo000_
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0>03oool200000?l0ooooF`3oool1
00000040oooo0@3oool002l0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0k0?oo
o`800000o`3ooomI0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo03h0oooo0P00003o0?oooeL0oooo0@0000010?ooo`40oooo000_0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`3o0?oooe@0oooo
0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0@P3o
ool200000?l0ooooE03oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0ooooD@3oool100000040oooo0@3oool0
02l0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`160?ooo`800000o`3ooomA0?oo
o`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo04P0
oooo0P00003o0?ooodl0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?oood`0oooo0@0000010?ooo`40oooo
000_0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0C03oool200000?l0ooooC03o
ool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0?l0ooooB@3oool100000040oooo0@3oool002l0oooo0`00000_0?oo
o`030000003oool0oooo0500oooo0P00003o0?ooodL0oooo0`0000020?ooo`00;`3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0o`3ooom60?ooo`40
00000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05@0oooo
0P00003o0?ooodH0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0E`3oool200000?l0ooooA03oool100000040oooo0@3oool002l0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0oooo@@3oool1
00000040oooo0@3oool002l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1K0?oo
o`800000o`3ooom10?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oooln0?ooo`4000000@3oool10?ooo`00
1P3oool00`3o_g@000000000000200000007001d_`3oool0oooo0?ooo`3OW4P0000004RLg`040?oo
o`040;md00000000000004RLg`@0oooo00H0_g@000000000000000000018W03Oool;0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0G`3oool200000?l0oooo?P3oool100000040oooo
0@3oool000P0oooo00<0_g@00000M02oool0103oool00`3OW4P0000004RLg`020?ooo`070?oog`2L
B00007Bo0?ooo`3ooml0W4P0001d_`020?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8W03O
ool02P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3o
ool0o`3ooolk0?ooo`4000000@3oool10?ooo`00203oool00`2oM000001d0;ooo`090?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`3ogi`0B7Bo0?ooo`090?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`3o0?ooocX0oooo
0@0000010?ooo`40oooo00080?ooo`030;md000007@0_ooo00P0oooo00@0oooO09a80000B9`0gooo
0P3oool00`3ooml0W4P0001d_`070?ooo`030?oo_`1d04P0W=oo00T0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`1T0?ooo`800000o`3ooolj0?ooo`4000000@3oool10?ooo`00203o
ool00`2oM000001d0;ooo`080?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3o
ool00`3ookl0M00007Boo`090?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`3o0?ooocL0oooo0@0000010?ooo`40oooo00080?ooo`030;md000007@0
_ooo00P0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`060?ooo`030?noM0000000
M;oo00T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0
oooo0?l0oooo=P3oool100000040oooo0@3oool000P0oooo00<0_g@00000M02oool0203oool00`3o
gi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00D0oooo00@0omnL04P0000007@0_ooo2@3oool4
000002L0oooo00<000000?ooo`3oool0JP3oool200000?l0oooo<`3oool400000080oooo00080?oo
o`030;md000007@0_ooo00P0oooo00<0omnL04P00018W=l0103oool01@3OW4P0001809cOo`3oool0
gmoO0080oooo00@0_g@0000000000000B9cO2P3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`4000000@3oool10?ooo`00203oool0
0`2oM000001d0;ooo`080?ooo`030?oo_`1d000007Bo00@0oooo00D0_g@00000M02oool0oooo0?no
M00400000003001d_`3oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`1^0?ooo`800000o`3ooolc0?ooo`4000000@3oool10?ooo`00203oool00`2oM000001d0;ooo`09
0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l00P3oool01@3ooml0W4P000000000
07@0_ooo00`0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo0?l0oooo<03oool100000040oooo0@3oool000P0oooo00<0_g@00000M02oool02@3oool0
0`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00<0oooo00<0okmd001d_`3oool03@3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0o`3oool_
0?ooo`4000000@3oool10?ooo`001P3oool01@3OW4P000000000000007@0_ooo00X0oooo00H0_g@0
0018W03Oool0oooo0;md0000M;l40?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool0
203oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo07<0oooo0P00003o0?ooobl0oooo
0@0000010?ooo`40oooo00070?ooo`040?oo_`1d0000001d0;ooo`/0oooo00@0_g@0000000000000
07Bo1P3oool00`3o_g@00000000000020000000307Boo`3oool0oooo00L0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0?l0oooo;03oool100000040
oooo0@3oool002l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo0?l0oooo:`3oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`1g0?ooo`800000o`3oool[0?ooo`4000000@3oool10?ooo`00;`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0o`3ooolX
0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
07/0oooo0P00003o0?ooobP0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`3o0?ooobD0oooo0@0000010?ooo`40
oooo000_0?ooo`<000009@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0?l0oooo
8P3oool300000080oooo000_0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0P03o
ool200000?l0oooo903oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`220?ooo`030000003oool0oooo0?l0oooo8@3oool100000040oooo0@3oool0
02l0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo
0?l0oooo803oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`240?ooo`800000o`3ooolP0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`400000
0@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo08P0oooo0P00
003o0?oooad0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?oooaX0oooo0@0000010?ooo`40oooo000_0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3o0?oo
oaT0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0S@3oool200000?l0oooo6@3oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0?l0oooo5P3oool100000040oooo
0@3oool002l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo0?l0oooo5@3oool100000040oooo0@3oool002l0oooo0`00000Q0?ooo`030000003oool0
oooo0980oooo0P00003o0?oooa<0oooo0`0000020?ooo`00;`3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo09@0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`4000000@3oool10?oo
o`00;`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3o
ool0o`3ooolA0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo09H0oooo0P00003o0?oooa40oooo0@0000010?ooo`40oooo000_0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`3o0?ooo`h0oooo0@00
00010?ooo`40oooo000_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0VP3oool0
0`000000oooo0?ooo`3o0?ooo`d0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0V`3oool200000?l0oooo3@3oool100000040oooo0@3oool002l0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0?l0
oooo2P3oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo0?l0oooo2@3oool100000040oooo0@3oool002l0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`2P0?ooo`800000o`3oool90?ooo`4000000@3o
ool10?ooo`00;`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0:80oooo00<00000
0?ooo`3oool0o`3oool60?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0o`3oool50?ooo`4000000@3oool10?oo
o`00;`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0:D0oooo0P00003o0?ooo`D0
oooo0@0000010?ooo`40oooo000_0?ooo`<000007P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0?l0oooo0`0000020?ooo`00;`3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3oool10?ooo`00;`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0:T0oooo0P00003o0?ooo`40oooo0@000001
0?ooo`40oooo000_0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0Z`3oool00`00
0000oooo0?ooo`3m0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0:d0oooo00<000000?ooo`3oool0o03oool100000040oooo0@3oool002l0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`2^0?ooo`800000o03oool100000040oooo
0@3oool002l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo0?T0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0/@3oool00`000000oooo0?ooo`3h0?ooo`4000000@3oool10?ooo`00;`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0;80oooo0P00003h0?ooo`4000000@3oool10?oo
o`00;`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3o
ool0m@3oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`2e0?ooo`030000003oool0oooo0?@0oooo0@0000010?ooo`40oooo000_0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0]`3oool200000?@0oooo0@0000010?ooo`40oooo000_
0?ooo`<00000703oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo0>l0oooo0`000002
0?ooo`00;`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0;X0oooo00<000000?oo
o`3oool0l03oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`2k0?ooo`800000l03oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0>d0oooo0@0000010?ooo`40oooo
000_0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?oo
o`3/0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0;l0oooo0P00003/0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0<80oooo00<000000?ooo`3oool0j@3oool100000040oooo0@3oool00100
oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3oool0gia800000018W=l00`3oool0
0`3o_g@000000000000200000003001d_`3oool0oooo00P0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`330?ooo`030000003oool0oooo0>P0oooo0@0000010?ooo`40oooo000B0?oo
o`030;md000007@0_ooo00@0oooo00<0gia800000018W=l01@3oool00`2oM000001d0;ooo`0;0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0a03oool200000>P0oooo0@0000010?oo
o`40oooo000B0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool02`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0i@3oool100000040
oooo0@3oool00180oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`0;0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0a`3oool200000>D0oooo0@0000010?ooo`40oooo
000B0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool02`3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0hP3oool100000040oooo0@3o
ool00180oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`0;0?ooo`@000006P3oool0
0`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0=h0oooo100000020?ooo`004P3oool00`2o
M000001d0;ooo`0<0?ooo`030;md000007@0_ooo00/0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`3<0?ooo`800000h@3oool100000040oooo0@3oool00180oooo00<0_g@00000M02o
ool0303oool00`2oM000001d0;ooo`0;0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`3N0?ooo`4000000@3oool10?ooo`004P3oool00`2oM000001d
0;ooo`0<0?ooo`030;md000007@0_ooo00/0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`3?0?ooo`800000gP3oool100000040oooo0@3oool00180oooo00<0_g@00000M02oool0303o
ool00`2oM000001d0;ooo`0;0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0d@3o
ool00`000000oooo0?ooo`3K0?ooo`4000000@3oool10?ooo`004P3oool00`2oM000001d0;ooo`0<
0?ooo`030;md000007@0_ooo00/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3B
0?ooo`800000f`3oool100000040oooo0@3oool00100oooo00D0gia8000000000000001d0;ooo`0:
0?ooo`050=nLB000000000000000M02oool02`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo0=@0oooo00<000000?ooo`3oool0f03oool100000040oooo0@3oool00140oooo00@0oono
07@0000007@0_ooo2`3oool0103ookl0M0000000M02oool;0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`3G0?ooo`4000000@3oool10?ooo`00;`3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0=L0oooo0P00003G0?ooo`4000000@3o
ool10?ooo`00;`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0=T0oooo00<00000
0?ooo`3oool0e03oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`3J0?ooo`800000e03oool100000040oooo0@3oool002l0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo0=40oooo0@0000010?ooo`40
oooo000_0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0g@3oool00`000000oooo
0?ooo`3@0?ooo`4000000@3oool10?ooo`00;`3oool3000001T0oooo00<000000?ooo`3oool0gP3o
ool200000<h0oooo0`0000020?ooo`00;`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0>00oooo00<000000?ooo`3oool0c@3oool100000040oooo0@3oool002l0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`3R0?ooo`800000c@3oool100000040oooo0@3oool002l0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo0<X0
oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
i@3oool200000<X0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0i`3oool00`000000oooo0?ooo`370?ooo`4000000@3oool10?ooo`00;`3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0>P0oooo00<000000?ooo`3oool0aP3oool1
00000040oooo0@3oool002l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3Y0?oo
o`800000aP3oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`3[0?ooo`030000003oool0oooo0<<0oooo0@0000010?ooo`40oooo000_0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0k@3oool200000<<0oooo0@0000010?ooo`40oooo
000_0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?oo
o`300?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0?00oooo0P0000300?ooo`4000000@3oool10?ooo`00;`3oool3000001L0oooo00<000000?oo
o`3oool0lP3oool00`000000oooo0?ooo`2k0?ooo`<000000P3oool002l0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo0;`0oooo0@0000010?ooo`40
oooo000_0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0m03oool200000;`0oooo
0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0mP3o
ool00`000000oooo0?ooo`2i0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0?P0oooo0P00002i0?ooo`4000000@3oool10?ooo`00;`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0?X0oooo00<000000?ooo`3oool0]P3oool10000
0040oooo0@3oool002l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3k0?ooo`80
0000]P3oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`3m0?ooo`030000003oool0oooo0;<0oooo0@0000010?ooo`40oooo000_0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0oP3oool200000;<0oooo0@0000010?ooo`40oooo000_
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003oool0
oooo0;00oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0o`3oool20?ooo`800000/03oool100000040oooo0@3oool002l0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool0[@3oool100000040
oooo0@3oool002l0oooo0`00000E0?ooo`030000003oool0oooo0?l0oooo1P3oool200000:/0oooo
0`0000020?ooo`00;`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0oooo203o
ool00`000000oooo0?ooo`2Z0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0?l0oooo2@3oool200000:X0oooo0@0000010?ooo`40oooo000_0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo
0:L0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0o`3oool<0?ooo`800000Y`3oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3oool0Y03oool100000040oooo
0@3oool002l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo0P00
002T0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0?l0oooo4@3oool200000:80oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`030000003oool0oooo09l0oooo0@0000010?oo
o`40oooo000_0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`80
0000W`3oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`3o0?oooaL0oooo00<000000?ooo`3oool0W03oool100000040oooo0@3oool002l0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?oooaP0oooo0P00002L0?ooo`4000000@3o
ool10?ooo`00;`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo6P3oool0
0`000000oooo0?ooo`2I0?ooo`4000000@3oool10?ooo`00;`3oool3000001@0oooo00<000000?oo
o`3oool0o`3ooolK0?ooo`800000U`3oool300000080oooo000_0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0o`3ooolM0?ooo`030000003oool0oooo09H0oooo0@0000010?ooo`40
oooo000_0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`800000
UP3oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`3o0?ooob00oooo00<000000?ooo`3oool0T`3oool100000040oooo0@3oool002l0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooob40oooo0P00002C0?ooo`4000000@3oool1
0?ooo`00;`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo8`3oool00`00
0000oooo0?ooo`2@0?ooo`4000000@3oool10?ooo`001P3oool00`3o_g@000000000000200000007
001d_`3oool0oooo0?ooo`3OW4P0000004RLg`030?ooo`030?noM000000000000080000000D007Bo
0?ooo`3oool0oooo0;md0003000000030018W03Oool0oooo00X0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`3o0?ooob@0oooo0P00002@0?ooo`4000000@3oool10?ooo`00203oool0
0`2oM000001d0;ooo`040?ooo`030=nLB0000000B9cO00D0oooo00<0_g@00000M02oool00`3oool0
0`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00X0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool0S@3oool100000040oooo0@3oool0
00P0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`090?ooo`030?oOW018M;l0oooo
00T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooobL0oooo0P00002=0?oo
o`4000000@3oool10?ooo`00203oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00T0
oooo00<0oono07@0B02Lgol02@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0
oooo:@3oool00`000000oooo0?ooo`2:0?ooo`4000000@3oool10?ooo`00203oool00`2oM000001d
0;ooo`0<0?ooo`030;md000007@0_ooo00T0oooo00<0oono07@0001d_ol02@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo:P3oool2000008X0oooo0@0000010?ooo`40oooo
00080?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool02@3oool00`3o_g@0000007Bo
o`090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3oool/0?ooo`800000R03o
ool100000040oooo0@3oool000P0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`08
0?ooo`040?oOW0180000001d0;ooo`T0oooo1000000B0?ooo`030000003oool0oooo0?l0oooo;`3o
ool00`000000oooo0?ooo`220?ooo`@000000P3oool000P0oooo00<0_g@00000M02oool0303oool0
0`2oM000001d0;ooo`040?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool0203o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo<03oool2000008D0oooo0@00
00010?ooo`40oooo00080?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0103oool0
0`3o_g@000000000000200000003001d_`3oool0oooo00T0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`3o0?oooc80oooo00<000000?ooo`3oool0PP3oool100000040oooo0@3oool0
00P0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`040?ooo`050?oog`2LB0000000
0000M02oool0303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo<`3oool2
00000880oooo0@0000010?ooo`40oooo00080?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000
M02oool01@3oool00`3o_g@007Bo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0o`3ooole0?ooo`030000003oool0oooo07l0oooo0@0000010?ooo`40oooo00060?ooo`05
0=nLB000000000000000M02oool02P3oool01@3OW4P000000000000007@0_ooo00D0oooo00<0oooO
09a8000000000P0000000`0007@0_ooo0?ooo`080?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0o`3ooolf0?ooo`800000O`3oool100000040oooo0@3oool000L0oooo00@0oono07@0
000007@0_ooo2`3oool0103ookl0M0000000M02oool60?ooo`030?noM000000000000080000000<0
M;oo0?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo>03o
ool2000007d0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0o`3ooolj0?ooo`030000003oool0oooo07X0oooo0@0000010?ooo`40oooo000_0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`800000NP3oool10000
0040oooo0@3oool002l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooocd0
oooo00<000000?ooo`3oool0M`3oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`3o0?oooch0oooo0P00001g0?ooo`4000000@3oool10?ooo`00;`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo@03oool00`000000oooo0?oo
o`1d0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0?l0oooo@@3oool2000007@0oooo0@0000010?ooo`40oooo000_0?ooo`<000004`3oool00`00
0000oooo0?ooo`3o0?oood<0oooo0P00001`0?ooo`<000000P3oool002l0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`3o0?ooodD0oooo00<000000?ooo`3oool0K`3oool100000040
oooo0@3oool002l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooodH0oooo
0P00001_0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`1/0?ooo`4000000@3oool10?ooo`00;`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooBP3oool2000006`0oooo0@000001
0?ooo`40oooo000_0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3ooom<0?oo
o`030000003oool0oooo06T0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0o`3ooom=0?ooo`800000J@3oool100000040oooo0@3oool002l0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?ooodl0oooo0P00001W0?ooo`400000
0@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooD@3o
ool00`000000oooo0?ooo`1T0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0?l0ooooDP3oool2000006@0oooo0@0000010?ooo`40oooo000_0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo
0640oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0o`3ooomE0?ooo`800000H@3oool100000040oooo0@3oool002l0oooo0`00000B0?ooo`030000
003oool0oooo0?l0ooooE`3oool2000005d0oooo0`0000020?ooo`00;`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0?l0ooooF@3oool2000005d0oooo0@0000010?ooo`40oooo000_
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3ooomK0?ooo`800000F`3oool1
00000040oooo0@3oool002l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?oo
oed0oooo00<000000?ooo`3oool0F03oool100000040oooo0@3oool002l0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`3o0?oooeh0oooo0P00001H0?ooo`4000000@3oool10?ooo`00
;`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooH03oool2000005H0oooo
0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3o
oomS0?ooo`800000E03oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`3o0?ooofD0oooo0P00001B0?ooo`4000000@3oool10?ooo`00;`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`1?0?oo
o`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0
ooooJ03oool2000004l0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0o`3ooomZ0?ooo`800000C@3oool100000040oooo0@3oool002l0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooof`0oooo0P00001;0?ooo`4000000@3o
ool10?ooo`00;`3oool300000140oooo00<000000?ooo`3oool0o`3ooom^0?ooo`800000A`3oool3
00000080oooo000_0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooom`0?oo
o`030000003oool0oooo04H0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0o`3oooma0?ooo`800000AP3oool100000040oooo0@3oool002l0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooog<0oooo0P0000140?ooo`400000
0@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooM@3o
ool200000480oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0o`3ooomg0?ooo`800000@03oool100000040oooo0@3oool002l0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`3o0?ooogT0oooo00<000000?ooo`3oool0?@3oool10000
0040oooo0@3oool002l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooogX0
oooo0P00000m0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0?l0ooooO03oool2000003/0oooo0@0000010?ooo`40oooo000_0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0o`3ooomo0?ooo`800000>@3oool100000040oooo0@3o
ool002l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oooh40oooo0P00000g
0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0?l0ooooP`3oool00`000000oooo0?ooo`0d0?ooo`4000000@3oool10?ooo`00;`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooQ03oool2000003@0oooo0@0000010?ooo`40
oooo000_0?ooo`<00000403oool00`000000oooo0?ooo`3o0?ooohH0oooo0P00000`0?ooo`<00000
0P3oool002l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooohP0oooo0P00
000`0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0?l0ooooRP3oool2000002h0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0o`3ooon<0?ooo`800000;03oool100000040oooo0@3oool002l0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooohh0oooo00<000000?ooo`3o
ool0:@3oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`3o0?ooohl0oooo0P00000Y0?ooo`4000000@3oool10?ooo`00403oool00`3o_g@000000000
000200000009001d_`3oool0oooo0?ooo`3OW4P0000004RLg`3oool0gia800L0000000<0M;oo0?oo
o`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooT@3oool20000
02L0oooo0@0000010?ooo`40oooo000B0?ooo`030;md000007@0_ooo00@0oooo00<0gia800000018
W=l00P3oool00`3OW4P000000000000400000003001d_`3oool0oooo00L0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`3o0?oooi<0oooo0P00000U0?ooo`4000000@3oool10?ooo`00
4P3oool00`2oM000001d0;ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool0
203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooU@3oool2000002<0oooo
0@0000010?ooo`40oooo000B0?ooo`030;md000007@0_ooo00/0oooo00<0gia804RLg`3oool0303o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooU`3oool200000240oooo0@00
00010?ooo`40oooo000B0?ooo`030;md000007@0_ooo00`0oooo00<0gia807Boo`3oool02`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooV@3oool00`000000oooo0?ooo`0N
0?ooo`4000000@3oool10?ooo`004P3oool00`2oM000001d0;ooo`0<0?ooo`030?oog`2LB4P0W=oo
00/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oooi/0oooo0P00000N0?oo
o`4000000@3oool10?ooo`004P3oool00`2oM000001d0;ooo`0=0?ooo`030?oOW01807@0_ooo00X0
oooo1000000>0?ooo`030000003oool0oooo0?l0ooooW@3oool2000001T0oooo100000020?ooo`00
4P3oool00`2oM000001d0;ooo`0>0?ooo`030;md0018W=l0oooo00T0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`3o0?oooil0oooo0P00000J0?ooo`4000000@3oool10?ooo`004P3o
ool00`2oM000001d0;ooo`0>0?ooo`030=nLB00007@0_ooo00T0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`3o0?oooj40oooo0P00000H0?ooo`4000000@3oool10?ooo`004P3oool0
0`2oM000001d0;ooo`0>0?ooo`030?noM0000000M;oo00T0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`3o0?oooj<0oooo0P00000F0?ooo`4000000@3oool10?ooo`004P3oool00`2o
M000001d0;ooo`080?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol02@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooY@3oool00`000000oooo0?ooo`0C0?oo
o`4000000@3oool10?ooo`00403oool01@3OW4P000000000000007@0_ooo00T0oooo00P0_g@007Bo
o`3oool0oooo0=nLB000000004RL0=ooo`T0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`3o0?ooojH0oooo0P00000C0?ooo`4000000@3oool10?ooo`004@3oool0103ookl0M0000000
M02oool:0?ooo`050;md00000000000000000000M;l02`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0?l0ooooZ03oool200000140oooo0@0000010?ooo`40oooo000_0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooonZ0?ooo`8000003`3oool100000040oooo
0@3oool002l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oooj`0oooo0P00
000=0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0?l0oooo[P3oool2000000/0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0o`3ooon`0?ooo`030000003oool0oooo00P0oooo0@0000010?oo
o`40oooo000_0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooonk0?ooo`40
00000@3oool10?ooo`00;`3oool3000000l0oooo00<000000?ooo`3oool0o`3oooni0?ooo`<00000
0P3oool002l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oook/0oooo0@00
00010?ooo`40oooo000_0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooonl
0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0?l0oooo_03oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`3o0?oook`0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0o`3ooonl0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0?l0oooo_03oool100000040oooo0@3oool002l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?oook`0oooo0@0000010?ooo`40oooo000_0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooonl0?ooo`4000000@3oool10?oo
o`00;`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo_03oool100000040
oooo0@3oool002l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?oook`0oooo
0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3o
oonl0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0?l0oooo_03oool100000040oooo0@3oool002l0oooo0`00000>0?ooo`030000003oool0oooo
0?l0oooo^P3oool300000080oooo000_0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0o`3ooonl0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0?l0oooo_03oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`3o0?oook`0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0o`3ooonl0?ooo`4000000@3oool10?ooo`00;`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo_@3oool100000040oooo0@3oool002l0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oookd0oooo0@0000010?ooo`40
oooo000_0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`400000
0@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo_@3o
ool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o
0?oookd0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0o`3ooonm0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0?l0oooo_@3oool100000040oooo0@3oool002l0oooo0`00000=0?ooo`030000
003oool0oooo0?l0oooo^`3oool300000080oooo000_0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0o`3ooonm0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0?l0oooo_@3oool100000040oooo0@3oool002l0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`3o0?oookd0oooo0@0000010?ooo`40oooo000_0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`4000000@3oool10?ooo`00
;`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo_@3oool100000040oooo
0@3oool002l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oookd0oooo0@00
00010?ooo`40oooo000_0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooonm
0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0?l0oooo_P3oool100000040oooo0@3oool002l0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`3o0?oookh0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0o`3ooonn0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0?l0oooo_P3oool100000040oooo0@3oool002l0oooo0`00000<
0?ooo`030000003oool0oooo0?l0oooo_03oool300000080oooo000_0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`4000000@3oool10?ooo`00;`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo_P3oool100000040oooo0@3oool002l0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?oookh0oooo0@0000010?ooo`40oooo
000_0?ooo`030000003oool0oooo0?l0ooooc@3oool100000040oooo0@3oool002l0oooo00<00000
0?ooo`3oool0o`3oooo=0?ooo`4000000@3oool10?ooo`00;`3oool00`000000oooo0?ooo`3o0?oo
old0oooo0@0000010?ooo`40oooo000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`40
oooo000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`40oooo000_0?ooool00000d@00
00020?ooo`00\
\>"],
  ImageRangeCache->{{{0, 512.625}, {316.438, 0}} -> {-0.132262, 0.991412, \
0.00226831, 0.000808579}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"f22", "=", 
      RowBox[{"ListPlot", "[", 
        RowBox[{
        "r1om", ",", \(Frame \[Rule] True\), ",", \(Axes \[Rule] False\), 
          ",", \(PlotJoined \[Rule] True\), 
          ",", \(FrameLabel \[Rule] {\*"\"\<\!\(\[Omega]\_\(0  m\)\)\>\"", \
\*"\"\<\!\(\[Chi]\^2\)\>\""}\), ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{\(Hue[0]\), ",", \(Thickness[0.002]\), ",", 
                RowBox[{
                  StyleBox["Dashing",
                    "MR"], 
                  StyleBox["[",
                    "MR"], 
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    RowBox[{
                      StyleBox["0.05",
                        "MR"], 
                      StyleBox[",",
                        "MR"], " ", 
                      StyleBox["0.01",
                        "MR"]}], 
                    StyleBox["}",
                      "MR"]}], 
                  StyleBox["]",
                    "MR"]}]}], "}"}]}]}], "]"}]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -2.71434 2.67172 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -14.5625 -24.5625 ]
[.21429 -0.0125 14.5625 0 ]
[.40476 -0.0125 -14.5625 -24.5625 ]
[.40476 -0.0125 14.5625 0 ]
[.59524 -0.0125 -14.5625 -24.5625 ]
[.59524 -0.0125 14.5625 0 ]
[.78571 -0.0125 -14.5625 -24.5625 ]
[.78571 -0.0125 14.5625 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.4063 -49.125 ]
[.5 -0.0125 19.4063 -24.5625 ]
[-0.0125 .09097 -39.1875 -12.2813 ]
[-0.0125 .09097 0 12.2813 ]
[-0.0125 .22455 -29.125 -12.2813 ]
[-0.0125 .22455 0 12.2813 ]
[-0.0125 .35814 -39.1875 -12.2813 ]
[-0.0125 .35814 0 12.2813 ]
[-0.0125 .49172 -29.125 -12.2813 ]
[-0.0125 .49172 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -63.75 -12.5625 ]
[-0.01875 .30902 -39.1875 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.4063 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
76.813 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
83.875 26.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
86.500 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
97.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .09097 m
.00625 .09097 L
s
gsave
-0.0125 .09097 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
1.000 setlinewidth
grestore
0 .22455 m
.00625 .22455 L
s
gsave
-0.0125 .22455 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
0 .35814 m
.00625 .35814 L
s
gsave
-0.0125 .35814 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
1.000 setlinewidth
grestore
0 .49172 m
.00625 .49172 L
s
gsave
-0.0125 .49172 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11768 m
.00375 .11768 L
s
0 .1444 m
.00375 .1444 L
s
0 .17112 m
.00375 .17112 L
s
0 .19783 m
.00375 .19783 L
s
0 .25127 m
.00375 .25127 L
s
0 .27799 m
.00375 .27799 L
s
0 .3047 m
.00375 .3047 L
s
0 .33142 m
.00375 .33142 L
s
0 .38485 m
.00375 .38485 L
s
0 .41157 m
.00375 .41157 L
s
0 .43829 m
.00375 .43829 L
s
0 .46501 m
.00375 .46501 L
s
0 .06425 m
.00375 .06425 L
s
0 .03753 m
.00375 .03753 L
s
0 .01081 m
.00375 .01081 L
s
0 .51844 m
.00375 .51844 L
s
0 .54516 m
.00375 .54516 L
s
0 .57187 m
.00375 .57187 L
s
0 .59859 m
.00375 .59859 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -125.031 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
73.5625 16.2813 translate
90 rotate
-73.5625 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.375 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
76.563 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09097 m
1 .09097 L
s
.99375 .22455 m
1 .22455 L
s
.99375 .35814 m
1 .35814 L
s
.99375 .49172 m
1 .49172 L
s
.125 Mabswid
.99625 .11768 m
1 .11768 L
s
.99625 .1444 m
1 .1444 L
s
.99625 .17112 m
1 .17112 L
s
.99625 .19783 m
1 .19783 L
s
.99625 .25127 m
1 .25127 L
s
.99625 .27799 m
1 .27799 L
s
.99625 .3047 m
1 .3047 L
s
.99625 .33142 m
1 .33142 L
s
.99625 .38485 m
1 .38485 L
s
.99625 .41157 m
1 .41157 L
s
.99625 .43829 m
1 .43829 L
s
.99625 .46501 m
1 .46501 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .03753 m
1 .03753 L
s
.99625 .01081 m
1 .01081 L
s
.99625 .51844 m
1 .51844 L
s
.99625 .54516 m
1 .54516 L
s
.99625 .57187 m
1 .57187 L
s
.99625 .59859 m
1 .59859 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.002 w
[ .05 .01 ] 0 setdash
.03333 .60332 m
.05238 .30709 L
.07143 .17216 L
.09048 .09846 L
.11905 .0423 L
.14762 .01964 L
.16667 .01494 L
.17619 .01472 L
.19524 .01742 L
.20476 .02004 L
.21429 .02334 L
.23333 .03159 L
.2619 .04704 L
.30952 .07778 L
.40476 .14683 L
.5 .21696 L
.59524 .28424 L
.69048 .34754 L
.78571 .40671 L
.88095 .46192 L
.97619 .51348 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{709.25, 438.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;50001]R000`400?l00000o`00003oo`3ooooo
0?ooolL0oooo003o0?ooool0ooooa`3oool00?l0ooooo`3oooo70?ooo`00o`3ooon60?ooo`040?oo
g`2LB0000000001d_`@0oooo00/0_g@00000000004P0W=oO09a800000000001d0;oo_`1d00000000
001d_`3o0?ooobh0oooo003o0?ooohH0oooo00D0_g@004RLg`3oool0gia804RLg`030?ooo`0;0?oo
g`2LB000M;oo0?ooo`3ookl0M01809cOo`3oool0omnL04P0M02oool0o`3oool^0?ooo`00o`3ooon5
0?ooo`070?oOW01807@0_ooo0?ooo`3ogi`0B01d0;ooo`020?ooo`0;0?oog`2LB000M;oo0?ooo`3o
okl0M01809cOo`3oool0omnL04P0M02oool0o`3oool^0?ooo`00o`3ooon50?ooo`070?noM000B9`0
gooo0?ooo`3ooml0W4P007Boo`020?ooo`0;0?oog`2LB000M;oo0?ooo`3ookl0M01809cOo`3oool0
omnL04P0M02oool0o`3oool^0?ooo`00o`3ooomh0?ooo`070=nLB000000000000000001d_ol0omnL
04P000020000000604RLg`3oool0oooo0?ooo`3OW4P007Bo0P3oool00`3ooml0W4P007Boo`020?oo
o`0;0?oog`2LB000M;oo0?ooo`3ookl0M01809cOo`3oool0omnL04P0M02oool0o`3oool^0?ooo`00
o`3ooomg0?ooo`030?noM000000007Bo0080oooo00/0_gA804Q8B02Lgol0oooo0?oOW018000004RL
0=ooo`3oool0gia8001d_`020?ooo`0@0?oog`2LB000M;oo0?ooo`3ooml0W4P00000000004P0W=oo
0?oOW0180000001d0;ooo`3o_g@004RL0=ooool0oooo;P3oool00?l0ooooM`3oool00`3OW4P00000
07Boo`020?ooo`030?oo_`1d04P0W=oo0080oooo00/0okmd00000000M;l0oooo0?noM000B9`0gooo
0?ooo`3ooml0W4P007Boo`020?ooo`0:0?oo_`1d0000M;oO09a80000000007Bo0?oo_`1d00000000
04RLgol0oooo;`3oool00?l0ooooM`3oool00`3OW4P0000007Boo`030?ooo`030;md001d_ol0oooo
0080oooo00X0_g@00000B02Lgol0omnL04P0M02oool0oooo0?oo_`1d07@0_oooo`3ooolk0?ooo`00
o`3ooomg0?ooo`030?noM0000000B9cO00<0oooo00<0okmd001d_`3oool00P3oool02@3o_g@00000
04RLg`3oool0_g@004RLg`3oool0gia8001d_`3o0?oooc`0oooo003o0?ooogL0oooo00<0oooO09a8
0000M;l00`3oool00`3ogi`0B01d0;ooo`020?ooo`090?oOW0180000B9cO0?ooo`3ooml0W4P00000
0000B9`0gooo0?l0oooo?03oool00?l0ooooN03oool00`3ogi`0B01809cOo`070?ooo`030?oo_`1d
0000M;oo0?l0oooo@P3oool00?l0ooooN@3oool00`3OW4P004RL0=ooo`060?ooo`030?oOW01807@0
_ooo0?l0oooo@P3oool00?l0ooooNP3oool00`3o_g@004RL0=ooo`050?ooo`030=nLB01d_ol0oooo
0?l0oooo@P3oool00?l0ooooo`3oooo70?ooo`00o`3ooooo0?ooolL0oooo003o0?ooool0ooooa`3o
ool00?l0ooooo`3oooo70?ooo`00o`3ooooo0?ooolL0oooo003o0?ooool0ooooa`3oool00?l0oooo
o`3oooo70?ooo`00o`3ooooo0?ooolL0oooo003o0?ooool0ooooa`3oool00?l0ooooo`3oooo70?oo
o`00o`3ooooo0?ooolL0oooo003o0?ooool0ooooa`3oool00?l0ooooo`3oooo70?ooo`00o`3ooooo
0?ooolL0oooo003o0?ooool0ooooa`3oool00600oooo00@0_g@0000000000000B9cOJP3oool0102o
M000000000000018W=l40?ooo`050=nLB0000000B9cO0?ooo`3OW4P01`0000000`1d_ol0oooo0?oo
o`1N0?ooo`040;md00000000000004RLg`@0oooo00<0gia800000018W=l01P3oool00`3o_g@00000
07Boo`1Q0?ooo`040;md00000000000004RLg`@0oooo00<0gia800000018W=l00`3oool01P3ooml0
W4P0000000000000001d0;ooof80oooo00@0_g@0000000000000B9cO103oool00`3OW4P0000004RL
g`030?ooo`060?oOW018000000000000000004P0W=ooI`3oool00`3o_g@000000000000200000003
001d_`3oool0oooo01@0oooo001N0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`1W0?oo
o`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00<0
gia8000000000000100000000`00M;l0oooo0?ooo`1L0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0
W4P0001d_`030?ooo`030=nLB0000000B9cO00H0oooo00<0okmd0000001d_ol0G`3oool01`3ooml0
W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`080?oo_`1d0000
04RL0=ooo`3oool0gia80000B02LgomO0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`03
0?ooo`030=nLB0000000B9cO0080oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B00007BoofP0
oooo00<0_g@00000M02oool05`3oool005h0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`1V0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool00`3OW4P0B9cO
0?ooo`020?ooo`030?oog`2LB7@0_ooo05d0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`0;0?ooo`030?noM0000000M;oo05l0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`070?ooo`030;md000007@0_ooo00<0oooo00<0_g@0001d_`3oool0GP3oool00`3o_g@00018
09cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<0_g@00000M02oool00`3oool00`3OW4P004RL
0=ooo`1W0?ooo`030;md000007@0_ooo01L0oooo001M0?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0oooO09a80000M;l0I@3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00T0
oooo00<0gia804RLg`3oool0H03oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo
00H0oooo00<0gia80000000000001@0000000`0004P0W=oo0?ooo`1K0?ooo`040?oog`2LB00004RL
0=ooo`80oooo00<0oooO09a80000M;l01P3oool00`3ookl0M000001d_`040?ooo`030=nLB00007@0
_ooo05d0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`070?ooo`030;md0000
07@0_ooo00<0oooo00<0_g@00018W03Oool0I`3oool00`2oM000001d0;ooo`0G0?ooo`00G@3oool0
0`3ookl0M000001d_`040?ooo`030;md000007@0_ooo06@0oooo00<0oono07@00000M;l0103oool0
0`2oM000001d0;ooo`090?ooo`030=nLB01d_ol0oooo05l0oooo00<0oono07@00000M;l0103oool0
0`2oM000001d0;ooo`050?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000001d_ol0GP3oool0
0`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04P00018W=l0103oool0
0`2oM000001809cOo`1M0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool0
0`3o_g@0001809cOo`020?ooo`030=nLB000000007Bo06P0oooo00<0_g@00000M02oool05`3oool0
05d0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`1T0?ooo`030?oOW0180000B9cO
00@0oooo00<0_g@00000M02oool02@3oool00`3ooml0W4Q809cOo`1O0?ooo`030?oOW0180000B9cO
00@0oooo00<0_g@00000M02oool01P3oool01`3OW4P0M;oo0?ooo`3oool0okmd0000001d_ol0GP3o
ool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04P00018W=l00`3o
ool0103ookl0M0000000M02ooomM0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0
1`3oool01`3OW4P007Bo0?ooo`2oM00000000000M02oool0J03oool00`2oM000001d0;ooo`0G0?oo
o`00G@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo06@0oooo00<0omnL04P00018
W=l0103oool00`3OW4P0001809cOo`0:0?ooo`030?oOW01807@0_ooo05h0oooo00<0omnL04P00018
W=l0103oool00`3OW4P0001809cOo`060?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0000007Boo`1N
0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01@3oool02@3ookl0M00000000000
B9`0gooo0?ooo`2oM000000004RLg`1N0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02L
gol0203oool01@3o_g@0000000000000B9`0gooo06T0oooo00<0_g@00000M02oool05`3oool005d0
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`1T0?ooo`030?oOW0180000B9cO00@0
oooo00<0gia80000B02Lgol02`3oool00`2oM000B9cO0?ooo`1M0?ooo`030?oOW0180000B9cO00@0
oooo00<0gia80000B02Lgol01`3oool01P3o_g@007Bo0?ooo`3o_g@0000007Booeh0oooo00<0omnL
04P00018W=l0103oool00`3OW4P0001809cOo`050?ooo`050?oog`2LB000001d0;oOW01800000P00
00000`18W=l0oooo0?ooo`1M0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01`3o
ool01@3ogi`0B000000000000000B9cO06X0oooo00<0_g@00000M02oool05`3oool005d0oooo00<0
oono07@00000M;l0103oool00`2oM000001d0;ooo`1T0?ooo`030?oo_`1d000007Bo00@0oooo00<0
_g@00000M02oool02`3oool00`3OW4P0001d0;ooo`1M0?ooo`030?oo_`1d000007Bo00@0oooo00<0
_g@00000M02oool0203oool01@2oM000M;oo0?noM0000000M;oo05h0oooo00<0oono07@00000M;l0
103oool00`2oM000001d0;ooo`060?ooo`030?noM0000000B9cO06<0oooo00<0oono07@00000M;l0
103oool00`2oM000001d0;ooo`060?ooo`070?oOW0180000001809cOo`3oool0gia8001d_`1Y0?oo
o`030;md000007@0_ooo01L0oooo001N0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000
M;l0IP3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00`0oooo00<0okmd0000001d
_ol0GP3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00T0oooo00D0oono07@0M02o
_g@0000007Boo`1O0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l01`3oool0103o
oml0W4P00000B02LgomS0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l01`3oool0
0`3OW4P0001809cOo`020?ooo`030?oog`2LB000M;oo06P0oooo00<0_g@00000M02oool05`3oool0
05h0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`1V0?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol01P3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo
05h0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0:0?ooo`040?noM00000000000
07Booel0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`080?ooo`040?oo_`1d0000
001d0;ooof80oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030=nLB000
B9`0gooo0080oooo00<0oooO09a80018W=l0J03oool00`2oM000001d0;ooo`0G0?ooo`00G`3oool0
1P2oM00004RL0=ooo`3oool0_g@0001d_fP0oooo00H0_g@00018W03Oool0oooo0;md0000M;l80?oo
o`080;md001d_ol0oooo0?ooo`3OW4P000000018W03OoomO0?ooo`060;md0000B9`0gooo0?ooo`2o
M00007Bo2`3oool0103ooml0W4P00000001d_omP0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo
2P3oool0103ooml0W4P000000000M;mR0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203oool0
0`3ogi`0B00004RLg`020?ooo`030?noM00004P0W=oo06H0oooo00D0gia8000000000000001d0;oo
o`0G0?ooo`00H03oool0102oM000000000000000M;mZ0?ooo`040;md000000000000001d_`X0oooo
00D0_g@00000000000000000001d_`1R0?ooo`040;md000000000000001d_`d0oooo00<0omnL04P0
001d_ol0H@3oool0102oM000000000000000M;l=0?ooo`050?oOW018000000000018W03Oool0H03o
ool0102oM000000000000000M;l:0?ooo`060?oo_`1d000000000000000004P0W=ooJ03oool0103o
okl0M0000000M02ooolG0?ooo`00o`3ooooo0?ooolL0oooo003o0?ooool0ooooa`3oool00?l0oooo
o`3oooo70?ooo`00o`3ooooo0?ooolL0oooo003o0?ooool0ooooa`3oool00?l0ooooo`3oooo70?oo
o`00o`3ooooo0?ooolL0oooo003o0?ooool0ooooa`3oool00?l0ooooo`3oooo70?ooo`00o`3ooooo
0?ooolL0oooo003o0?ooool0ooooa`3oool00?l0ooooo`3oooo70?ooo`00o`3ooooo0?ooolL0oooo
001C0?ooool00000o`00001[000000T0oooo001C0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?oo
o`00D`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0o`3o
oooo0?ooofL0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0o`3ooooo
0?ooofL0oooo00<000000?ooo`3oool01`3oool005<0oooo1000003o0?ooool0ooooI03oool30000
00T0oooo001C0?ooo`030000003oool0oooo0?l0ooooo`3ooomW0?ooo`030000003oool0oooo00L0
oooo001C0?ooo`030000003oool0oooo06<0oooo2`3o003o0?ooooP0oooo00<000000?ooo`3oool0
1`3oool005<0oooo00<000000?ooo`3oool0G`3oool40?l000/0oooo103o003o0?oooo@0oooo00<0
00000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0F`3oool40?l001P0oooo0P3o003o
0?ooond0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0F03oool30?l0
01h0oooo103o003o0?ooonT0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3o
ool0E`3oool00`3o0000oooo0?ooo`0S0?ooo`<0o`00o`3ooooV0?ooo`030000003oool0oooo00L0
oooo001C0?ooo`030000003oool0oooo05D0oooo0P3o000Y0?ooo`<0o`00o`3ooooS0?ooo`030000
003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo05@0oooo00<0o`000?ooo`3oool0;03o
ool20?l00?l0ooooh@3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`25
0?ooo`80o`00o`3ooooO0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo
08L0oooo0`3o003o0?ooom`0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3o
ool0RP3oool20?l00?l0oooofP3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo
0?ooo`1?0?ooo`030?l0003oool0oooo03X0oooo0P3o003o0?ooomP0oooo00<000000?ooo`3oool0
1`3oool005<0oooo00<000000?ooo`3oool0CP3oool00`3o0000oooo0?ooo`0m0?ooo`80o`00o`3o
oooF0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo04d0oooo00<0o`00
0?ooo`3oool0@03oool20?l00?l0ooooe03oool00`000000oooo0?ooo`070?ooo`00D`3oool00`00
0000oooo0?ooo`1<0?ooo`030?l0003oool0oooo04<0oooo0P3o003o0?ooom80oooo00<000000?oo
o`3oool01`3oool005<0oooo100000190?ooo`80o`00B03oool00`3o0000oooo0?ooo`3o0?ooold0
oooo0`0000090?ooo`00D`3oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo0?l0oooo
o`3ooolK0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo04P0oooo00<0
o`000?ooo`3oool0o`3ooooo0?oooa`0oooo00<000000?ooo`3oool01`3oool005<0oooo00<00000
0?ooo`3oool0A`3oool00`3o0000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0?l0oooobP3oool0
0`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`160?ooo`030?l0003oool0oooo
0540oooo0P3o003o0?ooolX0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3o
ool0AP3oool00`3o0000oooo0?ooo`1C0?ooo`80o`00o`3oooo80?ooo`030000003oool0oooo00L0
oooo001C0?ooo`030000003oool0oooo04D0oooo00<0o`000?ooo`3oool0EP3oool20?l00?l0oooo
aP3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`150?ooo`030?l0003o
ool0oooo05P0oooo0P3o003o0?oool@0oooo00<000000?ooo`3oool01`3oool005<0oooo00<00000
0?ooo`3oool0A03oool00`3o0000oooo0?ooo`1K0?ooo`030?l0003oool0oooo0?l0oooo`@3oool0
0`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`140?ooo`030?l0003oool0oooo
05`0oooo0P3o003o0?oool40oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3o
ool0@`3oool00`3o0000oooo0?ooo`1O0?ooo`030?l0003oool0oooo0?l0oooo_P3oool00`000000
oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`130?ooo`030?l0003oool0oooo0600oooo
0P3o003o0?oookh0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0@P3o
ool00`3o0000oooo0?ooo`1S0?ooo`030?l0003oool0oooo0?l0oooo^`3oool00`000000oooo0?oo
o`070?ooo`00D`3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo06@0oooo0P3o003o
0?oook/0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0@@3oool00`3o
0000oooo0?ooo`1W0?ooo`80o`00o`3oooni0?ooo`030000003oool0oooo00L0oooo001C0?ooo`03
0000003oool0oooo0440oooo00<0o`000?ooo`3oool0J@3oool00`3o0000oooo0?ooo`3o0?oookH0
oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0@03oool00`3o0000oooo
0?ooo`1[0?ooo`80o`00o`3ooonf0?ooo`030000003oool0oooo00L0oooo001C0?ooo`@00000?`3o
ool00`3o0000oooo0?ooo`1]0?ooo`030?l0003oool0oooo0?l0oooo/@3oool3000000T0oooo001C
0?ooo`030000003oool0oooo03l0oooo00<0o`000?ooo`3oool0K`3oool20?l00?l0oooo/`3oool0
0`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo
0740oooo00<0o`000?ooo`3oool0o`3ooon`0?ooo`030000003oool0oooo00L0oooo001C0?ooo`03
0000003oool0oooo03h0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooobH0oooo00<000000?ooo`3o
ool01`3oool005<0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo0?ooo`3o0?ooool0oooo
9P3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`3o0?ooool0ooooI`3o
ool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`2h0?ooo`030?l0003oool0
oooo0?l0ooooZ`3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`2i0?oo
o`80o`00o`3ooon[0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo0;/0
oooo0P3o003o0?ooojT0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0
>`3oool00`3o0000oooo0?ooo`1o0?ooo`80o`00o`3ooonW0?ooo`030000003oool0oooo00L0oooo
000Y0?ooo`030?noM000000000000080000000L007Bo0?ooo`3oool0oooo0=nLB0000000B9cO00@0
oooo00@0_g@0000000000000B9cO103oool01P2oM000000000000000000004RL0=ooo``0oooo00<0
00000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`220?ooo`030?l0003oool0oooo0?l0ooooY03o
ool00`000000oooo0?ooo`070?ooo`00:`3oool00`2oM000001d0;ooo`040?ooo`030=nLB0000000
B9cO0080oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo0080oooo00<0oooO09a80018W=l0
0P3oool00`3ogi`0B4RL0=ooo`0;0?ooo`030000003oool0oooo03X0oooo00<0o`000?ooo`3oool0
P`3oool00`3o0000oooo0?ooo`3o0?oooj<0oooo00<000000?ooo`3oool01`3oool002/0oooo00<0
_g@00000M02oool02@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<0
omnL04Qd_`3oool02P3oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo08D0oooo0P3o
003o0?oooj<0oooo00<000000?ooo`3oool01`3oool002/0oooo00<0_g@00000M02oool0203oool0
103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00L0oooo00<0oono07@0B02Lgol02P3o
ool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo08L0oooo00<0o`000?ooo`3oool0o`3o
oonP0?ooo`030000003oool0oooo00L0oooo000[0?ooo`030;md000007@0_ooo00P0oooo00<0oono
07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`030?oo_`1d0000M;oo00X0oooo00<00000
0?ooo`3oool0>03oool00`3o0000oooo0?ooo`290?ooo`80o`00o`3ooonP0?ooo`030000003oool0
oooo00L0oooo000[0?ooo`030;md000007@0_ooo00P0oooo00<0omnL04P00018W=l0103oool00`2o
M000001d0;ooo`060?ooo`030?noM0000000M;oo00X0oooo00<000000?ooo`3oool0>03oool00`3o
0000oooo0?ooo`2;0?ooo`030?l0003oool0oooo0?l0ooooW@3oool00`000000oooo0?ooo`070?oo
o`00:`3oool00`2oM000001d0;ooo`080?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02L
gol01@3oool0103ogi`0B0000000M02oool:0?ooo`D00000=@3oool00`3o0000oooo0?ooo`2=0?oo
o`030?l0003oool0oooo0?l0ooooV03oool5000000T0oooo000[0?ooo`030;md000007@0_ooo00P0
oooo00<0omnL04P00018W=l0103oool01@3OW4P0001809cOo`3oool0gmoO0080oooo00@0_g@00000
00000000B9cO2`3oool00`000000oooo0?ooo`0g0?ooo`030?l0003oool0oooo08h0oooo0P3o003o
0?oooi`0oooo00<000000?ooo`3oool01`3oool002/0oooo00<0_g@00000M02oool0203oool00`3o
okl0M000001d_`040?ooo`050;md000007@0_ooo0?ooo`3o_g@0100000000`00M;l0oooo0?ooo`0:
0?ooo`030000003oool0oooo03H0oooo00<0o`000?ooo`3oool0T@3oool00`3o0000oooo0?ooo`3o
0?oooiT0oooo00<000000?ooo`3oool01`3oool002/0oooo00<0_g@00000M02oool02@3oool00`2o
M00004RL0=ooo`020?ooo`030?oog`2LB00007Bo0080oooo00D0oooO09a800000000001d0;ooo`0=
0?ooo`030000003oool0oooo03H0oooo00<0o`000?ooo`3oool0TP3oool20?l00?l0ooooV@3oool0
0`000000oooo0?ooo`070?ooo`00:`3oool00`2oM000001d0;ooo`090?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol00`3oool00`3o_g@007Bo0?ooo`0>0?ooo`030000003oool0oooo
03D0oooo00<0o`000?ooo`3oool0U@3oool00`3o0000oooo0?ooo`3o0?oooiH0oooo00<000000?oo
o`3oool01`3oool002T0oooo00D0gia8000000000000001d0;ooo`0:0?ooo`060;md0000B9`0gooo
0?ooo`2oM00007Bo103oool00`3ooml0W4P000000002000000030000M02oool0oooo00T0oooo00<0
00000?ooo`3oool0=@3oool00`3o0000oooo0?ooo`2F0?ooo`030?l0003oool0oooo0?l0ooooU@3o
ool00`000000oooo0?ooo`070?ooo`00:P3oool0103ookl0M0000000M02oool;0?ooo`040;md0000
00000000001d_`H0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`080?ooo`030000
003oool0oooo03D0oooo00<0o`000?ooo`3oool0U`3oool20?l00?l0ooooU@3oool00`000000oooo
0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0e0?ooo`030?l0003oool0oooo09T0oooo00<0
o`000?ooo`3oool0o`3ooonB0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0
oooo03@0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooc00oooo00<000000?ooo`3oool01`3oool0
05<0oooo00<000000?ooo`3oool0=03oool00`3o0000oooo0?ooo`3o0?ooool0oooo<03oool00`00
0000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0d0?ooo`030?l0003oool0oooo0?l0
ooooo`3oool`0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo03@0oooo
00<0o`000?ooo`3oool0W`3oool00`3o0000oooo0?ooo`3o0?ooohd0oooo00<000000?ooo`3oool0
1`3oool005<0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`2Q0?ooo`80o`00o`3o
oon=0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo03<0oooo00<0o`00
0?ooo`3oool0X`3oool00`3o0000oooo0?ooo`3o0?ooohX0oooo00<000000?ooo`3oool01`3oool0
05<0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`2T0?ooo`030?l0003oool0oooo
0?l0ooooR@3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0c0?ooo`03
0?l0003oool0oooo0:D0oooo0P3o003o0?ooohT0oooo00<000000?ooo`3oool01`3oool005<0oooo
1000000a0?ooo`030?l0003oool0oooo0:P0oooo00<0o`000?ooo`3oool0o`3ooon40?ooo`<00000
2@3oool005<0oooo00<000000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`2Y0?ooo`80o`00o`3o
oon60?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo0380oooo00<0o`00
0?ooo`3oool0Z`3oool00`3o0000oooo0?ooo`3o0?oooh<0oooo00<000000?ooo`3oool01`3oool0
05<0oooo00<000000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`2/0?ooo`030?l0003oool0oooo
0?l0ooooPP3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0a0?ooo`03
0?l0003oool0oooo0:h0oooo0P3o003o0?oooh80oooo00<000000?ooo`3oool01`3oool005<0oooo
00<000000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`2`0?ooo`030?l0003oool0oooo0?l0oooo
O`3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0a0?ooo`030?l0003o
ool0oooo0;40oooo00<0o`000?ooo`3oool0o`3ooomn0?ooo`030000003oool0oooo00L0oooo001C
0?ooo`030000003oool0oooo0>H0oooo0P3o003o0?ooogh0oooo00<000000?ooo`3oool01`3oool0
05<0oooo00<000000?ooo`3oool0j03oool00`3o0000oooo0?ooo`3o0?ooog/0oooo00<000000?oo
o`3oool01`3oool005<0oooo00<000000?ooo`3oool0j@3oool20?l00?l0ooooN`3oool00`000000
oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`3[0?ooo`030?l0003oool0oooo0?l0oooo
N03oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`3/0?ooo`030?l0003o
ool0oooo0?l0ooooM`3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0_
0?ooo`030?l0003oool0oooo0;/0oooo0P3o003o0?ooogL0oooo00<000000?ooo`3oool01`3oool0
05<0oooo00<000000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`2m0?ooo`030?l0003oool0oooo
0?l0ooooM03oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0^0?ooo`03
0?l0003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000
003oool0oooo02h0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooocH0oooo00<000000?ooo`3oool0
1`3oool005<0oooo00<000000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`3o0?ooool0oooo=P3o
ool00`000000oooo0?ooo`070?ooo`00D`3oool4000002d0oooo00<0o`000?ooo`3oool0``3oool2
0?l00?l0ooooKP3oool3000000T0oooo001C0?ooo`030000003oool0oooo02d0oooo00<0o`000?oo
o`3oool0aP3oool20?l00?l0ooooKP3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000
oooo0?ooo`0]0?ooo`030?l0003oool0oooo0<P0oooo00<0o`000?ooo`3oool0o`3ooom[0?ooo`03
0000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo02d0oooo00<0o`000?ooo`3oool0
b@3oool20?l00?l0ooooJ`3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?oo
o`0]0?ooo`030?l0003oool0oooo0</0oooo00<0o`000?ooo`3oool0o`3ooomX0?ooo`030000003o
ool0oooo00L0oooo001C0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3oool0c@3oool0
0`3o0000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?oo
o`3oool0;03oool00`3o0000oooo0?ooo`3>0?ooo`80o`00o`3ooomW0?ooo`030000003oool0oooo
00L0oooo001C0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3oool0d03oool00`3o0000
oooo0?ooo`3o0?ooof@0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0
:`3oool00`3o0000oooo0?ooo`3B0?ooo`030?l0003oool0oooo0?l0ooooH`3oool00`000000oooo
0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo0=<0oooo00<0
o`000?ooo`3oool0o`3ooomR0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0
oooo02/0oooo00<0o`000?ooo`3oool0e03oool20?l00?l0ooooHP3oool00`000000oooo0?ooo`07
0?ooo`00D`3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo0=H0oooo00<0o`000?oo
o`3oool0o`3ooomO0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo02X0
oooo00<0o`000?ooo`3oool0f03oool00`3o0000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3o
ool01`3oool005<0oooo00<000000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`3I0?ooo`80o`00
o`3ooomN0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo02X0oooo00<0
o`000?ooo`3oool0f`3oool00`3o0000oooo0?ooo`3o0?oooe/0oooo00<000000?ooo`3oool01`3o
ool005<0oooo00<000000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`3L0?ooo`030?l0003oool0
oooo0?l0ooooFP3oool00`000000oooo0?ooo`070?ooo`00D`3oool4000002P0oooo00<0o`000?oo
o`3oool0gP3oool20?l00?l0ooooF03oool3000000T0oooo001C0?ooo`030000003oool0oooo02T0
oooo00<0o`000?ooo`3oool0h03oool00`3o0000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3o
ool01`3oool005<0oooo00<000000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`3Q0?ooo`030?l0
003oool0oooo0?l0ooooEP3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?oo
o`0Y0?ooo`030?l0003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo00L0oooo001C
0?ooo`030000003oool0oooo02T0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooc/0oooo00<00000
0?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0:03oool00`3o0000oooo0?ooo`3o0?oo
ool0oooo?03oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0X0?ooo`03
0?l0003oool0oooo0>L0oooo00<0o`000?ooo`3oool0o`3ooomA0?ooo`030000003oool0oooo00L0
oooo001C0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool0j03oool20?l00?l0oooo
D@3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0X0?ooo`030?l0003o
ool0oooo0>X0oooo00<0o`000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00L0oooo001C
0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool0j`3oool00`3o0000oooo0?ooo`3o
0?ooodd0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0o`3ooolH0?oo
o`80o`00o`3ooom=0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo0?l0
oooo6P3oool00`3o0000oooo0?ooo`3o0?ooodX0oooo00<000000?ooo`3oool01`3oool005<0oooo
00<000000?ooo`3oool0o`3ooolK0?ooo`80o`00o`3ooom:0?ooo`030000003oool0oooo00L0oooo
001C0?ooo`030000003oool0oooo0?l0oooo7@3oool00`3o0000oooo0?ooo`3o0?ooodL0oooo00<0
00000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`030?l0003oool0
oooo0?l0ooooAP3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0W0?oo
o`030?l0003oool0oooo0?@0oooo0P3o003o0?ooodH0oooo00<000000?ooo`3oool01`3oool005<0
oooo00<000000?ooo`3oool09`3oool00`3o0000oooo0?ooo`3f0?ooo`030?l0003oool0oooo0?l0
oooo@`3oool00`000000oooo0?ooo`070?ooo`00D`3oool4000002H0oooo00<0o`000?ooo`3oool0
m`3oool00`3o0000oooo0?ooo`3o0?oood00oooo0`0000090?ooo`00D`3oool00`000000oooo0?oo
o`0W0?ooo`030?l0003oool0oooo0?P0oooo0P3o003o0?oood80oooo00<000000?ooo`3oool01`3o
ool005<0oooo00<000000?ooo`3oool09P3oool00`3o0000oooo0?ooo`3k0?ooo`030?l0003oool0
oooo0?l0oooo?`3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0V0?oo
o`030?l0003oool0oooo0?`0oooo0P3o003o0?ooocl0oooo00<000000?ooo`3oool01`3oool005<0
oooo00<000000?ooo`3oool09P3oool00`3o0000oooo0?ooo`3n0?ooo`030?l0003oool0oooo0?l0
oooo?03oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0V0?ooo`030?l0
003oool0oooo0?l0oooo00<0o`000?ooo`3oool0o`3ooolk0?ooo`030000003oool0oooo00L0oooo
001C0?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`3oool0o`3oool10?ooo`80o`00o`3o
oolk0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo02H0oooo00<0o`00
0?ooo`3oool0o`3oool30?ooo`030?l0003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`07
0?ooo`00D`3oool00`000000oooo0?ooo`0V0?ooo`030?l0003oool0oooo0?l0ooooo`3oooln0?oo
o`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`3o
ool0o`3ooooo0?oooch0oooo00<000000?ooo`3oool01`3oool003<0oooo00<0okmd000000000000
0P0000001`00M;l0oooo0?ooo`3oool0gia800000018W=l00`3oool00`3o_g@00000000000020000
0003001d_`3oool0oooo00T0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`3o0?oo
o`T0oooo00<0o`000?ooo`3oool0o`3ooolc0?ooo`030000003oool0oooo00L0oooo000e0?ooo`03
0;md000007@0_ooo00@0oooo00<0gia800000018W=l01@3oool00`2oM000001d0;ooo`0<0?ooo`03
0000003oool0oooo02D0oooo00<0o`000?ooo`3oool0o`3oool90?ooo`030?l0003oool0oooo0?l0
oooo<`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`2oM000001d0;ooo`0<0?ooo`030;md
000007@0_ooo00`0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`3o0?ooo`X0oooo
00<0o`000?ooo`3oool0o`3ooolb0?ooo`030000003oool0oooo00L0oooo000e0?ooo`030;md0000
07@0_ooo00`0oooo00<0_g@00000M02oool0303oool00`000000oooo0?ooo`0U0?ooo`030?l0003o
ool0oooo0?l0oooo2`3oool20?l00?l0oooo<P3oool00`000000oooo0?ooo`070?ooo`00=@3oool0
0`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00`0oooo00<000000?ooo`3oool09@3oool0
0`3o0000oooo0?ooo`3o0?ooo`d0oooo00<0o`000?ooo`3oool0o`3oool_0?ooo`030000003oool0
oooo00L0oooo000e0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0303oool00`00
0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo0?l0oooo3P3oool20?l00?l0oooo;`3oool00`00
0000oooo0?ooo`070?ooo`00=@3oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00`0
oooo1@00000S0?ooo`030?l0003oool0oooo0?l0oooo403oool00`3o0000oooo0?ooo`3o0?ooobP0
oooo1@0000090?ooo`00=@3oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00`0oooo
00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`3o0?oooa40oooo0P3o003o0?ooob`0oooo
00<000000?ooo`3oool01`3oool003D0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;oo
o`0<0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool0o`3ooolD0?ooo`030?l0003o
ool0oooo0?l0oooo:@3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`2oM000001d0;ooo`0<
0?ooo`030;md000007@0_ooo00`0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`3o
0?oooaD0oooo0P3o003o0?ooobT0oooo00<000000?ooo`3oool01`3oool003D0oooo00<0_g@00000
M02oool0303oool00`2oM000001d0;ooo`0<0?ooo`030000003oool0oooo02@0oooo00<0o`000?oo
o`3oool0o`3ooolG0?ooo`030?l0003oool0oooo0?l0oooo9P3oool00`000000oooo0?ooo`070?oo
o`00<`3oool01@3OW4P000000000000007@0_ooo00X0oooo00D0gia8000000000000001d0;ooo`0<
0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool0o`3ooolH0?ooo`80o`00o`3ooolV
0?ooo`030000003oool0oooo00L0oooo000d0?ooo`040?oo_`1d0000001d0;ooo`/0oooo00@0oono
07@0000007@0_ooo303oool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo0?l0oooo6P3o
ool00`3o0000oooo0?ooo`3o0?ooob<0oooo00<000000?ooo`3oool01`3oool005<0oooo00<00000
0?ooo`3oool0903oool00`3o0000oooo0?ooo`3o0?oooa/0oooo0P3o003o0?ooob<0oooo00<00000
0?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`3o0?oo
oad0oooo00<0o`000?ooo`3oool0o`3ooolP0?ooo`030000003oool0oooo00L0oooo001C0?ooo`03
0000003oool0oooo02@0oooo00<0o`000?ooo`3oool0o`3ooolN0?ooo`80o`00o`3ooolP0?ooo`03
0000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool0
o`3ooolQ0?ooo`030?l0003oool0oooo0?l0oooo7@3oool00`000000oooo0?ooo`070?ooo`00D`3o
ool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0?l0oooo8P3oool20?l00?l0oooo7@3o
ool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0
oooo0?l0oooo903oool00`3o0000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool01`3oool0
05<0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`3o0?ooool0oooo@@3oool00`00
0000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`3o0?ooool0ooooI`3oool00`000000
oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`3o0?ooool0ooooI`3oool00`000000oooo
0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`3o0?ooodl0oooo00<0o`000?ooo`3oool0o`3o
oolE0?ooo`030000003oool0oooo00L0oooo001C0?ooo`@00000o`3ooom?0?ooo`80o`00o`3ooolC
0?ooo`<000002@3oool005<0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`030?l0003oool0oooo
0?l0oooo4P3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0R0?ooo`03
0?l0003oool0oooo0?l0oooo;P3oool00`3o0000oooo0?ooo`3o0?oooa40oooo00<000000?ooo`3o
ool01`3oool005<0oooo00<000000?ooo`3oool08P3oool00`3o0000oooo0?ooo`3o0?ooobl0oooo
0P3o003o0?oooa40oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool08P3o
ool00`3o0000oooo0?ooo`3o0?oooc40oooo00<0o`000?ooo`3oool0o`3oool>0?ooo`030000003o
ool0oooo00L0oooo001C0?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool0o`3ooolb
0?ooo`80o`00o`3oool>0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo
0240oooo00<0o`000?ooo`3oool0o`3ooole0?ooo`030?l0003oool0oooo0?l0oooo2`3oool00`00
0000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0?l0
oooo=P3oool00`3o0000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool005<0oooo
00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`3o0?ooocL0oooo0P3o003o0?ooo`X0oooo
00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?oo
o`3o0?ooocT0oooo00<0o`000?ooo`3oool0o`3oool70?ooo`030000003oool0oooo00L0oooo001C
0?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3oool0o`3ooolj0?ooo`030?l0003oool0
oooo0?l0oooo1P3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0Q0?oo
o`030?l0003oool0oooo0?l0oooo>`3oool20?l00?l0oooo1P3oool00`000000oooo0?ooo`070?oo
o`00D`3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0?l0oooo?@3oool00`3o0000
oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0
8@3oool00`3o0000oooo0?ooo`3o0?oooch0oooo0P3o003o0?ooo`<0oooo00<000000?ooo`3oool0
1`3oool005<0oooo00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`3o0?oood40oooo00<0
o`000?ooo`3oool0o`3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0P
0?ooo`030?l0003oool0oooo0?l0oooo@P3oool00`3o0000oooo0?ooo`3n0?ooo`030000003oool0
oooo00L0oooo001C0?ooo`@000007`3oool00`3o0000oooo0?ooo`3o0?oood<0oooo0P3o003l0?oo
o`<000002@3oool005<0oooo00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`3o0?ooodD0
oooo00<0o`000?ooo`3oool0n`3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo
0?ooo`0P0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo00L0oooo
001C0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool0o`3ooooo0?oood@0oooo00<0
00000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`3o
0?ooodX0oooo00<0o`000?ooo`3oool0mP3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`00
0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo0?l0ooooC03oool20?l00?H0oooo00<000000?oo
o`3oool01`3oool005<0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`3o0?ooodh0
oooo00<0o`000?ooo`3oool0l`3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo
0?ooo`0O0?ooo`030?l0003oool0oooo0?l0ooooC`3oool20?l00?<0oooo00<000000?ooo`3oool0
1`3oool005<0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`3o0?oooe40oooo00<0
o`000?ooo`3oool0l03oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0O
0?ooo`030?l0003oool0oooo0?l0ooooDP3oool20?l00?00oooo00<000000?ooo`3oool01`3oool0
01d0oooo00<0oooO09a8B02Lgol0<`3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo
0?l0ooooE03oool00`3o0000oooo0?ooo`3]0?ooo`030000003oool0oooo00L0oooo000L0?ooo`03
0?oo_`1d04P0W=oo03@0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`3o0?oooeD0
oooo0P3o003]0?ooo`030000003oool0oooo00L0oooo000K0?ooo`030?oOW01807@0_ooo03D0oooo
00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`3o0?oooeL0oooo00<0o`000?ooo`3oool0
jP3oool00`000000oooo0?ooo`070?ooo`004P3oool00`3OW9`0_ooo0?ooo`050?ooo`030?oOW018
B9`0gooo03H0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`3o0?oooeT0oooo0P3o
003Z0?ooo`030000003oool0oooo00L0oooo000A0?ooo`030?oog`2LB7@0_ooo00D0oooo00<0omnL
04Q8W03Oool0=`3oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0?l0ooooF`3oool2
0?l00>P0oooo00<000000?ooo`3oool01`3oool00140oooo00<0oono07@000000000100000000`00
B4P0B01d0;ooo`0h0?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool0o`3ooomM0?oo
o`030?l0003oool0oooo0>D0oooo00<000000?ooo`3oool01`3oool001@0oooo00<0okmd00000000
00001`0000000`18W=l0oooo0?ooo`0b0?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3o
ool0o`3ooomN0?ooo`80o`00i@3oool00`000000oooo0?ooo`070?ooo`005P3oool00`3ooml0W4Q8
09cOo`020?ooo`050;md0000000000000000B02Lgol0<`3oool400000?l0ooooP03oool00`3o0000
oooo0?ooo`3P0?ooo`<000002@3oool001D0oooo00<0oooO09a8B02Lgol01@3oool00`3ogi`0B4RL
0=ooo`0c0?ooo`030000003oool0oooo0?l0ooooPP3oool20?l00>80oooo00<000000?ooo`3oool0
1`3oool001@0oooo00<0oooO09a8B02Lgol01@3oool00`3ookl0M01d0;ooo`0d0?ooo`030000003o
ool0oooo0?l0ooooQ03oool00`3o0000oooo0?ooo`3O0?ooo`030000003oool0oooo00L0oooo000C
0?ooo`030?oo_`1d04P0W=oo03d0oooo00<000000?ooo`3oool0o`3ooon50?ooo`80o`00g`3oool0
0`000000oooo0?ooo`070?ooo`004P3oool00`3o_g@0001d0;ooo`0n0?ooo`030000003oool0oooo
0?l0ooooQ`3oool00`3o0000oooo0?ooo`3L0?ooo`030000003oool0oooo00L0oooo000A0?ooo`03
0?oo_`1dM;l0oooo03l0oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`3o0?ooool0
ooooA`3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0M0?ooo`030?l0
003oool0oooo0?l0ooooo`3ooom70?ooo`030000003oool0oooo00L0oooo000:0?ooo`030=nLB000
B9`0gooo00@0oooo00<0giad04Q8M02oool0?`3oool00`000000oooo0?ooo`0M0?ooo`030?l0003o
ool0oooo0?l0ooooo`3ooom70?ooo`030000003oool0oooo00L0oooo00090?ooo`030?noM000M;l0
oooo00@0oooo00@0_g@004RLW01d07@0_ooo?`3oool00`000000oooo0?ooo`0M0?ooo`030?l0003o
ool0oooo0?l0ooooK03oool00`3o0000oooo0?ooo`3G0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`030=nLB018W=l0oooo0080oooo00H0oooO09a8001d_ol0oono07@0M02ooolo0?ooo`030000
003oool0oooo01d0oooo00<0o`000?ooo`3oool0o`3ooom]0?ooo`80o`00e`3oool00`000000oooo
0?ooo`070?ooo`002@3oool02`3o_g@0001809cOo`3oool0okmd0000B02Lgol0oooo0?oOW01807@0
_ooo03l0oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`3o0?ooofl0oooo00<0o`00
0?ooo`3oool0e03oool00`000000oooo0?ooo`070?ooo`002P3oool0103OW4P0000000000000M;l2
0?ooo`040?oog`2LB00004RL0=ooocl0oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?oo
o`3o0?ooog00oooo0P3o003D0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0
oooo01d0oooo00<0o`000?ooo`3oool0o`3ooomb0?ooo`030?l0003oool0oooo0=40oooo00<00000
0?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`3o0?oo
og@0oooo0P3o003A0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01`0
oooo00<0o`000?ooo`3oool0o`3ooomf0?ooo`030?l0003oool0oooo0<h0oooo00<000000?ooo`3o
ool01`3oool005<0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`3o0?ooogL0oooo
0P3o003>0?ooo`030000003oool0oooo00L0oooo001C0?ooo`@000006`3oool00`3o0000oooo0?oo
o`3o0?ooogT0oooo00<0o`000?ooo`3oool0b@3oool3000000T0oooo001C0?ooo`030000003oool0
oooo01`0oooo00<0o`000?ooo`3oool0o`3ooomj0?ooo`030?l0003oool0oooo0<X0oooo00<00000
0?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`3o0?oo
og/0oooo0P3o003:0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01`0
oooo00<0o`000?ooo`3oool0o`3ooomm0?ooo`030?l0003oool0oooo0<L0oooo00<000000?ooo`3o
ool01`3oool005<0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`3o0?ooogh0oooo
0P3o00370?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01`0oooo00<0
o`000?ooo`3oool0o`3ooon00?ooo`030?l0003oool0oooo0<@0oooo00<000000?ooo`3oool01`3o
ool005<0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`3o0?oooh40oooo0P3o0034
0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01`0oooo00<0o`000?oo
o`3oool0o`3ooon30?ooo`030?l0003oool0oooo0<40oooo00<000000?ooo`3oool01`3oool005<0
oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`3o0?oooh@0oooo0P3o00310?ooo`03
0000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool0
o`3ooon60?ooo`030?l0003oool0oooo0;h0oooo00<000000?ooo`3oool01`3oool005<0oooo00<0
00000?ooo`3oool0703oool00`3o0000oooo0?ooo`3o0?ooool0ooooB03oool00`000000oooo0?oo
o`070?ooo`00:@3oool00`3o_g@000000000000200000007001d_`3oool0oooo0?ooo`3OW4P00000
04RLg`030?ooo`030?noM000000000000080000000D007Bo0?ooo`3oool0oooo0;md000300000003
0018W03Oool0oooo00/0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`3o0?ooool0
ooooB03oool00`000000oooo0?ooo`070?ooo`00:`3oool00`2oM000001d0;ooo`040?ooo`030=nL
B0000000B9cO00D0oooo00<0_g@00000M02oool00`3oool00`3ooml0W4P004RLg`020?ooo`030?oO
W018B9`0gooo00/0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`3o0?oooh`0oooo
00<0o`000?ooo`3oool0^03oool00`000000oooo0?ooo`070?ooo`00:`3oool00`2oM000001d0;oo
o`0<0?ooo`030;md000007@0_ooo00T0oooo00<0omnL04Qd_`3oool02P3oool00`000000oooo0?oo
o`0K0?ooo`030?l0003oool0oooo0?l0ooooSP3oool20?l00;P0oooo00<000000?ooo`3oool01`3o
ool002/0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`090?ooo`030?oo_`1d04P0
W=oo00X0oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`3o0?oooi00oooo0P3o002f
0?ooo`030000003oool0oooo00L0oooo000[0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000
M02oool02@3oool00`3ookl0M00007Boo`0:0?ooo`030000003oool0oooo01/0oooo00<0o`000?oo
o`3oool0o`3ooonB0?ooo`030?l0003oool0oooo0;<0oooo00<000000?ooo`3oool01`3oool002/0
oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`090?ooo`030?noM0000000M;oo00X0
oooo1@00000I0?ooo`030?l0003oool0oooo0?l0ooooT`3oool20?l00:l0oooo1@0000090?ooo`00
:`3oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00P0oooo00@0omnL04P0000007@0
_ooo2P3oool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0?l0ooooU@3oool00`3o0000
oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo000[0?ooo`030;md000007@0_ooo00`0oooo
00<0_g@00000M02oool0103oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00T0
oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`3o0?oooiH0oooo0P3o002`0?ooo`03
0000003oool0oooo00L0oooo000[0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0
103oool00`3o_g@000000000000200000003001d_`3oool0oooo00X0oooo00<000000?ooo`3oool0
6`3oool00`3o0000oooo0?ooo`3o0?oooiP0oooo0P3o002^0?ooo`030000003oool0oooo00L0oooo
000[0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0103oool01@3ooml0W4P00000
000007@0_ooo00d0oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`3o0?oooiX0oooo
00<0o`000?ooo`3oool0Z`3oool00`000000oooo0?ooo`070?ooo`00:`3oool00`2oM000001d0;oo
o`0<0?ooo`030;md000007@0_ooo00D0oooo00<0okmd001d_`3oool03P3oool00`000000oooo0?oo
o`3o0?oookT0oooo0P3o002[0?ooo`030000003oool0oooo00L0oooo000Y0?ooo`050=nLB0000000
00000000M02oool02P3oool01@3OW4P000000000000007@0_ooo00D0oooo00<0oooO09a800000000
0P0000000`0007@0_ooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo^`3oool20?l00:T0oooo
00<000000?ooo`3oool01`3oool002X0oooo00@0oono07@0000007@0_ooo2`3oool0103ookl0M000
0000M02oool60?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool0203oool00`000000
oooo0?ooo`3o0?oookd0oooo00<0o`000?ooo`3oool0YP3oool00`000000oooo0?ooo`070?ooo`00
D`3oool00`000000oooo0?ooo`3o0?oookh0oooo0P3o002V0?ooo`030000003oool0oooo00L0oooo
001C0?ooo`030000003oool0oooo0?l0oooo`03oool00`3o0000oooo0?ooo`2S0?ooo`030000003o
ool0oooo00L0oooo001C0?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool0o`3ooonS
0?ooo`80o`00X`3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0K0?oo
o`030?l0003oool0oooo0?l0ooooY@3oool20?l00:40oooo00<000000?ooo`3oool01`3oool005<0
oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`3o0?ooojL0oooo00<0o`000?ooo`3o
ool0WP3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0K0?ooo`030?l0
003oool0oooo0?l0ooooo`3ooom90?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003o
ool0oooo01/0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooodT0oooo00<000000?ooo`3oool01`3o
ool005<0oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`3o0?oooj`0oooo00<0o`00
0?ooo`3oool0V@3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0K0?oo
o`030?l0003oool0oooo0?l0oooo[@3oool20?l009T0oooo00<000000?ooo`3oool01`3oool005<0
oooo1000000J0?ooo`030?l0003oool0oooo0?l0oooo[`3oool00`3o0000oooo0?ooo`2D0?ooo`<0
00002@3oool005<0oooo00<000000?ooo`3oool06P3oool00`3o0000oooo0?ooo`3o0?oook40oooo
0P3o002F0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01X0oooo00<0
o`000?ooo`3oool0o`3ooonc0?ooo`80o`00U03oool00`000000oooo0?ooo`070?ooo`00D`3oool0
0`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo0?l0oooo]@3oool00`3o0000oooo0?ooo`2A
0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01X0oooo00<0o`000?oo
o`3oool0o`3ooonf0?ooo`80o`00T@3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000
oooo0?ooo`0J0?ooo`030?l0003oool0oooo0?l0oooo^03oool00`3o0000oooo0?ooo`2>0?ooo`03
0000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01X0oooo00<0o`000?ooo`3oool0
o`3oooni0?ooo`80o`00SP3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?oo
o`0J0?ooo`030?l0003oool0oooo0?l0oooo^`3oool20?l008`0oooo00<000000?ooo`3oool01`3o
ool005<0oooo00<000000?ooo`3oool06P3oool00`3o0000oooo0?ooo`3o0?oookd0oooo00<0o`00
0?ooo`3oool0R@3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0J0?oo
o`030?l0003oool0oooo0?l0oooo_P3oool20?l008T0oooo00<000000?ooo`3oool01`3oool005<0
oooo00<000000?ooo`3oool06P3oool00`3o0000oooo0?ooo`3o0?oool00oooo00<0o`000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0J0?ooo`030?l0
003oool0oooo0?l0oooo`@3oool20?l008H0oooo00<000000?ooo`3oool01`3oool005<0oooo00<0
00000?ooo`3oool06P3oool00`3o0000oooo0?ooo`3o0?oool<0oooo0P3o00240?ooo`030000003o
ool0oooo00L0oooo001C0?ooo`030000003oool0oooo01X0oooo00<0o`000?ooo`3oool0o`3oooo5
0?ooo`030?l0003oool0oooo0840oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?oo
o`3oool06P3oool00`3o0000oooo0?ooo`3o0?ooolH0oooo00<0o`000?ooo`3oool0P03oool00`00
0000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo0?l0
ooooa`3oool00`3o0000oooo0?ooo`1o0?ooo`030000003oool0oooo00L0oooo001C0?ooo`@00000
6@3oool00`3o0000oooo0?ooo`3o0?ooool0ooooB03oool3000000T0oooo001C0?ooo`030000003o
ool0oooo01T0oooo00<0o`000?ooo`3oool0o`3ooooo0?oood/0oooo00<000000?ooo`3oool01`3o
ool005<0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`3o0?ooolh0oooo00<0o`00
0?ooo`3oool0N@3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0I0?oo
o`030?l0003oool0oooo0?l0ooooc`3oool20?l007T0oooo00<000000?ooo`3oool01`3oool005<0
oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`3o0?ooom40oooo0P3o001g0?ooo`03
0000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0
o`3ooooC0?ooo`80o`00M@3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?oo
o`0I0?ooo`030?l0003oool0oooo0?l0ooooe@3oool00`3o0000oooo0?ooo`1b0?ooo`030000003o
ool0oooo00L0oooo001C0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0o`3ooooF
0?ooo`80o`00LP3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0I0?oo
o`030?l0003oool0oooo0?l0oooof03oool20?l00700oooo00<000000?ooo`3oool01`3oool005<0
oooo00<000000?ooo`3oool0o`3oooof0?ooo`030?l0003oool0oooo06d0oooo00<000000?ooo`3o
ool01`3oool005<0oooo00<000000?ooo`3oool0o`3oooog0?ooo`80o`00K@3oool00`000000oooo
0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`3o0?ooooT0oooo0P3o001[0?ooo`030000003o
ool0oooo00L0oooo001C0?ooo`030000003oool0oooo0?l0oooon`3oool20?l006T0oooo00<00000
0?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0o`3oooom0?ooo`030?l0003oool0oooo
06H0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool06@3oool00`3o0000
oooo0?ooo`3o0?ooon80oooo0P3o001V0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000
003oool0oooo01T0oooo00<0o`000?ooo`3oool0o`3ooooT0?ooo`80o`00I03oool00`000000oooo
0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo0?l0ooooiP3o
ool20?l00680oooo00<000000?ooo`3oool01`3oool005<0oooo1000000H0?ooo`030?l0003oool0
oooo0?l0ooooj03oool00`3o0000oooo0?ooo`1M0?ooo`<000002@3oool005<0oooo00<000000?oo
o`3oool06@3oool00`3o0000oooo0?ooo`3o0?ooool0ooooB`3oool00`000000oooo0?ooo`070?oo
o`00D`3oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom;0?ooo`03
0000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0
o`3oooo^0?ooo`030?l0003oool0oooo05T0oooo00<000000?ooo`3oool01`3oool005<0oooo00<0
00000?ooo`3oool06@3oool00`3o0000oooo0?ooo`3o0?ooonl0oooo0P3o001I0?ooo`030000003o
ool0oooo00L0oooo001C0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0o`3oooob
0?ooo`80o`00E`3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0H0?oo
o`030?l0003oool0oooo0?l0oooom03oool20?l005D0oooo00<000000?ooo`3oool01`3oool005<0
oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`3o0?ooooH0oooo00<0o`000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0H0?ooo`030?l0
003oool0oooo0?l0oooom`3oool20?l00580oooo00<000000?ooo`3oool01`3oool005<0oooo00<0
00000?ooo`3oool0603oool00`3o0000oooo0?ooo`3o0?ooooT0oooo0P3o001@0?ooo`030000003o
ool0oooo00L0oooo001C0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0o`3ooook
0?ooo`030?l0003oool0oooo04d0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?oo
o`3oool0603oool00`3o0000oooo0?ooo`3o0?oooo`0oooo0P3o001=0?ooo`030000003oool0oooo
00L0oooo001C0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0o`3oooon0?ooo`80
o`00B`3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0H0?ooo`030?l0
003oool0oooo0?l0ooooo`3oool10?ooo`80o`00B@3oool00`000000oooo0?ooo`070?ooo`00D`3o
ool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo0?l0ooooo`3oool30?ooo`030?l0003o
ool0oooo04H0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0603oool0
0`3o0000oooo0?ooo`3o0?ooool0oooo103oool20?l004H0oooo00<000000?ooo`3oool01`3oool0
05<0oooo1000000G0?ooo`030?l0003oool0oooo0?l0ooooo`3oool60?ooo`80o`00@P3oool30000
00T0oooo001C0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooo`P0
oooo0P3o00120?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01P0oooo
00<0o`000?ooo`3oool0o`3ooooo0?ooo`X0oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo
0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo0?l0ooooo`3o
oom<0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01P0oooo00<0o`00
0?ooo`3oool0o`3ooooo0?oood`0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?oo
o`3oool05`3oool00`3o0000oooo0?ooo`3o0?ooool0oooo4@3oool00`3o0000oooo0?ooo`0i0?oo
o`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3o
ool0o`3ooooo0?oooa80oooo0P3o000i0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000
003oool0oooo01L0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooa@0oooo0P3o000g0?ooo`030000
003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0o`3o
oooo0?oooaH0oooo0P3o000e0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0
oooo01L0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooaP0oooo0P3o000c0?ooo`030000003oool0
oooo00L0oooo001C0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0o`3ooooo0?oo
oaX0oooo00<0o`000?ooo`3oool0<03oool00`000000oooo0?ooo`070?ooo`00<`3oool00`3o_g@0
00000000000200000009001d_`3oool0oooo0?ooo`3OW4P0000004RLg`3oool0gia800L0000000<0
M;oo0?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo0?l0ooooo`3o
oolK0?ooo`80o`00<03oool00`000000oooo0?ooo`070?ooo`00=@3oool00`2oM000001d0;ooo`04
0?ooo`030=nLB0000000B9cO0080oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`08
0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooad0oooo0P3o000^
0?ooo`030000003oool0oooo00L0oooo000e0?ooo`030;md000007@0_ooo00X0oooo00<0gia804RL
g`3oool00P3oool00`3ooml0W4Qd0;ooo`090?ooo`030000003oool0oooo0?l0ooooo`3oooli0?oo
o`80o`00;03oool00`000000oooo0?ooo`070?ooo`00=@3oool00`2oM000001d0;ooo`0;0?ooo`03
0=nLB018W=l0oooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?oooc/0oooo0P3o000Z0?ooo`03
0000003oool0oooo00L0oooo000e0?ooo`030;md000007@0_ooo00`0oooo00<0gia807Boo`3oool0
303oool00`000000oooo0?ooo`3o0?ooool0oooo?@3oool00`3o0000oooo0?ooo`0W0?ooo`030000
003oool0oooo00L0oooo000e0?ooo`030;md000007@0_ooo00`0oooo00<0oooO09a8B02Lgol0303o
ool00`000000oooo0?ooo`3o0?ooool0oooo?P3oool20?l002L0oooo00<000000?ooo`3oool01`3o
ool003D0oooo00<0_g@00000M02oool03@3oool00`3ogi`0B01d0;ooo`0;0?ooo`D00000o`3ooooo
0?oooch0oooo0P3o000Q0?ooo`D000002@3oool003D0oooo00<0_g@00000M02oool03P3oool00`2o
M000B9cO0?ooo`0:0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0o`3ooooo0?oo
obT0oooo0P3o000S0?ooo`030000003oool0oooo00L0oooo000e0?ooo`030;md000007@0_ooo00h0
oooo00<0gia80000M02oool02P3oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo0?l0
ooooo`3oool[0?ooo`80o`008@3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`2oM000001d
0;ooo`0>0?ooo`030?noM0000000M;oo00X0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo
0?ooo`3o0?ooool0oooo;@3oool00`3o0000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo
000e0?ooo`030;md000007@0_ooo00P0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Bo
o`0:0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooodh0oooo00<0
00000?ooo`3oool01`3oool003<0oooo00D0gia8000000000000001d0;ooo`090?ooo`080;md001d
_ol0oooo0?ooo`3OW4P000000018W03Oool:0?ooo`030000003oool0oooo01H0oooo00<0o`000?oo
o`3oool0o`3ooooo0?ooodh0oooo00<000000?ooo`3oool01`3oool003@0oooo00@0oono07@00000
07@0_ooo2P3oool01@2oM000000000000000000007Bo00`0oooo00<000000?ooo`3oool05P3oool0
0`3o0000oooo0?ooo`3o0?ooool0oooo<P3oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0
oooo00L0oooo001C0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0o`3ooooo0?oo
oc<0oooo0P3o000I0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01H0
oooo00<0o`000?ooo`3oool0o`3ooooo0?ooocD0oooo0P3o000G0?ooo`030000003oool0oooo00L0
oooo001C0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooocP0oooo
0P3o000E0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01D0oooo00<0
o`000?ooo`3oool0o`3ooooo0?ooocX0oooo0P3o000C0?ooo`030000003oool0oooo00L0oooo001C
0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooc`0oooo0P3o000A
0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01D0oooo00<0o`000?oo
o`3oool0o`3ooooo0?oooch0oooo0P3o000?0?ooo`030000003oool0oooo00L0oooo001C0?ooo`03
0000003oool0oooo01D0oooo00<0o`000?ooo`3oool0o`3ooooo0?oood00oooo00<0o`000?ooo`3o
ool0303oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0E0?ooo`030?l0
003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003o
ool0oooo01D0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool01`3o
ool005<0oooo1000000D0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom=0?ooo`<000002@3oool0
05<0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`3o0?ooool0ooooC`3oool00`00
0000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo0?l0
ooooo`3ooom?0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01D0oooo
00<0o`000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool01`3oool005<0oooo00<0
00000?ooo`3oool05@3oool00`3o0000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?oo
o`070?ooo`00D`3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom?
0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01D0oooo00<0o`000?oo
o`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3o
ool05@3oool00`3o0000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`070?ooo`00
D`3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom?0?ooo`030000
003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool0o`3o
oooo0?oooe00oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0503oool0
0`3o0000oooo0?ooo`3o0?ooool0ooooD03oool00`000000oooo0?ooo`070?ooo`00D`3oool00`00
0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom@0?ooo`030000003oool0oooo
00L0oooo001C0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooe00
oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0503oool00`3o0000oooo
0?ooo`3o0?ooool0ooooD03oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?oo
o`0D0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom@0?ooo`030000003oool0oooo00L0oooo001C
0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooe00oooo00<00000
0?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`3o0?oo
ool0ooooD03oool00`000000oooo0?ooo`070?ooo`00D`3oool400000?l0ooooo`3ooomT0?ooo`<0
00002@3oool005<0oooo00<000000?ooo`3oool0o`3ooooo0?ooofL0oooo00<000000?ooo`3oool0
1`3oool005<0oooo00<000000?ooo`3oool0o`3ooooo0?ooofL0oooo00<000000?ooo`3oool01`3o
ool005<0oooo00<000000?ooo`3oool0o`3ooooo0?ooofL0oooo00<000000?ooo`3oool01`3oool0
05<0oooo00<000000?ooo`3oool0o`3ooooo0?ooofL0oooo00<000000?ooo`3oool01`3oool005<0
oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`3o0?ooool0ooooD03oool00`000000
oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0?l0oooo
o`3ooom@0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01@0oooo00<0
o`000?ooo`3oool0o`3ooooo0?oooe00oooo00<000000?ooo`3oool01`3oool005<0oooo00<00000
0?ooo`3oool0503oool00`3o0000oooo0?ooo`3o0?ooool0ooooD03oool00`000000oooo0?ooo`07
0?ooo`00D`3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom@0?oo
o`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3o
ool0o`3ooooo0?oooe00oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0
503oool00`3o0000oooo0?ooo`3o0?ooool0ooooD03oool00`000000oooo0?ooo`070?ooo`00D`3o
ool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom@0?ooo`030000003o
ool0oooo00L0oooo001C0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool0o`3ooooo
0?oooe40oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool04`3oool00`3o
0000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000
oooo0?ooo`0C0?ooo`030?l0003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo00L0
oooo001C0?ooo`@000004P3oool00`3o0000oooo0?ooo`3o0?ooool0ooooC`3oool3000000T0oooo
001C0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooe40oooo00<0
00000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`3o
0?ooool0ooooD@3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0C0?oo
o`030?l0003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo00L0oooo001C0?ooo`03
0000003oool0oooo01<0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3o
ool01`3oool005<0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`3o0?ooool0oooo
D@3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0C0?ooo`030?l0003o
ool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0
oooo01<0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool01`3oool0
05<0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`3o0?ooool0ooooD@3oool00`00
0000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0oooo0?l0
ooooo`3ooomA0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo01<0oooo
00<0o`000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool01`3oool005<0oooo00<0
00000?ooo`3oool04`3oool00`3o0000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?oo
o`070?ooo`00D`3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo0?l0ooooo`3ooomB
0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo0180oooo00<0o`000?oo
o`3oool0o`3ooooo0?oooe80oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`3o0?ooool0ooooDP3oool00`000000oooo0?ooo`070?ooo`00
D`3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo0?l0ooooo`3ooomB0?ooo`030000
003oool0oooo00L0oooo001C0?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3oool0o`3o
oooo0?oooe80oooo00<000000?ooo`3oool01`3oool005<0oooo1000000A0?ooo`030?l0003oool0
oooo0?l0ooooo`3ooom@0?ooo`<000002@3oool005<0oooo00<000000?ooo`3oool04P3oool00`3o
0000oooo0?ooo`3o0?ooool0ooooDP3oool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000
oooo0?ooo`0B0?ooo`030?l0003oool0oooo0?l0ooooo`3ooomB0?ooo`030000003oool0oooo00L0
oooo001C0?ooo`030000003oool0oooo0?l0ooooo`3ooomW0?ooo`030000003oool0oooo00L0oooo
001C0?ooo`030000003oool0oooo0?l0ooooo`3ooomW0?ooo`030000003oool0oooo00L0oooo001C
0?ooo`030000003oool0oooo0?l0ooooo`3ooomW0?ooo`030000003oool0oooo00L0oooo001C0?oo
o`030000003oool0oooo0?l0ooooo`3ooomW0?ooo`030000003oool0oooo00L0oooo001C0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomW0?ooo`030000003oool0oooo00L0oooo001C0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool005<0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`070?ooo`00D`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00L0oooo001C0?ooool00000o`00001[000000T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 708.25}, {437.375, 0}} -> {-0.167963, 0.981411, \
0.00170525, 0.000607866}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ 
        Repeat\ above\ calculation\ for\ \((Log \((t\_lag)\) - 
              Log \((L)\))\)\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(omv = {0.01, 0.03, 0.05, 0.07, 0.09, 0.1, 0.15, 0.2, 0.25, 
        0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1}; valsom = Length[omv]; \ 
    r1om = {};\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[om = omv[\([q]\)]; \[IndentingNewLine]Clear[f, dl, dld]; 
      w0 = \(-1\); w1 = 0; h0 = 10^5\ h; \ c = 3\ 10^8; 
      h = 0.72; \[IndentingNewLine]f[z_] := 
        1/Sqrt[om*\((1 + z)\)^3\  + \((1 - 
                    om)\)*\((1 + z)\)^\((3 \((1 + w0\  + \ w1)\))\) 
                Exp[3\ w1\ \((\((1/\((1 + z)\))\) - 1)\)]]; \n
      dl[zz_] := c \((1 + zz)\)\ NIntegrate[f[z], {z, 0, zz}]/h0; \n
      dld = dl[zz[#]] 3\ 10^24 &; \nll = 4\ Pi\ dld[#]^2\ pbolo[#] &; \n
      sll = 4\ Pi\ dld[#]^2\ spbolo[#] &; \n
      eg = 4\ Pi\ dld[#]^2\ sbolo[#]\ fbeam[#]/\((1 + zz[#])\) &; \nzmin = 0; 
      zmax = 7; \n
      Clear[lltlag, slltlag]\n\(lltlag = {}; slltlag = {};\)\n
        Do[\[IndentingNewLine]If[
            tlag[i] > 0\  && \ zz[i] \[GreaterEqual] zmin\  && \ 
              zz[i] \[LessEqual] \ zmax, \[IndentingNewLine]AppendTo[
              lltlag, {Log[10, tlag[i]], 
                Log[10, ll[i]]}]; \[IndentingNewLine]AppendTo[
              slltlag, {stlag[i]/\((Log[10]\ tlag[i])\), 
                sll[i]/\((Log[10]\ ll[i])\)}]], {i, 1, 
            ndat}]; \[IndentingNewLine]\[IndentingNewLine]llp[a1_, b1_, x_] := 
        a1\  + \ b1\ x; \[IndentingNewLine]tlagp[a1_, b1_, 
          x_] := \((x - a1)\)/b1; \[IndentingNewLine]\[IndentingNewLine]chi2[
          a1_, b1_, s1_] := 
        Sum[\((\((lltlag[\([i, 2]\)] - 
                      llp[a1, b1, 
                        lltlag[\([i, 1]\)]])\)^2/\((slltlag[\([i, 2]\)]^2 + 
                    s1^2)\))\), {i, 1, Length[lltlag]}] + 
          Sum[\((\((lltlag[\([i, 1]\)] - 
                      tlagp[a1, b1, 
                        lltlag[\([i, 2]\)]])\)^2/\((slltlag[\([i, 1]\)]^2 + 
                    s1^2)\))\), {i, 1, 
              Length[lltlag]}]; \[IndentingNewLine]\[IndentingNewLine]s1 = 
        0.39; \npar = {a1, b1}; \n
      akl[a1_, b1_, k_, l_] := 
        1/2  D[D[chi2[a1, b1, 0.5], par[\([k]\)]], par[\([l]\)]\ ]; \n
      fmingrb = FindMinimum[chi2\ [a1, b1, s1], {a1, 1}, {b1, \(-10\)}]; \n
      a1o = fmingrb[\([2, 1, 2]\)]; \nb1o = fmingrb[\([2, 2, 2]\)]; \n
      aklo = Table[
          If[k \[LessSlantEqual] l, \(akl[a1, b1, k, l] /. a1 \[Rule] a1o\) /. 
              b1 \[Rule] b1o, \(akl[a1, b1, l, k] /. a1 \[Rule] a1o\) /. 
              b1 \[Rule] b1o], {k, 1, 2}, {l, 1, 2}]; cij = Inverse[aklo]; 
      spar = Table[Sqrt[cij[\([i, i]\)]], {i, 1, 2}]; 
      Print["\<a1= \>", a1o, "\<+-\>", spar[\([1]\)], "\<  b1= \>", 
        b1o, "\<+-\>", spar[\([2]\)]]; 
      cij // MatrixForm; \[IndentingNewLine]erra1o = 
        spar[\([1]\)]; \[IndentingNewLine]errb1o = 
        spar[\([2]\)]; \[IndentingNewLine]chi2r = 
        Part[fmingrb, 
            1]/\((2\ Length[
                lltlag])\); \[IndentingNewLine]Print["\<chi2r=\>", 
        chi2r, "\<  ngrb=\>", ngrb]; \[IndentingNewLine]AppendTo[
        r1om, {om, chi2r}], \[IndentingNewLine]{q, 1, valsom}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.60193542327563`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.06268332534175933`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.1075240919770453`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.08221151856420839`\),
      SequenceForm[ 
      "a1= ", 52.601935423275627, "+-", .062683325341759327, 
        "  b1= ", -1.1075240919770453, "+-", .082211518564208386],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.3790458330103224`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.3790458330103224, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.541215512638104`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.062023033499901466`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]\(-1.0799887958237042`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.08174727934256266`\),
      SequenceForm[ 
      "a1= ", 52.541215512638104, "+-", .062023033499901466, 
        "  b1= ", -1.0799887958237042, "+-", .081747279342562665],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.2787501739106257`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.2787501739106257, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.496217175767676`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.061593821875994145`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]\(-1.0627150366482971`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.08142550085085143`\),
      SequenceForm[ 
      "a1= ", 52.496217175767676, "+-", .061593821875994145, 
        "  b1= ", -1.0627150366482971, "+-", .081425500850851429],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.2202301981252481`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.2202301981252481, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.45949372168888`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.061274225131924015`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]\(-1.0501544710567772`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.08117704125388897`\),
      SequenceForm[ 
      "a1= ", 52.459493721688879, "+-", .061274225131924015, 
        "  b1= ", -1.0501544710567772, "+-", .081177041253888971],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.1795667634108475`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.1795667634108475, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.42808814313234`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.06102002017718787`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.0403404385797594`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.0809744844048261`\),
      SequenceForm[ 
      "a1= ", 52.428088143132342, "+-", .06102002017718787, 
        "  b1= ", -1.0403404385797594, "+-", .080974484404826103],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.1488125462972858`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.1488125462972858, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.41386938024595`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.0609102385625541`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.0361491845370703`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.08088573221730495`\),
      SequenceForm[ 
      "a1= ", 52.413869380245949, "+-", .060910238562554099, 
        "  b1= ", -1.0361491845370703, "+-", .080885732217304954],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.1359350261207242`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.1359350261207242, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.353158008193745`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.06047515771703798`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.0198091636640036`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.08052688046697426`\),
      SequenceForm[ 
      "a1= ", 52.353158008193745, "+-", .060475157717037979, 
        "  b1= ", -1.0198091636640036, "+-", .08052688046697426],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0871016853112725`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0871016853112725, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.3041770194836`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.060159872928438746`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]\(-1.0082293670145983`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.08026012997084718`\),
      SequenceForm[ 
      "a1= ", 52.304177019483603, "+-", .060159872928438746, 
        "  b1= ", -1.0082293670145983, "+-", .08026012997084718],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.053726214135331`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.053726214135331, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.26275746384209`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05991530831354588`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-0.9993924422917467`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.08004952059517377`\),
      SequenceForm[ 
      "a1= ", 52.262757463842092, "+-", .059915308313545877, 
        "  b1= ", -.99939244229174673, "+-", .08004952059517377],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0288937965019251`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0288937965019251, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.22668792407404`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05971730915705118`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-0.9923285402376796`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07987669165958984`\),
      SequenceForm[ 
      "a1= ", 52.226687924074042, "+-", .059717309157051181, 
        "  b1= ", -.99232854023767958, "+-", .079876691659589841],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0094228281432303`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0094228281432303, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.165723668419695`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.059411418956027716`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]\(-0.9815702079902601`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07960558486762584`\),
      SequenceForm[ 
      "a1= ", 52.165723668419695, "+-", .059411418956027716, 
        "  b1= ", -.98157020799026007, "+-", .079605584867625839],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9803981517348566`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .98039815173485656, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.11506397714753`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05918213465235232`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-0.9736260513084525`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07939900282289941`\),
      SequenceForm[ 
      "a1= ", 52.115063977147528, "+-", .059182134652352322, 
        "  b1= ", -.97362605130845248, "+-", .079399002822899412],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9594520337401128`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .95945203374011279, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.07152588913335`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05900140502883694`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-0.9674347409459587`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07923401044900312`\),
      SequenceForm[ 
      "a1= ", 52.071525889133348, "+-", .05900140502883694, 
        "  b1= ", -.96743474094595872, "+-", .07923401044900312],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9434214384082026`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .94342143840820258, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.033238759504016`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05885393499590303`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-0.9624279727212685`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.0790978739576187`\),
      SequenceForm[ 
      "a1= ", 52.033238759504016, "+-", .05885393499590303, 
        "  b1= ", -.96242797272126845, "+-", .079097873957618706],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9306549746181455`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .9306549746181455, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]51.99900086927101`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.058730510906940786`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]\(-0.9582682872527509`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07898281894187714`\),
      SequenceForm[ 
      "a1= ", 51.999000869271008, "+-", .058730510906940786, 
        "  b1= ", -.95826828725275093, "+-", .078982818941877142],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.92019025718846`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .92019025718846004, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]51.96799037314523`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.058625179057488506`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]\(-0.9547401826780005`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07888376799984084`\),
      SequenceForm[ 
      "a1= ", 51.967990373145227, "+-", .058625179057488506, 
        "  b1= ", -.95474018267800054, "+-", .078883767999840843],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9114216612931606`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .9114216612931606, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]51.93961840148197`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05853388544464538`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-0.9516983714228539`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07879723316044548`\),
      SequenceForm[ 
      "a1= ", 51.939618401481972, "+-", .058533885444645377, 
        "  b1= ", -.95169837142285385, "+-", .078797233160445485],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9039457483073475`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .90394574830734753, "  ngrb=", 27],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[r1om, Frame \[Rule] True, Axes \[Rule] False]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -1.10519 1.2389 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -14.5625 -24.5625 ]
[.21429 -0.0125 14.5625 0 ]
[.40476 -0.0125 -14.5625 -24.5625 ]
[.40476 -0.0125 14.5625 0 ]
[.59524 -0.0125 -14.5625 -24.5625 ]
[.59524 -0.0125 14.5625 0 ]
[.78571 -0.0125 -14.5625 -24.5625 ]
[.78571 -0.0125 14.5625 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00983 -29.125 -12.2813 ]
[-0.0125 .00983 0 12.2813 ]
[-0.0125 .13372 -14.0625 -12.2813 ]
[-0.0125 .13372 0 12.2813 ]
[-0.0125 .25761 -29.125 -12.2813 ]
[-0.0125 .25761 0 12.2813 ]
[-0.0125 .3815 -29.125 -12.2813 ]
[-0.0125 .3815 0 12.2813 ]
[-0.0125 .50539 -29.125 -12.2813 ]
[-0.0125 .50539 0 12.2813 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00983 m
.00625 .00983 L
s
gsave
-0.0125 .00983 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
0 .13372 m
.00625 .13372 L
s
gsave
-0.0125 .13372 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .25761 m
.00625 .25761 L
s
gsave
-0.0125 .25761 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
0 .3815 m
.00625 .3815 L
s
gsave
-0.0125 .3815 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .50539 m
.00625 .50539 L
s
gsave
-0.0125 .50539 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0346 m
.00375 .0346 L
s
0 .05938 m
.00375 .05938 L
s
0 .08416 m
.00375 .08416 L
s
0 .10894 m
.00375 .10894 L
s
0 .1585 m
.00375 .1585 L
s
0 .18327 m
.00375 .18327 L
s
0 .20805 m
.00375 .20805 L
s
0 .23283 m
.00375 .23283 L
s
0 .28239 m
.00375 .28239 L
s
0 .30716 m
.00375 .30716 L
s
0 .33194 m
.00375 .33194 L
s
0 .35672 m
.00375 .35672 L
s
0 .40628 m
.00375 .40628 L
s
0 .43105 m
.00375 .43105 L
s
0 .45583 m
.00375 .45583 L
s
0 .48061 m
.00375 .48061 L
s
0 .53017 m
.00375 .53017 L
s
0 .55494 m
.00375 .55494 L
s
0 .57972 m
.00375 .57972 L
s
0 .6045 m
.00375 .6045 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00983 m
1 .00983 L
s
.99375 .13372 m
1 .13372 L
s
.99375 .25761 m
1 .25761 L
s
.99375 .3815 m
1 .3815 L
s
.99375 .50539 m
1 .50539 L
s
.125 Mabswid
.99625 .0346 m
1 .0346 L
s
.99625 .05938 m
1 .05938 L
s
.99625 .08416 m
1 .08416 L
s
.99625 .10894 m
1 .10894 L
s
.99625 .1585 m
1 .1585 L
s
.99625 .18327 m
1 .18327 L
s
.99625 .20805 m
1 .20805 L
s
.99625 .23283 m
1 .23283 L
s
.99625 .28239 m
1 .28239 L
s
.99625 .30716 m
1 .30716 L
s
.99625 .33194 m
1 .33194 L
s
.99625 .35672 m
1 .35672 L
s
.99625 .40628 m
1 .40628 L
s
.99625 .43105 m
1 .43105 L
s
.99625 .45583 m
1 .45583 L
s
.99625 .48061 m
1 .48061 L
s
.99625 .53017 m
1 .53017 L
s
.99625 .55494 m
1 .55494 L
s
.99625 .57972 m
1 .57972 L
s
.99625 .6045 m
1 .6045 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03333 .60332 Mdot
.05238 .47906 Mdot
.07143 .40656 Mdot
.09048 .35618 Mdot
.10952 .31808 Mdot
.11905 .30213 Mdot
.16667 .24163 Mdot
.21429 .20028 Mdot
.2619 .16951 Mdot
.30952 .14539 Mdot
.40476 .10943 Mdot
.5 .08348 Mdot
.59524 .06362 Mdot
.69048 .04781 Mdot
.78571 .03484 Mdot
.88095 .02398 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{516.25, 319.063},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000840001?b000`400?l00000o`00003oo`3ooooo
0?ooo`H0oooo003o0?ooool0oooo1P3oool00?l0ooooo`3oool60?ooo`00o`3ooooo0?ooo`H0oooo
003o0?ooool0oooo1P3oool00?l0ooooo`3oool60?ooo`00o`3ooooo0?ooo`H0oooo000c0?ooo`04
0;md00000000000004RLgdd0oooo00@0_g@0000000000000B9cO103oool01@3OW4P0000004RLg`3o
ool0gia800L0000000<0M;oo0?ooo`3oool0@P3oool0102oM000000000000018W=l40?ooo`030=nL
B0000000B9cO00H0oooo00<0okmd0000001d_ol0A03oool0102oM000000000000018W=l40?ooo`03
0=nLB0000000B9cO00<0oooo00H0oooO09a80000000000000000M02ooom50?ooo`040;md00000000
000004RLg`@0oooo00<0gia800000018W=l00`3oool01P3ogi`0B000000000000000001809cOod/0
oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0?0?ooo`00<@3oool01`3ooml0W4P0
001d_`3oool0oooO09a80000M;l0BP3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3o
ool00`3OW4P0000004RLg`020?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool0@03o
ool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`060?ooo`03
0?noM0000000M;oo0480oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia8
00000018W=l00P3oool0203ookl0M0000018W03Oool0oooo0=nLB00004P0W=oo@P3oool01`3ooml0
W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`080?oOW0180000
04RL0=ooo`3oool0omnL04P0001d_om<0?ooo`030;md000007@0_ooo0180oooo000a0?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol0B@3oool00`3o_g@0001809cOo`020?ooo`030?oO
W0180000M;oo00P0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`110?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol02`3oool00`3o_g@0000007Boo`120?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`2oM000001d0;ooo`030?ooo`030;md
0000M;l0oooo0440oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030;md
000007@0_ooo00<0oooo00<0gia80018W03Oool0B`3oool00`2oM000001d0;ooo`0B0?ooo`00<03o
ool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo04P0oooo00@0oooO09a80000B9`0
gooo0P3oool00`3ooml0W4P0001d_`090?ooo`030=nLB018W=l0oooo04@0oooo00@0oooO09a80000
B9`0gooo0P3oool00`3ooml0W4P0001d_`060?ooo`030=nLB0000000000000D0000000<0001809cO
o`3oool0?P3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00H0oooo00<0oono
07@00000M;l0103oool00`3OW4P0001d0;ooo`100?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
oooO09a80000M;l01`3oool00`2oM000001d0;ooo`030?ooo`030;md0000B9`0gooo04/0oooo00<0
_g@00000M02oool04P3oool00300oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`17
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02@3oool00`3OW4P0M;oo0?ooo`13
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01@3oool00`3ogi`0B7Bo0?ooo`02
0?ooo`030?noM0000000M;oo0440oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`05
0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000B02Lgol0@03oool00`3ookl0M000001d_`04
0?ooo`030;md000007@0_ooo00H0oooo00<0okmd0000B02Lgol00P3oool00`3OW4P00000001d_`1<
0?ooo`030;md000007@0_ooo0180oooo000`0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000
M02oool0A`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00T0oooo00<0oooO09a8
B02Lgol0@`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00H0oooo00L0gia807Bo
o`3oool0oooo0?noM0000000M;oo0440oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;oo
o`050?ooo`030?oOW0180000B9cO00<0oooo00@0oono07@0000007@0_ooo@03oool00`3ogi`0B000
04RLg`040?ooo`030;md000007@0_ooo00L0oooo00L0gia8001d_`3oool0_g@00000000007@0_ooo
04`0oooo00<0_g@00000M02oool04P3oool00300oooo00<0omnL04P00018W=l0103oool00`3OW4P0
001809cOo`170?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol02P3oool00`3ogi`0
B01d0;ooo`120?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01P3oool01`3ookl0
M01d0;ooo`3oool0okmd0000001d_ol0@@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0
W=oo00D0oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l0@@3oool00`3ogi`0
B00004RLg`040?ooo`030=nLB00004P0W=oo00P0oooo00D0okmd00000000000004RL0=ooo`1=0?oo
o`030;md000007@0_ooo0180oooo000`0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02L
gol0A`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00/0oooo00<0_g@004RLg`3o
ool0@@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0oooo00H0okmd001d_`3o
ool0okmd0000001d_om10?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01@3oool0
1@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool0@03oool00`3ogi`0B00004RL
g`040?ooo`030=nLB00004P0W=oo00L0oooo00D0omnL04P000000000000004RLg`1>0?ooo`030;md
000007@0_ooo0180oooo000`0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0A`3o
ool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0gia80000M02oool0@@3o
ool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00P0oooo00D0_g@007Boo`3o_g@00000
07Boo`110?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@00000
04RLg`160?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool01`3ogi`0B000
0000B02Lgol0oooo0=nLB000M;l0C@3oool00`2oM000001d0;ooo`0B0?ooo`00<@3oool00`2oM000
04RL0=ooo`020?ooo`030?oog`2LB00007Bo04T0oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`0<0?ooo`030?noM0000000M;oo0480oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`090?ooo`050?oo_`1d07@0_kmd0000001d_ol0@P3oool00`2oM00004RL0=ooo`020?oo
o`030?oog`2LB00007Bo00L0oooo00@0oooO09a8000004P0W=ooAP3oool00`2oM00004RL0=ooo`02
0?ooo`030?oog`2LB00007Bo00L0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P007Boo`1<
0?ooo`030;md000007@0_ooo0180oooo000a0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0
001d_ol0B@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00H0oooo00<0omnL09bo
o`3oool00`3oool00`2oM000000007Boo`120?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0
001d_ol02P3oool0103o_g@000000000001d_om20?ooo`030?noM00004P0W=oo0080oooo00<0omnL
04P0001d_ol0203oool0103ookl0M0000000M02ooom50?ooo`030?noM00004P0W=oo0080oooo00<0
omnL04P0001d_ol01`3oool00`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO04`0oooo00<0
_g@00000M02oool04P3oool00380oooo00H0_g@00018W03Oool0oooo0;md0000M;m;0?ooo`060;md
0000B9`0gooo0?ooo`2oM00007Bo203oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo
@`3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`/0oooo00@0oooO09a800000000M;oo@`3oool0
1P2oM00004RL0=ooo`3oool0_g@0001d_`X0oooo00@0oooO09a80000000007BoA@3oool01P2oM000
04RL0=ooo`3oool0_g@0001d_`P0oooo00<0omnL04P00018W=l00P3oool00`3o_g@0001809cOo`1:
0?ooo`050=nLB000000000000000M02oool04P3oool003<0oooo00@0_g@000000000000007BoC@3o
ool0102oM000000000000000M;l:0?ooo`050;md00000000000000000000M;l0AP3oool0102oM000
000000000000M;l=0?ooo`030?oOW0180000M;oo04@0oooo00@0_g@000000000000007Bo3@3oool0
1@3ogi`0B00000000000B9`0gooo04<0oooo00@0_g@000000000000007Bo2P3oool01P3ookl0M000
000000000000001809cOod`0oooo00@0oono07@0000007@0_ooo4P3oool00?l0ooooo`3oool60?oo
o`00o`3ooooo0?ooo`H0oooo003o0?ooool0oooo1P3oool00?l0ooooo`3oool60?ooo`00o`3ooooo
0?ooo`H0oooo003o0?ooool0oooo1P3oool00?l0ooooo`3oool60?ooo`00o`3ooooo0?ooo`H0oooo
003o0?ooool0oooo1P3oool00?l0ooooo`3oool60?ooo`00303oool0102oM000000000000018W=l4
0?ooo`090=nLB0000000B9cO0?ooo`3ooml0W4P00000000004P0W=oo0?l0ooooj03oool000X0oooo
00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l0103oool0103O
W4P000000018W03Oool;0?ooool00000d`0000080?ooo`002P3oool00`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo00X0oooo00@0oono07@0000007@0_ooo2P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00H0oooo00090?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO
09a80000M;l02`3oool0103ookl0M0000018W03Oool90?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01P3oool000T0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0;
0?ooo`030=nLB0000000M;oo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`06
0?ooo`002@3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00L0oooo00<0gia80000
000000000`0000000`00B9`0gooo0?ooo`070?ooo`@00000o`3oooo;0?ooo`@00000203oool000T0
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`060?ooo`030;md0000000007Bo0080
oooo00@0oono07@0000007@0_ooo203oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?oo
o`3oool01P3oool000T0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`050?ooo`04
0?oo_`1d000004RL0=ooo`<0oooo00<0_g@00000B02Lgol0203oool00`000000oooo0?ooo`3o0?oo
ol@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`002@3oool00`3ookl0
M000001d_`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04P00018W=l0103oool00`3OW4P0
001809cOo`080?ooo`030000003oool0oooo0?l0oooo``3oool3000000T0oooo00<000000?ooo`3o
ool01P3oool000X0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`060?ooo`030?oO
W0180000B9cO00@0oooo00<0_g@00000M02oool0203oool00`000000oooo0?ooo`3o0?oool@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`002P3oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo00H0oooo00<0oooO09a80000M;l00`3oool00`3ookl0M00004RL
g`090?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`002`3oool0
1P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00P0omnL04P0001d_ol0oooo0?oog`2LB00004RL
0=ooo`T0oooo00<000000?ooo`3oool0o`3ooonH0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool01P3oool000`0oooo00@0_g@000000000000007Bo2P3oool01P3ookl0M00000000000
000004RL0=ooo`X0oooo00<000000?ooo`3oool0o`3ooonG0?ooo`<00000=@3oool00`000000oooo
0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooiP0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<00000
0?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo
00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooJ`3oool00`000000oooo0?ooo`1Q0?ooo`03
0000003oool0oooo00H0oooo000Z0?ooo`<00000o`3ooomZ0?ooo`<00000H@3oool2000000P0oooo
000Z0?ooo`030000003oool0oooo0?l0ooooJ`3oool00`000000oooo0?ooo`1Q0?ooo`030000003o
ool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`06
0?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0
oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000
003oool0oooo0?l0oooo?`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00H0oooo
000Z0?ooo`030000003oool0oooo0?l0oooo?P3oool3000008h0oooo00<000000?ooo`3oool01P3o
ool002X0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo
00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00
:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo0`00
003o0?ooolh0oooo0P0000080?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<00000
0?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`030000003oool0oooo
0;T0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`<0
0000^P3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooa<0oooo
00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?oo
o`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?
0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`00
0000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3o
ool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo
000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool0
0`000000oooo0?ooo`3U0?ooo`030000003oool0oooo0>H0oooo00<000000?ooo`3oool01P3oool0
02X0oooo0`00003T0?ooo`<00000iP3oool2000000P0oooo000Z0?ooo`030000003oool0oooo0>D0
oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo
0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3o
ooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool0
0`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?oo
o`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0
oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3o
ool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<00000
0?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo
0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`2i0?ooo`03
0000003oool0oooo0?l0oooo4`3oool00`000000oooo0?ooo`060?ooo`00:P3oool300000;P0oooo
0`00003o0?oooa<0oooo0P0000080?ooo`00:P3oool00`000000oooo0?ooo`2i0?ooo`030000003o
ool0oooo0?l0oooo4`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o
0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?oo
o`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000
oooo0?ooo`060?ooo`006P3oool00`3o_g@000000000000200000003001d_`3oool0oooo00P0oooo
00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000L0?ooo`030;md0000
07@0_ooo00/0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000L
0?ooo`030;md000007@0_ooo00/0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0
oooo00H0oooo000L0?ooo`030;md000007@0_ooo00/0oooo00<000000?ooo`3oool0o`3oooo?0?oo
o`030000003oool0oooo00H0oooo000L0?ooo`030;md000007@0_ooo00/0oooo00<000000?ooo`3o
ool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000L0?ooo`030;md000007@0_ooo00/0oooo
00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000L0?ooo`030;md0000
07@0_ooo00/0oooo1000003o0?oool/0oooo100000080?ooo`00703oool00`2oM000001d0;ooo`0;
0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00703oool00`2o
M000001d0;ooo`0;0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?oo
o`00703oool00`2oM000001d0;ooo`0;0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000
oooo0?ooo`060?ooo`00703oool00`2oM000001d0;ooo`0;0?ooo`030000003oool0oooo0?l0oooo
c`3oool00`000000oooo0?ooo`060?ooo`006P3oool01@3OW4P000000000000007@0_ooo00/0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3o0?ooocl0oooo00<000000?ooo`3oool0
1P3oool001/0oooo00@0oono07@0000007@0_ooo2`3oool00`000000oooo0?ooo`2<0?ooo`<00000
o`3ooom00?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0o`3ooolo0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0
oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oo
oll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`03
0000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo
0?ooo`060?ooo`00:P3oool300000?l0oooocP3oool2000000P0oooo000Z0?ooo`030000003oool0
oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oo
oll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`03
0000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
o`3ooomF0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo07D0oooo0`00
003o0?oooeL0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`3o0?oooeH0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?oo
o`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0
ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo
00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003o
ool0oooo00H0oooo000Z0?ooo`<00000o`3oooo>0?ooo`800000203oool002X0oooo00<000000?oo
o`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0
ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo
00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003o
ool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`06
0?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?ooof`0oooo00<000000?ooo`3o
ool01P3oool002X0oooo00<000000?ooo`3oool0G`3oool300000?l0ooooK@3oool00`000000oooo
0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0ooooK03o
ool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<00000
0?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo
00H0oooo000Z0?ooo`<00000o`3oooo>0?ooo`800000203oool002X0oooo00<000000?ooo`3oool0
o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3o
ool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<00000
0?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo
00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00
:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<0
00000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0
oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oo
oll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`03
0000003oool0oooo00H0oooo000Z0?ooo`<00000o`3oooo>0?ooo`800000203oool002X0oooo00<0
00000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0
oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oo
oll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`3o0?oooh80oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0
B@3oool300000?l0ooooP`3oool00`000000oooo0?ooo`060?ooo`002`3oool00`3o_g@000000000
000200000007001d_`3oool0oooo0?ooo`3OW4P0000004RLg`030?ooo`030?noM000000000000080
000000<007Bo0?ooo`3oool0203oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0
ooooPP3oool00`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`040?ooo`030=nL
B0000000B9cO00D0oooo00<0_g@00000M02oool02`3oool00`000000oooo0?ooo`3o0?oooll0oooo
00<000000?ooo`3oool01P3oool000d0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;oo
o`0;0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`003@3oool0
0`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00/0oooo00<000000?ooo`3oool0o`3oooo?
0?ooo`030000003oool0oooo00H0oooo000=0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000
M02oool02`3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool000d0
oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`0;0?ooo`030000003oool0oooo0?l0
ooooc`3oool00`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`0<0?ooo`030;md
000007@0_ooo00/0oooo1000003o0?oool/0oooo100000080?ooo`003@3oool00`2oM000001d0;oo
o`0<0?ooo`030;md000007@0_ooo00/0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003o
ool0oooo00H0oooo000=0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool02`3oool0
0`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool000d0oooo00<0_g@00000
M02oool0303oool00`2oM000001d0;ooo`0;0?ooo`030000003oool0oooo0?l0ooooc`3oool00`00
0000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00/0
oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000;0?ooo`050=nL
B000000000000000M02oool02P3oool01@3OW4P000000000000007@0_ooo00/0oooo00<000000?oo
o`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000<0?ooo`040?oo_`1d0000001d0;oo
o`/0oooo00@0oono07@0000007@0_ooo2`3oool00`000000oooo0?ooo`3o0?oooll0oooo00<00000
0?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo
00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00
:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<0
00000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`<00000o`3oooo>
0?ooo`800000203oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo
00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00
:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<0
00000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0
oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oo
oll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`03
0000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo
0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0ooooV03o
ool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`0c0?ooo`<00000o`3ooonI
0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0o`3ooonH0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`<00000o`3oooo>0?ooo`80
0000203oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo
000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool0
0`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`3o0?oooid0oooo00<000000?ooo`3oool01P3oool002X0
oooo00<000000?ooo`3oool0;P3oool300000?l0ooooWP3oool00`000000oooo0?ooo`060?ooo`00
:P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0ooooW@3oool00`000000oooo
0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3o
ool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?oo
o`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000
oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo0`00003o0?ooolh0oooo
0P0000080?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3o
ool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?oo
o`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000
oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0
o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3o
ool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<00000
0?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo
00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00
:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool01P3o
ool002X0oooo0`00000V0?ooo`<00000o`3ooonU0?ooo`800000203oool002X0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool01P3oool002X0
oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000
003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?oo
o`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?
0?ooo`030000003oool0oooo00H0oooo000;0?ooo`030?noM000000000000080000000T007Bo0?oo
o`3oool0oooo0=nLB0000000B9cO0?ooo`3OW4P01`0000000`1d_ol0oooo0?ooo`070?ooo`030000
003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;oo
o`040?ooo`030=nLB0000000B9cO0080oooo00<0gia8000000000000100000000`00M;l0oooo0?oo
o`070?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`003@3oool0
0`2oM000001d0;ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool0203oool0
0`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool000d0oooo00<0_g@00000
M02oool02`3oool00`3OW4P0B9cO0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooc`3oool00`00
0000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;ooo`0<0?ooo`030=nLB01d_ol0oooo00/0
oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000=0?ooo`030;md
000007@0_ooo00`0oooo00<0oooO09a8B02Lgol02`3oool400000?l0oooob`3oool4000000P0oooo
000=0?ooo`030;md000007@0_ooo00d0oooo00<0omnL04P0M02oool02P3oool00`000000oooo0?oo
o`3o0?oooll0oooo00<000000?ooo`3oool01P3oool000d0oooo00<0_g@00000M02oool03P3oool0
0`2oM000B9cO0?ooo`090?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`06
0?ooo`003@3oool00`2oM000001d0;ooo`0>0?ooo`030=nLB00007@0_ooo00T0oooo00<000000?oo
o`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000=0?ooo`030;md000007@0_ooo00h0
oooo00<0okmd0000001d_ol02@3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3o
ool01P3oool000d0oooo00<0_g@00000M02oool0203oool00`3ogi`0W;oo0?ooo`030?ooo`030;md
00000000M;oo00T0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo
000;0?ooo`050=nLB000000000000000M02oool02@3oool0202oM000M;oo0?ooo`3oool0gia80000
0000B9`0gooo2@3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool0
00`0oooo00@0oono07@0000007@0_ooo2P3oool01@2oM000000000000000000007Bo00/0oooo00<0
00000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0
oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oo
oll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`03
0000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
o`3ooon^0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`<000007@3oool300000?l0oooo[P3o
ool2000000P0oooo000Z0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooon^
0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`00
0000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3o
ool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo
000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool0
0`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?oo
o`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0
ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo
00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003o
ool0oooo00H0oooo000Z0?ooo`<00000o`3oooo>0?ooo`800000203oool002X0oooo00<000000?oo
o`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0
ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo
00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003o
ool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`06
0?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0
oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000
003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?oo
o`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?
0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`00
0000oooo0?ooo`060?ooo`00:P3oool300000?l0oooocP3oool2000000P0oooo000Z0?ooo`030000
003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?oo
o`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?
0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`00
0000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3o
ool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo
000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool0
0`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?oo
o`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0o`3ooong0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000
003oool0oooo01@0oooo0`00003o0?oookP0oooo00<000000?ooo`3oool01P3oool002X0oooo0`00
000E0?ooo`030000003oool0oooo0?l0oooo]P3oool2000000P0oooo000Z0?ooo`030000003oool0
oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oo
oll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`03
0000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo
0?ooo`060?ooo`002`3oool00`3o_g@00000000000020000000:001d_`3oool0oooo0?ooo`3OW4P0
000004RLg`3oool0oooO09a800<0000000<004RL0=ooo`3oool02P3oool00`000000oooo0?ooo`3o
0?oooll0oooo00<000000?ooo`3oool01P3oool000d0oooo00<0_g@00000M02oool0103oool0303O
W4P0000004RLg`3oool0omnL04P00000B9`0gooo0?ooo`3ogi`0B01809cOo`X0oooo00<000000?oo
o`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000=0?ooo`030;md000007@0_ooo00h0
oooo00<0okmd0018W03Oool02@3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3o
ool01P3oool000d0oooo00<0_g@00000M02oool03P3oool00`3o_g@0001809cOo`090?ooo`030000
003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`003@3oool00`2oM000001d0;oo
o`0>0?ooo`030;md000004P0W=oo00T0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003o
ool0oooo00H0oooo000=0?ooo`030;md000007@0_ooo00d0oooo00@0_g@00000000007@0_ooo2@3o
ool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool000d0oooo00<0_g@0
0000M02oool02P3oool00`3ookl0M000000000020000000304RLg`3oool0oooo00P0oooo1000003o
0?oool/0oooo100000080?ooo`003@3oool00`2oM000001d0;ooo`0<0?ooo`030?noM00004P0W=oo
00/0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000=0?ooo`03
0;md000007@0_ooo00d0oooo00<0omnL04Qd_`3oool02P3oool00`000000oooo0?ooo`3o0?oooll0
oooo00<000000?ooo`3oool01P3oool000d0oooo00<0_g@00000M02oool03@3oool00`3ooml0W4P0
04RLg`0:0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`003@3o
ool00`2oM000001d0;ooo`080?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO09a80000M;l02P3o
ool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool000/0oooo00D0gia8
000000000000001d0;ooo`090?ooo`070?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`0:0?ooo`03
0000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00303oool0103ookl0M000
0000M02oool:0?ooo`050?oOW0180000000000000018W=l02`3oool00`000000oooo0?ooo`3o0?oo
oll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`03
0000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo
0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3o
ool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?oo
o`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool300000?l0
oooocP3oool2000000P0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo
0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3o
ool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?oo
o`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000
oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0
o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3o
ool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<00000
0?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo
00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00
:P3oool300000?l0oooocP3oool2000000P0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3o
ool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<00000
0?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo
00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00
:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<0
00000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0
oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oo
oll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`03
0000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo
0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3o
ool002X0oooo0`00003o0?ooolh0oooo0P0000080?ooo`00:P3oool00`000000oooo0?ooo`3o0?oo
oll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`03
0000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3oool00`000000oooo
0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3o
ool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?oo
o`030000003oool0oooo0?l0ooooc`3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000
oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0
o`3oooo?0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo0?l0ooooc`3o
ool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0?l0oooo`03oool00`000000oooo0?ooo`060?ooo`00:P3oool3000000/0oooo0`00003o0?oo
ol00oooo0P0000080?ooo`00:P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
oooo`03oool00`000000oooo0?ooo`060?ooo`00:P3oool00`000000oooo0?ooo`3o0?oooll0oooo
00<000000?ooo`3oool01P3oool002X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003o
ool0oooo00H0oooo000Z0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool0
02X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`00:P3ooooo00000=<0
0000203oool00001\
\>"],
  ImageRangeCache->{{{0, 515.25}, {318.063, 0}} -> {-0.120409, 0.839388, \
0.00225575, 0.00173407}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"f23", "=", 
      RowBox[{"ListPlot", "[", 
        RowBox[{
        "r1om", ",", \(Frame \[Rule] True\), ",", \(Axes \[Rule] False\), 
          ",", \(PlotJoined \[Rule] True\), 
          ",", \(FrameLabel \[Rule] {\*"\"\<\!\(\[Omega]\_\(0  m\)\)\>\"", \
\*"\"\<\!\(\[Chi]\^2\)\>\""}\), ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{\(Hue[5]\), ",", \(Thickness[0.004]\), ",", 
                RowBox[{
                  StyleBox["Dashing",
                    "MR"], 
                  StyleBox["[",
                    "MR"], 
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    RowBox[{
                      StyleBox["0.05",
                        "MR"], 
                      StyleBox[",",
                        "MR"], " ", 
                      StyleBox["0.05",
                        "MR"]}], 
                    StyleBox["}",
                      "MR"]}], 
                  StyleBox["]",
                    "MR"]}]}], "}"}]}]}], "]"}]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -1.10519 1.2389 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -14.5625 -24.5625 ]
[.21429 -0.0125 14.5625 0 ]
[.40476 -0.0125 -14.5625 -24.5625 ]
[.40476 -0.0125 14.5625 0 ]
[.59524 -0.0125 -14.5625 -24.5625 ]
[.59524 -0.0125 14.5625 0 ]
[.78571 -0.0125 -14.5625 -24.5625 ]
[.78571 -0.0125 14.5625 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.4063 -49.125 ]
[.5 -0.0125 19.4063 -24.5625 ]
[-0.0125 .00983 -29.125 -12.2813 ]
[-0.0125 .00983 0 12.2813 ]
[-0.0125 .13372 -14.0625 -12.2813 ]
[-0.0125 .13372 0 12.2813 ]
[-0.0125 .25761 -29.125 -12.2813 ]
[-0.0125 .25761 0 12.2813 ]
[-0.0125 .3815 -29.125 -12.2813 ]
[-0.0125 .3815 0 12.2813 ]
[-0.0125 .50539 -29.125 -12.2813 ]
[-0.0125 .50539 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -53.6875 -12.5625 ]
[-0.01875 .30902 -29.125 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.4063 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
76.813 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
83.875 26.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
86.500 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
97.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00983 m
.00625 .00983 L
s
gsave
-0.0125 .00983 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
0 .13372 m
.00625 .13372 L
s
gsave
-0.0125 .13372 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .25761 m
.00625 .25761 L
s
gsave
-0.0125 .25761 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
0 .3815 m
.00625 .3815 L
s
gsave
-0.0125 .3815 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .50539 m
.00625 .50539 L
s
gsave
-0.0125 .50539 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0346 m
.00375 .0346 L
s
0 .05938 m
.00375 .05938 L
s
0 .08416 m
.00375 .08416 L
s
0 .10894 m
.00375 .10894 L
s
0 .1585 m
.00375 .1585 L
s
0 .18327 m
.00375 .18327 L
s
0 .20805 m
.00375 .20805 L
s
0 .23283 m
.00375 .23283 L
s
0 .28239 m
.00375 .28239 L
s
0 .30716 m
.00375 .30716 L
s
0 .33194 m
.00375 .33194 L
s
0 .35672 m
.00375 .35672 L
s
0 .40628 m
.00375 .40628 L
s
0 .43105 m
.00375 .43105 L
s
0 .45583 m
.00375 .45583 L
s
0 .48061 m
.00375 .48061 L
s
0 .53017 m
.00375 .53017 L
s
0 .55494 m
.00375 .55494 L
s
0 .57972 m
.00375 .57972 L
s
0 .6045 m
.00375 .6045 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -114.969 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
73.5625 16.2813 translate
90 rotate
-73.5625 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.375 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
76.563 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00983 m
1 .00983 L
s
.99375 .13372 m
1 .13372 L
s
.99375 .25761 m
1 .25761 L
s
.99375 .3815 m
1 .3815 L
s
.99375 .50539 m
1 .50539 L
s
.125 Mabswid
.99625 .0346 m
1 .0346 L
s
.99625 .05938 m
1 .05938 L
s
.99625 .08416 m
1 .08416 L
s
.99625 .10894 m
1 .10894 L
s
.99625 .1585 m
1 .1585 L
s
.99625 .18327 m
1 .18327 L
s
.99625 .20805 m
1 .20805 L
s
.99625 .23283 m
1 .23283 L
s
.99625 .28239 m
1 .28239 L
s
.99625 .30716 m
1 .30716 L
s
.99625 .33194 m
1 .33194 L
s
.99625 .35672 m
1 .35672 L
s
.99625 .40628 m
1 .40628 L
s
.99625 .43105 m
1 .43105 L
s
.99625 .45583 m
1 .45583 L
s
.99625 .48061 m
1 .48061 L
s
.99625 .53017 m
1 .53017 L
s
.99625 .55494 m
1 .55494 L
s
.99625 .57972 m
1 .57972 L
s
.99625 .6045 m
1 .6045 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.004 w
[ .05 .05 ] 0 setdash
.03333 .60332 m
.05238 .47906 L
.07143 .40656 L
.09048 .35618 L
.10952 .31808 L
.11905 .30213 L
.16667 .24163 L
.21429 .20028 L
.2619 .16951 L
.30952 .14539 L
.40476 .10943 L
.5 .08348 L
.59524 .06362 L
.69048 .04781 L
.78571 .03484 L
.88095 .02398 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{549.625, 339.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008U0001Db000`400?l00000o`00003oo`3ooooo
0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW0?ooo`00o`3oool_0?ooo`040?oo
g`2LB0000000001d_`D0oooo00/0_g@00000000004P0W=oO09a800000000001d0;oo_`1d00000000
001d_`3S0?ooo`00o`3oool_0?ooo`050;md0018W=l0oooo0=nLB018W=l0103oool02`3ooml0W4P0
07Boo`3oool0oono07@0B02Lgol0oooo0?oOW01807@0_ooo0><0oooo003o0?ooobh0oooo00L0omnL
04P0M02oool0oooo0?oOW01807@0_ooo00<0oooo00/0oooO09a8001d_ol0oooo0?oo_`1d04P0W=oo
0?ooo`3ogi`0B01d0;ooo`3S0?ooo`00o`3ooolQ0?ooo`070=nLB000000000000000001d_ol0omnL
04P000020000000;04RLg`3oool0oooo0?ooo`3o_g@004RL0=ooo`3oool0oooO09a8001d_ol00`3o
ool02`3ooml0W4P007Boo`3oool0oono07@0B02Lgol0oooo0?oOW01807@0_ooo0><0oooo003o0?oo
ob00oooo00<0okmd00000000M;l00P3oool02`2oM4P0B4Q809cOo`3oool0omnL04P00000B9`0gooo
0?ooo`3OW4P007Bo0080oooo00<0oooO09a8001d_ol00`3oool02`3ooml0W4P007Boo`3oool0oono
07@0B02Lgol0oooo0?oOW01807@0_ooo0><0oooo003o0?ooob00oooo00<0gia80000001d_ol00P3o
ool00`3ookl0M01809cOo`020?ooo`060?noM000000007Bo0?ooo`3OW4P007Bo0P3oool00`3ooml0
W4P007Boo`020?ooo`0<0?oog`2LB00000000000B02Lgol0omnL04P0000007@0_ooo0?noM000B9`0
goooh`3oool00?l0oooo803oool00`3OW4P0000007Boo`030?ooo`030;md001d_ol0oooo0080oooo
00X0_g@00000B02Lgol0okmd0018W03Oool0oooo0?oog`2LB000M;oo0`3oool02P3ookl0M00007Bo
g`2LB0000000001d_`3ookl0M00000000018W=oT0?ooo`00o`3ooolP0?ooo`030?noM0000000B9cO
00<0oooo00<0okmd001d_`3oool00P3oool02P3o_g@0000004RLg`3ogi`0B01d0;ooo`3oool0oono
07@0M02ooooa0?ooo`00o`3ooolP0?ooo`030?oog`2LB00007Bo00<0oooo00<0omnL04P0M02oool0
0P3oool02@3ogi`0B00004RLg`3oool0_g@004RLg`3oool0gia8001d_`3b0?ooo`00o`3ooolQ0?oo
o`030?oOW01804P0W=oo00L0oooo00T0oono07@0001d_ol0oooo0?oog`2LB00000000018W03Oool0
lP3oool00?l0oooo8P3oool00`3OW4P004RL0=ooo`060?ooo`030?oOW01807@0_ooo0?P0oooo003o
0?ooob<0oooo00<0okmd0018W03Oool01@3oool00`3OW4P0M;oo0?ooo`3h0?ooo`00o`3ooooo0?oo
obL0oooo003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo003o
0?ooool0oooo9`3oool00?l0ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo
9`3oool00?l0ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0
ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW
0?ooo`00o`3ooooo0?ooobL0oooo001D0?ooo`040;md00000000000004RLgd`0oooo00@0_g@00000
00000000B9cO103oool01@3OW4P0000004RLg`3oool0gia800L0000000<0M;oo0?ooo`3oool0@@3o
ool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO00H0oooo00<0okmd0000001d_ol0
@`3oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO00<0oooo00H0oooO09a80000
000000000000M02ooom40?ooo`040;md00000000000004RLg`@0oooo00<0gia800000018W=l00`3o
ool01P3ogi`0B000000000000000001809cOodX0oooo00<0okmd0000000000000P0000000`00M;l0
oooo0?ooo`0D0?ooo`00DP3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0B@3oool01`3o
oml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`030=nLB000
0000000000@0000000<007Bo0?ooo`3oool0?`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000
M;l00`3oool00`3OW4P0000004RLg`060?ooo`030?noM0000000M;oo0440oooo00L0oooO09a80000
M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l00P3oool0203ookl0M0000018W03O
ool0oooo0=nLB00004P0W=oo@@3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool0
0`3OW4P0000004RLg`020?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0001d_om;0?ooo`03
0;md000007@0_ooo01L0oooo001B0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0
B03oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo00<0gia804RLg`3oool0
0P3oool00`3ooml0W4Qd0;ooo`100?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0
2`3oool00`3o_g@0000007Boo`110?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0
1`3oool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo0400oooo00<0okmd0000B02Lgol0
0P3oool00`3ogi`0B00007Boo`070?ooo`030;md000007@0_ooo00<0oooo00<0gia80018W03Oool0
BP3oool00`2oM000001d0;ooo`0G0?ooo`00D@3oool0103ooml0W4P00018W03Oool20?ooo`030?oo
g`2LB00007Bo04L0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`090?ooo`03
0=nLB018W=l0oooo04<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`060?oo
o`030=nLB0000000000000D0000000<0001809cOo`3oool0?@3oool0103ooml0W4P00018W03Oool2
0?ooo`030?oog`2LB00007Bo00H0oooo00<0oono07@00000M;l0103oool00`3OW4P0001d0;ooo`0o
0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l01`3oool00`2oM000001d0;oo
o`030?ooo`030;md0000B9`0gooo04X0oooo00<0_g@00000M02oool05`3oool00540oooo00<0oono
07@00000M;l0103oool00`2oM000001d0;ooo`160?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool02@3oool00`3OW4P0M;oo0?ooo`120?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool01@3oool00`3ogi`0B7Bo0?ooo`020?ooo`030?noM0000000M;oo0400oooo00<0oono
07@00000M;l0103oool00`2oM000001d0;ooo`050?ooo`030?oOW0180000B9cO00@0oooo00<0_g@0
0000B02Lgol0?`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo00<0okmd
0000B02Lgol00P3oool00`3OW4P00000001d_`1;0?ooo`030;md000007@0_ooo01L0oooo001A0?oo
o`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0AP3oool00`3ogi`0B00004RLg`040?oo
o`030;md000007@0_ooo00T0oooo00<0oooO09a8B02Lgol0@P3oool00`3ogi`0B00004RLg`040?oo
o`030;md000007@0_ooo00H0oooo00L0gia807Boo`3oool0oooo0?noM0000000M;oo0400oooo00<0
omnL04P00018W=l0103oool00`2oM000001d0;ooo`050?ooo`030?oOW0180000B9cO00<0oooo00@0
oono07@0000007@0_ooo?`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00L0oooo
00L0gia8001d_`3oool0_g@00000000007@0_ooo04/0oooo00<0_g@00000M02oool05`3oool00540
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`160?ooo`030?oOW0180000B9cO00@0
oooo00<0gia80000B02Lgol02P3oool00`3ogi`0B01d0;ooo`110?ooo`030?oOW0180000B9cO00@0
oooo00<0gia80000B02Lgol01P3oool01`3ookl0M01d0;ooo`3oool0okmd0000001d_ol0@03oool0
0`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00D0oooo00T0oono07@00000000004RL0=oo
o`3oool0_g@000000018W=l0@03oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00P0
oooo00D0okmd00000000000004RL0=ooo`1<0?ooo`030;md000007@0_ooo01L0oooo001A0?ooo`03
0?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0AP3oool00`3ogi`0B00004RLg`040?ooo`03
0=nLB00004P0W=oo00/0oooo00<0_g@004RLg`3oool0@03oool00`3ogi`0B00004RLg`040?ooo`03
0=nLB00004P0W=oo00L0oooo00H0okmd001d_`3oool0okmd0000001d_om00?ooo`030?oOW0180000
B9cO00@0oooo00<0gia80000B02Lgol01@3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0
B9cO0?ooo`3oool0?`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0oooo00D0
omnL04P000000000000004RLg`1=0?ooo`030;md000007@0_ooo01L0oooo001A0?ooo`030?oo_`1d
000007Bo00@0oooo00<0_g@00000M02oool0AP3oool00`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo00/0oooo00<0gia80000M02oool0@03oool00`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo00P0oooo00D0_g@007Boo`3o_g@0000007Boo`100?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool01P3oool00`3o_g@0000004RLg`150?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool01P3oool01`3ogi`0B0000000B02Lgol0oooo0=nLB000M;l0C03oool00`2o
M000001d0;ooo`0G0?ooo`00DP3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo04P0
oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`0<0?ooo`030?noM0000000M;oo0440
oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`090?ooo`050?oo_`1d07@0_kmd0000
001d_ol0@@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00@0oooO09a8
000004P0W=ooA@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00<0gia8
0000B02Lgol00P3oool00`3ooml0W4P007Boo`1;0?ooo`030;md000007@0_ooo01L0oooo001B0?oo
o`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0B03oool00`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo00H0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`110?oo
o`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol02P3oool0103o_g@000000000001d_om1
0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool0103ookl0M0000000M02o
oom40?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`3OW4P004RL0=oo
o`020?ooo`030?oog`2LB000B9cO04/0oooo00<0_g@00000M02oool05`3oool005<0oooo00H0_g@0
0018W03Oool0oooo0;md0000M;m:0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203oool0202o
M000M;oo0?ooo`3oool0gia800000000B9`0gooo@P3oool01P2oM00004RL0=ooo`3oool0_g@0001d
_`/0oooo00@0oooO09a800000000M;oo@P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`X0oooo
00@0oooO09a80000000007BoA03oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00<0omnL
04P00018W=l00P3oool00`3o_g@0001809cOo`190?ooo`050=nLB000000000000000M02oool05`3o
ool005@0oooo00@0_g@000000000000007BoC03oool0102oM000000000000000M;l:0?ooo`050;md
00000000000000000000M;l0A@3oool0102oM000000000000000M;l=0?ooo`030?oOW0180000M;oo
04<0oooo00@0_g@000000000000007Bo3@3oool01@3ogi`0B00000000000B9`0gooo0480oooo00@0
_g@000000000000007Bo2P3oool01P3ookl0M000000000000000001809cOod/0oooo00@0oono07@0
000007@0_ooo5`3oool00?l0ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo
9`3oool00?l0ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0
ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo9`3oool002d0oooo00@0_g@0
000000000000B9cO103oool02@3OW4P0000004RLg`3oool0oooO09a800000000001809cOo`3o0?oo
onP0oooo000[0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000
B9cO00@0oooo00@0gia800000000B9`0goooo`3ooooV0?ooo`00:`3oool00`3o_g@0001809cOo`02
0?ooo`030?oOW0180000M;oo00X0oooo00@0oono07@0000007@0_ooo2P3ooooo00000<h000003@3o
ool002X0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0;0?ooo`040?oo_`1d
000004RL0=ooo`T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`00:P3o
ool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0gia80000001d_ol02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030?oOW0180000
B9cO00@0oooo00<0_g@00000M02oool01`3oool00`3OW4P0000000000003000000030018W03Oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`00:P3oool00`3o
gi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00H0oooo00<0_g@000000000M;l00P3oool0103o
okl0M0000000M02oool80?ooo`@00000o`3oooo60?ooo`@000003@3oool002X0oooo00<0omnL04P0
0018W=l0103oool00`3OW4P0001809cOo`050?ooo`040?oo_`1d000004RL0=ooo`<0oooo00<0_g@0
0000B02Lgol0203oool00`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool0
02X0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`050?ooo`030?oOW0180000B9cO
00@0oooo00<0gia80000B02Lgol0203oool00`000000oooo0?ooo`3o0?oook`0oooo103o000:0?oo
o`030000003oool0oooo00/0oooo000[0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000
M;l01P3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00P0oooo00<000000?ooo`3o
ool0o`3ooone0?ooo`L0o`003P3oool00`000000oooo0?ooo`0;0?ooo`00:`3oool00`3o_g@00018
09cOo`020?ooo`030?oOW0180000M;oo00H0oooo00<0oooO09a80000M;l00`3oool00`3ookl0M000
04RLg`090?ooo`030000003oool0oooo0?l0oooo[@3oool80?l001D0oooo00<000000?ooo`3oool0
2`3oool002`0oooo00H0_g@00018W03Oool0oooo0;md0000M;l80?ooo`080?oOW0180000M;oo0?oo
o`3ooml0W4P00018W03Oool90?ooo`030000003oool0oooo0?l0ooooZ@3oool40?l001d0oooo00<0
00000?ooo`3oool02`3oool002d0oooo00@0_g@000000000000007Bo2P3oool01P3ookl0M0000000
0000000004RL0=ooo`X0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0
oooo001;0?ooo`030000003oool0oooo0?l0ooooS@3oool60?l003L0oooo00<000000?ooo`3oool0
2`3oool004/0oooo00<000000?ooo`3oool0o`3ooon10?ooo``0o`00?@3oool00`000000oooo0?oo
o`0;0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooog/0oooo1P3o00190?ooo`030000003oool0
oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?oo
o`00B`3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo
0`00003o0?ooof40oooo103o001S0?ooo`<000003@3oool004/0oooo00<000000?ooo`3oool0o`3o
oomI0?ooo`P0o`00J@3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`3o
0?oooe40oooo203o001a0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo
0?l0ooooC@3oool40?l007T0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3o
ool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0oooo
bP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooocD0oooo0`3o
002B0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0oooo;`3oool6
0?l009D0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0o`3ooolY0?oo
o`H0o`00V`3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooob<0
oooo1P3o002Q0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0oooo
803oool30?l00:L0oooo00<000000?ooo`3oool02`3oool004/0oooo0`00003o0?ooolP0oooo0`00
000=0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool0
04/0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`03
0000003oool0oooo0?l0oooo203oool30?l00;l0oooo00<000000?ooo`3oool02`3oool004/0oooo
00<000000?ooo`3oool0o`3oool40?ooo`@0o`00`P3oool00`000000oooo0?ooo`0;0?ooo`00B`3o
ool00`000000oooo0?ooo`3n0?ooo`D0o`00aP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool0
0`000000oooo0?ooo`3i0?ooo`D0o`00b`3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`00
0000oooo0?ooo`3e0?ooo`@0o`00d03oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000
oooo0?ooo`3b0?ooo`<0o`00e03oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo
0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0o`3o
ooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`<00000o`3oooo80?ooo`<000003@3oool0
04/0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`03
0000003oool0oooo0=/0oooo0P3o003/0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000
003oool0oooo0=L0oooo103o003^0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003o
ool0oooo0=<0oooo103o003b0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0
oooo0<l0oooo103o003f0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo
0</0oooo103o003j0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0<L0
oooo103o003n0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0<D0oooo
0P3o003o0?ooo`<0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0o`3o
ooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0oooobP3oool0
0`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<000000?oo
o`3oool02`3oool004/0oooo0`00003o0?ooolP0oooo0`00000=0?ooo`00B`3oool00`000000oooo
0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0o`3o
ooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0:l0oooo0P3o003o
0?oooaT0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0[03oool30?l0
0?l0oooo6`3oool00`000000oooo0?ooo`0;0?ooo`00?03oool00`3o_g@000000000000200000003
001d_`3oool0oooo00L0oooo00<000000?ooo`3oool0ZP3oool20?l00?l0oooo7P3oool00`000000
oooo0?ooo`0;0?ooo`00?P3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo0:L0oooo
0`3o003o0?ooob00oooo00<000000?ooo`3oool02`3oool003h0oooo00<0_g@00000M02oool02P3o
ool00`000000oooo0?ooo`2T0?ooo`<0o`00o`3ooolS0?ooo`030000003oool0oooo00/0oooo000n
0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0X@3oool30?l00?l0oooo9P3oool0
0`000000oooo0?ooo`0;0?ooo`00?P3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo
09l0oooo0P3o003o0?ooobT0oooo00<000000?ooo`3oool02`3oool003h0oooo00<0_g@00000M02o
ool02P3oool00`000000oooo0?ooo`2L0?ooo`<0o`00o`3oool[0?ooo`030000003oool0oooo00/0
oooo000n0?ooo`030;md000007@0_ooo00X0oooo1000002I0?ooo`80o`00o`3oool[0?ooo`@00000
3@3oool003h0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<0
00000?ooo`3oool02`3oool003h0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3o
0?ooolX0oooo00<000000?ooo`3oool02`3oool003h0oooo00<0_g@00000M02oool02P3oool00`00
0000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool003h0oooo00<0_g@00000M02o
ool02P3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool003`0oooo
00D0gia8000000000000001d0;ooo`0:0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000
oooo0?ooo`0;0?ooo`00?@3oool0103ookl0M0000000M02oool:0?ooo`030000003oool0oooo0?l0
oooobP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooolX0oooo
00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003o
ool0oooo00/0oooo001;0?ooo`030000003oool0oooo08D0oooo00<0o`000?ooo`3oool0o`3ooom2
0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo08<0oooo0P3o003o0?oo
odD0oooo00<000000?ooo`3oool02`3oool004/0oooo0`0000210?ooo`80o`00o`3ooom50?ooo`<0
00003@3oool004/0oooo00<000000?ooo`3oool0O`3oool20?l00?l0ooooB@3oool00`000000oooo
0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`1m0?ooo`80o`00o`3ooom;0?ooo`030000003o
ool0oooo00/0oooo001;0?ooo`030000003oool0oooo07/0oooo0P3o003o0?ooodd0oooo00<00000
0?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0N@3oool20?l00?l0ooooC`3oool00`00
0000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`1g0?ooo`80o`00o`3ooomA0?ooo`03
0000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo07H0oooo00<0o`000?ooo`3oool0
o`3ooomA0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo07@0oooo0P3o
003o0?oooe@0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0LP3oool2
0?l00?l0ooooEP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`1a0?oo
o`030?l0003oool0oooo0?l0ooooEP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000
oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0
o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`<00000o`3oooo80?ooo`<000003@3o
ool004/0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?oo
o`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000
oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0
o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0oooobP3o
ool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<00000
0?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo
00/0oooo001;0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?ooo`00
B`3oool00`000000oooo0?ooo`1N0?ooo`030?l0003oool0oooo0?l0ooooJ@3oool00`000000oooo
0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`1M0?ooo`030?l0003oool0oooo0?l0ooooJP3o
ool00`000000oooo0?ooo`0;0?ooo`00B`3oool3000005`0oooo00<0o`000?ooo`3oool0o`3ooomY
0?ooo`<000003@3oool004/0oooo00<000000?ooo`3oool0FP3oool20?l00?l0ooooKP3oool00`00
0000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`1I0?ooo`030?l0003oool0oooo0?l0
ooooKP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`1H0?ooo`030?l0
003oool0oooo0?l0ooooK`3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?oo
o`1G0?ooo`030?l0003oool0oooo0?l0ooooL03oool00`000000oooo0?ooo`0;0?ooo`00B`3oool0
0`000000oooo0?ooo`1F0?ooo`030?l0003oool0oooo0?l0ooooL@3oool00`000000oooo0?ooo`0;
0?ooo`00B`3oool00`000000oooo0?ooo`1D0?ooo`80o`00o`3ooomd0?ooo`030000003oool0oooo
00/0oooo001;0?ooo`030000003oool0oooo05<0oooo00<0o`000?ooo`3oool0o`3ooomd0?ooo`03
0000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0
o`3ooome0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0540oooo00<0
o`000?ooo`3oool0o`3ooomf0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0
oooo0500oooo00<0o`000?ooo`3oool0o`3ooomg0?ooo`030000003oool0oooo00/0oooo001;0?oo
o`030000003oool0oooo04h0oooo0P3o003o0?ooogX0oooo00<000000?ooo`3oool02`3oool004/0
oooo0`00001=0?ooo`030?l0003oool0oooo0?l0ooooN03oool3000000d0oooo001;0?ooo`030000
003oool0oooo04`0oooo00<0o`000?ooo`3oool0o`3ooomk0?ooo`030000003oool0oooo00/0oooo
001;0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool0
0`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?oo
o`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo000/0?ooo`030?noM000000000000080
000000L007Bo0?ooo`3oool0oooo0=nLB0000000B9cO00<0oooo00<0okmd0000000000000P000000
0`00M;l0oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;
0?ooo`00;P3oool00`2oM000001d0;ooo`040?ooo`030=nLB0000000B9cO00D0oooo00<0_g@00000
M02oool02`3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool002h0
oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`0;0?ooo`030000003oool0oooo0?l0
oooobP3oool00`000000oooo0?ooo`0;0?ooo`00;P3oool00`2oM000001d0;ooo`0<0?ooo`030;md
000007@0_ooo00/0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo
000^0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool02`3oool00`000000oooo0?oo
o`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool002h0oooo00<0_g@00000M02oool0303oool0
0`2oM000001d0;ooo`0;0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;
0?ooo`00;P3oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00/0oooo1000003o0?oo
olH0oooo1000000=0?ooo`00;P3oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00/0
oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo000^0?ooo`030;md
000007@0_ooo00`0oooo00<0_g@00000M02oool02`3oool00`000000oooo0?ooo`3o0?ooolX0oooo
00<000000?ooo`3oool02`3oool002h0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;oo
o`0;0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?ooo`00;P3oool0
0`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00/0oooo00<000000?ooo`3oool0o`3oooo:
0?ooo`030000003oool0oooo00/0oooo000/0?ooo`050=nLB000000000000000M02oool02P3oool0
1@3OW4P000000000000007@0_ooo00/0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003o
ool0oooo00/0oooo000]0?ooo`040?oo_`1d0000001d0;ooo`/0oooo00@0oono07@0000007@0_ooo
2`3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo00<0
00000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0
oooo03h0oooo00<0o`000?ooo`3oool0o`3ooon90?ooo`030000003oool0oooo00/0oooo001;0?oo
o`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0o`3ooon:0?ooo`030000003oool0oooo
00/0oooo001;0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0o`3ooon;0?ooo`03
0000003oool0oooo00/0oooo001;0?ooo`<00000>`3oool00`3o0000oooo0?ooo`3o0?ooohX0oooo
0`00000=0?ooo`00B`3oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo0?l0ooooS03o
ool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0
oooo0?l0ooooS@3oool00`000000oooo0?ooo`0;0?ooo`008P3oool00`3ooml0W4Q809cOo`0V0?oo
o`030000003oool0oooo03T0oooo00<0o`000?ooo`3oool0o`3ooon>0?ooo`030000003oool0oooo
00/0oooo000Q0?ooo`030?oo_`1d04P0W=oo02L0oooo00<000000?ooo`3oool0>03oool00`3o0000
oooo0?ooo`3o0?ooohl0oooo00<000000?ooo`3oool02`3oool00200oooo00<0omnL04P0M02oool0
:03oool00`000000oooo0?ooo`0g0?ooo`030?l0003oool0oooo0?l0ooooT03oool00`000000oooo
0?ooo`0;0?ooo`005`3oool00`3OW9`0_ooo0?ooo`050?ooo`030?oOW018B9`0gooo02T0oooo00<0
00000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`3o0?oooi40oooo00<000000?ooo`3oool02`3o
ool001H0oooo00<0oooO09a8M02oool01@3oool00`3ogi`0B4RL0=ooo`0Z0?ooo`030000003oool0
oooo03H0oooo00<0o`000?ooo`3oool0o`3ooonA0?ooo`030000003oool0oooo00/0oooo000F0?oo
o`030?oo_`1d0000000000@0000000<004Q804P0M02oool0:`3oool00`000000oooo0?ooo`0e0?oo
o`030?l0003oool0oooo0?l0ooooTP3oool00`000000oooo0?ooo`0;0?ooo`006@3oool00`3o_g@0
0000000000070000000304RLg`3oool0oooo02D0oooo00<000000?ooo`3oool0=03oool00`3o0000
oooo0?ooo`3o0?oooi<0oooo00<000000?ooo`3oool02`3oool001/0oooo00<0oooO09a8B02Lgol0
0P3oool01@2oM00000000000000004P0W=oo02H0oooo00<000000?ooo`3oool0<`3oool00`3o0000
oooo0?ooo`3o0?oooi@0oooo00<000000?ooo`3oool02`3oool001X0oooo00<0oooO09a8B02Lgol0
1@3oool00`3ogi`0B4RL0=ooo`0V0?ooo`030000003oool0oooo03<0oooo00<0o`000?ooo`3oool0
o`3ooonD0?ooo`030000003oool0oooo00/0oooo000I0?ooo`030?oog`2LB4P0W=oo00D0oooo00<0
oono07@0M02oool09`3oool300000380oooo00<0o`000?ooo`3oool0o`3ooonC0?ooo`<000003@3o
ool001P0oooo00<0oono07@0B02Lgol0<03oool00`000000oooo0?ooo`0b0?ooo`030?l0003oool0
oooo0?l0ooooU@3oool00`000000oooo0?ooo`0;0?ooo`005`3oool00`3o_g@0001d0;ooo`0a0?oo
o`030000003oool0oooo0340oooo00<0o`000?ooo`3oool0o`3ooonF0?ooo`030000003oool0oooo
00/0oooo000F0?ooo`030?oo_`1dM;l0oooo0380oooo00<000000?ooo`3oool0<@3oool00`3o0000
oooo0?ooo`3o0?oooiH0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0
<03oool00`3o0000oooo0?ooo`3o0?oooiL0oooo00<000000?ooo`3oool02`3oool004/0oooo00<0
00000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo000?0?ooo`030=nLB000B9`0
gooo00@0oooo00<0giad04Q8M02oool0<P3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<00000
0?ooo`3oool02`3oool000h0oooo00<0okmd001d_`3oool0103oool0102oM000B9bL07@0M02ooolb
0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?ooo`003P3oool00`3O
W4P0B9cO0?ooo`020?ooo`060?oog`2LB000M;oo0?oo_`1d07@0_ooo<P3oool00`000000oooo0?oo
o`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool000h0oooo00/0okmd0000B02Lgol0oooo0?no
M00004P0W=oo0?ooo`3ogi`0B01d0;ooo`0b0?ooo`030000003oool0oooo0?l0oooobP3oool00`00
0000oooo0?ooo`0;0?ooo`003`3oool0103OW4P0000000000000M;l20?ooo`040?oog`2LB00004RL
0=oooc80oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?oo
o`<00000o`3oooo80?ooo`<000003@3oool004/0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`03
0000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo
0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3o
ool004/0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?oo
o`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000
oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0
o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0oooobP3o
ool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<00000
0?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo
00/0oooo001;0?ooo`<00000o`3oooo80?ooo`<000003@3oool004/0oooo00<000000?ooo`3oool0
o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo02H0oooo00<0
o`000?ooo`3oool0o`3ooonQ0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0
oooo02H0oooo00<0o`000?ooo`3oool0o`3ooonQ0?ooo`030000003oool0oooo00/0oooo001;0?oo
o`030000003oool0oooo02D0oooo00<0o`000?ooo`3oool0o`3ooonR0?ooo`030000003oool0oooo
00/0oooo001;0?ooo`030000003oool0oooo02D0oooo00<0o`000?ooo`3oool0o`3ooonR0?ooo`03
0000003oool0oooo00/0oooo000/0?ooo`030?noM000000000000080000000T007Bo0?ooo`3oool0
oooo0=nLB0000000B9cO0?ooo`3OW4P01`0000000`1d_ol0oooo0?ooo`070?ooo`030000003oool0
oooo02@0oooo00<0o`000?ooo`3oool0o`3ooonS0?ooo`030000003oool0oooo00/0oooo000^0?oo
o`030;md000007@0_ooo00@0oooo00<0gia800000018W=l00P3oool00`3OW4P00000000000040000
0003001d_`3oool0oooo00L0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`3o0?oo
oj<0oooo00<000000?ooo`3oool02`3oool002h0oooo00<0_g@00000M02oool02P3oool00`3OW4P0
B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo00P0oooo00<000000?ooo`3oool0903oool00`3o0000
oooo0?ooo`3o0?oooj<0oooo00<000000?ooo`3oool02`3oool002h0oooo00<0_g@00000M02oool0
2`3oool00`3OW4P0B9cO0?ooo`0<0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool0
o`3ooonT0?ooo`030000003oool0oooo00/0oooo000^0?ooo`030;md000007@0_ooo00`0oooo00<0
gia807Boo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0?l0ooooY03o
ool00`000000oooo0?ooo`0;0?ooo`00;P3oool00`2oM000001d0;ooo`0<0?ooo`030?oog`2LB4P0
W=oo00/0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`3o0?oooj@0oooo00<00000
0?ooo`3oool02`3oool002h0oooo00<0_g@00000M02oool03@3oool00`3ogi`0B01d0;ooo`0:0?oo
o`@000008@3oool00`3o0000oooo0?ooo`3o0?oooj80oooo1000000=0?ooo`00;P3oool00`2oM000
001d0;ooo`0>0?ooo`030;md0018W=l0oooo00T0oooo00<000000?ooo`3oool08P3oool00`3o0000
oooo0?ooo`3o0?ooojD0oooo00<000000?ooo`3oool02`3oool002h0oooo00<0_g@00000M02oool0
3P3oool00`3OW4P0001d0;ooo`090?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3oool0
o`3ooonV0?ooo`030000003oool0oooo00/0oooo000^0?ooo`030;md000007@0_ooo00h0oooo00<0
okmd0000001d_ol02@3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0?l0ooooYP3o
ool00`000000oooo0?ooo`0;0?ooo`00;P3oool00`2oM000001d0;ooo`080?ooo`030?oOW02L_ol0
oooo00<0oooo00<0_g@00000001d_ol02@3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0
oooo0?l0ooooYP3oool00`000000oooo0?ooo`0;0?ooo`00;03oool01@3OW4P000000000000007@0
_ooo00T0oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=ooo`T0oooo00<000000?ooo`3o
ool0803oool00`3o0000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool02`3oool002d0oooo
00@0oono07@0000007@0_ooo2P3oool01@2oM000000000000000000007Bo00/0oooo00<000000?oo
o`3oool0803oool00`3o0000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool02`3oool004/0
oooo00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3o
ool02`3oool004/0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`3o0?ooojP0oooo
00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?oo
o`3o0?ooojP0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool07P3oool0
0`3o0000oooo0?ooo`3o0?ooojT0oooo00<000000?ooo`3oool02`3oool004/0oooo0`00000N0?oo
o`030?l0003oool0oooo0?l0ooooY`3oool3000000d0oooo001;0?ooo`030000003oool0oooo01h0
oooo00<0o`000?ooo`3oool0o`3ooonY0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000
003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?oo
o`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0o`3oooo:
0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0oooobP3oool00`00
0000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3o
ool02`3oool004/0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo
001;0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool0
0`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?oo
o`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0
oooobP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool300000?l0oooob03oool3000000d0oooo
001;0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool0
0`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?oo
o`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0
oooobP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooolX0oooo
00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003o
ool0oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;
0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0
oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000
003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool3000001P0oooo00<0
o`000?ooo`3oool0o`3ooon]0?ooo`<000003@3oool004/0oooo00<000000?ooo`3oool0603oool0
0`3o0000oooo0?ooo`3o0?ooojl0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?oo
o`3oool05`3oool00`3o0000oooo0?ooo`3o0?oook00oooo00<000000?ooo`3oool02`3oool004/0
oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`3o0?oook00oooo00<000000?ooo`3o
ool02`3oool004/0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`3o0?oook00oooo
00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?oo
o`3o0?oook00oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool05P3oool0
0`3o0000oooo0?ooo`3o0?oook40oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?oo
o`3oool05P3oool00`3o0000oooo0?ooo`3o0?oook40oooo00<000000?ooo`3oool02`3oool004/0
oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?ooo`3o0?oook40oooo00<000000?ooo`3o
ool02`3oool004/0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?ooo`3o0?oook40oooo
00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?oo
o`3o0?oook80oooo00<000000?ooo`3oool02`3oool004/0oooo0`00000E0?ooo`030?l0003oool0
oooo0?l0oooo/03oool3000000d0oooo001;0?ooo`030000003oool0oooo01D0oooo00<0o`000?oo
o`3oool0o`3ooonb0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo01D0
oooo00<0o`000?ooo`3oool0o`3ooonb0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000
003oool0oooo01D0oooo00<0o`000?ooo`3oool0o`3ooonb0?ooo`030000003oool0oooo00/0oooo
001;0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool0o`3ooonb0?ooo`030000003o
ool0oooo00/0oooo001;0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool0o`3ooonb
0?ooo`030000003oool0oooo00/0oooo000/0?ooo`030?noM000000000000080000000X007Bo0?oo
o`3oool0oooo0=nLB0000000B9cO0?ooo`3ooml0W4P00`0000000`00B9`0gooo0?ooo`0:0?ooo`03
0000003oool0oooo01@0oooo00<0o`000?ooo`3oool0o`3ooonc0?ooo`030000003oool0oooo00/0
oooo000^0?ooo`030;md000007@0_ooo00@0oooo00`0gia800000018W=l0oooo0?oOW018000004RL
0=ooo`3oool0omnL04P0B02Lgol:0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool0
o`3ooonc0?ooo`030000003oool0oooo00/0oooo000^0?ooo`030;md000007@0_ooo00h0oooo00<0
okmd0018W03Oool02@3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0?l0oooo/`3o
ool00`000000oooo0?ooo`0;0?ooo`00;P3oool00`2oM000001d0;ooo`0>0?ooo`030?noM00004P0
W=oo00T0oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`3o0?oook<0oooo00<00000
0?ooo`3oool02`3oool002h0oooo00<0_g@00000M02oool03P3oool00`2oM000001809cOo`090?oo
o`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool0o`3ooonc0?ooo`030000003oool0oooo
00/0oooo000^0?ooo`030;md000007@0_ooo00d0oooo00@0_g@00000000007@0_ooo2@3oool00`00
0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0?l0oooo/`3oool00`000000oooo0?ooo`0;0?oo
o`00;P3oool00`2oM000001d0;ooo`0:0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3o
ool0203oool400000?l0ooooaP3oool4000000d0oooo000^0?ooo`030;md000007@0_ooo00`0oooo
00<0okmd0000B02Lgol02`3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool0
2`3oool002h0oooo00<0_g@00000M02oool03@3oool00`3ogi`0B7Bo0?ooo`0:0?ooo`030000003o
ool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?ooo`00;P3oool00`2oM000001d0;ooo`0=
0?ooo`030?oog`2LB000B9cO00X0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0
oooo00/0oooo000^0?ooo`030;md000007@0_ooo00P0oooo00<0oooO09adW03Oool00P3oool00`3o
oml0W4P0001d_`0:0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?oo
o`00;03oool01@3OW4P000000000000007@0_ooo00T0oooo00L0omnL04Q8W03Oool0oooo0=nLB000
0000M;oo00X0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo000]
0?ooo`040?oo_`1d0000001d0;ooo`X0oooo00D0omnL04P000000000000004RLg`0;0?ooo`030000
003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?oo
o`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0o`3oooo:
0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0oooobP3oool00`00
0000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3o
ool02`3oool004/0oooo0`00003o0?ooolP0oooo0`00000=0?ooo`00B`3oool00`000000oooo0?oo
o`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0o`3oooo:
0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0oooobP3oool00`00
0000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3o
ool02`3oool004/0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo
001;0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool0
0`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?oo
o`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0?l0
oooobP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooolX0oooo
00<000000?ooo`3oool02`3oool004/0oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?oo
o`3o0?oookL0oooo00<000000?ooo`3oool02`3oool004/0oooo0`00000@0?ooo`030?l0003oool0
oooo0?l0oooo]@3oool3000000d0oooo001;0?ooo`030000003oool0oooo0100oooo00<0o`000?oo
o`3oool0o`3ooong0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo0100
oooo00<0o`000?ooo`3oool0o`3ooong0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000
003oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3ooonh0?ooo`030000003oool0oooo00/0oooo
001;0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3ooonh0?ooo`030000003o
ool0oooo00/0oooo001;0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3ooonh
0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo00l0oooo00<0o`000?oo
o`3oool0o`3ooonh0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000003oool0oooo00l0
oooo00<0o`000?ooo`3oool0o`3ooonh0?ooo`030000003oool0oooo00/0oooo001;0?ooo`030000
003oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3ooonh0?ooo`030000003oool0oooo00/0oooo
001;0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3ooonh0?ooo`030000003o
ool0oooo00/0oooo001;0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3ooonh
0?ooo`030000003oool0oooo00/0oooo001;0?ooo`<000003P3oool00`3o0000oooo0?ooo`3o0?oo
okL0oooo0`00000=0?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0?l0
oooo^@3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`030?l0
003oool0oooo0?l0oooo^@3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?oo
o`0>0?ooo`030?l0003oool0oooo0?l0oooo^@3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool0
0`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0?l0oooo^@3oool00`000000oooo0?ooo`0;
0?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0?l0oooo^@3oool00`00
0000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0?l0
oooo^@3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`030?l0
003oool0oooo0?l0oooo^@3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?oo
o`0=0?ooo`030?l0003oool0oooo0?l0oooo^P3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool0
0`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0?l0oooo^P3oool00`000000oooo0?ooo`0;
0?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0?l0oooo^P3oool00`00
0000oooo0?ooo`0;0?ooo`00B`3oool3000000d0oooo00<0o`000?ooo`3oool0o`3ooonh0?ooo`<0
00003@3oool004/0oooo00<000000?ooo`3oool0o`3oooo:0?ooo`030000003oool0oooo00/0oooo
001;0?ooo`030000003oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`0;0?ooo`00B`3oool0
0`000000oooo0?ooo`3o0?ooolX0oooo00<000000?ooo`3oool02`3oool004/0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0;0?ooo`00B`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00/0oooo001;0?ooool00000cP00000=0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 548.625}, {338.688, 0}} -> {-0.198272, 0.795637, \
0.00228643, 0.00175765}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ 
        Repeat\ above\ calculation\ for\ \((Log \((Var)\) - 
              Log \((L)\))\)\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    \(omv = {0.01, 0.03, 0.05, 0.07, 0.09, 0.1, 0.13, 0.15, 0.2, 0.25, 0.3, 
        0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1}; valsom = Length[omv]; 
    r1om = {};\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[om = omv[\([q]\)]; \[IndentingNewLine]Clear[f, dl, dld, zmin, zmax]; 
      w0 = \(-1\); w1 = 0; h0 = 10^5\ h; \ c = 3\ 10^8; 
      h = 0.72; \[IndentingNewLine]f[z_] := 
        1/Sqrt[om*\((1 + z)\)^3\  + \((1 - 
                    om)\)*\((1 + z)\)^\((3 \((1 + w0\  + \ w1)\))\) 
                Exp[3\ w1\ \((\((1/\((1 + z)\))\) - 1)\)]]; \n
      dl[zz_] := c \((1 + zz)\)\ NIntegrate[f[z], {z, 0, zz}]/h0; \n
      dld = dl[zz[#]] 3\ 10^24 &; \nll = 4\ Pi\ dld[#]^2\ pbolo[#] &; \n
      sll = 4\ Pi\ dld[#]^2\ spbolo[#] &; \n
      eg = 4\ Pi\ dld[#]^2\ sbolo[#]\ fbeam[#]/\((1 + zz[#])\) &; \nzmin = 0; 
      zmax = 7; \nClear[llvar, sllvar]; \nllvar = {}; sllvar = {}; \n
      Do[\[IndentingNewLine]If[
          var[i] > 0\  && \ zz[i] \[GreaterEqual] zmin\  && \ 
            zz[i] \[LessEqual] \ zmax, \[IndentingNewLine]AppendTo[
            llvar, {Log[10, \ var[i]], 
              Log[10, ll[i]]}]; \[IndentingNewLine]AppendTo[
            sllvar, {svar[i]/\((Log[10]\ var[i])\), 
              sll[i]/\((Log[10]\ ll[i])\)}]], {i, 1, 
          ndat}]; \n\[IndentingNewLine]llp[a1_, b1_, x_] := 
        a1\  + \ b1\ x; \[IndentingNewLine]varp[a1_, b1_, x_] := \((x - a1)\)/
          b1; \[IndentingNewLine]\[IndentingNewLine]chi2[a1_, b1_, s1_] := 
        Sum[\((\((llvar[\([i, 2]\)] - 
                      llp[a1, b1, 
                        llvar[\([i, 1]\)]])\)^2/\((sllvar[\([i, 2]\)]^2 + 
                    s1^2)\))\), {i, 1, Length[llvar]}] + 
          Sum[\((\((llvar[\([i, 1]\)] - 
                      varp[a1, b1, 
                        llvar[\([i, 2]\)]])\)^2/\((sllvar[\([i, 1]\)]^2 + 
                    s1^2)\))\), {i, 1, 
              Length[llvar]}]; \[IndentingNewLine]\[IndentingNewLine]s1 = 
        0.42; \npar = {a1, b1}; \n
      akl[a1_, b1_, k_, l_] := 
        1/2  D[D[chi2[a1, b1, s1], par[\([k]\)]], par[\([l]\)]\ ]; \n
      fmingrb = FindMinimum[chi2\ [a1, b1, s1], {a1, 1}, {b1, 1}]; \n
      a1o = fmingrb[\([2, 1, 2]\)]; \nb1o = fmingrb[\([2, 2, 2]\)]; \n
      aklo = Table[
          If[k \[LessSlantEqual] l, \(akl[a1, b1, k, l] /. a1 \[Rule] a1o\) /. 
              b1 \[Rule] b1o, \(akl[a1, b1, l, k] /. a1 \[Rule] a1o\) /. 
              b1 \[Rule] b1o], {k, 1, 2}, {l, 1, 2}]; cij = Inverse[aklo]; 
      spar = Table[Sqrt[cij[\([i, i]\)]], {i, 1, 2}]; 
      Print["\<a1= \>", a1o, "\<+-\>", spar[\([1]\)], "\<  b1= \>", 
        b1o, "\<+-\>", spar[\([2]\)]]; 
      cij // MatrixForm; \[IndentingNewLine]erra1o = 
        spar[\([1]\)]; \[IndentingNewLine]errb1o = 
        spar[\([2]\)]; \[IndentingNewLine]chi2r = 
        Part[fmingrb, 
            1]/\((2\ Length[llvar])\); \[IndentingNewLine]Print["\<chi2r=\>", 
        chi2r, "\<  ngrb=\>", ngrb]; \[IndentingNewLine]AppendTo[
        r1om, {om, chi2r}], \[IndentingNewLine]{q, 1, valsom}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.80060014725438`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05280554613664385`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.7525069316982975`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.12737704966636096`\),
      SequenceForm[ 
      "a1= ", 52.800600147254379, "+-", .052805546136643851, "  b1= ", 
        1.7525069316982975, "+-", .12737704966636096],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.1907487611486147`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.1907487611486147, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.73803385216936`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.052469751559842556`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]1.7051997819342537`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.12641722643625897`\),
      SequenceForm[ 
      "a1= ", 52.738033852169359, "+-", .052469751559842556, "  b1= ", 
        1.7051997819342537, "+-", .12641722643625897],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.1214464588417143`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.1214464588417143, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.69285877334791`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05225373867664085`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.6762790355087358`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.12571898653954575`\),
      SequenceForm[ 
      "a1= ", 52.692858773347908, "+-", .052253738676640848, "  b1= ", 
        1.6762790355087358, "+-", .12571898653954575],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0875421451679173`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0875421451679173, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.65632136620191`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.0520937797961476`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.6555698038550417`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.12517230779877103`\),
      SequenceForm[ 
      "a1= ", 52.656321366201908, "+-", .052093779796147599, "  b1= ", 
        1.6555698038550417, "+-", .12517230779877103],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0663500814830522`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0663500814830522, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.62520481189877`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05196708737258362`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.6395713934534513`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.12472390515481138`\),
      SequenceForm[ 
      "a1= ", 52.625204811898769, "+-", .051967087372583619, "  b1= ", 
        1.6395713934534513, "+-", .12472390515481138],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0515632541488005`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0515632541488005, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.61114191879871`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05191252473022156`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.6327873539782205`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.12452691170866946`\),
      SequenceForm[ 
      "a1= ", 52.611141918798708, "+-", .051912524730221558, "  b1= ", 
        1.6327873539782205, "+-", .12452691170866946],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.045688260098613`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.045688260098613, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.57342307054719`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.051773928656904174`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]1.6158323065647302`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.12401663947356231`\),
      SequenceForm[ 
      "a1= ", 52.573423070547193, "+-", .051773928656904174, "  b1= ", 
        1.6158323065647302, "+-", .12401663947356231],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0319957498032737`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0319957498032737, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.55118941546422`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05169721427951899`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.606613783490324`\[InvisibleSpace]"+-"\[InvisibleSpace]\
0.12372836590937186`\),
      SequenceForm[ 
      "a1= ", 52.551189415464222, "+-", .05169721427951899, "  b1= ", 
        1.606613783490324, "+-", .12372836590937186],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0251297089382805`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0251297089382805, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.502859927528434`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05154214424229796`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5883276746996344`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.1231336221894167`\),
      SequenceForm[ 
      "a1= ", 52.502859927528434, "+-", .051542144242297958, "  b1= ", 
        1.5883276746996344, "+-", .1231336221894167],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0126834174212718`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0126834174212718, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.46198172263922`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05142241845105838`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5745169207585488`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.12266389909505038`\),
      SequenceForm[ 
      "a1= ", 52.461981722639223, "+-", .051422418451058383, "  b1= ", 
        1.5745169207585488, "+-", .12266389909505038],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0042988039982386`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0042988039982386, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.42636386060625`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05132584188660545`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5635646461636734`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.1222785731179933`\),
      SequenceForm[ 
      "a1= ", 52.426363860606251, "+-", .051325841886605453, "  b1= ", 
        1.5635646461636734, "+-", .1222785731179933],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9982637020844358`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .99826370208443582, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.3661062226683`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.051177229386126726`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]1.5470279895655434`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.12167476047272849`\),
      SequenceForm[ 
      "a1= ", 52.3661062226683, "+-", .051177229386126726, "  b1= ", 
        1.5470279895655434, "+-", .12167476047272849],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9901786505772416`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .99017865057724164, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.31597303560799`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05106625891257547`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5349220140224837`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.12121544403010145`\),
      SequenceForm[ 
      "a1= ", 52.315973035607989, "+-", .05106625891257547, "  b1= ", 
        1.5349220140224837, "+-", .12121544403010145],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9850500849578667`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .98505008495786672, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.272842782801035`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05097900368072174`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5255439706161833`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.12084921884966839`\),
      SequenceForm[ 
      "a1= ", 52.272842782801035, "+-", .050979003680721738, "  b1= ", 
        1.5255439706161833, "+-", .12084921884966839],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9815458727652764`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .98154587276527638, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.23488142388066`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05090791769613728`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5179932013892172`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.12054750323750568`\),
      SequenceForm[ 
      "a1= ", 52.234881423880658, "+-", .050907917696137277, "  b1= ", 
        1.5179932013892172, "+-", .12054750323750568],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9790300465732289`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .9790300465732289, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.20091020258223`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05084847926713802`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5117401097873922`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.12029284464282465`\),
      SequenceForm[ 
      "a1= ", 52.200910202582229, "+-", .050848479267138022, "  b1= ", 
        1.5117401097873922, "+-", .12029284464282465],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.97715949042196`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .97715949042196004, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.170122372040396`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.050797779385771714`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]1.5064491878309916`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.12007385052174428`\),
      SequenceForm[ 
      "a1= ", 52.170122372040396, "+-", .050797779385771714, "  b1= ", 
        1.5064491878309916, "+-", .12007385052174428],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9757324926753413`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .97573249267534135, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.14193939409764`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.050753844794303185`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]1.5018957663258534`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.11988270384866788`\),
      SequenceForm[ 
      "a1= ", 52.141939394097641, "+-", .050753844794303185, "  b1= ", 
        1.5018957663258534, "+-", .11988270384866788],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9746226511890147`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .9746226511890147, "  ngrb=", 27],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[r1om, Frame \[Rule] True, Axes \[Rule] False, 
      PlotRange \[Rule] All]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0141895 0.962001 -2.6396 2.72343 [
[.01419 -0.0125 -7.03125 -24.5625 ]
[.01419 -0.0125 7.03125 0 ]
[.20659 -0.0125 -14.5625 -24.5625 ]
[.20659 -0.0125 14.5625 0 ]
[.39899 -0.0125 -14.5625 -24.5625 ]
[.39899 -0.0125 14.5625 0 ]
[.59139 -0.0125 -14.5625 -24.5625 ]
[.59139 -0.0125 14.5625 0 ]
[.78379 -0.0125 -14.5625 -24.5625 ]
[.78379 -0.0125 14.5625 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08383 -14.0625 -12.2813 ]
[-0.0125 .08383 0 12.2813 ]
[-0.0125 .22 -39.1875 -12.2813 ]
[-0.0125 .22 0 12.2813 ]
[-0.0125 .35617 -29.125 -12.2813 ]
[-0.0125 .35617 0 12.2813 ]
[-0.0125 .49234 -39.1875 -12.2813 ]
[-0.0125 .49234 0 12.2813 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01419 0 m
.01419 .00625 L
s
gsave
.01419 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20659 0 m
.20659 .00625 L
s
gsave
.20659 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.39899 0 m
.39899 .00625 L
s
gsave
.39899 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59139 0 m
.59139 .00625 L
s
gsave
.59139 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78379 0 m
.78379 .00625 L
s
gsave
.78379 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.06229 0 m
.06229 .00375 L
s
.11039 0 m
.11039 .00375 L
s
.15849 0 m
.15849 .00375 L
s
.25469 0 m
.25469 .00375 L
s
.30279 0 m
.30279 .00375 L
s
.35089 0 m
.35089 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.49519 0 m
.49519 .00375 L
s
.54329 0 m
.54329 .00375 L
s
.63949 0 m
.63949 .00375 L
s
.68759 0 m
.68759 .00375 L
s
.73569 0 m
.73569 .00375 L
s
.83189 0 m
.83189 .00375 L
s
.87999 0 m
.87999 .00375 L
s
.92809 0 m
.92809 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08383 m
.00625 .08383 L
s
gsave
-0.0125 .08383 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .22 m
.00625 .22 L
s
gsave
-0.0125 .22 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
1.000 setlinewidth
grestore
0 .35617 m
.00625 .35617 L
s
gsave
-0.0125 .35617 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
0 .49234 m
.00625 .49234 L
s
gsave
-0.0125 .49234 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11106 m
.00375 .11106 L
s
0 .1383 m
.00375 .1383 L
s
0 .16553 m
.00375 .16553 L
s
0 .19277 m
.00375 .19277 L
s
0 .24723 m
.00375 .24723 L
s
0 .27447 m
.00375 .27447 L
s
0 .3017 m
.00375 .3017 L
s
0 .32894 m
.00375 .32894 L
s
0 .38341 m
.00375 .38341 L
s
0 .41064 m
.00375 .41064 L
s
0 .43787 m
.00375 .43787 L
s
0 .46511 m
.00375 .46511 L
s
0 .05659 m
.00375 .05659 L
s
0 .02936 m
.00375 .02936 L
s
0 .00213 m
.00375 .00213 L
s
0 .51958 m
.00375 .51958 L
s
0 .54681 m
.00375 .54681 L
s
0 .57405 m
.00375 .57405 L
s
0 .60128 m
.00375 .60128 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.01419 .61178 m
.01419 .61803 L
s
.20659 .61178 m
.20659 .61803 L
s
.39899 .61178 m
.39899 .61803 L
s
.59139 .61178 m
.59139 .61803 L
s
.78379 .61178 m
.78379 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06229 .61428 m
.06229 .61803 L
s
.11039 .61428 m
.11039 .61803 L
s
.15849 .61428 m
.15849 .61803 L
s
.25469 .61428 m
.25469 .61803 L
s
.30279 .61428 m
.30279 .61803 L
s
.35089 .61428 m
.35089 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.49519 .61428 m
.49519 .61803 L
s
.54329 .61428 m
.54329 .61803 L
s
.63949 .61428 m
.63949 .61803 L
s
.68759 .61428 m
.68759 .61803 L
s
.73569 .61428 m
.73569 .61803 L
s
.83189 .61428 m
.83189 .61803 L
s
.87999 .61428 m
.87999 .61803 L
s
.92809 .61428 m
.92809 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08383 m
1 .08383 L
s
.99375 .22 m
1 .22 L
s
.99375 .35617 m
1 .35617 L
s
.99375 .49234 m
1 .49234 L
s
.125 Mabswid
.99625 .11106 m
1 .11106 L
s
.99625 .1383 m
1 .1383 L
s
.99625 .16553 m
1 .16553 L
s
.99625 .19277 m
1 .19277 L
s
.99625 .24723 m
1 .24723 L
s
.99625 .27447 m
1 .27447 L
s
.99625 .3017 m
1 .3017 L
s
.99625 .32894 m
1 .32894 L
s
.99625 .38341 m
1 .38341 L
s
.99625 .41064 m
1 .41064 L
s
.99625 .43787 m
1 .43787 L
s
.99625 .46511 m
1 .46511 L
s
.99625 .05659 m
1 .05659 L
s
.99625 .02936 m
1 .02936 L
s
.99625 .00213 m
1 .00213 L
s
.99625 .51958 m
1 .51958 L
s
.99625 .54681 m
1 .54681 L
s
.99625 .57405 m
1 .57405 L
s
.99625 .60128 m
1 .60128 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.008 w
.02381 .60332 Mdot
.04305 .41458 Mdot
.06229 .32224 Mdot
.08153 .26453 Mdot
.10077 .22426 Mdot
.11039 .20826 Mdot
.13925 .17097 Mdot
.15849 .15227 Mdot
.20659 .11837 Mdot
.25469 .09554 Mdot
.30279 .0791 Mdot
.39899 .05708 Mdot
.49519 .04311 Mdot
.59139 .03357 Mdot
.68759 .02672 Mdot
.78379 .02162 Mdot
.87999 .01774 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{647.5, 400.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:70001T2000`400?l00000o`00003oo`3ooooo
0?ooohT0oooo003o0?ooool0ooooR@3oool00?l0ooooo`3ooon90?ooo`00o`3ooooo0?ooohT0oooo
003o0?ooool0ooooR@3oool00?l0ooooo`3ooon90?ooo`00o`3ooooo0?ooohT0oooo000g0?ooo`04
0;md00000000000004RLgfL0oooo00@0_g@0000000000000B9cO103oool01@3OW4P0000004RLg`3o
ool0gia800L0000000<0M;oo0?ooo`3oool0F`3oool0102oM000000000000018W=l40?ooo`030=nL
B0000000B9cO00H0oooo00<0okmd0000001d_ol0G`3oool0102oM000000000000018W=l40?ooo`03
0=nLB0000000B9cO00<0oooo00H0oooO09a80000000000000000M02ooomN0?ooo`040;md00000000
000004RLg`@0oooo00<0gia800000018W=l00`3oool01P3ogi`0B000000000000000001809cOofD0
oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0=0?ooo`00=@3oool01`3ooml0W4P0
001d_`3oool0oooO09a80000M;l0I03oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3o
ool00`3OW4P0000004RLg`020?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool0F@3o
ool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`060?ooo`03
0?noM0000000M;oo05d0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia8
00000018W=l00P3oool0203ookl0M0000018W03Oool0oooo0=nLB00004P0W=ooF`3oool01`3ooml0
W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`080?oOW0180000
04RL0=ooo`3oool0omnL04P0001d_omV0?ooo`030;md000007@0_ooo0100oooo000e0?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol0H`3oool00`3o_g@0001809cOo`020?ooo`030?oO
W0180000M;oo00P0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`1J0?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol02`3oool00`3o_g@0000007Boo`1M0?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`2oM000001d0;ooo`030?ooo`030;md
0000M;l0oooo05X0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030;md
000007@0_ooo00<0oooo00<0gia80018W03Oool0I@3oool00`2oM000001d0;ooo`0@0?ooo`00=03o
ool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo0680oooo00@0oooO09a80000B9`0
gooo0P3oool00`3ooml0W4P0001d_`090?ooo`030=nLB018W=l0oooo05d0oooo00@0oooO09a80000
B9`0gooo0P3oool00`3ooml0W4P0001d_`060?ooo`030=nLB0000000000000D0000000<0001809cO
o`3oool0F@3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00H0oooo00<0oono
07@00000M;l0103oool00`3OW4P0001d0;ooo`1I0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
oooO09a80000M;l01`3oool00`2oM000001d0;ooo`030?ooo`030;md0000B9`0gooo06D0oooo00<0
_g@00000M02oool0403oool003@0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`1Q
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02@3oool00`3OW4P0M;oo0?ooo`1L
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01@3oool00`3ogi`0B7Bo0?ooo`02
0?ooo`030?noM0000000M;oo05`0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`05
0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000B02Lgol0F@3oool00`3ookl0M000001d_`04
0?ooo`030;md000007@0_ooo00H0oooo00<0okmd0000B02Lgol00P3oool00`3OW4P00000001d_`1V
0?ooo`030;md000007@0_ooo0100oooo000d0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000
M02oool0H@3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00T0oooo00<0oooO09a8
B02Lgol0G03oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00H0oooo00L0gia807Bo
o`3oool0oooo0?noM0000000M;oo05`0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;oo
o`050?ooo`030?oOW0180000B9cO00<0oooo00@0oono07@0000007@0_oooF@3oool00`3ogi`0B000
04RLg`040?ooo`030;md000007@0_ooo00L0oooo00L0gia8001d_`3oool0_g@00000000007@0_ooo
06H0oooo00<0_g@00000M02oool0403oool003@0oooo00<0omnL04P00018W=l0103oool00`3OW4P0
001809cOo`1Q0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol02P3oool00`3ogi`0
B01d0;ooo`1K0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01P3oool01`3ookl0
M01d0;ooo`3oool0okmd0000001d_ol0G03oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0
W=oo00D0oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l0FP3oool00`3ogi`0
B00004RLg`040?ooo`030=nLB00004P0W=oo00P0oooo00D0okmd00000000000004RL0=ooo`1W0?oo
o`030;md000007@0_ooo0100oooo000d0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02L
gol0H@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00/0oooo00<0_g@004RLg`3o
ool0FP3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0oooo00H0okmd001d_`3o
ool0okmd0000001d_omL0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01@3oool0
1@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool0F@3oool00`3ogi`0B00004RL
g`040?ooo`030=nLB00004P0W=oo00L0oooo00D0omnL04P000000000000004RLg`1X0?ooo`030;md
000007@0_ooo0100oooo000d0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0H@3o
ool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0gia80000M02oool0FP3o
ool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00P0oooo00D0_g@007Boo`3o_g@00000
07Boo`1L0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@00000
04RLg`1O0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool01`3ogi`0B000
0000B02Lgol0oooo0=nLB000M;l0I`3oool00`2oM000001d0;ooo`0@0?ooo`00=@3oool00`2oM000
04RL0=ooo`020?ooo`030?oog`2LB00007Bo06<0oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`0<0?ooo`030?noM0000000M;oo05/0oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`090?ooo`050?oo_`1d07@0_kmd0000001d_ol0G@3oool00`2oM00004RL0=ooo`020?oo
o`030?oog`2LB00007Bo00L0oooo00@0oooO09a8000004P0W=ooG`3oool00`2oM00004RL0=ooo`02
0?ooo`030?oog`2LB00007Bo00L0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P007Boo`1V
0?ooo`030;md000007@0_ooo0100oooo000e0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0
001d_ol0H`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00H0oooo00<0omnL09bo
o`3oool00`3oool00`2oM000000007Boo`1K0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0
001d_ol02P3oool0103o_g@000000000001d_omM0?ooo`030?noM00004P0W=oo0080oooo00<0omnL
04P0001d_ol0203oool0103ookl0M0000000M02ooomN0?ooo`030?noM00004P0W=oo0080oooo00<0
omnL04P0001d_ol01`3oool00`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO06H0oooo00<0
_g@00000M02oool0403oool003H0oooo00H0_g@00018W03Oool0oooo0;md0000M;mU0?ooo`060;md
0000B9`0gooo0?ooo`2oM00007Bo203oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo
G03oool01P2oM00004RL0=ooo`3oool0_g@0001d_`/0oooo00@0oooO09a800000000M;ooGP3oool0
1P2oM00004RL0=ooo`3oool0_g@0001d_`X0oooo00@0oooO09a80000000007BoGP3oool01P2oM000
04RL0=ooo`3oool0_g@0001d_`P0oooo00<0omnL04P00018W=l00P3oool00`3o_g@0001809cOo`1T
0?ooo`050=nLB000000000000000M02oool0403oool003L0oooo00@0_g@000000000000007BoI`3o
ool0102oM000000000000000M;l:0?ooo`050;md00000000000000000000M;l0G`3oool0102oM000
000000000000M;l=0?ooo`030?oOW0180000M;oo05l0oooo00@0_g@000000000000007Bo3@3oool0
1@3ogi`0B00000000000B9`0gooo05`0oooo00@0_g@000000000000007Bo2P3oool01P3ookl0M000
000000000000001809cOofH0oooo00@0oono07@0000007@0_ooo403oool00?l0ooooo`3ooon90?oo
o`00o`3ooooo0?ooohT0oooo003o0?ooool0ooooR@3oool00?l0ooooo`3ooon90?ooo`00o`3ooooo
0?ooohT0oooo003o0?ooool0ooooR@3oool00?l0ooooo`3ooon90?ooo`00o`3ooooo0?ooohT0oooo
003o0?ooool0ooooR@3oool00?l0ooooo`3ooon90?ooo`00o`3ooooo0?ooohT0oooo003o0?ooool0
ooooR@3oool00340ooooo`00003o000005D000000`3oool00340oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`010?ooo`00<@3oool3000000D0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00T0oooo0`0000030?ooo`00<@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo06l0
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo
00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<0
00000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<00000
0?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oood80oooo0P00000=0?oo
o`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooom10?ooo`@0
0000303oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0oooo
2@3oool2000003H0oooo1000000<0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003o
ool0oooo0?l0ooooo`3oool80?ooo`@00000=P3oool2000000d0oooo00<000000?ooo`3oool00@3o
ool00340oooo00<000000?ooo`3oool0o`3oooo?0?ooo`800000=P3oool4000004D0oooo00<00000
0?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3oooo>0?ooo`@00000=P3oool20000
04H0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3oooo>0?ooo`@0
0000OP3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?oooiH0oooo
0P00000g0?ooo`800000O`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?oo
o`3o0?oooiD0oooo1000002g0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0
oooo0?l0ooooU@3oool400000;L0oooo00<000000?ooo`3oool00@3oool00340oooo0`00003o0?oo
oiH0oooo0P00002f0?ooo`<000000`3oool00340oooo00<000000?ooo`3oool0o`3ooomL0?ooo`80
0000lP3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?oooe/0oooo
1000003a0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooF`3o
ool400000?40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooomL
0?ooo`800000lP3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0
ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooob<0oooo
0P00003o0?ooob`0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3o
oolR0?ooo`@00000o`3oool[0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0
oooo0?l0oooo8P3oool400000?l0oooo:`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`00
0000oooo0?ooo`3o0?ooob<0oooo0P00003o0?ooob`0oooo00<000000?ooo`3oool00@3oool00340
oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<0
00000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?oo
o`3oool0j@3oool200000?l0ooooI@3oool00`000000oooo0?ooo`010?ooo`00<@3oool300000>P0
oooo1000003o0?ooof80oooo0`0000030?ooo`00<@3oool00`000000oooo0?ooo`3X0?ooo`@00000
o`3ooomT0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0>T0oooo0P00
003o0?ooofD0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo
0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40
oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo
00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<0
00000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<00000
0?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?oo
o`3oool00@3oool001l0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0:0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000Q0?ooo`030;md
000007@0_ooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool0
0@3oool00240oooo00<0_g@00000M02oool03@3oool00`000000oooo0?ooo`2`0?ooo`800000o`3o
oonN0?ooo`030000003oool0oooo0040oooo000Q0?ooo`030;md000007@0_ooo00d0oooo00<00000
0?ooo`3oool0[`3oool400000?l0ooooW@3oool00`000000oooo0?ooo`010?ooo`008@3oool00`2o
M000001d0;ooo`0=0?ooo`030000003oool0oooo0:l0oooo1000003o0?oooid0oooo00<000000?oo
o`3oool00@3oool00240oooo00<0_g@00000M02oool03@3oool00`000000oooo0?ooo`2`0?ooo`80
0000o`3ooonN0?ooo`030000003oool0oooo0040oooo000Q0?ooo`030;md000007@0_ooo00d0oooo
1@00003o0?ooool0ooooB`3oool5000000<0oooo000Q0?ooo`030;md000007@0_ooo00d0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00240oooo00<0_g@0
0000M02oool03@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`01
0?ooo`008@3oool00`2oM000001d0;ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?oo
o`030000003oool0oooo0040oooo000Q0?ooo`030;md000007@0_ooo00d0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool001l0oooo00D0gia8000000000000
001d0;ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040
oooo000P0?ooo`040?oo_`1d0000001d0;ooo`d0oooo00<000000?ooo`3oool0T`3oool200000?l0
oooo^`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`2B0?ooo`@00000
o`3ooonj0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0980oooo1000
003o0?oookX0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0T`3oool2
00000?l0oooo^`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0
ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0oooo
D@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3o
ool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool0
0`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`00
0000oooo0?ooo`010?ooo`00<@3oool300000?l0ooooo`3ooom?0?ooo`<000000`3oool00340oooo
00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<0
00000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?oo
o`3oool0M`3oool200000?l0ooooe`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000
oooo0?ooo`1f0?ooo`@00000o`3ooooF0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000
003oool0oooo07H0oooo1000003o0?ooomH0oooo00<000000?ooo`3oool00@3oool00340oooo00<0
00000?ooo`3oool0M`3oool200000?l0ooooe`3oool00`000000oooo0?ooo`010?ooo`00<@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000
oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo
0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?oo
o`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o
0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0
ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool300000?l0ooooo`3ooom?0?ooo`<00000
0`3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3o
ool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool0
0340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340
oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<0
00000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?oo
o`3oool0FP3oool200000?l0oooom03oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000
oooo0?ooo`1I0?ooo`@00000o`3ooooc0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000
003oool0oooo05T0oooo1000003o0?oooo<0oooo00<000000?ooo`3oool00@3oool00340oooo00<0
00000?ooo`3oool0FP3oool200000?l0oooom03oool00`000000oooo0?ooo`010?ooo`00<@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000
oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo
0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?oo
o`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool300000?l0ooooo`3ooom?
0?ooo`<000000`3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?oo
o`3oool00@3oool00340oooo00<000000?ooo`3oool0C`3oool200000?l0ooooo`3oool00`000000
oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`1>0?ooo`@00000o`3oooon0?ooo`030000
003oool0oooo0040oooo000a0?ooo`030000003oool0oooo04h0oooo1000003o0?ooooh0oooo00<0
00000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0C`3oool200000?l0ooooo`3oool0
0`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`00
0000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000
oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo
0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?oo
o`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`01
0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?oo
o`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00
<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool30000
0?l0ooooo`3ooom?0?ooo`<000000`3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40
oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo
00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<0
00000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<00000
0?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?oo
o`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3o
ool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool0
0@3oool00340oooo00<000000?ooo`3oool0?P3oool200000?l0ooooo`3ooolA0?ooo`030000003o
ool0oooo0040oooo000a0?ooo`030000003oool0oooo03d0oooo1000003o0?ooool0oooo403oool0
0`000000oooo0?ooo`010?ooo`001P3oool00`3o_g@000000000000200000007001d_`3oool0oooo
0?ooo`3OW4P0000004RLg`040?ooo`040;md00000000000004RLg`@0oooo00H0_g@0000000000000
00000018W03Oool=0?ooo`030000003oool0oooo03d0oooo1000003o0?ooool0oooo403oool00`00
0000oooo0?ooo`010?ooo`00203oool00`2oM000001d0;ooo`040?ooo`030=nLB0000000B9cO0080
oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo0080oooo00<0oooO09a80018W=l00P3oool0
0`3ogi`0B4RL0=ooo`0<0?ooo`030000003oool0oooo03h0oooo0P00003o0?ooool0oooo4@3oool0
0`000000oooo0?ooo`010?ooo`00203oool00`2oM000001d0;ooo`090?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol01`3oool00`3ogi`0B7Bo0?ooo`0;0?ooo`030000003oool0oooo
0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo00080?ooo`030;md000007@0_ooo00P0
oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`070?ooo`030?oo_`1d04P0W=oo
00/0oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool000P0
oooo00<0_g@00000M02oool0203oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0
oooo00<0oono07@0001d_ol02`3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000
oooo0?ooo`010?ooo`00203oool00`2oM000001d0;ooo`080?ooo`030?oOW0180000B9cO00@0oooo
00<0_g@00000M02oool01P3oool00`3o_g@0000007Boo`0;0?ooo`030000003oool0oooo0?l0oooo
o`3ooomA0?ooo`030000003oool0oooo0040oooo00080?ooo`030;md000007@0_ooo00P0oooo00<0
omnL04P00018W=l0103oool00`3OW4P0001809cOo`050?ooo`040?oOW0180000001d0;ooo`/0oooo
1@00003o0?ooool0ooooB`3oool5000000<0oooo00080?ooo`030;md000007@0_ooo00P0oooo00<0
omnL04P00018W=l0103oool01@3OW4P0001809cOo`3oool0gmoO0080oooo00@0_g@0000000000000
B9cO303oool00`000000oooo0?ooo`0h0?ooo`800000o`3ooooo0?oooaL0oooo00<000000?ooo`3o
ool00@3oool000P0oooo00<0_g@00000M02oool0203oool00`3ookl0M000001d_`040?ooo`050;md
000007@0_ooo0?ooo`3o_g@0100000000`00M;l0oooo0?ooo`0;0?ooo`030000003oool0oooo03L0
oooo1000003o0?ooool0oooo5P3oool00`000000oooo0?ooo`010?ooo`00203oool00`2oM000001d
0;ooo`090?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l00P3oool01@3ooml0W4P0
0000000007@0_ooo00h0oooo00<000000?ooo`3oool0=`3oool400000?l0ooooo`3ooolF0?ooo`03
0000003oool0oooo0040oooo00080?ooo`030;md000007@0_ooo00T0oooo00<0okmd0000B02Lgol0
0P3oool00`3ogi`0B00007Boo`030?ooo`030?noM000M;l0oooo00l0oooo00<000000?ooo`3oool0
>03oool200000?l0ooooo`3ooolG0?ooo`030000003oool0oooo0040oooo00060?ooo`050=nLB000
000000000000M02oool02P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`@0oooo00<0oooO09a8
000000000P0000000`0007@0_ooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?oo
o`030000003oool0oooo0040oooo00070?ooo`040?oo_`1d0000001d0;ooo`/0oooo00@0_g@00000
0000000007Bo1P3oool00`3o_g@00000000000020000000307Boo`3oool0oooo00T0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?oo
o`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3o
ool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0
o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3o
oooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo
0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40
oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo
00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<0
00000?ooo`3oool00@3oool00340oooo0`00003o0?ooool0ooooC`3oool3000000<0oooo000a0?oo
o`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000
003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0
oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo
0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0
ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0oooo
o`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo02`0oooo0P00
003o0?ooool0oooo8`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0[
0?ooo`@00000o`3ooooo0?ooob80oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?oo
o`3oool0:`3oool400000?l0ooooo`3ooolR0?ooo`030000003oool0oooo0040oooo000a0?ooo`03
0000003oool0oooo02`0oooo0P00003o0?ooool0oooo8`3oool00`000000oooo0?ooo`010?ooo`00
<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool30000
0?l0ooooo`3ooom?0?ooo`<000000`3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40
oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo
00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<0
00000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<00000
0?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?oo
o`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3o
ool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool0
0@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3o
ool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool0
0340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340
oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<0
00000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?oo
o`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3o
ool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo0`00003o0?ooool0oooo
C`3oool3000000<0oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003o
ool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0
oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo
0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040
oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo
000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a
0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?oo
o`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000
003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003o
ool0oooo0240oooo0P00003o0?ooool0oooo;P3oool00`000000oooo0?ooo`010?ooo`00<@3oool0
0`000000oooo0?ooo`0P0?ooo`@00000o`3ooooo0?ooobd0oooo00<000000?ooo`3oool00@3oool0
0340oooo00<000000?ooo`3oool0803oool400000?l0ooooo`3oool]0?ooo`030000003oool0oooo
0040oooo000a0?ooo`030000003oool0oooo0240oooo0P00003o0?ooool0oooo;P3oool00`000000
oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo
0?ooo`010?ooo`00<@3oool300000?l0ooooo`3ooom?0?ooo`<000000`3oool00340oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?oo
o`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3o
ool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0
o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3o
oooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo
0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40
oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo
00<000000?ooo`3oool00@3oool00100oooo00<0okmd0000000000000P0000001`00M;l0oooo0?oo
o`3oool0gia800000018W=l00`3oool00`3o_g@000000000000200000003001d_`3oool0oooo00X0
oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00180oooo
00<0_g@00000M02oool0103oool00`3OW4P0000004RLg`050?ooo`030;md000007@0_ooo00d0oooo
00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00180oooo00<0
_g@00000M02oool0303oool00`2oM000001d0;ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3o
oomA0?ooo`030000003oool0oooo0040oooo000B0?ooo`030;md000007@0_ooo00`0oooo00<0_g@0
0000M02oool03@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`01
0?ooo`004P3oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00d0oooo00<000000?oo
o`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00180oooo00<0_g@00000M02o
ool0303oool00`2oM000001d0;ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`03
0000003oool0oooo0040oooo000B0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0
3@3oool500000?l0ooooo`3ooom;0?ooo`D000000`3oool00180oooo00<0_g@00000M02oool0303o
ool00`2oM000001d0;ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003o
ool0oooo0040oooo000B0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool03@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`004P3oool00`2o
M000001d0;ooo`0<0?ooo`030;md000007@0_ooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe40oooo00<000000?ooo`3oool00@3oool00180oooo00<0_g@00000M02oool0303oool00`2oM000
001d0;ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040
oooo000@0?ooo`050=nLB000000000000000M02oool02P3oool01@3OW4P000000000000007@0_ooo
00d0oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00140
oooo00@0oono07@0000007@0_ooo2`3oool0103ookl0M0000000M02oool=0?ooo`030000003oool0
oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo
0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0
ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0oooo
o`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3o
oomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA
0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?oo
o`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`03
0000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000
003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003o
ool0oooo0040oooo000a0?ooo`<00000o`3ooooo0?ooodl0oooo0`0000030?ooo`00<@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000
oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo
0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?oo
o`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o
0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0
ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0oooo
D@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3o
ool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool0
0`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`00
0000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000
oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo
0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?oo
o`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`01
0?ooo`00<@3oool300000?l0ooooo`3ooom?0?ooo`<000000`3oool00340oooo00<000000?ooo`3o
ool05P3oool200000?l0ooooo`3oooli0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000
003oool0oooo01D0oooo1000003o0?ooool0oooo>03oool00`000000oooo0?ooo`010?ooo`00<@3o
ool00`000000oooo0?ooo`0E0?ooo`@00000o`3ooooo0?ooocP0oooo00<000000?ooo`3oool00@3o
ool00340oooo00<000000?ooo`3oool05P3oool200000?l0ooooo`3oooli0?ooo`030000003oool0
oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo
0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040
oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo
000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a
0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?oo
o`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000
003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0
oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo
0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`<00000o`3ooooo0?ooodl0
oooo0`0000030?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo
0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?oo
o`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`01
0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?oo
o`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00
<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000
oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo
0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?oo
o`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o
0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0
ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0oooo
D@3oool00`000000oooo0?ooo`010?ooo`00<@3oool300000?l0ooooo`3ooom?0?ooo`<000000`3o
ool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool0
0340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340
oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<0
00000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?oo
o`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3o
ool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0
o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool000H0oooo00<0okmd0000000000000P00
00001`00M;l0oooo0?ooo`3oool0gia800000018W=l00`3oool00`3o_g@000000000000200000005
001d_`3oool0oooo0?ooo`2oM0000`0000000`00B9`0gooo0?ooo`0<0?ooo`030000003oool0oooo
0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo00080?ooo`030;md000007@0_ooo00@0
oooo00<0gia800000018W=l01@3oool00`2oM000001d0;ooo`030?ooo`030?oog`2LB000B9cO0080
oooo00<0omnL04Q8W03Oool0303oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000
oooo0?ooo`010?ooo`00203oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00T0oooo
00<0omnL04Qd_`3oool02`3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo
0?ooo`010?ooo`00203oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00T0oooo00<0
oono07@0B02Lgol02`3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?oo
o`010?ooo`00203oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00T0oooo00<0oono
07@0001d_ol02`3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`01
0?ooo`00203oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00T0oooo00<0okmd0000
001d_ol02`3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?oo
o`00203oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00P0oooo00@0omnL04P00000
07@0_ooo2`3oool500000?l0ooooo`3ooom;0?ooo`D000000`3oool000P0oooo00<0_g@00000M02o
ool0303oool00`2oM000001d0;ooo`040?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?oo
o`3oool02P3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?oo
o`00203oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00@0oooo00<0okmd00000000
00000P0000000`00M;l0oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`03
0000003oool0oooo0040oooo00080?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0
103oool01@3ooml0W4P00000000007@0_ooo00h0oooo00<000000?ooo`3oool0o`3ooooo0?oooe40
oooo00<000000?ooo`3oool00@3oool000P0oooo00<0_g@00000M02oool0303oool00`2oM000001d
0;ooo`050?ooo`030?noM000M;l0oooo00l0oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo
00<000000?ooo`3oool00@3oool000H0oooo00D0gia8000000000000001d0;ooo`0:0?ooo`050=nL
B000000000000000M02oool01@3oool00`3ooml0W4P000000002000000030000M02oool0oooo00X0
oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool000L0oooo
00@0oono07@0000007@0_ooo2`3oool0103ookl0M0000000M02oool60?ooo`030?noM00000000000
0080000000<0M;oo0?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`00
0000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000
oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo
0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?oo
o`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`01
0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?oo
o`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00
<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool30000
0?l0ooooo`3ooom?0?ooo`<000000`3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40
oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo
00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<0
00000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<00000
0?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?oo
o`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3o
ool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool0
0@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3o
ool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool0
0340oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340
oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<0
00000?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?oo
o`3oool0o`3ooooo0?oooe40oooo00<000000?ooo`3oool00@3oool00340oooo0`00003o0?ooool0
ooooC`3oool3000000<0oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000
003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003o
ool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0
oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo
0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040
oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo
000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a
0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?oo
o`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000
003oool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0
oooo0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo
0?l0ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0
ooooo`3ooomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`<00000o`3ooooo0?ooodl0oooo
0`0000030?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?oo
o`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`01
0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?oo
o`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00
<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000
oooo0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo
0?ooo`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?oo
o`3o0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o
0?ooool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0
ooooD@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0oooo
D@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooD@3o
ool00`000000oooo0?ooo`010?ooo`00<@3oool3000000X0oooo0P00003o0?ooool0oooo@`3oool3
000000<0oooo000a0?ooo`030000003oool0oooo00T0oooo1000003o0?ooool0ooooA03oool00`00
0000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`090?ooo`@00000o`3ooooo0?oood@0
oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool02P3oool200000?l0oooo
o`3ooom50?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3o
oomA0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomA
0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L03oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo06l0oooo00<000000?oo
o`3oool0L03oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00@3oool00340oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`00
<@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000a0?ooool00000o`00
001E000000<0oooo0000\
\>"],
  ImageRangeCache->{{{0, 646.5}, {399.188, 0}} -> {-0.101226, 0.949448, \
0.0017496, 0.000618012}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"f24", "=", 
      RowBox[{"ListPlot", "[", 
        RowBox[{
        "r1om", ",", \(Frame \[Rule] True\), ",", \(Axes \[Rule] False\), 
          ",", \(PlotJoined \[Rule] True\), 
          ",", \(FrameLabel \[Rule] {\*"\"\<\!\(\[Omega]\_\(0  m\)\)\>\"", \
\*"\"\<\!\(\[Chi]\^2\)\>\""}\), ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{\(Hue[1.2]\), ",", \(Thickness[0.004]\), ",", 
                RowBox[{
                  StyleBox["Dashing",
                    "MR"], 
                  StyleBox["[",
                    "MR"], 
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    RowBox[{
                      StyleBox["0.005",
                        "MR"], 
                      StyleBox[",",
                        "MR"], " ", 
                      StyleBox["0.005",
                        "MR"]}], 
                    StyleBox["}",
                      "MR"]}], 
                  StyleBox["]",
                    "MR"]}]}], "}"}]}]}], "]"}]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -2.6396 2.72343 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -14.5625 -24.5625 ]
[.21429 -0.0125 14.5625 0 ]
[.40476 -0.0125 -14.5625 -24.5625 ]
[.40476 -0.0125 14.5625 0 ]
[.59524 -0.0125 -14.5625 -24.5625 ]
[.59524 -0.0125 14.5625 0 ]
[.78571 -0.0125 -14.5625 -24.5625 ]
[.78571 -0.0125 14.5625 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.4063 -49.125 ]
[.5 -0.0125 19.4063 -24.5625 ]
[-0.0125 .08383 -14.0625 -12.2813 ]
[-0.0125 .08383 0 12.2813 ]
[-0.0125 .22 -39.1875 -12.2813 ]
[-0.0125 .22 0 12.2813 ]
[-0.0125 .35617 -29.125 -12.2813 ]
[-0.0125 .35617 0 12.2813 ]
[-0.0125 .49234 -39.1875 -12.2813 ]
[-0.0125 .49234 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -63.75 -12.5625 ]
[-0.01875 .30902 -39.1875 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.4063 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
76.813 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
83.875 26.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
86.500 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
97.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08383 m
.00625 .08383 L
s
gsave
-0.0125 .08383 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .22 m
.00625 .22 L
s
gsave
-0.0125 .22 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
1.000 setlinewidth
grestore
0 .35617 m
.00625 .35617 L
s
gsave
-0.0125 .35617 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
0 .49234 m
.00625 .49234 L
s
gsave
-0.0125 .49234 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11106 m
.00375 .11106 L
s
0 .1383 m
.00375 .1383 L
s
0 .16553 m
.00375 .16553 L
s
0 .19277 m
.00375 .19277 L
s
0 .24723 m
.00375 .24723 L
s
0 .27447 m
.00375 .27447 L
s
0 .3017 m
.00375 .3017 L
s
0 .32894 m
.00375 .32894 L
s
0 .38341 m
.00375 .38341 L
s
0 .41064 m
.00375 .41064 L
s
0 .43787 m
.00375 .43787 L
s
0 .46511 m
.00375 .46511 L
s
0 .05659 m
.00375 .05659 L
s
0 .02936 m
.00375 .02936 L
s
0 .00213 m
.00375 .00213 L
s
0 .51958 m
.00375 .51958 L
s
0 .54681 m
.00375 .54681 L
s
0 .57405 m
.00375 .57405 L
s
0 .60128 m
.00375 .60128 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -125.031 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
73.5625 16.2813 translate
90 rotate
-73.5625 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.375 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
76.563 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08383 m
1 .08383 L
s
.99375 .22 m
1 .22 L
s
.99375 .35617 m
1 .35617 L
s
.99375 .49234 m
1 .49234 L
s
.125 Mabswid
.99625 .11106 m
1 .11106 L
s
.99625 .1383 m
1 .1383 L
s
.99625 .16553 m
1 .16553 L
s
.99625 .19277 m
1 .19277 L
s
.99625 .24723 m
1 .24723 L
s
.99625 .27447 m
1 .27447 L
s
.99625 .3017 m
1 .3017 L
s
.99625 .32894 m
1 .32894 L
s
.99625 .38341 m
1 .38341 L
s
.99625 .41064 m
1 .41064 L
s
.99625 .43787 m
1 .43787 L
s
.99625 .46511 m
1 .46511 L
s
.99625 .05659 m
1 .05659 L
s
.99625 .02936 m
1 .02936 L
s
.99625 .00213 m
1 .00213 L
s
.99625 .51958 m
1 .51958 L
s
.99625 .54681 m
1 .54681 L
s
.99625 .57405 m
1 .57405 L
s
.99625 .60128 m
1 .60128 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.8 1 0 r
.004 w
[ .005 .005 ] 0 setdash
.03333 .60332 m
.05238 .41458 L
.07143 .32224 L
.09048 .26453 L
.10952 .22426 L
.11905 .20826 L
.14762 .17097 L
.16667 .15227 L
.21429 .11837 L
.2619 .09554 L
.30952 .0791 L
.40476 .05708 L
.5 .04311 L
.59524 .03357 L
.69048 .02672 L
.78571 .02162 L
.88095 .01774 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{728, 449.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["(*",
        FontSize->18], 
      StyleBox[" ",
        FontSize->18], 
      RowBox[{
        StyleBox["Repeat",
          FontSize->18], 
        StyleBox[" ",
          FontSize->18], 
        StyleBox["above",
          FontSize->18], 
        StyleBox[" ",
          FontSize->18], 
        StyleBox["calculation",
          FontSize->18], 
        StyleBox[" ",
          FontSize->18], 
        StyleBox["for",
          FontSize->18], 
        StyleBox[" ",
          FontSize->18], 
        RowBox[{
          StyleBox["(",
            FontSize->18], 
          RowBox[{
            RowBox[{
              StyleBox["Log",
                FontSize->18], 
              RowBox[{"(", 
                StyleBox[\(t\_trt\),
                  FontSize->18], 
                StyleBox[")",
                  FontSize->18]}]}], 
            StyleBox["-",
              FontSize->18], 
            StyleBox[\(Log \((L)\)\),
              FontSize->18]}], 
          StyleBox[")",
            FontSize->18]}]}], 
      StyleBox[" ",
        FontSize->18], 
      StyleBox["*)",
        FontSize->18]}]], "Input"],

Cell[BoxData[
    \(omv = {0.01, 0.03, 0.05, 0.07, 0.09, 0.1, 0.13, 0.15, 0.2, 0.25, 0.3, 
        0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1}; valsom = Length[omv]; 
    r1om = {};\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[om = omv[\([q]\)]; \[IndentingNewLine]Clear[f, dl, dld, zmin, zmax]; 
      w0 = \(-1\); w1 = 0; h0 = 10^5\ h; \ c = 3\ 10^8; 
      h = 0.72; \[IndentingNewLine]f[z_] := 
        1/Sqrt[om*\((1 + z)\)^3\  + \((1 - 
                    om)\)*\((1 + z)\)^\((3 \((1 + w0\  + \ w1)\))\) 
                Exp[3\ w1\ \((\((1/\((1 + z)\))\) - 1)\)]]; \n
      dl[zz_] := c \((1 + zz)\)\ NIntegrate[f[z], {z, 0, zz}]/h0; \n
      dld = dl[zz[#]] 3\ 10^24 &; \nll = 4\ Pi\ dld[#]^2\ pbolo[#] &; \n
      sll = 4\ Pi\ dld[#]^2\ spbolo[#] &; \n
      eg = 4\ Pi\ dld[#]^2\ sbolo[#]\ fbeam[#]/\((1 + zz[#])\) &; \nzmin = 0; 
      zmax = 7; \nClear[lltlag, slltlag]; \nlltrt = {}; slltrt = {}; \n
      Do[\[IndentingNewLine]If[
          trt[i] > 0\  && \ zz[i] \[GreaterEqual] zmin\  && \ 
            zz[i] \[LessEqual] \ zmax, \[IndentingNewLine]AppendTo[
            lltrt, {Log[10, \ trt[i]], 
              Log[10, ll[i]]}]; \[IndentingNewLine]AppendTo[
            slltrt, {strt[i]/\((Log[10]\ trt[i])\), 
              sll[i]/\((Log[10]\ ll[i])\)}]], {i, 1, 
          ndat}]; \n\[IndentingNewLine]llp[a1_, b1_, x_] := 
        a1\  + \ b1\ x; \[IndentingNewLine]trtp[a1_, b1_, x_] := \((x - a1)\)/
          b1; \[IndentingNewLine]\[IndentingNewLine]chi2[a1_, b1_, s1_] := 
        Sum[\((\((lltrt[\([i, 2]\)] - 
                      llp[a1, b1, 
                        lltrt[\([i, 1]\)]])\)^2/\((slltrt[\([i, 2]\)]^2 + 
                    s1^2)\))\), {i, 1, Length[lltrt]}] + 
          Sum[\((\((lltrt[\([i, 1]\)] - 
                      trtp[a1, b1, 
                        lltrt[\([i, 2]\)]])\)^2/\((slltrt[\([i, 1]\)]^2 + 
                    s1^2)\))\), {i, 1, 
              Length[lltrt]}]; \[IndentingNewLine]\[IndentingNewLine]s1 = 
        0.45; \npar = {a1, b1}; \n
      akl[a1_, b1_, k_, l_] := 
        1/2  D[D[chi2[a1, b1, 0.5], par[\([k]\)]], par[\([l]\)]\ ]; \n
      fmingrb = FindMinimum[chi2\ [a1, b1, s1], {a1, 1}, {b1, \(-10\)}]; \n
      a1o = fmingrb[\([2, 1, 2]\)]; \nb1o = fmingrb[\([2, 2, 2]\)]; \n
      aklo = Table[
          If[k \[LessSlantEqual] l, \(akl[a1, b1, k, l] /. a1 \[Rule] a1o\) /. 
              b1 \[Rule] b1o, \(akl[a1, b1, l, k] /. a1 \[Rule] a1o\) /. 
              b1 \[Rule] b1o], {k, 1, 2}, {l, 1, 2}]; cij = Inverse[aklo]; 
      spar = Table[Sqrt[cij[\([i, i]\)]], {i, 1, 2}]; 
      Print["\<a1= \>", a1o, "\<+-\>", spar[\([1]\)], "\<  b1= \>", 
        b1o, "\<+-\>", spar[\([2]\)]]; 
      cij // MatrixForm; \[IndentingNewLine]erra1o = 
        spar[\([1]\)]; \[IndentingNewLine]errb1o = 
        spar[\([2]\)]; \[IndentingNewLine]chi2r = 
        Part[fmingrb, 
            1]/\((2\ Length[lltrt])\); \[IndentingNewLine]Print["\<chi2r=\>", 
        chi2r, "\<  ngrb=\>", ngrb]; \[IndentingNewLine]AppendTo[
        r1om, {om, chi2r}], \[IndentingNewLine]{q, 1, valsom}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.87683814391162`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05351147223635777`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.2872489321965637`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07877370348932107`\),
      SequenceForm[ 
      "a1= ", 52.87683814391162, "+-", .053511472236357771, 
        "  b1= ", -1.2872489321965637, "+-", .07877370348932107],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.2225959508839679`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.2225959508839679, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.806190568218994`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05297925522803702`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.2517583617450265`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07828709677723092`\),
      SequenceForm[ 
      "a1= ", 52.806190568218994, "+-", .052979255228037023, 
        "  b1= ", -1.2517583617450265, "+-", .078287096777230919],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.1417017626103354`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.1417017626103354, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.75624401866902`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.052653573377166`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.2310888640088993`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.0779453053864907`\),
      SequenceForm[ 
      "a1= ", 52.756244018669022, "+-", .052653573377166002, 
        "  b1= ", -1.2310888640088993, "+-", .077945305386490693],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.1014839154699085`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.1014839154699085, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.71635791140961`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05241876757879613`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.2166344811350502`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.077680888781562`\),
      SequenceForm[ 
      "a1= ", 52.716357911409609, "+-", .052418767578796127, 
        "  b1= ", -1.2166344811350502, "+-", .077680888781561999],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.076176868512411`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0761768685124109, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.68269294393409`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05223627784844351`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.205646260152089`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07746534765253009`\),
      SequenceForm[ 
      "a1= ", 52.682692943934093, "+-", .052236277848443508, 
        "  b1= ", -1.205646260152089, "+-", .077465347652530089],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0584892794679126`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0584892794679126, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.667559479022636`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05215859697623582`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.2010320473095653`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07737095063707318`\),
      SequenceForm[ 
      "a1= ", 52.667559479022636, "+-", .052158596976235823, 
        "  b1= ", -1.2010320473095653, "+-", .07737095063707318],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0514671486157534`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0514671486157534, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.62719080234455`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.0519636947052204`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.1896166580173428`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07712710996719212`\),
      SequenceForm[ 
      "a1= ", 52.62719080234455, "+-", .051963694705220401, 
        "  b1= ", -1.1896166580173428, "+-", .077127109967192117],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0351497806340444`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0351497806340444, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.60353156263917`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05185729153463426`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.1834802613226327`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07698971766950749`\),
      SequenceForm[ 
      "a1= ", 52.603531562639169, "+-", .05185729153463426, 
        "  b1= ", -1.1834802613226327, "+-", .07698971766950749],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0270161013599794`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0270161013599794, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.552404475904176`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.051645412818536046`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]\(-1.1714569983972947`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07670691688280165`\),
      SequenceForm[ 
      "a1= ", 52.552404475904176, "+-", .051645412818536046, 
        "  b1= ", -1.1714569983972947, "+-", .076706916882801651],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0124324204146353`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0124324204146353, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.50943854217096`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05148477453465645`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.1625116420630914`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07648405924774813`\),
      SequenceForm[ 
      "a1= ", 52.509438542170962, "+-", .051484774534656448, 
        "  b1= ", -1.1625116420630914, "+-", .076484059247748135],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.0028067644234555`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", 1.0028067644234555, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.47217931883756`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05135708965845279`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.1555039436629728`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07630149136021475`\),
      SequenceForm[ 
      "a1= ", 52.472179318837561, "+-", .051357089658452787, 
        "  b1= ", -1.1555039436629728, "+-", .076301491360214746],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9960445126129948`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .99604451261299476, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.40946506775416`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.051163966755659276`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]\(-1.1450746237214926`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07601573268665561`\),
      SequenceForm[ 
      "a1= ", 52.409465067754162, "+-", .051163966755659276, 
        "  b1= ", -1.1450746237214926, "+-", .07601573268665561],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9873434912353463`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .98734349123534626, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.35754804408025`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.051022468712624246`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]\(-1.1375613040172114`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.0757985426546625`\),
      SequenceForm[ 
      "a1= ", 52.357548044080247, "+-", .051022468712624246, 
        "  b1= ", -1.1375613040172114, "+-", .075798542654662501],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9821723744351154`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .9821723744351154, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.31304314302284`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05091287241299758`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.1318156690787524`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07562544696622457`\),
      SequenceForm[ 
      "a1= ", 52.313043143022838, "+-", .050912872412997578, 
        "  b1= ", -1.1318156690787524, "+-", .075625446966224572],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9788969235381954`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .97889692353819535, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.27397887549879`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.050824687606102675`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]\(-1.1272390984785186`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07548287975984531`\),
      SequenceForm[ 
      "a1= ", 52.273978875498791, "+-", .050824687606102675, 
        "  b1= ", -1.1272390984785186, "+-", .075482879759845314],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9767438939551113`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .9767438939551113, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.239096510017525`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05075172388342588`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.1234838257524085`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07536257244685982`\),
      SequenceForm[ 
      "a1= ", 52.239096510017525, "+-", .05075172388342588, 
        "  b1= ", -1.1234838257524085, "+-", .075362572446859816],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9753014396110742`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .97530143961107418, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.20753904305529`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.050690050517150725`\[InvisibleSpace]" \
 b1= "\[InvisibleSpace]\(-1.1203318181653428`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07525913375276985`\),
      SequenceForm[ 
      "a1= ", 52.207539043055291, "+-", .050690050517150725, 
        "  b1= ", -1.1203318181653428, "+-", .075259133752769852],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9743312213011878`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .97433122130118777, "  ngrb=", 27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.178694492849566`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.05063703117860094`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-1.1176383866311583`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.07516886598212912`\),
      SequenceForm[ 
      "a1= ", 52.178694492849566, "+-", .050637031178600939, 
        "  b1= ", -1.1176383866311583, "+-", .075168865982129116],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.9736865408241262`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]27\),
      SequenceForm[ "chi2r=", .9736865408241262, "  ngrb=", 27],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[r1om, Frame \[Rule] True, Axes \[Rule] False, 
      PlotRange \[Rule] All]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0141895 0.962001 -2.28779 2.36473 [
[.01419 -0.0125 -7.03125 -24.5625 ]
[.01419 -0.0125 7.03125 0 ]
[.20659 -0.0125 -14.5625 -24.5625 ]
[.20659 -0.0125 14.5625 0 ]
[.39899 -0.0125 -14.5625 -24.5625 ]
[.39899 -0.0125 14.5625 0 ]
[.59139 -0.0125 -14.5625 -24.5625 ]
[.59139 -0.0125 14.5625 0 ]
[.78379 -0.0125 -14.5625 -24.5625 ]
[.78379 -0.0125 14.5625 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07694 -14.0625 -12.2813 ]
[-0.0125 .07694 0 12.2813 ]
[-0.0125 .19518 -39.1875 -12.2813 ]
[-0.0125 .19518 0 12.2813 ]
[-0.0125 .31341 -29.125 -12.2813 ]
[-0.0125 .31341 0 12.2813 ]
[-0.0125 .43165 -39.1875 -12.2813 ]
[-0.0125 .43165 0 12.2813 ]
[-0.0125 .54989 -29.125 -12.2813 ]
[-0.0125 .54989 0 12.2813 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01419 0 m
.01419 .00625 L
s
gsave
.01419 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20659 0 m
.20659 .00625 L
s
gsave
.20659 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.39899 0 m
.39899 .00625 L
s
gsave
.39899 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59139 0 m
.59139 .00625 L
s
gsave
.59139 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78379 0 m
.78379 .00625 L
s
gsave
.78379 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.06229 0 m
.06229 .00375 L
s
.11039 0 m
.11039 .00375 L
s
.15849 0 m
.15849 .00375 L
s
.25469 0 m
.25469 .00375 L
s
.30279 0 m
.30279 .00375 L
s
.35089 0 m
.35089 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.49519 0 m
.49519 .00375 L
s
.54329 0 m
.54329 .00375 L
s
.63949 0 m
.63949 .00375 L
s
.68759 0 m
.68759 .00375 L
s
.73569 0 m
.73569 .00375 L
s
.83189 0 m
.83189 .00375 L
s
.87999 0 m
.87999 .00375 L
s
.92809 0 m
.92809 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07694 m
.00625 .07694 L
s
gsave
-0.0125 .07694 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .19518 m
.00625 .19518 L
s
gsave
-0.0125 .19518 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
1.000 setlinewidth
grestore
0 .31341 m
.00625 .31341 L
s
gsave
-0.0125 .31341 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
0 .43165 m
.00625 .43165 L
s
gsave
-0.0125 .43165 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
1.000 setlinewidth
grestore
0 .54989 m
.00625 .54989 L
s
gsave
-0.0125 .54989 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .10059 m
.00375 .10059 L
s
0 .12423 m
.00375 .12423 L
s
0 .14788 m
.00375 .14788 L
s
0 .17153 m
.00375 .17153 L
s
0 .21882 m
.00375 .21882 L
s
0 .24247 m
.00375 .24247 L
s
0 .26612 m
.00375 .26612 L
s
0 .28977 m
.00375 .28977 L
s
0 .33706 m
.00375 .33706 L
s
0 .36071 m
.00375 .36071 L
s
0 .38435 m
.00375 .38435 L
s
0 .408 m
.00375 .408 L
s
0 .4553 m
.00375 .4553 L
s
0 .47894 m
.00375 .47894 L
s
0 .50259 m
.00375 .50259 L
s
0 .52624 m
.00375 .52624 L
s
0 .05329 m
.00375 .05329 L
s
0 .02964 m
.00375 .02964 L
s
0 .006 m
.00375 .006 L
s
0 .57353 m
.00375 .57353 L
s
0 .59718 m
.00375 .59718 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.01419 .61178 m
.01419 .61803 L
s
.20659 .61178 m
.20659 .61803 L
s
.39899 .61178 m
.39899 .61803 L
s
.59139 .61178 m
.59139 .61803 L
s
.78379 .61178 m
.78379 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06229 .61428 m
.06229 .61803 L
s
.11039 .61428 m
.11039 .61803 L
s
.15849 .61428 m
.15849 .61803 L
s
.25469 .61428 m
.25469 .61803 L
s
.30279 .61428 m
.30279 .61803 L
s
.35089 .61428 m
.35089 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.49519 .61428 m
.49519 .61803 L
s
.54329 .61428 m
.54329 .61803 L
s
.63949 .61428 m
.63949 .61803 L
s
.68759 .61428 m
.68759 .61803 L
s
.73569 .61428 m
.73569 .61803 L
s
.83189 .61428 m
.83189 .61803 L
s
.87999 .61428 m
.87999 .61803 L
s
.92809 .61428 m
.92809 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07694 m
1 .07694 L
s
.99375 .19518 m
1 .19518 L
s
.99375 .31341 m
1 .31341 L
s
.99375 .43165 m
1 .43165 L
s
.99375 .54989 m
1 .54989 L
s
.125 Mabswid
.99625 .10059 m
1 .10059 L
s
.99625 .12423 m
1 .12423 L
s
.99625 .14788 m
1 .14788 L
s
.99625 .17153 m
1 .17153 L
s
.99625 .21882 m
1 .21882 L
s
.99625 .24247 m
1 .24247 L
s
.99625 .26612 m
1 .26612 L
s
.99625 .28977 m
1 .28977 L
s
.99625 .33706 m
1 .33706 L
s
.99625 .36071 m
1 .36071 L
s
.99625 .38435 m
1 .38435 L
s
.99625 .408 m
1 .408 L
s
.99625 .4553 m
1 .4553 L
s
.99625 .47894 m
1 .47894 L
s
.99625 .50259 m
1 .50259 L
s
.99625 .52624 m
1 .52624 L
s
.99625 .05329 m
1 .05329 L
s
.99625 .02964 m
1 .02964 L
s
.99625 .006 m
1 .006 L
s
.99625 .57353 m
1 .57353 L
s
.99625 .59718 m
1 .59718 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.008 w
.02381 .60332 Mdot
.04305 .41203 Mdot
.06229 .31692 Mdot
.08153 .25708 Mdot
.10077 .21525 Mdot
.11039 .19865 Mdot
.13925 .16006 Mdot
.15849 .14083 Mdot
.20659 .10634 Mdot
.25469 .08358 Mdot
.30279 .06759 Mdot
.39899 .04701 Mdot
.49519 .03478 Mdot
.59139 .02704 Mdot
.68759 .02194 Mdot
.78379 .01853 Mdot
.87999 .01624 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{648.688, 400.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"f25", "=", 
      RowBox[{"ListPlot", "[", 
        RowBox[{
        "r1om", ",", \(Frame \[Rule] True\), ",", \(Axes \[Rule] False\), 
          ",", \(PlotJoined \[Rule] True\), 
          ",", \(FrameLabel \[Rule] {\*"\"\<\!\(\[Omega]\_\(0  m\)\)\>\"", \
\*"\"\<\!\(\[Chi]\^2\)\>\""}\), ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{\(Hue[0.87]\), ",", \(Thickness[0.004]\), ",", 
                RowBox[{
                  StyleBox["Dashing",
                    "MR"], 
                  StyleBox["[",
                    "MR"], 
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    RowBox[{
                      StyleBox["0",
                        "MR"], 
                      StyleBox[",",
                        "MR"], " ", 
                      StyleBox["0",
                        "MR"]}], 
                    StyleBox["}",
                      "MR"]}], 
                  StyleBox["]",
                    "MR"]}]}], "}"}]}]}], "]"}]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -2.28779 2.36473 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -14.5625 -24.5625 ]
[.21429 -0.0125 14.5625 0 ]
[.40476 -0.0125 -14.5625 -24.5625 ]
[.40476 -0.0125 14.5625 0 ]
[.59524 -0.0125 -14.5625 -24.5625 ]
[.59524 -0.0125 14.5625 0 ]
[.78571 -0.0125 -14.5625 -24.5625 ]
[.78571 -0.0125 14.5625 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.4063 -49.125 ]
[.5 -0.0125 19.4063 -24.5625 ]
[-0.0125 .07694 -14.0625 -12.2813 ]
[-0.0125 .07694 0 12.2813 ]
[-0.0125 .19518 -39.1875 -12.2813 ]
[-0.0125 .19518 0 12.2813 ]
[-0.0125 .31341 -29.125 -12.2813 ]
[-0.0125 .31341 0 12.2813 ]
[-0.0125 .43165 -39.1875 -12.2813 ]
[-0.0125 .43165 0 12.2813 ]
[-0.0125 .54989 -29.125 -12.2813 ]
[-0.0125 .54989 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -63.75 -12.5625 ]
[-0.01875 .30902 -39.1875 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.4063 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
76.813 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
83.875 26.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
86.500 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
97.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07694 m
.00625 .07694 L
s
gsave
-0.0125 .07694 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .19518 m
.00625 .19518 L
s
gsave
-0.0125 .19518 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
1.000 setlinewidth
grestore
0 .31341 m
.00625 .31341 L
s
gsave
-0.0125 .31341 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
0 .43165 m
.00625 .43165 L
s
gsave
-0.0125 .43165 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
1.000 setlinewidth
grestore
0 .54989 m
.00625 .54989 L
s
gsave
-0.0125 .54989 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .10059 m
.00375 .10059 L
s
0 .12423 m
.00375 .12423 L
s
0 .14788 m
.00375 .14788 L
s
0 .17153 m
.00375 .17153 L
s
0 .21882 m
.00375 .21882 L
s
0 .24247 m
.00375 .24247 L
s
0 .26612 m
.00375 .26612 L
s
0 .28977 m
.00375 .28977 L
s
0 .33706 m
.00375 .33706 L
s
0 .36071 m
.00375 .36071 L
s
0 .38435 m
.00375 .38435 L
s
0 .408 m
.00375 .408 L
s
0 .4553 m
.00375 .4553 L
s
0 .47894 m
.00375 .47894 L
s
0 .50259 m
.00375 .50259 L
s
0 .52624 m
.00375 .52624 L
s
0 .05329 m
.00375 .05329 L
s
0 .02964 m
.00375 .02964 L
s
0 .006 m
.00375 .006 L
s
0 .57353 m
.00375 .57353 L
s
0 .59718 m
.00375 .59718 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -125.031 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
73.5625 16.2813 translate
90 rotate
-73.5625 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.375 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
76.563 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07694 m
1 .07694 L
s
.99375 .19518 m
1 .19518 L
s
.99375 .31341 m
1 .31341 L
s
.99375 .43165 m
1 .43165 L
s
.99375 .54989 m
1 .54989 L
s
.125 Mabswid
.99625 .10059 m
1 .10059 L
s
.99625 .12423 m
1 .12423 L
s
.99625 .14788 m
1 .14788 L
s
.99625 .17153 m
1 .17153 L
s
.99625 .21882 m
1 .21882 L
s
.99625 .24247 m
1 .24247 L
s
.99625 .26612 m
1 .26612 L
s
.99625 .28977 m
1 .28977 L
s
.99625 .33706 m
1 .33706 L
s
.99625 .36071 m
1 .36071 L
s
.99625 .38435 m
1 .38435 L
s
.99625 .408 m
1 .408 L
s
.99625 .4553 m
1 .4553 L
s
.99625 .47894 m
1 .47894 L
s
.99625 .50259 m
1 .50259 L
s
.99625 .52624 m
1 .52624 L
s
.99625 .05329 m
1 .05329 L
s
.99625 .02964 m
1 .02964 L
s
.99625 .006 m
1 .006 L
s
.99625 .57353 m
1 .57353 L
s
.99625 .59718 m
1 .59718 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 .78 r
.004 w
.03333 .60332 m
.05238 .41203 L
.07143 .31692 L
.09048 .25708 L
.10952 .21525 L
.11905 .19865 L
.14762 .16006 L
.16667 .14083 L
.21429 .10634 L
.2619 .08358 L
.30952 .06759 L
.40476 .04701 L
.5 .03478 L
.59524 .02704 L
.69048 .02194 L
.78571 .01853 L
.88095 .01624 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{616.875, 381.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009X0001OB000`400?l00000o`00003oo`3ooooo
0?ooofX0oooo003o0?ooool0ooooJP3oool00?l0ooooo`3ooomZ0?ooo`00o`3ooooo0?ooofX0oooo
003o0?oooeL0oooo00@0oooO09a80000000007Bo103oool02`2oM00000000000B02Lgml0W4P00000
000007@0_ono07@00000000007Bo0?l0oooo003o0?oooeL0oooo00D0_g@004RLg`3oool0gia804RL
g`030?ooo`0;0?oog`2LB000M;oo0?ooo`3ookl0M01809cOo`3oool0omnL04P0M02oool0o`3oool0
0?l0ooooEP3oool01`3ogi`0B01d0;ooo`3oool0omnL04P0M02oool00P3oool02`3ooml0W4P007Bo
o`3oool0oono07@0B02Lgol0oooo0?oOW01807@0_ooo0?l0oooo003o0?ooodT0oooo00L0gia80000
00000000000007Boo`3ogi`0B0000080000000/0B9cO0?ooo`3oool0oooo0?noM000B9`0gooo0?oo
o`3ooml0W4P007Boo`020?ooo`0;0?oog`2LB000M;oo0?ooo`3ookl0M01809cOo`3oool0omnL04P0
M02oool0o`3oool00?l0ooooB03oool00`3o_g@00000001d_`020?ooo`0;0;mdB018B4P0W=oo0?oo
o`3ogi`0B0000018W03Oool0oooo0=nLB000M;l00P3oool00`3ooml0W4P007Boo`020?ooo`0;0?oo
g`2LB000M;oo0?ooo`3ookl0M01809cOo`3oool0omnL04P0M02oool0o`3oool00?l0ooooB03oool0
0`3OW4P0000007Boo`020?ooo`030?oo_`1d04P0W=oo0080oooo00H0okmd00000000M;l0oooo0=nL
B000M;l20?ooo`0@0?oog`2LB000M;oo0?ooo`3ooml0W4P00000000004P0W=oo0?oOW0180000001d
0;ooo`3o_g@004RL0=ooool0oooo003o0?ooodP0oooo00<0gia80000001d_ol00`3oool00`2oM000
M;oo0?ooo`020?ooo`0:0;md000004P0W=oo0?noM000B9`0gooo0?ooo`3ooml0W4P007Boo`80oooo
00X0oono07@0001d_ml0W4P000000000M;l0oono07@000000000B9cOo`3oool10?ooo`00o`3ooom8
0?ooo`030?noM0000000B9cO00<0oooo00<0okmd001d_`3oool00P3oool02P3o_g@0000004RLg`3o
gi`0B01d0;ooo`3oool0oono07@0M02ooooo0?ooo`d0oooo003o0?ooodP0oooo00<0oooO09a80000
M;l00`3oool00`3ogi`0B01d0;ooo`020?ooo`090?oOW0180000B9cO0?ooo`2oM000B9cO0?ooo`3O
W4P007Bo0?l0oooo3P3oool00?l0ooooB@3oool00`3ogi`0B01809cOo`070?ooo`090?oo_`1d0000
M;oo0?ooo`3ooml0W4P000000000B9`0gooo0?l0oooo3P3oool00?l0ooooBP3oool00`3OW4P004RL
0=ooo`060?ooo`030?oOW01807@0_ooo0?l0oooo503oool00?l0ooooB`3oool00`3o_g@004RL0=oo
o`050?ooo`030=nLB01d_ol0oooo0?l0oooo503oool00?l0ooooo`3ooomZ0?ooo`00o`3ooooo0?oo
ofX0oooo003o0?ooool0ooooJP3oool00?l0ooooo`3ooomZ0?ooo`00o`3ooooo0?ooofX0oooo003o
0?ooool0ooooJP3oool00?l0ooooo`3ooomZ0?ooo`00o`3ooooo0?ooofX0oooo003o0?ooool0oooo
JP3oool00?l0ooooo`3ooomZ0?ooo`00o`3ooooo0?ooofX0oooo003o0?ooool0ooooJP3oool00?l0
ooooo`3ooomZ0?ooo`00o`3ooooo0?ooofX0oooo003o0?ooool0ooooJP3oool005`0oooo00@0_g@0
000000000000B9cOF@3oool0102oM000000000000018W=l40?ooo`050=nLB0000000B9cO0?ooo`3O
W4P01`0000000`1d_ol0oooo0?ooo`1=0?ooo`040;md00000000000004RLg`@0oooo00<0gia80000
0018W=l01P3oool00`3o_g@0000007Boo`1@0?ooo`040;md00000000000004RLg`@0oooo00<0gia8
00000018W=l00`3oool01P3ooml0W4P0000000000000001d0;oooe00oooo00@0_g@0000000000000
B9cO103oool00`3OW4P0000004RLg`030?ooo`060?oOW018000000000000000004P0W=ooEP3oool0
0`3o_g@000000000000200000003001d_`3oool0oooo0140oooo001J0?ooo`070?oog`2LB00007Bo
0?ooo`3ooml0W4P0001d_`1F0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`03
0=nLB0000000B9cO0080oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`1;0?ooo`07
0?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO00H0oooo00<0okmd
0000001d_ol0CP3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P00000
04RLg`020?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000B02Lgom=0?ooo`070?oog`2LB000
07Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00P0omnL04P00000B9`0
gooo0?ooo`3ogi`0B00007BooeL0oooo00<0_g@00000M02oool0503oool005X0oooo00<0okmd0000
B02Lgol00P3oool00`3ogi`0B00007Boo`1E0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0
001d_ol0203oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo04`0oooo00<0okmd0000
B02Lgol00P3oool00`3ogi`0B00007Boo`0;0?ooo`030?noM0000000M;oo04h0oooo00<0okmd0000
B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030;md000007@0_ooo00<0oooo00<0_g@0001d
_`3oool0C03oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<0_g@00000
M02oool00`3oool00`3OW4P004RL0=ooo`1F0?ooo`030;md000007@0_ooo01@0oooo001I0?ooo`04
0?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0E03oool0103ooml0W4P00018W03Oool2
0?ooo`030?oog`2LB00007Bo00T0oooo00<0gia804RLg`3oool0C`3oool0103ooml0W4P00018W03O
ool20?ooo`030?oog`2LB00007Bo00H0oooo00<0gia80000000000001@0000000`0004P0W=oo0?oo
o`1:0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l01P3oool00`3ookl0M000
001d_`040?ooo`030=nLB00007@0_ooo04/0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0
W4P0001d_`070?ooo`030;md000007@0_ooo00<0oooo00<0_g@00018W03Oool0EP3oool00`2oM000
001d0;ooo`0D0?ooo`00F@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo05<0oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`090?ooo`030=nLB01d_ol0oooo04h0oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`050?ooo`030?oOW018M;l0oooo0080oooo
00<0okmd0000001d_ol0C@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00D0oooo
00<0omnL04P00018W=l0103oool00`2oM000001809cOo`1;0?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool01P3oool00`3o_g@0001809cOo`020?ooo`030=nLB000000007Bo05L0oooo
00<0_g@00000M02oool0503oool005T0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;oo
o`1C0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool02@3oool00`3ooml0W4Q809cO
o`1>0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01P3oool01`3OW4P0M;oo0?oo
o`3oool0okmd0000001d_ol0C@3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00D0
oooo00<0omnL04P00018W=l00`3oool0103ookl0M0000000M02ooom;0?ooo`030?oOW0180000B9cO
00@0oooo00<0_g@00000M02oool01`3oool01`3OW4P007Bo0?ooo`2oM00000000000M02oool0E`3o
ool00`2oM000001d0;ooo`0D0?ooo`00F@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0
W=oo05<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0:0?ooo`030?oOW01807@0
_ooo04d0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`060?ooo`070?oo_`1d07@0
_ooo0?ooo`3o_g@0000007Boo`1=0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
1@3oool02@3ookl0M00000000000B9`0gooo0?ooo`2oM000000004RLg`1<0?ooo`030?oOW0180000
B9cO00@0oooo00<0gia80000B02Lgol0203oool01@3o_g@0000000000000B9`0gooo05P0oooo00<0
_g@00000M02oool0503oool005T0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`1C
0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol02`3oool00`2oM000B9cO0?ooo`1<
0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01`3oool01P3o_g@007Bo0?ooo`3o
_g@0000007Boodd0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`050?ooo`050?oo
g`2LB000001d0;oOW01800000P0000000`18W=l0oooo0?ooo`1;0?ooo`030?oOW0180000B9cO00@0
oooo00<0gia80000B02Lgol01`3oool01@3ogi`0B000000000000000B9cO05T0oooo00<0_g@00000
M02oool0503oool005T0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`1C0?ooo`03
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02`3oool00`3OW4P0001d0;ooo`1<0?ooo`03
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0203oool01@2oM000M;oo0?noM0000000M;oo
04d0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`030?noM0000000B9cO
0540oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`070?oOW01800000018
09cOo`3oool0gia8001d_`1H0?ooo`030;md000007@0_ooo01@0oooo001J0?ooo`030;md0000B9`0
gooo0080oooo00<0oooO09a80000M;l0E@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB000
07Bo00`0oooo00<0okmd0000001d_ol0C@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB000
07Bo00T0oooo00D0oono07@0M02o_g@0000007Boo`1>0?ooo`030;md0000B9`0gooo0080oooo00<0
oooO09a80000M;l01`3oool0103ooml0W4P00000B02LgomA0?ooo`030;md0000B9`0gooo0080oooo
00<0oooO09a80000M;l01`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000M;oo05L0oooo
00<0_g@00000M02oool0503oool005X0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Bo
o`1E0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01P3oool00`3ogi`0W;oo0?oo
o`030?ooo`030;md00000000M;oo04d0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Bo
o`0:0?ooo`040?noM0000000000007Boodh0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`080?ooo`040?oo_`1d0000001d0;oooe00oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0
B00007Boo`070?ooo`030=nLB000B9`0gooo0080oooo00<0oooO09a80018W=l0E`3oool00`2oM000
001d0;ooo`0D0?ooo`00F`3oool01P2oM00004RL0=ooo`3oool0_g@0001d_eL0oooo00H0_g@00018
W03Oool0oooo0;md0000M;l80?ooo`080;md001d_ol0oooo0?ooo`3OW4P000000018W03Ooom>0?oo
o`060;md0000B9`0gooo0?ooo`2oM00007Bo2`3oool0103ooml0W4P00000001d_om?0?ooo`060;md
0000B9`0gooo0?ooo`2oM00007Bo2P3oool0103ooml0W4P000000000M;m@0?ooo`060;md0000B9`0
gooo0?ooo`2oM00007Bo203oool00`3ogi`0B00004RLg`020?ooo`030?noM00004P0W=oo05D0oooo
00D0gia8000000000000001d0;ooo`0D0?ooo`00G03oool0102oM000000000000000M;mI0?ooo`04
0;md000000000000001d_`X0oooo00D0_g@00000000000000000001d_`1A0?ooo`040;md00000000
0000001d_`d0oooo00<0omnL04P0001d_ol0D03oool0102oM000000000000000M;l=0?ooo`050?oO
W018000000000018W03Oool0CP3oool0102oM000000000000000M;l:0?ooo`060?oo_`1d00000000
0000000004P0W=ooE`3oool0103ookl0M0000000M02ooolD0?ooo`00o`3ooooo0?ooofX0oooo003o
0?ooool0ooooJP3oool00?l0ooooo`3ooomZ0?ooo`00o`3ooooo0?ooofX0oooo003o0?ooool0oooo
JP3oool00?l0ooooo`3ooomZ0?ooo`00o`3ooooo0?ooofX0oooo003o0?ooool0ooooJP3oool00?l0
ooooo`3ooomZ0?ooo`00o`3ooooo0?ooofX0oooo003o0?ooool0ooooJP3oool00?l0ooooo`3ooomZ
0?ooo`00DP3ooooo00000?l00000400000080?ooo`00DP3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1P3oool00580oooo0`0000090?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`080?ooo`<00000203oool00580oooo00<000000?ooo`3oool0o`3ooooo
0?ooo``0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0o`3ooooo0?oo
o``0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0o`3ooooo0?ooo``0
oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0o`3ooooo0?ooo``0oooo
00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0o`3ooonc0?oood`0o`37303o
ool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`3o0?oooiX0ooooI@3o0<L<
0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo0?l0ooooJ03ooom;0?l0
aeP0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0o`3ooomH0?oood80
o`37L@3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`3o0?ooodL0oooo
8@3o0<NS0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo0?l0oooo=P3o
oolR0?l0ak<0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0o`3ooolZ
0?oooad0o`37a03oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`3o0?oo
oad0oooo6@3o0<OE0?ooo`030000003oool0oooo00H0oooo001B0?ooo`<00000o`3ooolA0?oooaT0
o`37g`3oool3000000P0oooo001B0?ooo`030000003oool0oooo0?l0oooo103ooolI0?l0anh0oooo
00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0o03ooolD0?l0aoX0oooo00<0
00000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0m@3oool>0?l0aol0oooo203oool0
0`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`3^0?ooo`h0o`37o`3oool?0?oo
o`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo0>L0oooo3P3o0<Oo0?oooaH0
oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0h03oool>0?l0aol0oooo
7@3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`3I0?ooo`h0o`37o`3o
oolT0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo0=40oooo3`3o0<Oo
0?ooob/0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0c03oool=0?l0
aol0oooo<P3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`370?ooo`X0
o`37o`3ooolj0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo0<80oooo
2P3o0<Oo0?ooocl0oooo00<000000?ooo`3oool01P3oool00580oooo0`00002m0?ooo`X0o`37o`3o
oom20?ooo`<00000203oool00580oooo00<000000?ooo`3oool0^03oool:0?l0aol0ooooB@3oool0
0`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`2c0?ooo`X0o`37o`3ooom>0?oo
o`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo0:h0oooo2P3o0<Oo0?oooe<0
oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0Z@3oool:0?l0aol0oooo
F03oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`2T0?ooo`X0o`37o`3o
oomM0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo09l0oooo2P3o0<Oo
0?ooof80oooo00<000000?ooo`3oool01P3oool00440oooo00<0okmd0000000000000P0000000`00
M;l0oooo0?ooo`090?ooo`030000003oool0oooo09`0oooo203o0<Oo0?ooofL0oooo00<000000?oo
o`3oool01P3oool004<0oooo00<0_g@00000M02oool0303oool00`000000oooo0?ooo`2I0?ooo`L0
o`37o`3ooom[0?ooo`030000003oool0oooo00H0oooo00130?ooo`030;md000007@0_ooo00`0oooo
00<000000?ooo`3oool0U`3oool60?l0aol0ooooKP3oool00`000000oooo0?ooo`060?ooo`00@`3o
ool00`2oM000001d0;ooo`0<0?ooo`030000003oool0oooo09@0oooo1P3o0<Oo0?ooog40oooo00<0
00000?ooo`3oool01P3oool004<0oooo00<0_g@00000M02oool0303oool00`000000oooo0?ooo`2A
0?ooo`L0o`37o`3ooomc0?ooo`030000003oool0oooo00H0oooo00130?ooo`030;md000007@0_ooo
00`0oooo1000002=0?ooo`L0o`37o`3ooomb0?ooo`D00000203oool004<0oooo00<0_g@00000M02o
ool0303oool00`000000oooo0?ooo`2<0?ooo`H0o`37o`3ooomi0?ooo`030000003oool0oooo00H0
oooo00130?ooo`030;md000007@0_ooo00`0oooo00<000000?ooo`3oool0R@3oool60?l0aol0oooo
O03oool00`000000oooo0?ooo`060?ooo`00@`3oool00`2oM000001d0;ooo`0<0?ooo`030000003o
ool0oooo08H0oooo1`3o0<Oo0?ooogh0oooo00<000000?ooo`3oool01P3oool004<0oooo00<0_g@0
0000M02oool0303oool00`000000oooo0?ooo`240?ooo`H0o`37o`3ooon10?ooo`030000003oool0
oooo00H0oooo00130?ooo`030;md000007@0_ooo00`0oooo00<000000?ooo`3oool0PP3oool50?l0
aol0ooooQ03oool00`000000oooo0?ooo`060?ooo`00@@3oool01@3OW4P000000000000007@0_ooo
00`0oooo00<000000?ooo`3oool0P03oool50?l0aol0ooooQP3oool00`000000oooo0?ooo`060?oo
o`00@P3oool0103ookl0M0000000M02oool<0?ooo`030000003oool0oooo07h0oooo1@3o0<Oo0?oo
ohP0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0O03oool50?l0aol0
ooooRP3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`1i0?ooo`H0o`37
o`3ooon<0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo07L0oooo1P3o
0<Oo0?ooohh0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0M@3oool5
0?l0aol0ooooT@3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`1c0?oo
o`D0o`37o`3ooonC0?ooo`030000003oool0oooo00H0oooo001B0?ooo`<00000L@3oool50?l0aol0
ooooT`3oool3000000P0oooo001B0?ooo`030000003oool0oooo06l0oooo1@3o0<Oo0?oooiL0oooo
00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0K@3oool50?l0aol0ooooV@3o
ool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`1/0?ooo`@0o`37o`3ooonK
0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo06X0oooo103o0<Oo0?oo
oid0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0J@3oool40?l0aol0
ooooWP3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`1W0?ooo`@0o`37
o`3ooonP0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo06H0oooo103o
0<Oo0?oooj40oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0I@3oool3
0?l0aol0ooooX`3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`1S0?oo
o`@0o`37o`3ooonT0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo0680
oooo103o0<Oo0?ooojD0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0
H03oool40?l0aol0ooooY`3oool00`000000oooo0?ooo`060?ooo`00DP3oool3000005l0oooo103o
0<Oo0?ooojH0oooo0`0000080?ooo`00DP3oool00`000000oooo0?ooo`1N0?ooo`<0o`37o`3ooonZ
0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo05`0oooo103o0<Oo0?oo
oj/0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0F`3oool40?l0aol0
oooo[03oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`1J0?ooo`<0o`37
o`3ooon^0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo05P0oooo103o
0<Oo0?ooojl0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0E`3oool4
0?l0aol0oooo/03oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`1E0?oo
o`@0o`37o`3ooonb0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo05@0
oooo103o0<Oo0?oook<0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0
D`3oool30?l0aol0oooo]@3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?oo
o`1B0?ooo`<0o`37o`3ooonf0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0
oooo0540oooo0`3o0<Oo0?oookL0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?oo
o`3oool0D03oool30?l0aol0oooo^03oool00`000000oooo0?ooo`060?ooo`00DP3oool3000004l0
oooo0`3o0<Oo0?oookL0oooo0`0000080?ooo`00DP3oool00`000000oooo0?ooo`1>0?ooo`<0o`37
o`3ooonj0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo04d0oooo0`3o
0<Oo0?oook/0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0C03oool3
0?l0aol0oooo_03oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`1;0?oo
o`<0o`37o`3ooonm0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo04X0
oooo0`3o0<Oo0?oookh0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0
BP3oool20?l0aol0oooo_`3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?oo
o`190?ooo`80o`37o`3oooo00?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0
oooo04P0oooo0P3o0<Oo0?oool40oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?oo
o`3oool0A`3oool20?l0aol0oooo`P3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000
oooo0?ooo`170?ooo`030?l0a`3oool0oooo0?l0oooo`@3oool00`000000oooo0?ooo`060?ooo`00
DP3oool00`000000oooo0?ooo`160?ooo`80o`37o`3oooo30?ooo`030000003oool0oooo00H0oooo
001B0?ooo`<00000A@3oool20?l0aol0oooo`P3oool3000000P0oooo001B0?ooo`030000003oool0
oooo04@0oooo0P3o0<Oo0?ooolD0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?oo
o`3oool0A03oool00`3o0<L0oooo0?ooo`3o0?oool@0oooo00<000000?ooo`3oool01P3oool00580
oooo00<000000?ooo`3oool0@`3oool20?l0aol0ooooaP3oool00`000000oooo0?ooo`060?ooo`00
DP3oool00`000000oooo0?ooo`120?ooo`80o`37o`3oooo70?ooo`030000003oool0oooo00H0oooo
001B0?ooo`030000003oool0oooo0440oooo0P3o0<Oo0?ooolP0oooo00<000000?ooo`3oool01P3o
ool00580oooo00<000000?ooo`3oool0@@3oool00`3o0<L0oooo0?ooo`3o0?ooolL0oooo00<00000
0?ooo`3oool01P3oool002P0oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3oool0
gia800000018W=l0103oool0102oM000000000000018W=l40?ooo`060;md00000000000000000000
B9`0gooo303oool00`000000oooo0?ooo`100?ooo`80o`37o`3oooo90?ooo`030000003oool0oooo
00H0oooo000Z0?ooo`030;md000007@0_ooo00@0oooo00<0gia800000018W=l00P3oool01`3ooml0
W4P0001d_`3oool0oooO09a80000M;l00P3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0
gooo00/0oooo00<000000?ooo`3oool0?`3oool20?l0aol0oooobP3oool00`000000oooo0?ooo`06
0?ooo`00:P3oool00`2oM000001d0;ooo`090?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0
001d_ol01`3oool00`3ogi`0B7Bo0?ooo`0:0?ooo`030000003oool0oooo03h0oooo0P3o0<Oo0?oo
ol/0oooo00<000000?ooo`3oool01P3oool002X0oooo00<0_g@00000M02oool0203oool0103ooml0
W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00L0oooo00<0oono07@0B02Lgol02P3oool00`00
0000oooo0?ooo`0n0?ooo`030?l0a`3oool0oooo0?l0oooobP3oool00`000000oooo0?ooo`060?oo
o`00:P3oool00`2oM000001d0;ooo`080?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02o
ool01P3oool00`3ookl0M00007Boo`0:0?ooo`030000003oool0oooo03d0oooo0P3o0<Oo0?oool`0
oooo00<000000?ooo`3oool01P3oool002X0oooo00<0_g@00000M02oool0203oool00`3ogi`0B000
04RLg`040?ooo`030;md000007@0_ooo00H0oooo00<0okmd0000001d_ol02P3oool4000003/0oooo
0P3o0<Oo0?ooolT0oooo1@0000080?ooo`00:P3oool00`2oM000001d0;ooo`080?ooo`030?oOW018
0000B9cO00@0oooo00<0gia80000B02Lgol01@3oool0103ogi`0B0000000M02oool:0?ooo`030000
003oool0oooo03/0oooo0P3o0<Oo0?ooolh0oooo00<000000?ooo`3oool01P3oool002X0oooo00<0
_g@00000M02oool0203oool00`3ogi`0B00004RLg`040?ooo`050=nLB00004P0W=oo0?ooo`3Ogml0
0P3oool0102oM000000000000018W=l;0?ooo`030000003oool0oooo03/0oooo00<0o`370?ooo`3o
ool0o`3oooo=0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030;md000007@0_ooo00P0oooo
00<0oono07@00000M;l0103oool01@2oM000001d0;ooo`3oool0okmd00@0000000<007Bo0?ooo`3o
ool02P3oool00`000000oooo0?ooo`0j0?ooo`80o`37o`3oooo?0?ooo`030000003oool0oooo00H0
oooo000Z0?ooo`030;md000007@0_ooo00T0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0
001d_`020?ooo`050?oog`2LB00000000000M02oool03@3oool00`000000oooo0?ooo`0j0?ooo`03
0?l0a`3oool0oooo0?l0oooocP3oool00`000000oooo0?ooo`060?ooo`00:P3oool00`2oM000001d
0;ooo`090?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol00`3oool00`3o_g@007Bo
0?ooo`0>0?ooo`030000003oool0oooo03T0oooo0P3o0<Oo0?ooom00oooo00<000000?ooo`3oool0
1P3oool002P0oooo00D0gia8000000000000001d0;ooo`0:0?ooo`060;md0000B9`0gooo0?ooo`2o
M00007Bo103oool00`3ooml0W4P000000002000000030000M02oool0oooo00T0oooo00<000000?oo
o`3oool0>03oool20?l0aol0ooood@3oool00`000000oooo0?ooo`060?ooo`00:@3oool0103ookl0
M0000000M02oool;0?ooo`040;md000000000000001d_`H0oooo00<0okmd0000000000000P000000
0`1d_ol0oooo0?ooo`080?ooo`030000003oool0oooo03P0oooo00<0o`370?ooo`3oool0o`3oooo@
0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo03L0oooo0P3o0<Oo0?oo
om80oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0=`3oool00`3o0<L0
oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0
=P3oool20?l0aol0ooood`3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?oo
o`0f0?ooo`030?l0a`3oool0oooo0?l0oooodP3oool00`000000oooo0?ooo`060?ooo`00DP3oool0
0`000000oooo0?ooo`0e0?ooo`80o`37o`3ooooD0?ooo`030000003oool0oooo00H0oooo001B0?oo
o`<00000=@3oool00`3o0<L0oooo0?ooo`3o0?ooom40oooo0`0000080?ooo`00DP3oool00`000000
oooo0?ooo`0d0?ooo`80o`37o`3ooooE0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000
003oool0oooo03@0oooo00<0o`370?ooo`3oool0o`3ooooD0?ooo`030000003oool0oooo00H0oooo
001B0?ooo`030000003oool0oooo03<0oooo0P3o0<Oo0?ooomH0oooo00<000000?ooo`3oool01P3o
ool00580oooo00<000000?ooo`3oool0<`3oool00`3o0<L0oooo0?ooo`3o0?ooomD0oooo00<00000
0?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0<`3oool00`3o0<L0oooo0?ooo`3o0?oo
omD0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0<P3oool20?l0aol0
ooooe`3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0b0?ooo`030?l0
a`3oool0oooo0?l0ooooeP3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?oo
o`0a0?ooo`80o`37o`3ooooH0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0
oooo0340oooo00<0o`370?ooo`3oool0o`3ooooG0?ooo`030000003oool0oooo00H0oooo001B0?oo
o`030000003oool0oooo0300oooo0P3o0<Oo0?ooomT0oooo00<000000?ooo`3oool01P3oool00580
oooo00<000000?ooo`3oool0<03oool00`3o0<L0oooo0?ooo`3o0?ooomP0oooo00<000000?ooo`3o
ool01P3oool00580oooo0`00000_0?ooo`80o`37o`3ooooH0?ooo`<00000203oool00580oooo00<0
00000?ooo`3oool0;`3oool00`3o0<L0oooo0?ooo`3o0?ooomT0oooo00<000000?ooo`3oool01P3o
ool00580oooo00<000000?ooo`3oool0;P3oool20?l0aol0oooof`3oool00`000000oooo0?ooo`06
0?ooo`00DP3oool00`000000oooo0?ooo`0^0?ooo`030?l0a`3oool0oooo0?l0oooofP3oool00`00
0000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0^0?ooo`030?l0a`3oool0oooo0?l0
oooofP3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0]0?ooo`80o`37
o`3ooooL0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo02d0oooo00<0
o`370?ooo`3oool0o`3ooooK0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0
oooo02`0oooo0P3o0<Oo0?ooomd0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?oo
o`3oool0;03oool00`3o0<L0oooo0?ooo`3o0?ooom`0oooo00<000000?ooo`3oool01P3oool00580
oooo00<000000?ooo`3oool0:`3oool20?l0aol0oooogP3oool00`000000oooo0?ooo`060?ooo`00
DP3oool00`000000oooo0?ooo`0[0?ooo`80o`37o`3ooooN0?ooo`030000003oool0oooo00H0oooo
001B0?ooo`030000003oool0oooo02X0oooo0`3o0<Oo0?ooomh0oooo00<000000?ooo`3oool01P3o
ool00580oooo00<000000?ooo`3oool0:P3oool20?l0aol0oooog`3oool00`000000oooo0?ooo`06
0?ooo`00DP3oool3000002X0oooo0P3o0<Oo0?ooomd0oooo0`0000080?ooo`00DP3oool00`000000
oooo0?ooo`0Y0?ooo`<0o`37o`3ooooO0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000
003oool0oooo02T0oooo0P3o0<Oo0?ooon00oooo00<000000?ooo`3oool01P3oool00580oooo00<0
00000?ooo`3oool0:@3oool20?l0aol0ooooh03oool00`000000oooo0?ooo`060?ooo`00DP3oool0
0`000000oooo0?ooo`0X0?ooo`<0o`37o`3ooooP0?ooo`030000003oool0oooo00H0oooo001B0?oo
o`030000003oool0oooo02P0oooo0P3o0<Oo0?ooon40oooo00<000000?ooo`3oool01P3oool00580
oooo00<000000?ooo`3oool0:03oool20?l0aol0ooooh@3oool00`000000oooo0?ooo`060?ooo`00
DP3oool00`000000oooo0?ooo`0W0?ooo`<0o`37o`3ooooQ0?ooo`030000003oool0oooo00H0oooo
001B0?ooo`030000003oool0oooo02L0oooo0P3o0<Oo0?ooon80oooo00<000000?ooo`3oool01P3o
ool00580oooo00<000000?ooo`3oool09`3oool20?l0aol0oooohP3oool00`000000oooo0?ooo`06
0?ooo`00DP3oool00`000000oooo0?ooo`0V0?ooo`<0o`37o`3ooooR0?ooo`030000003oool0oooo
00H0oooo001B0?ooo`030000003oool0oooo02H0oooo0P3o0<Oo0?ooon<0oooo00<000000?ooo`3o
ool01P3oool00580oooo0`00000V0?ooo`80o`37o`3ooooQ0?ooo`<00000203oool001d0oooo00<0
oooO09a8B02Lgol0<P3oool00`000000oooo0?ooo`0V0?ooo`80o`37o`3ooooS0?ooo`030000003o
ool0oooo00H0oooo000L0?ooo`030?oo_`1d04P0W=oo03<0oooo00<000000?ooo`3oool09@3oool3
0?l0aol0ooooh`3oool00`000000oooo0?ooo`060?ooo`006`3oool00`3ogi`0B01d0;ooo`0d0?oo
o`030000003oool0oooo02D0oooo0P3o0<Oo0?ooon@0oooo00<000000?ooo`3oool01P3oool00180
oooo00<0gibL0;ooo`3oool01@3oool00`3ogi`0B4RL0=ooo`0e0?ooo`030000003oool0oooo02D0
oooo0P3o0<Oo0?ooon@0oooo00<000000?ooo`3oool01P3oool00140oooo00<0oooO09a8M02oool0
1@3oool00`3ogi`0B4RL0=ooo`0f0?ooo`030000003oool0oooo02@0oooo0`3o0<Oo0?ooon@0oooo
00<000000?ooo`3oool01P3oool00140oooo00<0oono07@000000000100000000`00B4P0B01d0;oo
o`0g0?ooo`030000003oool0oooo02@0oooo0P3o0<Oo0?ooonD0oooo00<000000?ooo`3oool01P3o
ool001@0oooo00<0okmd0000000000001`0000000`18W=l0oooo0?ooo`0A0?ooo`030?noM0000000
00000080000000L007Bo0?ooo`3oool0oooo0=nLB0000000B9cO00<0oooo00<0okmd000000000000
0P0000000`00M;l0oooo0?ooo`090?ooo`030000003oool0oooo02@0oooo0P3o0<Oo0?ooonD0oooo
00<000000?ooo`3oool01P3oool001H0oooo00<0oooO09a8B02Lgol00P3oool01@2oM00000000000
000004P0W=oo01@0oooo00<0_g@00000M02oool0103oool00`3OW4P0000004RLg`050?ooo`030;md
000007@0_ooo00`0oooo00<000000?ooo`3oool08`3oool30?l0aol0ooooi@3oool00`000000oooo
0?ooo`060?ooo`005@3oool00`3ooml0W4Q809cOo`050?ooo`030?oOW018B9`0gooo01@0oooo00<0
_g@00000M02oool0303oool00`2oM000001d0;ooo`0<0?ooo`030000003oool0oooo02<0oooo0P3o
0<Oo0?ooonH0oooo00<000000?ooo`3oool01P3oool001@0oooo00<0oooO09a8B02Lgol01@3oool0
0`3ookl0M01d0;ooo`0E0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0303oool0
0`000000oooo0?ooo`0S0?ooo`80o`37o`3ooooV0?ooo`030000003oool0oooo00H0oooo000C0?oo
o`030?oo_`1d04P0W=oo01h0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`0<0?oo
o`030000003oool0oooo0280oooo0`3o0<Oo0?ooonH0oooo00<000000?ooo`3oool01P3oool00180
oooo00<0okmd0000M02oool07`3oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00`0
oooo00<000000?ooo`3oool08P3oool20?l0aol0ooooi`3oool00`000000oooo0?ooo`060?ooo`00
4@3oool00`3ookl0M7Bo0?ooo`0P0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0
303oool400000240oooo0P3o0<Oo0?ooon<0oooo1@0000080?ooo`00=03oool00`2oM000001d0;oo
o`0<0?ooo`030;md000007@0_ooo00`0oooo00<000000?ooo`3oool08@3oool30?l0aol0ooooi`3o
ool00`000000oooo0?ooo`060?ooo`002P3oool00`3OW4P004RL0=ooo`040?ooo`030=nLM018B7@0
_ooo0200oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`0<0?ooo`030000003oool0
oooo0240oooo0P3o0<Oo0?ooonP0oooo00<000000?ooo`3oool01P3oool000T0oooo00<0okmd001d
_`3oool0103oool0102oM000B9bL07@0M02ooolP0?ooo`030;md000007@0_ooo00`0oooo00<0_g@0
0000M02oool0303oool00`000000oooo0?ooo`0Q0?ooo`80o`37o`3ooooX0?ooo`030000003oool0
oooo00H0oooo00090?ooo`030=nLB018W=l0oooo0080oooo00H0oooO09a8001d_ol0oono07@0M02o
oolP0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0303oool00`000000oooo0?oo
o`0Q0?ooo`80o`37o`3ooooX0?ooo`030000003oool0oooo00H0oooo00090?ooo`0;0?noM00004P0
W=oo0?ooo`3o_g@0001809cOo`3oool0omnL04P0M02oool07P3oool01@3OW4P000000000000007@0
_ooo00X0oooo00D0gia8000000000000001d0;ooo`0<0?ooo`030000003oool0oooo0240oooo0P3o
0<Oo0?ooonP0oooo00<000000?ooo`3oool01P3oool000X0oooo00@0gia800000000000007Bo0P3o
ool0103ooml0W4P00018W03OoolO0?ooo`040?oo_`1d0000001d0;ooo`/0oooo00@0oono07@00000
07@0_ooo303oool00`000000oooo0?ooo`0P0?ooo`80o`37o`3ooooY0?ooo`030000003oool0oooo
00H0oooo001B0?ooo`030000003oool0oooo0200oooo0P3o0<Oo0?ooonT0oooo00<000000?ooo`3o
ool01P3oool00580oooo00<000000?ooo`3oool0803oool20?l0aol0ooooj@3oool00`000000oooo
0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0P0?ooo`80o`37o`3ooooY0?ooo`030000003o
ool0oooo00H0oooo001B0?ooo`030000003oool0oooo0200oooo0P3o0<Oo0?ooonT0oooo00<00000
0?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool07`3oool20?l0aol0oooojP3oool00`00
0000oooo0?ooo`060?ooo`00DP3oool3000001l0oooo0P3o0<Oo0?ooonP0oooo0`0000080?ooo`00
DP3oool00`000000oooo0?ooo`0O0?ooo`80o`37o`3ooooZ0?ooo`030000003oool0oooo00H0oooo
001B0?ooo`030000003oool0oooo01l0oooo0P3o0<Oo0?ooonX0oooo00<000000?ooo`3oool01P3o
ool00580oooo00<000000?ooo`3oool07`3oool20?l0aol0oooojP3oool00`000000oooo0?ooo`06
0?ooo`00DP3oool00`000000oooo0?ooo`0N0?ooo`80o`37o`3oooo[0?ooo`030000003oool0oooo
00H0oooo001B0?ooo`030000003oool0oooo01h0oooo0P3o0<Oo0?ooon/0oooo00<000000?ooo`3o
ool01P3oool00580oooo00<000000?ooo`3oool07P3oool20?l0aol0ooooj`3oool00`000000oooo
0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0N0?ooo`80o`37o`3oooo[0?ooo`030000003o
ool0oooo00H0oooo001B0?ooo`030000003oool0oooo01h0oooo0P3o0<Oo0?ooon/0oooo00<00000
0?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool07@3oool20?l0aol0ooook03oool00`00
0000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0M0?ooo`80o`37o`3oooo/0?ooo`03
0000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo01d0oooo0P3o0<Oo0?ooon`0oooo
00<000000?ooo`3oool01P3oool00580oooo0`00000M0?ooo`80o`37o`3ooooZ0?ooo`<00000203o
ool00580oooo00<000000?ooo`3oool07@3oool20?l0aol0ooook03oool00`000000oooo0?ooo`06
0?ooo`00DP3oool00`000000oooo0?ooo`0L0?ooo`80o`37o`3oooo]0?ooo`030000003oool0oooo
00H0oooo001B0?ooo`030000003oool0oooo01`0oooo0P3o0<Oo0?ooond0oooo00<000000?ooo`3o
ool01P3oool00580oooo00<000000?ooo`3oool0703oool20?l0aol0ooook@3oool00`000000oooo
0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0L0?ooo`80o`37o`3oooo]0?ooo`030000003o
ool0oooo00H0oooo001B0?ooo`030000003oool0oooo01`0oooo0P3o0<Oo0?ooond0oooo00<00000
0?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool06`3oool20?l0aol0ooookP3oool00`00
0000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0K0?ooo`80o`37o`3oooo^0?ooo`03
0000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo01/0oooo0P3o0<Oo0?ooonh0oooo
00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool06`3oool20?l0aol0ooookP3o
ool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0K0?ooo`80o`37o`3oooo^
0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo01X0oooo0P3o0<Oo0?oo
onl0oooo00<000000?ooo`3oool01P3oool00580oooo0`00000J0?ooo`80o`37o`3oooo]0?ooo`<0
0000203oool00580oooo00<000000?ooo`3oool06P3oool20?l0aol0ooook`3oool00`000000oooo
0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0J0?ooo`80o`37o`3oooo_0?ooo`030000003o
ool0oooo00H0oooo001B0?ooo`030000003oool0oooo01X0oooo0P3o0<Oo0?ooonl0oooo00<00000
0?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool06@3oool20?l0aol0ooool03oool00`00
0000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0I0?ooo`80o`37o`3oooo`0?ooo`03
0000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo01T0oooo0P3o0<Oo0?oooo00oooo
00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool06@3oool20?l0aol0ooool03o
ool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0I0?ooo`80o`37o`3oooo`
0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo01P0oooo0P3o0<Oo0?oo
oo40oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0603oool20?l0aol0
ooool@3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0H0?ooo`80o`37
o`3ooooa0?ooo`030000003oool0oooo00H0oooo001B0?ooo`<00000603oool20?l0aol0ooook`3o
ool3000000P0oooo001B0?ooo`030000003oool0oooo01P0oooo0P3o0<Oo0?oooo40oooo00<00000
0?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool05`3oool20?l0aol0oooolP3oool00`00
0000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0G0?ooo`80o`37o`3oooob0?ooo`03
0000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo01L0oooo0P3o0<Oo0?oooo80oooo
00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool05`3oool20?l0aol0oooolP3o
ool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0G0?ooo`80o`37o`3oooob
0?ooo`030000003oool0oooo00H0oooo000X0?ooo`030?noM000000000000080000000L007Bo0?oo
o`3oool0oooo0=nLB0000000B9cO00<0oooo00<0okmd0000000000000P0000001@00M;l0oooo0?oo
o`3oool0_g@000<0000000<004RL0=ooo`3oool02`3oool00`000000oooo0?ooo`0G0?ooo`80o`37
o`3oooob0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030;md000007@0_ooo00@0oooo00<0
gia800000018W=l01@3oool00`2oM000001d0;ooo`030?ooo`030?oog`2LB000B9cO0080oooo00<0
omnL04Q8W03Oool02`3oool00`000000oooo0?ooo`0G0?ooo`80o`37o`3oooob0?ooo`030000003o
ool0oooo00H0oooo000Z0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool02@3oool0
0`3ogi`0B7Bo0?ooo`0:0?ooo`030000003oool0oooo01L0oooo0P3o0<Oo0?oooo80oooo00<00000
0?ooo`3oool01P3oool002X0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`090?oo
o`030?oo_`1d04P0W=oo00X0oooo00<000000?ooo`3oool05`3oool20?l0aol0oooolP3oool00`00
0000oooo0?ooo`060?ooo`00:P3oool00`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00T0
oooo00<0oono07@0001d_ol02P3oool00`000000oooo0?ooo`0G0?ooo`80o`37o`3oooob0?ooo`03
0000003oool0oooo00H0oooo000Z0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0
2@3oool00`3o_g@0000007Boo`0:0?ooo`030000003oool0oooo01L0oooo0P3o0<Oo0?oooo80oooo
00<000000?ooo`3oool01P3oool002X0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;oo
o`080?ooo`040?oOW0180000001d0;ooo`X0oooo1000000E0?ooo`80o`37o`3oooo_0?ooo`D00000
203oool002X0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`040?ooo`040=oOg`3o
ool0oooo0;md0080000000<0B9cO0?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`80o`37
o`3ooooc0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030;md000007@0_ooo00`0oooo00<0
_g@00000M02oool0103oool00`3o_g@000000000000200000003001d_`3oool0oooo00X0oooo00<0
00000?ooo`3oool05P3oool20?l0aol0ooool`3oool00`000000oooo0?ooo`060?ooo`00:P3oool0
0`2oM000001d0;ooo`0<0?ooo`030;md000007@0_ooo00@0oooo00D0oooO09a800000000001d0;oo
o`0=0?ooo`030000003oool0oooo01H0oooo0P3o0<Oo0?oooo<0oooo00<000000?ooo`3oool01P3o
ool002X0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`050?ooo`030?noM000M;l0
oooo00h0oooo00<000000?ooo`3oool05P3oool20?l0aol0ooool`3oool00`000000oooo0?ooo`06
0?ooo`00:03oool01@3OW4P000000000000007@0_ooo00X0oooo00D0gia8000000000000001d0;oo
o`050?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool02@3oool00`000000oooo0?oo
o`0F0?ooo`80o`37o`3ooooc0?ooo`030000003oool0oooo00H0oooo000Y0?ooo`040?oo_`1d0000
001d0;ooo`/0oooo00@0oono07@0000007@0_ooo1P3oool00`3o_g@00000000000020000000307Bo
o`3oool0oooo00P0oooo00<000000?ooo`3oool05P3oool20?l0aol0ooool`3oool00`000000oooo
0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0F0?ooo`80o`37o`3ooooc0?ooo`030000003o
ool0oooo00H0oooo001B0?ooo`030000003oool0oooo01H0oooo0P3o0<Oo0?oooo<0oooo00<00000
0?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool05P3oool20?l0aol0ooool`3oool00`00
0000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0E0?ooo`80o`37o`3ooood0?ooo`03
0000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo01D0oooo0P3o0<Oo0?oooo@0oooo
00<000000?ooo`3oool01P3oool00580oooo0`00000E0?ooo`80o`37o`3oooob0?ooo`<00000203o
ool00580oooo00<000000?ooo`3oool05@3oool20?l0aol0oooom03oool00`000000oooo0?ooo`06
0?ooo`00DP3oool00`000000oooo0?ooo`0E0?ooo`80o`37o`3ooood0?ooo`030000003oool0oooo
00H0oooo001B0?ooo`030000003oool0oooo01D0oooo0P3o0<Oo0?oooo@0oooo00<000000?ooo`3o
ool01P3oool00580oooo00<000000?ooo`3oool05@3oool20?l0aol0oooom03oool00`000000oooo
0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0E0?ooo`80o`37o`3ooood0?ooo`030000003o
ool0oooo00H0oooo001B0?ooo`030000003oool0oooo01D0oooo0P3o0<Oo0?oooo@0oooo00<00000
0?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool05@3oool20?l0aol0oooom03oool00`00
0000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0D0?ooo`80o`37o`3ooooe0?ooo`03
0000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo01@0oooo0P3o0<Oo0?ooooD0oooo
00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0503oool20?l0aol0oooom@3o
ool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0D0?ooo`80o`37o`3ooooe
0?ooo`030000003oool0oooo00H0oooo001B0?ooo`<00000503oool20?l0aol0ooool`3oool30000
00P0oooo001B0?ooo`030000003oool0oooo01@0oooo0P3o0<Oo0?ooooD0oooo00<000000?ooo`3o
ool01P3oool00580oooo00<000000?ooo`3oool0503oool20?l0aol0oooom@3oool00`000000oooo
0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0D0?ooo`80o`37o`3ooooe0?ooo`030000003o
ool0oooo00H0oooo001B0?ooo`030000003oool0oooo01@0oooo0P3o0<Oo0?ooooD0oooo00<00000
0?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool0503oool20?l0aol0oooom@3oool00`00
0000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0C0?ooo`80o`37o`3oooof0?ooo`03
0000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo01<0oooo0P3o0<Oo0?ooooH0oooo
00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool04`3oool20?l0aol0oooomP3o
ool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0C0?ooo`80o`37o`3oooof
0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo01<0oooo0P3o0<Oo0?oo
ooH0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool04`3oool20?l0aol0
oooomP3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0C0?ooo`80o`37
o`3oooof0?ooo`030000003oool0oooo00H0oooo001B0?ooo`<000004`3oool20?l0aol0oooom03o
ool3000000P0oooo001B0?ooo`030000003oool0oooo01<0oooo0P3o0<Oo0?ooooH0oooo00<00000
0?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool04`3oool20?l0aol0oooomP3oool00`00
0000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0B0?ooo`80o`37o`3oooog0?ooo`03
0000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo0180oooo0P3o0<Oo0?ooooL0oooo
00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool04P3oool20?l0aol0oooom`3o
ool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0B0?ooo`80o`37o`3oooog
0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo0180oooo0P3o0<Oo0?oo
ooL0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool04P3oool20?l0aol0
oooom`3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0B0?ooo`80o`37
o`3oooog0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo0180oooo0P3o
0<Oo0?ooooL0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool04P3oool2
0?l0aol0oooom`3oool00`000000oooo0?ooo`060?ooo`00DP3oool300000180oooo0P3o0<Oo0?oo
ooD0oooo0`0000080?ooo`00DP3oool00`000000oooo0?ooo`0A0?ooo`80o`37o`3ooooh0?ooo`03
0000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo0140oooo0P3o0<Oo0?ooooP0oooo
00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool04@3oool20?l0aol0oooon03o
ool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0A0?ooo`80o`37o`3ooooh
0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo0140oooo0P3o0<Oo0?oo
ooP0oooo00<000000?ooo`3oool01P3oool00580oooo00<000000?ooo`3oool04@3oool20?l0aol0
oooon03oool00`000000oooo0?ooo`060?ooo`00<P3oool00`3o_g@000000000000200000009001d
_`3oool0oooo0?ooo`3OW4P0000004RLg`3oool0gia800L0000000<0M;oo0?ooo`3oool0203oool0
0`000000oooo0?ooo`0A0?ooo`80o`37o`3ooooh0?ooo`030000003oool0oooo00H0oooo000d0?oo
o`030;md000007@0_ooo00@0oooo00<0gia800000018W=l00P3oool00`3OW4P00000000000040000
0003001d_`3oool0oooo00P0oooo00<000000?ooo`3oool04@3oool20?l0aol0oooon03oool00`00
0000oooo0?ooo`060?ooo`00=03oool00`2oM000001d0;ooo`0:0?ooo`030=nLB018W=l0oooo0080
oooo00<0oooO09a8M02oool02@3oool00`000000oooo0?ooo`0A0?ooo`80o`37o`3ooooh0?ooo`03
0000003oool0oooo00H0oooo000d0?ooo`030;md000007@0_ooo00/0oooo00<0gia804RLg`3oool0
3@3oool00`000000oooo0?ooo`0A0?ooo`80o`37o`3ooooh0?ooo`030000003oool0oooo00H0oooo
000d0?ooo`030;md000007@0_ooo00`0oooo00<0gia807Boo`3oool0303oool00`000000oooo0?oo
o`0@0?ooo`80o`37o`3ooooi0?ooo`030000003oool0oooo00H0oooo000d0?ooo`030;md000007@0
_ooo00`0oooo00<0oooO09a8B02Lgol0303oool00`000000oooo0?ooo`0@0?ooo`80o`37o`3ooooi
0?ooo`030000003oool0oooo00H0oooo000d0?ooo`030;md000007@0_ooo00d0oooo00<0omnL04P0
M02oool02`3oool4000000l0oooo0P3o0<Oo0?ooooD0oooo1@0000080?ooo`00=03oool00`2oM000
001d0;ooo`0>0?ooo`030;md0018W=l0oooo00X0oooo00<000000?ooo`3oool0403oool20?l0aol0
oooon@3oool00`000000oooo0?ooo`060?ooo`00=03oool00`2oM000001d0;ooo`0>0?ooo`030=nL
B00007@0_ooo00X0oooo00<000000?ooo`3oool0403oool20?l0aol0oooon@3oool00`000000oooo
0?ooo`060?ooo`00=03oool00`2oM000001d0;ooo`0>0?ooo`030?noM0000000M;oo00X0oooo00<0
00000?ooo`3oool0403oool20?l0aol0oooon@3oool00`000000oooo0?ooo`060?ooo`00=03oool0
0`2oM000001d0;ooo`080?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol02P3oool0
0`000000oooo0?ooo`0@0?ooo`80o`37o`3ooooi0?ooo`030000003oool0oooo00H0oooo000b0?oo
o`050=nLB000000000000000M02oool02@3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0
gooo2P3oool00`000000oooo0?ooo`0@0?ooo`80o`37o`3ooooi0?ooo`030000003oool0oooo00H0
oooo000c0?ooo`040?oo_`1d0000001d0;ooo`X0oooo00D0_g@00000000000000000001d_`0<0?oo
o`030000003oool0oooo0100oooo0P3o0<Oo0?ooooT0oooo00<000000?ooo`3oool01P3oool00580
oooo00<000000?ooo`3oool0403oool20?l0aol0oooon@3oool00`000000oooo0?ooo`060?ooo`00
DP3oool00`000000oooo0?ooo`0?0?ooo`80o`37o`3ooooj0?ooo`030000003oool0oooo00H0oooo
001B0?ooo`030000003oool0oooo00l0oooo0P3o0<Oo0?ooooX0oooo00<000000?ooo`3oool01P3o
ool00580oooo00<000000?ooo`3oool03`3oool20?l0aol0oooonP3oool00`000000oooo0?ooo`06
0?ooo`00DP3oool00`000000oooo0?ooo`0?0?ooo`80o`37o`3ooooj0?ooo`030000003oool0oooo
00H0oooo001B0?ooo`<000003`3oool20?l0aol0oooon03oool3000000P0oooo001B0?ooo`030000
003oool0oooo00l0oooo0P3o0<Oo0?ooooX0oooo00<000000?ooo`3oool01P3oool00580oooo00<0
00000?ooo`3oool03`3oool20?l0aol0oooonP3oool00`000000oooo0?ooo`060?ooo`00DP3oool0
0`000000oooo0?ooo`0?0?ooo`80o`37o`3ooooj0?ooo`030000003oool0oooo00H0oooo001B0?oo
o`030000003oool0oooo00l0oooo0P3o0<Oo0?ooooX0oooo00<000000?ooo`3oool01P3oool00580
oooo00<000000?ooo`3oool03`3oool20?l0aol0oooonP3oool00`000000oooo0?ooo`060?ooo`00
DP3oool00`000000oooo0?ooo`0>0?ooo`80o`37o`3ooook0?ooo`030000003oool0oooo00H0oooo
001B0?ooo`030000003oool0oooo00h0oooo0P3o0<Oo0?oooo/0oooo00<000000?ooo`3oool01P3o
ool00580oooo00<000000?ooo`3oool03P3oool20?l0aol0oooon`3oool00`000000oooo0?ooo`06
0?ooo`00DP3oool00`000000oooo0?ooo`0>0?ooo`80o`37o`3ooook0?ooo`030000003oool0oooo
00H0oooo001B0?ooo`030000003oool0oooo00h0oooo0P3o0<Oo0?oooo/0oooo00<000000?ooo`3o
ool01P3oool00580oooo00<000000?ooo`3oool03P3oool20?l0aol0oooon`3oool00`000000oooo
0?ooo`060?ooo`00DP3oool00`000000oooo0?ooo`0>0?ooo`80o`37o`3ooook0?ooo`030000003o
ool0oooo00H0oooo001B0?ooo`<000003P3oool20?l0aol0oooon@3oool3000000P0oooo001B0?oo
o`030000003oool0oooo00h0oooo0P3o0<Oo0?oooo/0oooo00<000000?ooo`3oool01P3oool00580
oooo00<000000?ooo`3oool03P3oool20?l0aol0oooon`3oool00`000000oooo0?ooo`060?ooo`00
DP3oool00`000000oooo0?ooo`0=0?ooo`80o`37o`3ooool0?ooo`030000003oool0oooo00H0oooo
001B0?ooo`030000003oool0oooo00d0oooo0P3o0<Oo0?oooo`0oooo00<000000?ooo`3oool01P3o
ool00580oooo00<000000?ooo`3oool0o`3ooooo0?ooo``0oooo00<000000?ooo`3oool01P3oool0
0580oooo00<000000?ooo`3oool0o`3ooooo0?ooo``0oooo00<000000?ooo`3oool01P3oool00580
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0640
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0640
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`00DP3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00H0oooo001B0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01P3oool00580ooooo`00003o000001000000203oool00001\
\>"],
  ImageRangeCache->{{{0, 615.875}, {380.25, 0}} -> {-0.189152, 0.922618, \
0.00199944, 0.000805261}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[f21, f22]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -1.68598 1.84358 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -14.5625 -24.5625 ]
[.21429 -0.0125 14.5625 0 ]
[.40476 -0.0125 -14.5625 -24.5625 ]
[.40476 -0.0125 14.5625 0 ]
[.59524 -0.0125 -14.5625 -24.5625 ]
[.59524 -0.0125 14.5625 0 ]
[.78571 -0.0125 -14.5625 -24.5625 ]
[.78571 -0.0125 14.5625 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.4063 -49.125 ]
[.5 -0.0125 19.4063 -24.5625 ]
[-0.0125 .06542 -39.1875 -12.2813 ]
[-0.0125 .06542 0 12.2813 ]
[-0.0125 .1576 -14.0625 -12.2813 ]
[-0.0125 .1576 0 12.2813 ]
[-0.0125 .24978 -39.1875 -12.2813 ]
[-0.0125 .24978 0 12.2813 ]
[-0.0125 .34196 -29.125 -12.2813 ]
[-0.0125 .34196 0 12.2813 ]
[-0.0125 .43413 -39.1875 -12.2813 ]
[-0.0125 .43413 0 12.2813 ]
[-0.0125 .52631 -29.125 -12.2813 ]
[-0.0125 .52631 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -63.75 -12.5625 ]
[-0.01875 .30902 -39.1875 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.4063 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
76.813 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
83.875 26.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
86.500 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
97.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .06542 m
.00625 .06542 L
s
gsave
-0.0125 .06542 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
1.000 setlinewidth
grestore
0 .1576 m
.00625 .1576 L
s
gsave
-0.0125 .1576 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .24978 m
.00625 .24978 L
s
gsave
-0.0125 .24978 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
1.000 setlinewidth
grestore
0 .34196 m
.00625 .34196 L
s
gsave
-0.0125 .34196 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
0 .43413 m
.00625 .43413 L
s
gsave
-0.0125 .43413 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
1.000 setlinewidth
grestore
0 .52631 m
.00625 .52631 L
s
gsave
-0.0125 .52631 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08385 m
.00375 .08385 L
s
0 .10229 m
.00375 .10229 L
s
0 .12073 m
.00375 .12073 L
s
0 .13916 m
.00375 .13916 L
s
0 .17603 m
.00375 .17603 L
s
0 .19447 m
.00375 .19447 L
s
0 .21291 m
.00375 .21291 L
s
0 .23134 m
.00375 .23134 L
s
0 .26821 m
.00375 .26821 L
s
0 .28665 m
.00375 .28665 L
s
0 .30508 m
.00375 .30508 L
s
0 .32352 m
.00375 .32352 L
s
0 .36039 m
.00375 .36039 L
s
0 .37883 m
.00375 .37883 L
s
0 .39726 m
.00375 .39726 L
s
0 .4157 m
.00375 .4157 L
s
0 .45257 m
.00375 .45257 L
s
0 .47101 m
.00375 .47101 L
s
0 .48944 m
.00375 .48944 L
s
0 .50788 m
.00375 .50788 L
s
0 .54475 m
.00375 .54475 L
s
0 .56319 m
.00375 .56319 L
s
0 .58162 m
.00375 .58162 L
s
0 .60006 m
.00375 .60006 L
s
0 .04698 m
.00375 .04698 L
s
0 .02855 m
.00375 .02855 L
s
0 .01011 m
.00375 .01011 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -125.031 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
73.5625 16.2813 translate
90 rotate
-73.5625 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.375 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
76.563 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06542 m
1 .06542 L
s
.99375 .1576 m
1 .1576 L
s
.99375 .24978 m
1 .24978 L
s
.99375 .34196 m
1 .34196 L
s
.99375 .43413 m
1 .43413 L
s
.99375 .52631 m
1 .52631 L
s
.125 Mabswid
.99625 .08385 m
1 .08385 L
s
.99625 .10229 m
1 .10229 L
s
.99625 .12073 m
1 .12073 L
s
.99625 .13916 m
1 .13916 L
s
.99625 .17603 m
1 .17603 L
s
.99625 .19447 m
1 .19447 L
s
.99625 .21291 m
1 .21291 L
s
.99625 .23134 m
1 .23134 L
s
.99625 .26821 m
1 .26821 L
s
.99625 .28665 m
1 .28665 L
s
.99625 .30508 m
1 .30508 L
s
.99625 .32352 m
1 .32352 L
s
.99625 .36039 m
1 .36039 L
s
.99625 .37883 m
1 .37883 L
s
.99625 .39726 m
1 .39726 L
s
.99625 .4157 m
1 .4157 L
s
.99625 .45257 m
1 .45257 L
s
.99625 .47101 m
1 .47101 L
s
.99625 .48944 m
1 .48944 L
s
.99625 .50788 m
1 .50788 L
s
.99625 .54475 m
1 .54475 L
s
.99625 .56319 m
1 .56319 L
s
.99625 .58162 m
1 .58162 L
s
.99625 .60006 m
1 .60006 L
s
.99625 .04698 m
1 .04698 L
s
.99625 .02855 m
1 .02855 L
s
.99625 .01011 m
1 .01011 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.8 0 1 r
.005 w
[ .01 .01 ] 0 setdash
.03333 .60301 m
.05238 .43067 L
.07143 .33767 L
.09048 .27714 L
.11905 .21667 L
.16667 .1555 L
.21429 .11833 L
.2619 .09345 L
.30952 .07578 L
.40476 .05271 L
.5 .03873 L
.59524 .02972 L
.69048 .02368 L
.78571 .01954 L
.88095 .01668 L
.97619 .01472 L
s
1 0 0 r
.002 w
[ .05 .01 ] 0 setdash
.03333 .60332 m
.05238 .39891 L
.07143 .3058 L
.09048 .25495 L
.11905 .2162 L
.14762 .20056 L
.16667 .19732 L
.17619 .19716 L
.19524 .19903 L
.20476 .20084 L
.21429 .20311 L
.23333 .20881 L
.2619 .21947 L
.30952 .24068 L
.40476 .28832 L
.5 .33672 L
.59524 .38314 L
.69048 .42682 L
.78571 .46765 L
.88095 .50575 L
.97619 .54133 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ Combine\ Plots\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f2 = 
      Show[f21, f22, f23, f24, f25, 
        Graphics[{Text["\<1\>", {0.445, 1.08}, {\(-1\), 0}], 
            Text["\<2\>", {0.93, 0.93}, {\(-1\), 0}], 
            Text["\<3\>", {0.58, 0.95}, {\(-1\), 0}], 
            Text["\<4\>", {0.932, 0.984}, {\(-1\), 0}], 
            Text["\<5\>", {0.945, 0.965}, {\(-1\), 0}]}], 
        PlotRange \[Rule] {0.9, 1.12}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -2.52832 2.80925 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -14.5625 -24.5625 ]
[.21429 -0.0125 14.5625 0 ]
[.40476 -0.0125 -14.5625 -24.5625 ]
[.40476 -0.0125 14.5625 0 ]
[.59524 -0.0125 -14.5625 -24.5625 ]
[.59524 -0.0125 14.5625 0 ]
[.78571 -0.0125 -14.5625 -24.5625 ]
[.78571 -0.0125 14.5625 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.4063 -49.125 ]
[.5 -0.0125 19.4063 -24.5625 ]
[-0.0125 .14046 -39.1875 -12.2813 ]
[-0.0125 .14046 0 12.2813 ]
[-0.0125 .28092 -14.0625 -12.2813 ]
[-0.0125 .28092 0 12.2813 ]
[-0.0125 .42139 -39.1875 -12.2813 ]
[-0.0125 .42139 0 12.2813 ]
[-0.0125 .56185 -29.125 -12.2813 ]
[-0.0125 .56185 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -63.75 -12.5625 ]
[-0.01875 .30902 -39.1875 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.4063 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
76.813 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
83.875 26.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
86.500 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
97.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .14046 m
.00625 .14046 L
s
gsave
-0.0125 .14046 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
1.000 setlinewidth
grestore
0 .28092 m
.00625 .28092 L
s
gsave
-0.0125 .28092 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .42139 m
.00625 .42139 L
s
gsave
-0.0125 .42139 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
1.000 setlinewidth
grestore
0 .56185 m
.00625 .56185 L
s
gsave
-0.0125 .56185 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .30902 m
.00375 .30902 L
s
0 .33711 m
.00375 .33711 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .44948 m
.00375 .44948 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -125.031 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
73.5625 16.2813 translate
90 rotate
-73.5625 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.375 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
76.563 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .14046 m
1 .14046 L
s
.99375 .28092 m
1 .28092 L
s
.99375 .42139 m
1 .42139 L
s
.99375 .56185 m
1 .56185 L
s
.125 Mabswid
.99625 .02809 m
1 .02809 L
s
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .16855 m
1 .16855 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .58994 m
1 .58994 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.8 0 1 r
.005 w
[ .01 .01 ] 0 setdash
.063 .61803 m
.07143 .55532 L
.09048 .46309 L
.11905 .37093 L
.16667 .27772 L
.21429 .22108 L
.2619 .18318 L
.30952 .15625 L
.40476 .12109 L
.5 .0998 L
.59524 .08606 L
.69048 .07686 L
.78571 .07055 L
.88095 .0662 L
.97619 .0632 L
s
1 0 0 r
.002 w
[ .05 .01 ] 0 setdash
.05649 .61803 m
.07143 .50676 L
.09048 .42927 L
.11905 .37022 L
.14762 .34639 L
.16667 .34145 L
.17619 .34121 L
.19524 .34406 L
.20476 .34681 L
.21429 .35028 L
.23333 .35896 L
.2619 .3752 L
.30952 .40752 L
.40476 .48012 L
.5 .55386 L
s
.5 .55386 m
.58639 .61803 L
s
.004 w
[ .05 .05 ] 0 setdash
.13459 .61803 m
.16667 .52561 L
.21429 .43185 L
.2619 .36209 L
.30952 .3074 L
.40476 .22586 L
.5 .16702 L
.59524 .12198 L
.69048 .08612 L
.78571 .05672 L
.88095 .03209 L
.97619 .01108 L
s
.8 1 0 r
[ .005 .005 ] 0 setdash
.05319 .61803 m
.07143 .52685 L
.09048 .46732 L
.10952 .42578 L
.11905 .40927 L
.14762 .37081 L
.16667 .35152 L
.21429 .31656 L
.2619 .293 L
.30952 .27605 L
.40476 .25333 L
.5 .23893 L
.59524 .22908 L
.69048 .22201 L
.78571 .21676 L
.88095 .21275 L
.97619 .20963 L
s
1 0 .78 r
[ ] 0 setdash
.06266 .61803 m
.07143 .56602 L
.09048 .49492 L
.10952 .44524 L
.11905 .42551 L
.14762 .37967 L
.16667 .35682 L
.21429 .31585 L
.2619 .28881 L
.30952 .26981 L
.40476 .24537 L
.5 .23084 L
.59524 .22164 L
.69048 .21559 L
.78571 .21154 L
.88095 .20881 L
.97619 .207 L
s
0 g
gsave
.44762 .50566 -61 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
73.063 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.90952 .08428 -61 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
73.063 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57619 .14046 -61 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
73.063 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.91143 .23598 -61 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
73.063 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.92381 .1826 -61 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
73.063 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{938.75, 580.188},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>Z0002A2000`400?l00000o`00003oo`3ooooo
0?ooool0oooo[@3oool00?l0ooooo`3ooooo0?ooojd0oooo003o0?ooool0ooooo`3ooon]0?ooo`00
o`3ooooo0?ooool0oooo[@3oool00?l0oooonP3oool0103ooml0W4P000000000M;l50?ooo`0;0;md
00000000001809cOg`2LB00000000000M02ookl0M00000000000M;l0o`3ooonN0?ooo`00o`3ooooj
0?ooo`050;md0018W=l0oooo0=nLB018W=l0103oool02`3ooml0W4P007Boo`3oool0oono07@0B02L
gol0oooo0?oOW01807@0_ooo0?l0ooooWP3oool00?l0oooon@3oool01`3ogi`0B01d0;ooo`3oool0
omnL04P0M02oool00`3oool02`3ooml0W4P007Boo`3oool0oono07@0B02Lgol0oooo0?oOW01807@0
_ooo0?l0ooooWP3oool00?l0ooook@3oool01`3OW4P00000000000000000M;oo0?oOW01800000P00
00002P18W=l0oooo0?ooo`3o_g@004RL0=ooo`3oool0oooO09a8001d_ol30?ooo`0;0?oog`2LB000
M;oo0?ooo`3ookl0M01809cOo`3oool0omnL04P0M02oool0o`3ooonN0?ooo`00o`3oooo/0?ooo`03
0?noM000000007Bo0080oooo00X0_gA804Q8B02Lgol0oooo0?oOW018000004RL0=ooo`3OW4P007Bo
0P3oool00`3ooml0W4P007Boo`030?ooo`0;0?oog`2LB000M;oo0?ooo`3ookl0M01809cOo`3oool0
omnL04P0M02oool0o`3ooonN0?ooo`00o`3oooo/0?ooo`030=nLB0000000M;oo0080oooo00<0oono
07@0B02Lgol00P3oool01@3o_g@00000001d_`3OW4P007Bo0080oooo00<0oooO09a8001d_ol00P3o
ool0303ooml0W4P00000000004P0W=oo0?oOW0180000001d0;ooo`3o_g@004RL0=ooool0ooooWP3o
ool00?l0ooook03oool00`3OW4P0000007Boo`030?ooo`030;md001d_ol0oooo0080oooo00T0_g@0
0000B02LYg@004RL0=ooo`3oool0oooO09a8001d_ol00`3oool02P3ookl0M00007Bog`2LB0000000
001d_`3ookl0M00000000018W=oo0?oooil0oooo003o0?ooon`0oooo00<0okmd00000018W=l00`3o
ool00`3o_g@007Bo0?ooo`020?ooo`090?noM0000000B8V804P0M02oool0oooo0?oo_`1d07@0_ooo
0?l0oooo[03oool00?l0ooook03oool00`3ooml0W4P0001d_`030?ooo`030?oOW01807@0_ooo0080
oooo00P0omnL04P00018W=l0_g@004RLg`3oool0gia8001d_ol0oooo[@3oool00?l0ooook@3oool0
0`3ogi`0B01809cOo`070?ooo`080?oo_`1d0000M;oo0?oog`2LB00000000018W03Ooooo0?ooojd0
oooo003o0?ooonh0oooo00<0gia80018W03Oool01P3oool00`3ogi`0B01d0;ooo`3o0?oook80oooo
003o0?ooonl0oooo00<0okmd0018W03Oool01@3oool00`3OW4P0M;oo0?ooo`3o0?oook80oooo003o
0?ooool0ooooo`3ooon]0?ooo`00o`3ooooo0?ooool0oooo[@3oool00?l0ooooo`3ooooo0?ooojd0
oooo003o0?ooool0ooooo`3ooon]0?ooo`00o`3ooooo0?ooool0oooo[@3oool00?l0ooooo`3ooooo
0?ooojd0oooo003o0?ooool0ooooo`3ooon]0?ooo`00o`3ooooo0?ooool0oooo[@3oool00?l0oooo
o`3ooooo0?ooojd0oooo003o0?ooool0ooooo`3ooon]0?ooo`00o`3ooooo0?ooool0oooo[@3oool0
0?l0ooooo`3ooooo0?ooojd0oooo003o0?ooool0ooooo`3ooon]0?ooo`00o`3ooooo0?ooool0oooo
[@3oool00?l0ooooo`3ooooo0?ooojd0oooo001Z0?ooo`040;md00000000000004RLgi@0oooo00@0
_g@0000000000000B9cO103oool01@3OW4P0000004RLg`3oool0gia800L0000000<0M;oo0?ooo`3o
ool0R@3oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO00H0oooo00<0okmd0000
001d_ol0S@3oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO00<0oooo00H0oooO
09a80000000000000000M02ooon<0?ooo`040;md00000000000004RLg`@0oooo00<0gia800000018
W=l00`3oool01P3ogi`0B000000000000000001809cOoi80oooo00<0okmd0000000000000P000000
0`00M;l0oooo0?ooo`0I0?ooo`00J03oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0T@3o
ool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`03
0=nLB0000000000000@0000000<007Bo0?ooo`3oool0Q`3oool01`3ooml0W4P0001d_`3oool0oooO
09a80000M;l00`3oool00`3OW4P0000004RLg`060?ooo`030?noM0000000M;oo08/0oooo00L0oooO
09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l00P3oool0203ookl0M000
0018W03Oool0oooo0=nLB00004P0W=ooR@3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0
0`3oool00`3OW4P0000004RLg`020?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0001d_onC
0?ooo`030;md000007@0_ooo01`0oooo001X0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0
001d_ol0T03oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo00<0gia804RL
g`3oool00P3oool00`3ooml0W4Qd0;ooo`280?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0
001d_ol02`3oool00`3o_g@0000007Boo`2;0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0
001d_ol01`3oool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo08P0oooo00<0okmd0000
B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030;md000007@0_ooo00<0oooo00<0gia80018
W03Oool0TP3oool00`2oM000001d0;ooo`0L0?ooo`00I`3oool0103ooml0W4P00018W03Oool20?oo
o`030?oog`2LB00007Bo08l0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`09
0?ooo`030=nLB018W=l0oooo08/0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d
_`060?ooo`030=nLB0000000000000D0000000<0001809cOo`3oool0Q`3oool0103ooml0W4P00018
W03Oool20?ooo`030?oog`2LB00007Bo00H0oooo00<0oono07@00000M;l0103oool00`3OW4P0001d
0;ooo`270?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l01`3oool00`2oM000
001d0;ooo`030?ooo`030;md0000B9`0gooo0980oooo00<0_g@00000M02oool0703oool006L0oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`2>0?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool02@3oool00`3OW4P0M;oo0?ooo`2:0?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool01@3oool00`3ogi`0B7Bo0?ooo`020?ooo`030?noM0000000M;oo08X0oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`050?ooo`030?oOW0180000B9cO00@0oooo
00<0_g@00000B02Lgol0Q`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo
00<0okmd0000B02Lgol00P3oool00`3OW4P00000001d_`2C0?ooo`030;md000007@0_ooo01`0oooo
001W0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0SP3oool00`3ogi`0B00004RL
g`040?ooo`030;md000007@0_ooo00T0oooo00<0oooO09a8B02Lgol0RP3oool00`3ogi`0B00004RL
g`040?ooo`030;md000007@0_ooo00H0oooo00L0gia807Boo`3oool0oooo0?noM0000000M;oo08X0
oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`050?ooo`030?oOW0180000B9cO00<0
oooo00@0oono07@0000007@0_oooQ`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo
00L0oooo00L0gia8001d_`3oool0_g@00000000007@0_ooo09<0oooo00<0_g@00000M02oool0703o
ool006L0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`2>0?ooo`030?oOW0180000
B9cO00@0oooo00<0gia80000B02Lgol02P3oool00`3ogi`0B01d0;ooo`290?ooo`030?oOW0180000
B9cO00@0oooo00<0gia80000B02Lgol01P3oool01`3ookl0M01d0;ooo`3oool0okmd0000001d_ol0
RP3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00D0oooo00T0oono07@000000000
04RL0=ooo`3oool0_g@000000018W=l0R03oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0
W=oo00P0oooo00D0okmd00000000000004RL0=ooo`2D0?ooo`030;md000007@0_ooo01`0oooo001W
0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0SP3oool00`3ogi`0B00004RLg`04
0?ooo`030=nLB00004P0W=oo00/0oooo00<0_g@004RLg`3oool0R03oool00`3ogi`0B00004RLg`04
0?ooo`030=nLB00004P0W=oo00L0oooo00H0okmd001d_`3oool0okmd0000001d_on:0?ooo`030?oO
W0180000B9cO00@0oooo00<0gia80000B02Lgol01@3oool01@3ooml0W4P00000M02ogi`0B0000080
000000<0B9cO0?ooo`3oool0Q`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0
oooo00D0omnL04P000000000000004RLg`2E0?ooo`030;md000007@0_ooo01`0oooo001W0?ooo`03
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0SP3oool00`3ookl0M000001d_`040?ooo`03
0;md000007@0_ooo00/0oooo00<0gia80000M02oool0R03oool00`3ookl0M000001d_`040?ooo`03
0;md000007@0_ooo00P0oooo00D0_g@007Boo`3o_g@0000007Boo`2:0?ooo`030?oo_`1d000007Bo
00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@0000004RLg`2=0?ooo`030?oo_`1d000007Bo
00@0oooo00<0_g@00000M02oool01P3oool01`3ogi`0B0000000B02Lgol0oooo0=nLB000M;l0U03o
ool00`2oM000001d0;ooo`0L0?ooo`00J03oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB000
07Bo0900oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`0<0?ooo`030?noM0000000
M;oo08T0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`090?ooo`050?oo_`1d07@0
_kmd0000001d_ol0R`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00@0
oooO09a8000004P0W=ooS@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo
00<0gia80000B02Lgol00P3oool00`3ooml0W4P007Boo`2C0?ooo`030;md000007@0_ooo01`0oooo
001X0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0T03oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo00H0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Bo
o`290?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol02P3oool0103o_g@000000000
001d_on;0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool0103ookl0M000
0000M02ooon<0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`3OW4P0
04RL0=ooo`020?ooo`030?oog`2LB000B9cO09<0oooo00<0_g@00000M02oool0703oool006T0oooo
00H0_g@00018W03Oool0oooo0;md0000M;nB0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203o
ool0202oM000M;oo0?ooo`3oool0gia800000000B9`0goooRP3oool01P2oM00004RL0=ooo`3oool0
_g@0001d_`/0oooo00@0oooO09a800000000M;ooS03oool01P2oM00004RL0=ooo`3oool0_g@0001d
_`X0oooo00@0oooO09a80000000007BoS03oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo
00<0omnL04P00018W=l00P3oool00`3o_g@0001809cOo`2A0?ooo`050=nLB000000000000000M02o
ool0703oool006X0oooo00@0_g@000000000000007BoU03oool0102oM000000000000000M;l:0?oo
o`050;md00000000000000000000M;l0S@3oool0102oM000000000000000M;l=0?ooo`030?oOW018
0000M;oo08d0oooo00@0_g@000000000000007Bo3@3oool01@3ogi`0B00000000000B9`0gooo08X0
oooo00@0_g@000000000000007Bo2P3oool01P3ookl0M000000000000000001809cOoi<0oooo00@0
oono07@0000007@0_ooo703oool00?l0ooooo`3ooooo0?ooojd0oooo003o0?ooool0ooooo`3ooon]
0?ooo`00o`3ooooo0?ooool0oooo[@3oool00?l0ooooo`3ooooo0?ooojd0oooo003o0?ooool0oooo
o`3ooon]0?ooo`00o`3ooooo0?ooool0oooo[@3oool00?l0ooooo`3ooooo0?ooojd0oooo003o0?oo
ool0ooooo`3ooon]0?ooo`00o`3ooooo0?ooool0oooo[@3oool00?l0ooooo`3ooooo0?ooojd0oooo
003o0?ooool0ooooo`3ooon]0?ooo`00o`3ooooo0?ooool0oooo[@3oool00?l0ooooo`3ooooo0?oo
ojd0oooo003o0?ooool0ooooo`3ooon]0?ooo`00o`3ooooo0?ooool0oooo[@3oool00?l0ooooo`3o
oooo0?ooojd0oooo001H0?ooool00000o`00003o000004`000002@3oool005P0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
1`3oool005P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2M0?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`2M0?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`00F03oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0W@3oool0
0`000000oooo0?ooo`2M0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0W@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooodP0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0ooooB03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooom80?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooodP0oooo00<000000?ooo`3oool01`3oool005P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0ooooB03oool00`000000oooo0?ooo`070?ooo`00F03oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooom80?ooo`030000003oool0oooo00L0oooo001H0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?ooodP0oooo00<000000?ooo`3oool01`3oool005P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0ooooB03oool00`000000oooo0?ooo`070?ooo`00F03o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom80?ooo`030000003oool0oooo00L0oooo001H
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooodP0oooo00<000000?ooo`3oool01`3oool0
05P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooB03oool00`000000oooo0?ooo`070?oo
o`00F03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool90?ooo`@0o`00>`3oool00`000000
oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool50?ooo`P0o`00
>`3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ool10?ooo``0o`00>`3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3o
0?ooool0oooon`3oool=0?l003l0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooooL0oooo3@3o00130?ooo`030000003oool0oooo00L0oooo001H0?ooo`03
0000003oool0oooo0?l0ooooo`3ooooc0?ooo`d0o`00A`3oool00`000000oooo0?ooo`070?ooo`00
F03oool00`000000oooo0?ooo`3o0?ooool0ooookP3oool=0?l004`0oooo00<000000?ooo`3oool0
1`3oool005P0oooo1000003o0?ooool0ooooj@3oool=0?l004d0oooo100000090?ooo`00F03oool0
0`000000oooo0?ooo`3o0?ooool0ooooiP3oool=0?l005@0oooo00<000000?ooo`3oool01`3oool0
05P0oooo00<000000?ooo`3oool0o`3ooooo0?ooon00oooo3P3o001I0?ooo`030000003oool0oooo
00L0oooo001H0?ooo`030000003oool0oooo0?l0ooooo`3ooooP0?ooo`X0o`00G@3oool00`000000
oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3o0?ooool0ooooh03oool60?l00640oooo
00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooB03o
ool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooom8
0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oo
odP0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0
ooooB03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3o0?ooool0oooo
o`3ooom80?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0ooooo`3o
oooo0?ooodP0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0ooooB03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooom80?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0
ooooo`3ooonh0?ooo`<0o`00S03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo
0?ooo`3o0?ooool0oooo]03oool70?l008`0oooo00<000000?ooo`3oool01`3oool005P0oooo00<0
00000?ooo`3oool0o`3ooooo0?oook00oooo2`3o002<0?ooo`030000003oool0oooo00L0oooo001H
0?ooo`030000003oool0oooo0?l0ooooo`3ooon/0?ooo``0o`00S`3oool00`000000oooo0?ooo`07
0?ooo`00F03oool00`000000oooo0?ooo`3o0?ooool0ooooZ03oool<0?l009<0oooo00<000000?oo
o`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooooo0?ooojD0oooo2`3o002G0?ooo`03
0000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0ooooo`3ooonQ0?ooo`/0o`00
V`3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3o0?ooool0ooooW@3o
ool;0?l009l0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooiT0oooo303o002R0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo
0?l0ooooo`3ooonE0?ooo``0o`00YP3oool00`000000oooo0?ooo`070?ooo`00F03oool400000?l0
ooooo`3ooon@0?ooo``0o`00Y`3oool4000000T0oooo001H0?ooo`030000003oool0oooo0?l0oooo
o`3ooon?0?ooo`X0o`00[P3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?oo
o`3o0?ooool0ooooS`3oool60?l00;80oooo00<000000?ooo`3oool01`3oool005P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooohl0oooo0`3o002e0?ooo`030000003oool0oooo00L0oooo001H0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooodP0oooo00<000000?ooo`3oool01`3oool005P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo;P3oool80<`0oa80oooo00<000000?ooo`3o
ool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo303oool=0<`0o`@0oooo
3@3<0?l40?ooo`P0c03o4P3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?oo
o`3o0?ooool0ooood`3oool20<`0o`h0oooo0P3<0?l50?ooo``0c03o1@3oool<0<`0o`@0oooo3@3<
0?l40?ooo`d0c03o103oool80<`0oa80oooo00<000000?ooo`3oool01`3oool005P0oooo00<00000
0?ooo`3oool0o`3ooooo0?oool80oooo0P3<0?l70?ooo`X0c03o103oool=0<`0o`@0oooo303<0?l5
0?ooo``0c03o103oool=0<`0o`@0oooo3@3<0?l40?ooo`P0c03o4P3oool00`000000oooo0?ooo`07
0?ooo`00F03oool00`000000oooo0?ooo`3o0?ooool0oooo^P3oool:0<`0o`@0oooo3@3<0?l40?oo
o`d0c03o103oool<0<`0o`D0oooo303<0?l40?ooo`d0c03o103oool=0<`0oah0oooo00<000000?oo
o`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooooo0?ooojL0oooo303<0?l40?ooo`d0
c03o103oool=0<`0o`@0oooo303<0?l50?ooo``0c03o1@3oool<0<`0od00oooo00<000000?ooo`3o
ool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooooo0?oooiH0oooo303<0?l50?ooo``0c03o
103oool=0<`0o`@0oooo2`3<0?l60?ooo``0c03oHP3oool00`000000oooo0?ooo`070?ooo`00F03o
ool00`000000oooo0?ooo`3o0?ooool0ooooQ@3oool<0<`0o`D0oooo303<0?l50?ooo``0c03o103o
ool;0<`0o`H0oooo0`3<0?ml0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0
oooo0?l0ooooo`3ooomV0?ooo`@0o`002P3oool=0<`0o`@0oooo303<0?l50?ooo``0c03o1@3oool<
0<`0o`@0oooo0`3<0?n=0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo
0?l0ooooo`3ooomS0?ooo`L0o`001P3<0?l40?ooo`d0c03o103oool<0<`0o`D0oooo303<0?nU0?oo
o`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0ooooo`3ooom<0?ooo`80
c03o1@3oool<0<`0o`030?ooo`3o0000o`0000P0o`001P3<0?l40?ooo`d0c03o103oool<0<`0okH0
oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooooo0?oooc/0oooo
0P3<0?l70?ooo`X0c03o1@3oool90<`0o`/0o`002@3<0?l40?ooo`d0c03oaP3oool00`000000oooo
0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3o0?ooool0oooo<`3oool:0<`0o`D0oooo303<
0?l50?ooo`H0c03o2`3o000<0<`0omL0oooo00<000000?ooo`3oool01`3oool005P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooob/0oooo0P3<0?l40?ooo``0c03o1@3oool<0<`0o`D0oooo0P3<0?l<
0?l009`0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`0o0?ooo`030000003oool0
oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0ooooo`3ooolS0?ooo`X0c03o103oool<0<`0
o`D0oooo2P3<0?l60?ooo`/0o`00X@3oool00`3OW4P000000000000400000003001d_`3oool0oooo
03l0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooooo0?ooob00
oooo3@3<0?l40?ooo`X0c03o1`3oool20<`0o`/0oooo2`3o002U0?ooo`030=nLB018W=l0oooo0080
oooo00<0oooO09a8M02oool0@03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo
0?ooo`3o0?ooool0oooo2@3oool20<`0o`D0oooo303<0?l40?ooo`d0c03o103oool20<`0oaP0oooo
2`3o002Z0?ooo`030=nLB018W=l0oooo04@0oooo00<000000?ooo`3oool01`3oool005P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`40oooo2P3<0?l50?ooo``0c03o103oool;0<`0oad0oooo2`3o
002^0?ooo`030=nLB01d_ol0oooo04<0oooo00<000000?ooo`3oool01`3oool005P0oooo00<00000
0?ooo`3oool0o`3oooob0?ooo`80c03o2P3oool<0<`0o`D0oooo303<0?l40?ooo`<0c03o8P3oool;
0?l00;40oooo00<0oooO09a8B02Lgol0@`3oool00`000000oooo0?ooo`070?ooo`00F03oool40000
0?l0ooookP3oool;0<`0o`@0oooo303<0?l50?ooo``0c03o9P3oool:0?l00;H0oooo00<0omnL04P0
M02oool0?`3oool4000000T0oooo001H0?ooo`030000003oool0oooo0?l0ooooi`3oool20<`0o`@0
oooo3@3<0?l40?ooo`X0c03o>03oool80?l00;X0oooo00<0_g@004RLg`3oool0@@3oool00`000000
oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3o0?oooml0oooo2P3<0?l40?ooo`d0c03o
103oool20<`0och0oooo1`3o002m0?ooo`030=nLB00007@0_ooo0440oooo00<000000?ooo`3oool0
1`3oool005P0oooo00<000000?ooo`3oool0o`3ooooF0?ooo`80c03o1@3oool<0<`0o`D0oooo303<
0?m40?ooo`@0o`00`03oool00`3o_g@0000007Boo`110?ooo`030000003oool0oooo00L0oooo001H
0?ooo`030000003oool0oooo0?l0oooodP3oool60<`0o`D0oooo303<0?l50?ooo`80c03oCP3oool3
0?l00;/0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`110?ooo`030000003oool0
oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0oooocP3oool;0<`0o`@0oooo2P3<0?oo0?oo
oaL0oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=oood40oooo00<000000?ooo`3oool0
1`3oool005P0oooo00<000000?ooo`3oool0o`3oooo60?ooo`80c03o103oool=0<`0o`@0oooo0P3<
0?oo0?ooob00oooo00D0_g@00000000000000000001d_`130?ooo`030000003oool0oooo00L0oooo
001H0?ooo`030000003oool0oooo0?l0oooo_P3oool:0<`0o`@0oooo2`3<0?oo0?ooog00oooo00<0
00000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooone0?ooo`80c03o103oool=
0<`0o`D0oooo1P3<0?oo0?ooog@0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?oo
o`3oool0o`3ooon]0?ooo`X0c03o103oool=0<`0o`D0oooo0P3<0?oo0?ooogP0oooo00<000000?oo
o`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooon[0?ooo``0c03o103oool;0<`0ool0
ooooP@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3o0?oooj80oooo
0P3<0?l70?ooo``0c03o103oool30<`0ool0ooooR@3oool00`000000oooo0?ooo`070?ooo`00F03o
ool00`000000oooo0?ooo`3o0?oooi`0oooo2P3<0?l50?ooo`X0c03oo`3ooonB0?ooo`030000003o
ool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0ooooVP3oool<0<`0o`D0oooo0P3<0?oo
0?oooiX0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooonD0?oo
o`80c03o103oool<0<`0ool0ooooX@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000
oooo0?ooo`3o0?oooi00oooo1P3<0?l50?ooo`/0c03oo`3ooonQ0?ooo`030000003oool0oooo00L0
oooo001H0?ooo`030000003oool0oooo0?l0ooooS03oool;0<`0o`@0oooo0P3<0?mi0?ooo`<0o`00
o`3oool^0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0ooooRP3o
ool=0<`0og`0oooo1P3o003o0?ooobh0oooo00<000000?ooo`3oool01`3oool005P0oooo00<00000
0?ooo`3oool0o`3ooon30?ooo`80c03o1@3oool;0<`0og/0oooo2@3o003o0?ooobh0oooo00<00000
0?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`H0c03o1P3oool60<`0
ogd0oooo2@3o003o0?oooc00oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3o
ool0o`3ooomk0?ooo`/0c03o1@3oool20<`0ogh0oooo2@3o003o0?oooc<0oooo00<000000?ooo`3o
ool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`80c03o103oool=0<`0oh80oooo
2@3o003o0?ooocH0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3o
oom_0?ooo`H0c03o103oool;0<`0oh80oooo2@3o003o0?ooocP0oooo00<000000?ooo`3oool01`3o
ool005P0oooo1000003o0?ooofX0oooo2`3<0?l40?ooo`H0c03oP`3oool90?l00?l0oooo>03oool4
000000T0oooo001H0?ooo`030000003oool0oooo0?l0ooooJ@3oool=0<`0o`@0oooo0P3<0?n50?oo
o`P0o`00o`3oooln0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0
ooooH`3oool20<`0o`@0oooo2`3<0?n:0?ooo`T0o`00o`3ooom00?ooo`030000003oool0oooo00L0
oooo001H0?ooo`030000003oool0oooo0?l0ooooGP3oool70<`0o`D0oooo1P3<0?n;0?ooo`T0o`00
o`3ooom30?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0ooooFP3o
ool<0<`0o`@0oooo0P3<0?n=0?ooo`T0o`00o`3ooom50?ooo`030000003oool0oooo00L0oooo001H
0?ooo`030000003oool0oooo0?l0ooooF03oool>0<`0oi00oooo2@3o003o0?ooodP0oooo00<00000
0?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`80c03o103oool<0<`0
ohl0oooo2@3o003o0?oood/0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3o
ool0o`3ooom?0?ooo`D0c03o1@3oool60<`0oi80oooo2@3o003o0?ooodd0oooo00<000000?ooo`3o
ool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`P0c03o103oool20<`0oi@0oooo
203o003o0?oooe00oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3o
oom:0?ooo`/0c03oVP3oool50?l00?l0ooooD`3oool00`000000oooo0?ooo`070?ooo`00F03oool0
0`000000oooo0?ooo`3o0?ooodP0oooo303<0?nK0?ooo`<0o`00o`3ooomE0?ooo`030000003oool0
oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0oooo@@3oool30<`0o`@0oooo203<0?oo0?oo
ooL0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`D0
c03o1@3oool50<`0ool0oooon@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo
0?ooo`3o0?ooocd0oooo203<0?l40?ooo`80c03oo`3ooool0?ooo`030000003oool0oooo00L0oooo
001H0?ooo`030000003oool0oooo0?l0oooo>`3oool:0<`0ool0ooooo`3oool30?ooo`030000003o
ool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0oooo>@3oool:0<`0ool0ooooo`3oool5
0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0oooo>@3oool80<`0
ool0ooooo`3oool70?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0
oooo<`3oool20<`0o`D0oooo1@3<0?oo0?ooool0oooo2@3oool00`000000oooo0?ooo`070?ooo`00
:`3oool0102oM000000000000018W=l40?ooo`090=nLB0000000B9cO0?ooo`3ooml0W4P000000000
04P0W=oo00H0oooo00H0_g@000000000000000000018W03Oool@0?ooo`030000003oool0oooo0?l0
oooo<03oool50<`0o`D0oooo0`3<0?nW0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3o
ool0o`3ooomK0?ooo`030000003oool0oooo00L0oooo000Y0?ooo`070?oog`2LB00007Bo0?ooo`3o
oml0W4P0001d_`030?ooo`030=nLB0000000B9cO00@0oooo00@0gia800000000B9`0gooo0`3oool0
0`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00l0oooo00<000000?ooo`3oool0o`3oool^
0?ooo`P0c03o[P3oool0203ogi`0B0000018W03Oool0oooo0?oOW01804P0W=ooo`3ooomK0?ooo`03
0000003oool0oooo00L0oooo000Y0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0
2P3oool0103ookl0M0000000M02oool80?ooo`030?oOW018M;l0oooo00h0oooo00<000000?ooo`3o
ool0o`3oool[0?ooo`/0c03o]03oool00`3o_g@004RL0=ooo`3o0?oooeX0oooo00<000000?ooo`3o
ool01`3oool002P0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0;0?ooo`04
0?oo_`1d000004RL0=ooo`L0oooo00<0oono07@0B02Lgol03P3oool00`000000oooo0?ooo`3o0?oo
obT0oooo2`3<0?nf0?ooo`030?noM00004P0W=oo0?l0ooooFP3oool00`000000oooo0?ooo`070?oo
o`00:03oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0gia80000001d
_ol01`3oool00`3ookl0M00007Boo`0>0?ooo`030000003oool0oooo0?l0oooo:@3oool80<`0okT0
oooo00<0_g@00000B02Lgol0o`3ooomJ0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030?oO
W0180000B9cO00@0oooo00<0_g@00000M02oool01`3oool00`3OW4P0000000000003000000030018
W03Oool0oooo00D0oooo00<0okmd0000001d_ol03P3oool00`000000oooo0?ooo`3o0?ooob<0oooo
0P3<0?l50?ooo`D0c03o^P3oool0102oM00000000000M02ooooo0?oooeX0oooo00<000000?ooo`3o
ool01`3oool002P0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`060?ooo`030;md
0000000007Bo0080oooo00@0oono07@0000007@0_ooo1@3oool0103ogi`0B0000000M02oool>0?oo
o`H00000o`3ooolM0?ooo`D0c03o1@3oool20<`0okX0oooo00<0oono07@0000000000P0000000`18
W=l0oooo0?ooo`3o0?oooe@0oooo1P0000090?ooo`00:03oool00`3ogi`0B00004RLg`040?ooo`03
0=nLB00004P0W=oo00D0oooo00@0oono07@00000B9`0gooo0`3oool01@2oM000001809cOo`3oool0
gmoO0080oooo00@0_g@0000000000000B9cO3`3oool00`000000oooo0?ooo`3o0?oooah0oooo203<
0?o20?ooo`030?noM00004P0W=oo0?l0ooooG03oool00`000000oooo0?ooo`070?ooo`00:03oool0
0`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04P00018W=l0103oool0
1@3OW4P0001809cOo`3oool0okmd00@0000000<007Bo0?ooo`3oool03P3oool00`000000oooo0?oo
o`3o0?oooa/0oooo2`3<0?nS0?ooo`<0o`007@3oool00`3ogi`0B7Bo0?ooo`3o0?oooe/0oooo00<0
00000?ooo`3oool01`3oool002T0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`06
0?ooo`030?oOW0180000B9cO00@0oooo00T0_g@00000M02oool0oooo0?oog`2LB00000000000M02o
ool04@3oool00`000000oooo0?ooo`3o0?oooaT0oooo2`3<0?nS0?ooo`D0o`007@3oool00`3ooml0
W4P004RLg`3o0?oooe/0oooo00<000000?ooo`3oool01`3oool002T0oooo00<0okmd0000B02Lgol0
0P3oool00`3ogi`0B00007Boo`060?ooo`030?oog`2LB00007Bo00<0oooo00<0oono07@00018W=l0
0`3oool00`3o_g@007Bo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo6@3oool80<`0oj@0oooo
1`3o000H0?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO09a80000M;l0o`3ooomK0?ooo`030000
003oool0oooo00L0oooo000Z0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203oool0203ogi`0
B00007Boo`3oool0oooO09a80000B9`0gooo0`3oool00`3ooml0W4P000000002000000030000M02o
ool0oooo00d0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`80c03o1@3oool50<`0oj@0oooo1`3o
000K0?ooo`070?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`3o0?oooe/0oooo00<000000?ooo`3o
ool01`3oool002/0oooo00@0_g@000000000000007Bo2P3oool01P3ookl0M00000000000000004RL
0=ooo`D0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0<0?ooo`030000003oool0
oooo0?l0oooo403oool50<`0o`D0oooo0P3<0?nU0?ooo`L0o`007P3oool01@3ogi`0B00000000000
0000B9cO0?l0ooooG03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3o
0?ooo`h0oooo203<0?nX0?ooo`P0o`00o`3ooon10?ooo`030000003oool0oooo00L0oooo001H0?oo
o`030000003oool0oooo0?l0oooo2`3oool;0<`0ojH0oooo203o003o0?oooh<0oooo00<000000?oo
o`3oool01`3oool005P0oooo00<000000?ooo`3oool0o`3oool90?ooo`/0c03oYP3oool80?l00?l0
ooooQ@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3o0?ooo`T0oooo
203<0?nW0?ooo`L0o`00o`3ooon80?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003o
ool0oooo0?l0oooo0P3oool20<`0o`H0oooo1@3<0?nW0?ooo`L0o`00o`3ooon:0?ooo`030000003o
ool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0oooo1@3<0?l50?ooo`80c03oZ03oool7
0?l00?l0ooooS03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3n0?oo
o`H0c03o[@3oool70?l00?l0ooooSP3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000
oooo0?ooo`3m0?ooo`L0c03oZ`3oool70?l00?l0ooooT03oool00`000000oooo0?ooo`070?ooo`00
F03oool00`000000oooo0?ooo`3k0?ooo`T0c03oZ03oool80?l00?l0ooooTP3oool00`000000oooo
0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3j0?ooo`H0c03oZP3oool80?l00?l0ooooU03o
ool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3i0?ooo`H0c03oZ@3oool8
0?l00?l0ooooUP3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3j0?oo
o`<0c03oZ@3oool70?l00?l0ooooV@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000
oooo0?ooo`3d0?ooo`80c03o103oool20<`0ojP0oooo1`3o003o0?oooi/0oooo00<000000?ooo`3o
ool01`3oool005P0oooo00<000000?ooo`3oool0lP3oool40<`0oj`0oooo1`3o003o0?oooid0oooo
00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0k`3oool80<`0oj/0oooo1@3o
003o0?oooil0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0k@3oool:
0<`0oj/0oooo0`3o003o0?oooj40oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?oo
o`3oool0j`3oool;0<`0ool0ooooo`3ooomA0?ooo`030000003oool0oooo00L0oooo001H0?ooo`@0
0000j@3oool:0<`0ool0ooooo`3ooom@0?ooo`@000002@3oool005P0oooo00<000000?ooo`3oool0
jP3oool70<`0ool0ooooo`3ooomF0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003o
ool0oooo0>/0oooo103<0?oo0?ooool0ooooF03oool00`000000oooo0?ooo`070?ooo`00F03oool0
0`000000oooo0?ooo`3U0?ooo`80c03o103oool20<`0ool0ooooo`3ooomJ0?ooo`030000003oool0
oooo00L0oooo001H0?ooo`030000003oool0oooo0>@0oooo0`3<0?oo0?ooool0ooooH03oool00`00
0000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3R0?ooo`H0c03oo`3ooooo0?oooel0
oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0h03oool70<`0ool0oooo
o`3ooolS0?ooo`060;md00000000000000000000B9`0gooo=`3oool00`000000oooo0?ooo`070?oo
o`00F03oool00`000000oooo0?ooo`3N0?ooo`P0c03oo`3ooooo0?ooob<0oooo00<0oooO09a80018
W=l00P3oool00`3ogi`0B4RL0=ooo`0f0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000
003oool0oooo0=d0oooo1`3<0?oo0?ooool0oooo:`3oool00`3ogi`0B7Bo0?ooo`0e0?ooo`030000
003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0=`0oooo1P3<0?oo0?ooool0oooo;@3o
ool00`3ookl0M01809cOo`0e0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0
oooo0=d0oooo0`3<0?oo0?ooool0oooo;`3oool00`3ookl0M00007Boo`0e0?ooo`030000003oool0
oooo00L0oooo001H0?ooo`030000003oool0oooo0=d0oooo0P3<0?oo0?ooool0oooo<03oool00`3o
_g@0000007Boo`0e0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0=L0
oooo0P3<0?oo0?ooool0oooo=@3oool0103ogi`0B0000000M02ooole0?ooo`030000003oool0oooo
00L0oooo001H0?ooo`030000003oool0oooo0=H0oooo0`3<0?oo0?ooool0oooo<@3oool0103Ogml0
oooo0?ooo`2oM0020000000304RLg`3oool0oooo03@0oooo00<000000?ooo`3oool01`3oool005P0
oooo00<000000?ooo`3oool0e03oool60<`0ool0ooooo`3oool`0?ooo`030?noM000000000000080
000000<007Bo0?ooo`3oool0=@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo
0?ooo`3C0?ooo`H0c03oo`3ooooo0?oooc40oooo00D0oooO09a800000000001d0;ooo`0h0?ooo`03
0000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0=80oooo1P3<0?oo0?ooool0oooo
<`3oool00`3o_g@007Bo0?ooo`0i0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003o
ool0oooo0=00oooo1P3<0?oo0?ooool0oooo=@3oool00`3ooml0W4P000000002000000030000M02o
ool0oooo03@0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0c`3oool6
0<`0ojT0oooo0`3o003o0?ooohX0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0c
0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0<h0oooo1P3<0?nY0?oo
o`@0o`00o`3oooo50?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0<l0
oooo0`3<0?nY0?ooo`H0o`00o`3oooo50?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000
003oool0oooo0<l0oooo0P3<0?nX0?ooo`H0o`00o`3oooo70?ooo`030000003oool0oooo00L0oooo
001H0?ooo`030000003oool0oooo0<T0oooo00<0c03o0?ooo`3oool0[03oool60?l00?l0oooob03o
ool00`000000oooo0?ooo`070?ooo`00F03oool400000<H0oooo103<0?n[0?ooo`H0o`00o`3oooo7
0?ooo`@000002@3oool005P0oooo00<000000?ooo`3oool0aP3oool60<`0ojT0oooo1@3o003o0?oo
ol`0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0a@3oool70<`0ojL0
oooo1P3o003o0?ooold0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0
a03oool60<`0ojL0oooo1P3o003o0?oooll0oooo00<000000?ooo`3oool01`3oool005P0oooo00<0
00000?ooo`3oool0``3oool60<`0ojL0oooo1P3o003o0?ooom00oooo00<000000?ooo`3oool01`3o
ool005P0oooo00<000000?ooo`3oool0`@3oool70<`0ojH0oooo1P3o003o0?ooom80oooo00<00000
0?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0`@3oool60<`0ojH0oooo1@3o003o0?oo
om@0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0`P3oool40<`0ojD0
oooo1P3o003o0?ooomD0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0
``3oool00`3<0?l0oooo0?ooo`2T0?ooo`D0o`00o`3ooonL0?ooobT0o`374P3oool00`000000oooo
0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`3o0?ooofT0oooo1P3o003o0?ooofL0ooooG`3o
0<LB0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0;`0oooo00<0c03o
0?ooo`3oool0Y`3oool60?l00?l0ooooCP3ooomj0?l0aa80oooo00<000000?ooo`3oool01`3oool0
05P0oooo00<000000?ooo`3oool0^P3oool40<`0ojL0oooo1P3o003o0?ooocD0ooooJ`3o0<L40<co
00030?ooo`3<o`00c?l000D0c?l00P3oool70<co00030?ooo`3<o`00c?l000D0c?l000<0oooo0<co
003<o`001P3<o`0E0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0;T0
oooo1P3<0?nT0?ooo`H0o`00o`3ooolL0?oooe00o`376P3oool70<co00030?ooo`3<o`00c?l000D0
c?l000<0oooo0<co003<o`001P3<o`000`3oool0c?l00<co00050<co00030?ooo`3<o`00c?l000D0
c?l00P3oool70<co00030?ooo`3<o`00c?l000D0c?l000<0oooo0<co003<o`001P3<o`0E0?ooo`03
0000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0;P0oooo1`3<0?nS0?ooo`D0o`00
o`3oool30?oooe00o`375P3oool40<co00030?ooo`3<o`00c?l000H0c?l000<0oooo0<co003<o`00
1@3<o`000`3oool0c?l00<co00050<co0080oooo1`3<o`000`3oool0c?l00<co00050<co00030?oo
o`3<o`00c?l000H0c?l000<0oooo0<co003<o`001@3<o`000`3oool0c?l00<co00050<co0080oooo
1`3<o`000`3oool0c?l00<co00050<co01h0oooo00<000000?ooo`3oool01`3oool005P0oooo00<0
00000?ooo`3oool0]`3oool60<`0oj<0oooo1P3o003Y0?oooe00o`37703oool70<co0080oooo1`3<
o`000`3oool0c?l00<co00050<co00030?ooo`3<o`00c?l000H0c?l000<0oooo0<co003<o`001@3<
o`000`3oool0c?l00<co00050<co0080oooo1`3<o`000`3oool0c?l00<co00050<co00030?ooo`3<
o`00c?l000H0c?l000@0oooo0<co003<o`00c?l0>`3oool00`000000oooo0?ooo`070?ooo`00F03o
ool00`000000oooo0?ooo`2f0?ooo`H0c03oXP3oool60?l00=D0ooooB`3o0<LN0?ooo`L0c?l000<0
oooo0<co003<o`001P3<o`000`3oool0c?l00<co00050<co00030?ooo`3<o`00c?l000D0c?l00P3o
ool70<co00030?ooo`3<o`00c?l000D0c?l000<0oooo0<co003<o`001P3<o`000`3oool0c?l00<co
00050<co00030?ooo`3<o`00c?l000D0c?l0F@3oool00`000000oooo0?ooo`070?ooo`00F03oool0
0`000000oooo0?ooo`2d0?ooo`L0c03oXP3oool60?l00<H0oooo@03o0<LS0?ooo`@0c?l000<0oooo
0<co003<o`001@3<o`020?ooo`L0c?l000<0oooo0<co003<o`001@3<o`000`3oool0c?l00<co0006
0<co00030?ooo`3<o`00c?l000D0c?l000<0oooo0<co003<o`001@3<o`020?ooo`L0c?l000@0oooo
0<co003<o`00c?l0MP3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`2d
0?ooo`H0c03oX@3oool60?l00;P0oooo=P3o0<L/0?ooo`@0c?l000<0oooo0<co003<o`001P3<o`00
0`3oool0c?l00<co00050<co00030?ooo`3<o`00c?l000D0c?l00P3oool70<co00030?ooo`3<o`00
c?l000D0c?l000<0oooo0<co003<o`001P3<o`000`3oool0c?l00<co00050<co08/0oooo00<00000
0?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0]@3oool40<`0oj80oooo103o002Z0?oo
oc00o`37;P3oool70<co0080oooo1`3<o`000`3oool0c?l00<co00050<co00030?ooo`3<o`00c?l0
00H0c?l000<0oooo0<co003<o`001@3<o`000`3oool0c?l00<co00050<co0080oooo1`3<o`2T0?oo
o`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0;H0oooo00<0c03o0?ooo`3o
ool0XP3oool30?l009/0oooo<03o0<L]0?ooo`P0c?l000<0oooo0<co003<o`001@3<o`000`3oool0
c?l00<co00050<co0080oooo1`3<o`000`3oool0c?l00<co00050<co00030?ooo`3<o`00c?l000H0
c?l000@0oooo0<co003<o`00c?l0^@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000
oooo0?ooo`2^0?ooo`80c03oo`3ooolm0?ooobd0o`37;@3oool70<co00030?ooo`3<o`00c?l000D0
c?l000<0oooo0<co003<o`001P3<o`000`3oool0c?l00<co00050<co00030?ooo`3<o`00c?l000D0
c?l00P3oool70<co00040?ooo`3<o`00c?l00<co0<X0oooo00<000000?ooo`3oool01`3oool005P0
oooo00<000000?ooo`3oool0[P3oool30<`0ool0oooo<P3ooolW0?l0ab`0oooo1`3<o`000`3oool0
c?l00<co00050<co0080oooo1`3<o`000`3oool0c?l00<co00050<co00030?ooo`3<o`00c?l000H0
c?l000<0oooo0<co003<o`001@3<o`3O0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000
003oool0oooo0:d0oooo1@3<0?oo0?ooobL0oooo8@3o0<L^0?ooo`@0c?l00P3oool70<co00030?oo
o`3<o`00c?l000D0c?l000<0oooo0<co003<o`001@3<o`020?ooo`L0c?l000<0oooo0<co003<o`00
1@3<o`3`0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0:`0oooo1@3<
0?oo0?oooah0oooo7P3o0<L`0?ooo`L0c?l000<0oooo0<co003<o`001@3<o`020?ooo`L0c?l000<0
oooo0<co003<o`001@3<o`000`3oool0c?l00<co00050<co0?l0oooo0P3oool00`000000oooo0?oo
o`070?ooo`00F03oool400000:X0oooo1P3<0?oo0?oooa@0oooo7P3o0<L/0?ooo`@0c?l000<0oooo
0<co003<o`001P3<o`000`3oool0c?l00<co00050<co00030?ooo`3<o`00c?l000D0c?l00P3oool7
0<co0?l0oooo3`3oool4000000T0oooo001H0?ooo`030000003oool0oooo0:/0oooo1@3<0?oo0?oo
o`/0oooo7P3o0<L[0?ooo`L0c?l000<0oooo0<co003<o`001@3<o`000`3oool0c?l00<co00060<co
00030?ooo`3<o`00c?l000D0c?l000@0oooo0<co003<o`00c?l0o`3ooolO0?ooo`030000003oool0
oooo00L0oooo001H0?ooo`030000003oool0oooo0:X0oooo1@3<0?oo0?ooo`80oooo7P3o0<LT0?oo
o`L0c?l000<0oooo0<co003<o`001@3<o`020?ooo`L0c?l000<0oooo0<co003<o`001@3<o`000`3o
ool0c?l00<co00060<co0?l0oooo:`3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000
oooo0?ooo`2Y0?ooo`D0c03on03ooolN0?l0abD0oooo203<o`000`3oool0c?l00<co00050<co0003
0?ooo`3<o`00c?l000D0c?l00P3oool70<co00040?ooo`3<o`00c?l00<co0?l0oooo>03oool00`00
0000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`2Y0?ooo`D0c03ol03ooolL0?l0abL0
oooo1`3<o`000`3oool0c?l00<co00060<co00030?ooo`3<o`00c?l000D0c?l000<0oooo0<co003<
o`001@3<o`3o0?ooo`80oooo00<0okmd0000001d_ol0@03oool00`000000oooo0?ooo`070?ooo`00
F03oool00`000000oooo0?ooo`2X0?ooo`D0c03ojP3ooolI0?l0ab@0oooo103<o`000`3oool0c?l0
0<co00050<co00030?ooo`3<o`00c?l000D0c?l000<0oooo0<co003<o`001P3<o`3o0?oooa80oooo
00<0okmd0000001d_ol0@03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?oo
o`2Y0?ooo`<0c03oi@3ooolE0?l0abD0oooo103<o`000`3oool0c?l00<co00060<co00030?ooo`3<
o`00c?l000D0c?l000<0oooo0<co003<o`001@3<o`3o0?oooa/0oooo00<0okmd0000001d_ol0@03o
ool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`2Z0?ooo`80c03ogP3ooolD
0?l0abD0oooo103<o`000`3oool0c?l00<co00050<co00030?ooo`3<o`00c?l000H0c?l000<0oooo
0<co003<o`001@3<o`3o0?oooah0oooo00<0gia80000000000001@0000000`0004P0W=oo0?ooo`0m
0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0ooooQ03ooolD0?l0
ab00oooo1`3<o`020?ooo`L0c?l000<0oooo0<co003<o`001@3<o`000`3oool0c?l00<co00020<co
0?l0oooo:P3oool00`3ogi`0B7Bo0?ooo`020?ooo`030?noM0000000M;oo0400oooo00<000000?oo
o`3oool01`3oool005P0oooo00<000000?ooo`3oool0Y03oool20<`0omL0oooo503o0<LN0?ooo`L0
c?l000<0oooo0<co003<o`001@3<o`020?ooo`L0c?l000@0oooo0<co003<o`00c?l0o`3ooold0?oo
o`070=nLB01d_ol0oooo0?ooo`3o_g@0000007Boo`100?ooo`030000003oool0oooo00L0oooo001H
0?ooo`030000003oool0oooo0:@0oooo0`3<0?o?0?oooa@0o`377@3oool70<co00030?ooo`3<o`00
c?l000D0c?l000<0oooo0<co003<o`001@3<o`020?ooo`<0c?l0o`3oooll0?ooo`070?oo_`1d07@0
_ooo0?ooo`3o_g@0000007Boo`100?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003o
ool0oooo0:<0oooo1@3<0?o70?oooa@0o`376`3oool70<co0080oooo1`3<o`000`3oool0c?l00<co
00050<co0?l0ooooBP3oool01P3o_g@007Bo0?ooo`3o_g@0000007Bood00oooo00<000000?ooo`3o
ool01`3oool005P0oooo00<000000?ooo`3oool0XP3oool50<`0ol80oooo503o0<LI0?ooo`L0c?l0
00<0oooo0<co003<o`001@3<o`020?ooo`L0c?l0o`3ooomC0?ooo`050;md001d_ol0okmd0000001d
_ol0@03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`2Q0?ooo`H0c03o
^`3ooolD0?l0aa/0oooo103<o`000`3oool0c?l00<co00050<co00030?ooo`3<o`00c?l000D0c?l0
o`3ooomL0?ooo`050?oo_`1d07@0_kmd0000001d_ol0@03oool00`000000oooo0?ooo`070?ooo`00
F03oool00`000000oooo0?ooo`2P0?ooo`H0c03o]@3ooolD0?l0aaT0oooo103<o`020?ooo`L0c?l0
00<0oooo0<co003<o`001@3<o`3o0?ooofD0oooo00@0okmd000000000000M;oo@03oool00`000000
oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`2O0?ooo`H0c03o/03ooolD0?l0aaL0oooo
103<o`000`3oool0c?l00<co00050<co0080oooo1`3<o`3o0?ooofd0oooo00@0oooO09a800000000
M;oo@03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`2N0?ooo`H0c03o
[03ooolB0?l0aa/0oooo1`3<o`000`3oool0c?l00<co00050<co0080oooo0`3<o`3o0?ooog80oooo
00<0omnL04P0001d_ol0@03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?oo
o`2N0?ooo`D0c03oZ@3oool?0?l0aaX0oooo1`3<o`000`3oool0c?l00<co00050<co00040?ooo`3<
o`00c?l00<co0?l0oooo_P3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?oo
o`2M0?ooo`D0c03oYP3oool=0?l0aaX0oooo103<o`020?ooo`L0c?l000@0oooo0<co003<o`00c?l0
o`3oooo60?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo09h0oooo0`3<
0?nH0?ooo`<0o`00203oool<0?l0aaL0oooo103<o`000`3oool0c?l00<co00050<co0080oooo1`3<
o`3o0?ooolX0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0W`3oool2
0<`0oiL0oooo1@3o00030?ooo``0o`37603oool70<co00030?ooo`3<o`00c?l000D0c?l0o`3ooooC
0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0oooo>03oool40?l0
0080oooo2`3o0<LD0?ooo`L0c?l000<0oooo0<co003<o`001@3<o`00103oool0c?l00<co003<o`3o
0?ooomL0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0V@3oool20<`0
oi/0oooo0`3o000;0?l0a`l0oooo203<o`000`3oool0c?l00<co00050<co00040?ooo`3<o`00c?l0
0<co0?l0oooog`3oool00`000000oooo0?ooo`070?ooo`00F03oool4000009P0oooo0`3<0?nI0?oo
o`/0o`373P3oool40<co00030?ooo`3<o`00c?l000H0c?l000<0oooo0<co003<o`001@3<o`3o0?oo
on00oooo100000090?ooo`00F03oool00`000000oooo0?ooo`2H0?ooo`D0c03oU03oool<0?l0a`h0
oooo1`3<o`000`3oool0c?l00<co00060<co0?l0ooooj`3oool00`000000oooo0?ooo`070?ooo`00
F03oool00`000000oooo0?ooo`2G0?ooo`D0c03oT@3oool<0?l0a`d0oooo103<o`000`3oool0c?l0
0<co00050<co0?l0oooom03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?oo
o`2F0?ooo`H0c03oS@3oool<0?l0a`030?l0003oool0oooo00/0oooo1`3<o`00103oool0c?l00<co
003<o`3o0?ooooP0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0U@3o
ool60<`0oh/0oooo2`3o0<L40?l000T0oooo103<o`000`3oool0c?l00<co00050<co0?l0ooooo03o
ool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`2D0?ooo`H0c03oR03oool;
0?l0a`80oooo103o00080?ooo`L0c?l000@0oooo0<co003<o`00c?l0o`3ooooo0?ooo`40oooo00<0
00000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0T`3oool60<`0ohD0oooo2`3o0<L5
0?ooo`@0o`00103oool40<co00030?ooo`3<o`00c?l000D0c?l0o`3ooooo0?ooo`D0oooo00<00000
0?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0T`3oool50<`0oh80oooo303o0<L70?oo
o`@0o`000P3oool70<co00040?ooo`3<o`00c?l00<co0?l0ooooo`3oool90?ooo`030000003oool0
oooo00L0oooo001H0?ooo`030000003oool0oooo0980oooo1@3<0?mo0?ooo``0o`372P3oool20?l0
00@0c?l000<0oooo0<co003<o`001@3<o`3o0?ooool0oooo3@3oool00`000000oooo0?ooo`070?oo
o`00F03oool00`000000oooo0?ooo`2C0?ooo`<0c03oO@3oool;0?l0a``0oooo203<o`00103oool0
c?l00<co003<o`3o0?ooool0oooo4@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000
oooo0?ooo`2D0?ooo`80c03oN@3oool;0?l0a`/0oooo103<o`000`3o0000c?l00<co00060<co0?l0
ooooo`3ooolE0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0?l0oooo
303oool;0?l0a``0oooo1`3<o`000`3o0000c?l00<co00020<co0?l0ooooo`3ooolI0?ooo`030000
003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo08h0oooo0P3<0?mg0?ooo``0o`372P3o
ool40<co00030?ooo`3<o`00c?l000D0c?l00P3o003o0?ooool0oooo703oool00`000000oooo0?oo
o`070?ooo`00F03oool00`000000oooo0?ooo`2>0?ooo`<0c03oLP3oool<0?l0a`/0oooo1`3<o`00
1@3oool0c?l00<co003<o`00oooo00@0o`00o`3ooooo0?oooad0oooo00<000000?ooo`3oool01`3o
ool005P0oooo00<000000?ooo`3oool0S@3oool50<`0ofh0oooo2`3o0<L:0?ooo`@0c?l000<0oooo
0<co003<o`001@3<o`040?ooo`@0o`00o`3ooooo0?oooah0oooo00<000000?ooo`3oool01`3oool0
05P0oooo00<000000?ooo`3oool0S03oool50<`0of`0oooo2P3o0<L;0?ooo`L0c?l000@0oooo0<co
003<o`00c?l01`3oool40?l00?l0ooooo`3ooolO0?ooo`030000003oool0oooo00L0oooo001H0?oo
o`030000003oool0oooo08/0oooo1P3<0?mZ0?ooo`P0o`372P3oool40<co00030?ooo`3<o`00c?l0
00D0c?l02P3oool40?l00?l0ooooo`3ooolP0?ooo`030000003oool0oooo00L0oooo001H0?ooo`03
0000003oool0oooo08/0oooo1@3<0?mX0?ooo`T0o`372@3oool70<co00040?ooo`3<o`00c?l00<co
00`0oooo1@3o003o0?ooool0oooo8@3oool00`000000oooo0?ooo`070?ooo`00@`3oool00`3o_g@0
00000000000200000003001d_`3oool0oooo00d0oooo00<000000?ooo`3oool0RP3oool50<`0ofL0
oooo203o0<L70?ooo`@0c?l000<0oooo0<co003<o`001@3<o`0?0?ooo`D0o`00o`3ooooo0?ooob80
oooo00<000000?ooo`3oool01`3oool004D0oooo00<0_g@00000M02oool0403oool00`000000oooo
0?ooo`290?ooo`D0c03oI@3oool90?l0a`H0oooo1`3<o`00103oool0c?l00<co003<o`0B0?ooo`@0
o`00o`3ooooo0?ooob@0oooo00<000000?ooo`3oool01`3oool004D0oooo00<0_g@00000M02oool0
403oool00`000000oooo0?ooo`290?ooo`D0c03oH`3oool80?l0a`@0oooo103<o`000`3oool0c?l0
0<co00050<co01D0oooo103o003o0?ooool0oooo9@3oool00`000000oooo0?ooo`070?ooo`00A@3o
ool00`2oM000001d0;ooo`0@0?ooo`030000003oool0oooo08P0oooo1@3<0?mQ0?ooo`T0o`370`3o
ool70<co00040?ooo`3<o`00c?l00<co01P0oooo103o003o0?ooool0oooo9P3oool00`000000oooo
0?ooo`070?ooo`00A@3oool00`2oM000001d0;ooo`0@0?ooo`030000003oool0oooo08T0oooo0`3<
0?mP0?ooo`P0o`371P3oool70<co01/0oooo103o003o0?ooool0oooo9`3oool00`000000oooo0?oo
o`070?ooo`00A@3oool00`2oM000001d0;ooo`0@0?ooo`030000003oool0oooo08X0oooo0P3<0?mM
0?ooo`T0o`370`3oool40<co00040?ooo`3<o`00c?l00<co01h0oooo103o003o0?ooool0oooo:03o
ool00`000000oooo0?ooo`070?ooo`00A@3oool00`2oM000001d0;ooo`0@0?ooo`H00000i03oool8
0?l0a`<0oooo1`3<o`0P0?ooo`D0o`00o`3ooooo0?ooob@0oooo1P0000090?ooo`00A@3oool00`2o
M000001d0;ooo`0@0?ooo`030000003oool0oooo0>@0oooo2@3o0<L50?ooo`L0c?l08@3oool30?l0
0?l0ooooo`3ooolZ0?ooo`030000003oool0oooo00L0oooo00150?ooo`030;md000007@0_ooo0100
oooo00<000000?ooo`3oool0QP3oool00`3<0?l0oooo0?ooo`1I0?ooo`P0o`370`3oool40<co0004
0?ooo`3<o`00c?l00<co0?l0ooooo`3ooomB0?ooo`030000003oool0oooo00L0oooo00150?ooo`03
0;md000007@0_ooo0100oooo00<000000?ooo`3oool0Q@3oool40<`0oeH0oooo2@3o0<L20?ooo`L0
c?l0o`3ooooo0?oooeH0oooo00<000000?ooo`3oool01`3oool004D0oooo00<0_g@00000M02oool0
403oool00`000000oooo0?ooo`240?ooo`D0c03oE03oool80?l0a`050?ooo`3<o`00c?l00<co003o
ool01`3<o`3o0?ooool0ooooEP3oool00`000000oooo0?ooo`070?ooo`00@`3oool01@3OW4P00000
0000000007@0_ooo0100oooo00<000000?ooo`3oool0Q03oool40<`0oe80oooo2@3o0<L00`3oool0
c?l00<co00030<co00040?ooo`3<o`00c?l00<co0?l0ooooo`3ooomJ0?ooo`030000003oool0oooo
00L0oooo00140?ooo`040?oo_`1d0000001d0;oooa00oooo00<000000?ooo`3oool0P`3oool40<`0
oe40oooo203o0<L20?ooo`L0c?l0o`3ooooo0?oooeh0oooo00<000000?ooo`3oool01`3oool005P0
oooo00<000000?ooo`3oool0P`3oool40<`0odl0oooo203o0<L30<co00030?ooo`3<o`00c?l000<0
c?l0o`3ooooo0?ooof00oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0
PP3oool40<`0odh0oooo1`3o0<L00`3oool0c?l00<co00030<co00040?ooo`3<o`00c?l00<co0?l0
ooooo`3ooomR0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0880oooo
103<0?m=0?ooo`H0o`3700<0oooo0<co003<o`001@3<o`3o0?ooool0ooooIP3oool00`000000oooo
0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`210?ooo`@0c03oC03oool60?l0a`80c?l000<0
oooo0<co003<o`000`3<o`3o0?ooool0ooooJ03oool00`000000oooo0?ooo`070?ooo`00F03oool0
0`000000oooo0?ooo`200?ooo`D0c03oBP3oool60?l0a`@0c?l000@0oooo0<co003<o`00c?l0o`3o
oooo0?ooofX0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0P03oool4
0<`0odT0oooo1`3o0<L50<co0?l0ooooo`3ooom^0?ooo`030000003oool0oooo00L0oooo001H0?oo
o`030000003oool0oooo0880oooo00<0c03o0?ooo`3oool0AP3oool70?l0a`D0c?l0o`3ooooo0?oo
og00oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0bP3oool60?l0a`D0
c?l0o`3ooooo0?ooog80oooo00<000000?ooo`3oool01`3oool001d0oooo00<0oooO09a8B02Lgol0
>03oool00`000000oooo0?ooo`380?ooo`H0o`37103<o`3o0?ooool0ooooM@3oool00`000000oooo
0?ooo`070?ooo`00703oool00`3ookl0M01809cOo`0i0?ooo`030000003oool0oooo0<H0oooo1P3o
0<L60<co0?l0ooooo`3ooome0?ooo`030000003oool0oooo00L0oooo000K0?ooo`030?oOW01807@0
_ooo03X0oooo00<000000?ooo`3oool0OP3oool00`3<0?l0oooo0?ooo`130?ooo`L0o`371@3<o`3o
0?ooool0ooooM`3oool00`000000oooo0?ooo`070?ooo`004P3oool00`3OW9`0_ooo0?ooo`050?oo
o`030?oOW018B9`0gooo03/0oooo00<000000?ooo`3oool0O@3oool40<`0od40oooo1`3o0<L00`3<
o`00oooo0<co00020<co0?l0ooooo`3ooomi0?ooo`030000003oool0oooo00L0oooo000A0?ooo`03
0?oog`2LB7@0_ooo00D0oooo00<0omnL04Q8W03Oool0?03oool00`000000oooo0?ooo`1l0?ooo`D0
c03o?`3oool70?l0a`<0c?l0o`3ooooo0?ooogd0oooo00<000000?ooo`3oool01`3oool00140oooo
00<0oono07@000000000100000000`00B4P0B01d0;ooo`0m0?ooo`030000003oool0oooo07`0oooo
103<0?lo0?ooo`H0o`371@3<o`3o0?ooool0ooooO@3oool00`000000oooo0?ooo`070?ooo`00503o
ool00`3o_g@00000000000070000000304RLg`3oool0oooo03L0oooo00<000000?ooo`3oool0N`3o
ool40<`0och0oooo1P3o0<L50<co0?l0ooooo`3ooomo0?ooo`030000003oool0oooo00L0oooo000F
0?ooo`030?oog`2LB4P0W=oo0080oooo00D0_g@0000000000000001809cOo`0h0?ooo`030000003o
ool0oooo07/0oooo103<0?ll0?ooo`H0o`3700<0c?l00?ooo`3<o`000P3<o`3o0?ooool0ooooP@3o
ool00`000000oooo0?ooo`070?ooo`005@3oool00`3ooml0W4Q809cOo`050?ooo`030?oOW018B9`0
gooo03P0oooo00<000000?ooo`3oool0NP3oool40<`0oc/0oooo1`3o0<L20<co0?l0ooooo`3ooon5
0?ooo`030000003oool0oooo00L0oooo000D0?ooo`030?oog`2LB4P0W=oo00D0oooo00<0oono07@0
M02oool0>@3oool4000007T0oooo103<0?li0?ooo`L0o`370P3<o`3o0?ooool0ooooQ03oool40000
00T0oooo000C0?ooo`030?oo_`1d04P0W=oo0480oooo00<000000?ooo`3oool0N@3oool40<`0ocT0
oooo1P3o0<L30<co0?l0ooooo`3ooon80?ooo`030000003oool0oooo00L0oooo000B0?ooo`030?no
M00007@0_ooo04<0oooo00<000000?ooo`3oool0N03oool50<`0ocL0oooo1P3o0<L00`3<o`00oooo
0?ooo`3o0?ooool0ooooRP3oool00`000000oooo0?ooo`070?ooo`004@3oool00`3ookl0M7Bo0?oo
o`140?ooo`030000003oool0oooo07P0oooo103<0?lf0?ooo`H0o`370`3<o`100?ooo`030?l0003o
ool0oooo0?l0ooooo`3ooom90?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0
oooo07X0oooo00<0c03o0?ooo`3oool0<`3oool70?l0a`80c?l0@P3oool20?l00?l0ooooo`3ooom:
0?ooo`030000003oool0oooo00L0oooo000:0?ooo`030=nLB000B9`0gooo00@0oooo00<0giad04Q8
M02oool0A03oool00`000000oooo0?ooo`2_0?ooo`H0o`370P3<o`130?ooo`<0o`00o`3ooooo0?oo
odX0oooo00<000000?ooo`3oool01`3oool000T0oooo00<0okmd001d_`3oool0103oool0102oM000
B9bL07@0M02ooom40?ooo`030000003oool0oooo0:h0oooo1@3o0<M60?ooo`@0o`00o`3ooooo0?oo
odX0oooo00<000000?ooo`3oool01`3oool000T0oooo00<0gia804RLg`3oool00P3oool01P3ooml0
W4P007Boo`3ookl0M01d0;oood@0oooo00<000000?ooo`3oool0[@3oool40?l0a`80c?l0A@3oool4
0?l00?l0ooooo`3ooom;0?ooo`030000003oool0oooo00L0oooo00090?ooo`0;0?noM00004P0W=oo
0?ooo`3o_g@0001809cOo`3oool0omnL04P0M02oool0A03oool00`000000oooo0?ooo`1f0?ooo`03
0<`0o`3oool0oooo03<0oooo103o0<L00`3<o`00oooo0?ooo`140?ooo`@0o`00o`3ooooo0?oood`0
oooo00<000000?ooo`3oool01`3oool000X0oooo00@0gia800000000000007Bo0P3oool0103ooml0
W4P00018W03Ooom40?ooo`030000003oool0oooo07D0oooo103<0?lb0?ooo`@0o`3700<0c?l00?oo
o`3oool0A03oool40?l00?l0ooooo`3ooom=0?ooo`030000003oool0oooo00L0oooo001H0?ooo`03
0000003oool0oooo07@0oooo1@3<0?la0?ooo`@0o`37A`3oool40?l00?l0ooooo`3ooom>0?ooo`03
0000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo07@0oooo103<0?l`0?ooo`D0o`37
A`3oool40?l00?l0ooooo`3ooom?0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003o
ool0oooo07<0oooo103<0?l_0?ooo`030<co003o0<L0o`3700<0o`3700<0c?l00?ooo`3oool0A@3o
ool30?l00?l0ooooo`3ooom@0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0
oooo07<0oooo103<0?l_0?ooo`@0o`3700<0c?l00?ooo`3oool0AP3oool30?l00?l0ooooo`3ooomA
0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0780oooo103<0?l_0?oo
o`@0o`37B@3oool40?l00?l0ooooo`3ooomA0?ooo`030000003oool0oooo00L0oooo001H0?ooo`03
0000003oool0oooo0780oooo103<0?l]0?ooo`030<co003o0<L0o`370080o`37B@3oool40?l00?l0
ooooo`3ooomB0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0740oooo
103<0?l/0?ooo`80c?l0103o0<M90?ooo`@0o`00o`3ooooo0?oooe<0oooo00<000000?ooo`3oool0
1`3oool005P0oooo00<000000?ooo`3oool0L03oool50<`0obX0oooo0`3<o`040?l0adT0oooo103o
003o0?ooool0ooooE03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1`
0?ooo`@0c03o:`3oool00`3<o`00o`370?l0a`030?l0adT0oooo103o003o0?ooool0ooooE@3oool0
0`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1b0?ooo`030<`0o`3oool0oooo
02X0oooo1@3o0<M90?ooo`@0o`00o`3ooooo0?oooeH0oooo00<000000?ooo`3oool01`3oool005P0
oooo00<000000?ooo`3oool0W03oool20<co00@0o`37B`3oool30?l00?l0ooooo`3ooomG0?ooo`03
0000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo09/0oooo0P3<o`040?l0ad/0oooo
0`3o003o0?ooool0ooooF03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?oo
o`2I0?ooo`<0c?l0103o0<M;0?ooo`@0o`00o`3ooooo0?oooeP0oooo00<000000?ooo`3oool01`3o
ool005P0oooo1000001^0?ooo`030<`0o`3oool0oooo02L0oooo0P3<o`040?l0ad/0oooo103o003o
0?ooool0ooooEP3oool4000000T0oooo001H0?ooo`030000003oool0oooo06h0oooo103<0?lW0?oo
o`030<co003o0<L0o`370080o`37B`3oool40?l00?l0ooooo`3ooomJ0?ooo`030000003oool0oooo
00L0oooo001H0?ooo`030000003oool0oooo06d0oooo1@3<0?lS0?ooo`<0c?l01@3o0<M;0?ooo`@0
o`00o`3ooooo0?oooe/0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0
K@3oool40<`0ob<0oooo0`3<o`050?l0ad/0oooo103o003o0?ooool0ooooG03oool00`000000oooo
0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1/0?ooo`@0c03o603oool:0?l000@0c?l0103o
0<M<0?ooo`@0o`00o`3ooooo0?oooed0oooo00<000000?ooo`3oool01`3oool005P0oooo00<00000
0?ooo`3oool0K03oool40<`0oa@0oooo103o000:0?ooo`<0c?l0103o0<L40?l004T0oooo0`3o003o
0?ooool0ooooGP3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1[0?oo
o`@0c03o4@3oool40?l000h0oooo0P3<o`040?l0a`D0oooo1P3o00120?ooo`<0o`00o`3ooooo0?oo
oel0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0J`3oool40<`0o`h0
oooo0`3o000>0?ooo`<0c?l00P3oool40?l0a``0oooo0P3o000o0?ooo`@0o`00o`3ooooo0?oooel0
oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0JP3oool40<`0oal0oooo
103<o`000`3oool0o`370?l0a`020?l0a`l0oooo0P3o000l0?ooo`@0o`00o`3ooooo0?ooof00oooo
00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0J@3oool50<`0oad0oooo1@3<
o`050?l0add0oooo103o003o0?ooool0ooooH@3oool00`000000oooo0?ooo`070?ooo`00F03oool0
0`000000oooo0?ooo`1Y0?ooo`@0c03o7P3oool40<co00D0o`376P3oool20?l00340oooo103o003o
0?ooool0ooooHP3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1[0?oo
o`030<`0o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0403oool00`3<o`00oooo0<co00020<co
00@0o`377P3oool20?l002h0oooo103o003o0?ooool0ooooH`3oool00`000000oooo0?ooo`070?oo
o`00F03oool00`000000oooo0?ooo`1e0?ooo`030?l0003oool0oooo0100oooo0`3<o`020?ooo`@0
o`378@3oool20?l002/0oooo103o003o0?ooool0ooooI03oool00`000000oooo0?ooo`070?ooo`00
F03oool00`000000oooo0?ooo`1c0?ooo`80o`004P3oool40<co00030?ooo`3o0<L0o`370080o`37
903oool20?l002T0oooo0`3o003o0?ooool0ooooI@3oool00`000000oooo0?ooo`070?ooo`00F03o
ool00`000000oooo0?ooo`1b0?ooo`030?l0003oool0oooo0140oooo103<o`000`3oool0o`370?l0
a`020?l0abL0oooo0P3o000W0?ooo`80o`00o`3ooooo0?ooofH0oooo00<000000?ooo`3oool01`3o
ool005P0oooo00<000000?ooo`3oool0I`3oool00`3<0?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo0140oooo103<o`000`3oool0o`370?l0a`020?l0abX0oooo0P3o000V0?ooo`030?l0003oool0
oooo0?l0ooooo`3ooomT0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo
06H0oooo103<0?l60?ooo`030?l0003oool0oooo0140oooo103<o`050?l0abd0oooo0P3o003o0?oo
ool0ooooR`3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1U0?ooo`D0
c03o103oool20?l001<0oooo00D0c?l00?ooo`3<o`00c?l00?ooo`040?l0ac00oooo0P3o003o0?oo
ool0ooooR@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1U0?ooo`@0
c03o103oool00`3o0000oooo0?ooo`0B0?ooo`<0c?l00P3oool30?l0ac@0oooo0P3o003o0?ooool0
ooooQ`3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1T0?ooo`@0c03o
103oool00`3o0000oooo0?ooo`0B0?ooo`@0c?l000<0oooo0?l0a`3o0<L00P3o0<Lf0?ooo`80o`00
o`3ooooo0?ooohD0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0I03o
ool40<`0o`<0oooo00<0o`000?ooo`3oool04P3oool40<co00030?ooo`3o0<L0o`370080o`37>@3o
ool20?l00?l0ooooo`3ooon30?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0
oooo06<0oooo103<0?l30?ooo`030?l0003oool0oooo0180oooo103<o`000`3oool0o`370?l0a`02
0?l0ac`0oooo0P3o003o0?ooool0ooooP@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`00
0000oooo0?ooo`1S0?ooo`@0c03o00<0oooo0?l0003o0000503oool40<co00030?ooo`3o0<L0o`37
0080o`37?`3oool20?l00?l0ooooo`3ooomo0?ooo`030000003oool0oooo00L0oooo001H0?ooo`03
0000003oool0oooo0680oooo103<0?l00`3oool0o`000?ooo`0D0?ooo`040<co003oool0c?l00<co
0080oooo0`3o0<M20?ooo`80o`00o`3ooooo0?ooogd0oooo00<000000?ooo`3oool01`3oool005P0
oooo1000001P0?ooo`D0c03o00<0o`000?ooo`3oool04`3oool30<co00<0oooo0`3o0<M50?ooo`80
o`00o`3ooooo0?ooogP0oooo100000090?ooo`00F03oool00`000000oooo0?ooo`1Q0?ooo`@0c03o
00<0o`000?ooo`3oool04`3oool40<co0080oooo103o0<M70?ooo`80o`00o`3ooooo0?ooogT0oooo
00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0H`3oool20?l001D0oooo103<
o`020?ooo`@0o`37BP3oool20?l00?l0ooooo`3ooomg0?ooo`030000003oool0oooo00L0oooo001H
0?ooo`030000003oool0oooo0680oooo00<0o`000?ooo`3oool0503oool40<co0080oooo103o0<M=
0?ooo`80o`00o`3ooooo0?ooogD0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?oo
o`3oool0H@3oool00`3o0000oooo0?ooo`0D0?ooo`@0c?l00P3oool40?l0ae00oooo0P3o003o0?oo
ool0ooooL`3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1P0?ooo`03
0?l0003oool0oooo01H0oooo0P3<o`030?ooo`<0o`37D`3oool00`3o0000oooo0?ooo`3o0?ooool0
ooooL03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1O0?ooo`030<`0
o`3o0000oooo01@0oooo0`3<o`040?ooo`<0o`37o`3ooooo0?ooolL0oooo00<000000?ooo`3oool0
1`3oool005P0oooo00<000000?ooo`3oool0GP3oool00`3<0?l0o`000<`0o`020<`0oa<0oooo0`3<
o`030?ooo`@0o`37o`3ooooo0?ooolL0oooo00<000000?ooo`3oool01`3oool005P0oooo00<00000
0?ooo`3oool0GP3oool00`3<0?l0o`000<`0o`020<`0oa80oooo103<o`020?ooo`@0o`37o`3ooooo
0?ooolP0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0GP3oool0103o
0000c03o0<`0o`3<0?lB0?ooo`@0c?l00P3oool40?l0aol0ooooo`3oooo90?ooo`030000003oool0
oooo00L0oooo001H0?ooo`030000003oool0oooo05d0oooo00<0c03o0?l0003<0?l00P3<0?lB0?oo
o`<0c?l00P3oool40?l0aeh0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooofT0oooo00<000000?oo
o`3oool01`3oool005P0oooo00<000000?ooo`3oool0G@3oool00`3o0000c03o0<`0o`020<`0oa80
oooo0`3<o`000`3oool0o`370?l0a`020?l0af00oooo0P3o003o0?ooool0ooooJ@3oool00`000000
oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1M0?ooo`040?l0003<0?l0c03o0<`0oaL0
oooo0`3o0<MS0?ooo`030?l0003oool0oooo0?l0ooooo`3ooomV0?ooo`030000003oool0oooo00L0
oooo001H0?ooo`030000003oool0oooo05`0oooo00<0o`000<`0o`3<0?l00P3<0?l@0?ooo`<0c?l0
0`3oool40?l0af@0oooo0P3o003o0?ooool0ooooIP3oool00`000000oooo0?ooo`070?ooo`00F03o
ool00`000000oooo0?ooo`1L0?ooo`030?l0003<0?l0c03o0080c03o403oool30<co0080oooo103o
0<MW0?ooo`030?l0003oool0oooo0?l0ooooo`3ooomS0?ooo`030000003oool0oooo00L0oooo001H
0?ooo`030000003oool0oooo05/0oooo00<0o`000<`0o`3<0?l00P3<0?l@0?ooo`@0c?l00P3oool3
0?l0afT0oooo0P3o003o0?ooool0ooooH`3oool00`000000oooo0?ooo`070?ooo`00F03oool00`00
0000oooo0?ooo`1K0?ooo`030?l0003<0?l0c03o0080c03o3`3oool40<co0080oooo103o0<M[0?oo
o`030?l0003oool0oooo0?l0ooooo`3ooomP0?ooo`030000003oool0oooo00L0oooo001H0?ooo`03
0000003oool0oooo05X0oooo00<0o`000<`0o`3<0?l00`3<0?l?0?ooo`<0c?l00`3oool30?l0afd0
oooo0P3o003o0?ooool0ooooH03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo
0?ooo`1J0?ooo`030?l0003oool0oooo0080c03o403oool30<co0080oooo103o0<M_0?ooo`030?l0
003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003o
ool0oooo06`0oooo0`3<o`040?ooo`@0o`37L@3oool20?l00?l0ooooo`3ooomM0?ooo`030000003o
ool0oooo00L0oooo001H0?ooo`030000003oool0oooo06`0oooo0`3<o`040?ooo`<0o`37M03oool0
0`3o0000oooo0?ooo`3o0?ooool0ooooFP3oool00`000000oooo0?ooo`070?ooo`00F03oool00`00
0000oooo0?ooo`1[0?ooo`@0c?l00`3oool40?l0agD0oooo0P3o003o0?ooool0ooooFP3oool00`00
0000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1J0?ooo`80c03o3`3oool30<co00@0
oooo0`3o0<MA0?ooo`<0o`00903oool20?l00?l0ooooo`3ooomH0?ooo`030000003oool0oooo00L0
oooo001H0?ooo`030000003oool0oooo05T0oooo1@3<0?l<0?ooo`@0c?l00`3oool40?l0ae40oooo
0`3o000V0?ooo`030?l0003oool0oooo0?l0ooooo`3ooomE0?ooo`030000003oool0oooo00L0oooo
001H0?ooo`@00000F03oool50<`0o``0oooo0`3<o`030?ooo`@0o`37D@3oool40?l002L0oooo0P3o
003o0?ooool0ooooDP3oool4000000T0oooo001H0?ooo`030000003oool0oooo05L0oooo00<0o`00
0?ooo`3<0?l00`3<0?l=0?ooo`<0c?l00`3oool30?l0ae40oooo103o000Z0?ooo`030?l0003oool0
oooo0?l0ooooo`3ooomB0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo
05L0oooo00<0o`000<`0o`3<0?l00`3<0?l:0?ooo`<0c?l01@3oool40?l0ae40oooo0`3o000/0?oo
o`80o`00o`3ooooo0?oooe80oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3o
ool0EP3oool00`3o0000oooo0<`0o`040<`0o`X0oooo0`3<o`040?ooo`@0o`37D@3oool40?l002h0
oooo00<0o`000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool01`3oool005P0oooo
00<000000?ooo`3oool0EP3oool00`3o0000oooo0<`0o`030<`0o`X0oooo103<o`040?ooo`<0o`37
D@3oool40?l00300oooo0P3o003o0?ooool0ooooC`3oool00`000000oooo0?ooo`070?ooo`00F03o
ool00`000000oooo0?ooo`1E0?ooo`030?l0003oool0c03o00@0c03o2@3oool40<co00@0oooo103o
0<MA0?ooo`<0o`00<`3oool00`3o0000oooo0?ooo`3o0?ooool0ooooC03oool00`000000oooo0?oo
o`070?ooo`00F03oool00`000000oooo0?ooo`1E0?ooo`030?l0003oool0c03o00@0c03o2@3oool3
0<co00D0oooo0`3o0<MA0?ooo`@0o`00=03oool20?l00?l0ooooo`3ooom<0?ooo`030000003oool0
oooo00L0oooo001H0?ooo`030000003oool0oooo05@0oooo00<0o`000?ooo`3oool0103<0?l:0?oo
o`<0c?l0103oool40?l0ae00oooo103o000g0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom90?oo
o`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo05@0oooo00<0o`000?ooo`3<
0?l0103<0?l@0?ooo`@0o`37D@3oool30?l003T0oooo0P3o003o0?ooool0ooooB@3oool00`000000
oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1C0?ooo`030?l0003oool0oooo00D0c03o
1`3oool30<co00H0oooo0`3o0<MA0?ooo`@0o`00>`3oool00`3o0000oooo0?ooo`3o0?ooool0oooo
AP3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1C0?ooo`030?l0003o
ool0oooo0080oooo0P3<0?l80?ooo`<0c?l01@3oool40?l0ae00oooo103o003o0?ooool0ooooQ@3o
ool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`1B0?ooo`030?l0003oool0
oooo00`0oooo103<o`050?ooo`<0o`37D@3oool30?l00?l0ooooo`3ooon60?ooo`030000003oool0
oooo00L0oooo001H0?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool02P3oool50<co
00D0oooo103o0<M@0?ooo`@0o`00o`3ooooo0?ooohH0oooo00<000000?ooo`3oool01`3oool005P0
oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`0;0?ooo`@0c?l01@3oool40?l0ae00
oooo103o003o0?ooool0ooooQ`3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo
0?ooo`1A0?ooo`040?l0003oool0oooo0?ooo`80c03o203oool40<co00D0oooo0`3o0<MA0?ooo`<0
o`00A@3oool00`3o0000oooo0?ooo`3o0?ooool0oooo@03oool00`000000oooo0?ooo`070?ooo`00
F03oool00`000000oooo0?ooo`1@0?ooo`040?l0003oool0oooo0?ooo`D0c03o3P3oool40?l0ae00
oooo103o00160?ooo`030?l0003oool0oooo0?l0ooooo`3ooolo0?ooo`030000003oool0oooo00L0
oooo001H0?ooo`030000003oool0oooo0500oooo00@0o`000?ooo`3oool0oooo1@3<0?l50?ooo`<0
c?l01@3oool40?l0ae00oooo103o00180?ooo`80o`00o`3ooooo0?ooocl0oooo00<000000?ooo`3o
ool01`3oool002X0oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3oool0gia80000
0018W=l0103oool0102oM000000000000018W=l40?ooo`060;md00000000000000000000B9`0gooo
403oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0080oooo103<0?l60?ooo`<0c?l0
1@3oool30?l0ae40oooo0`3o001;0?ooo`030?l0003oool0oooo0?l0ooooo`3oooll0?ooo`030000
003oool0oooo00L0oooo000/0?ooo`030;md000007@0_ooo00@0oooo00<0gia800000018W=l00P3o
ool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00P3oool00`3ooml0W4P004RLg`020?ooo`03
0?oOW018B9`0gooo00l0oooo00<000000?ooo`3oool0C`3oool0103o0000oooo0?ooo`3oool50<`0
o`D0oooo103<o`040?ooo`@0o`37D03oool40?l004`0oooo00<0o`000?ooo`3oool0o`3ooooo0?oo
oc/0oooo00<000000?ooo`3oool01`3oool002`0oooo00<0_g@00000M02oool02@3oool00`3o_g@0
001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<0omnL04Qd_`3oool03P3oool00`000000
oooo0?ooo`1>0?ooo`030?l0003oool0oooo0080oooo1@3<0?l40?ooo`@0c?l01@3oool30?l0ae00
oooo103o001>0?ooo`80o`00o`3ooooo0?oooc/0oooo00<000000?ooo`3oool01`3oool002`0oooo
00<0_g@00000M02oool0203oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00L0
oooo00<0oono07@0B02Lgol03P3oool00`000000oooo0?ooo`1>0?ooo`030?l0003oool0oooo0080
oooo103<0?l50?ooo`<0c?l01@3oool40?l0ae00oooo0`3o001A0?ooo`030?l0003oool0oooo0?l0
ooooo`3ooolh0?ooo`030000003oool0oooo00L0oooo000/0?ooo`030;md000007@0_ooo00P0oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`030?oo_`1d0000M;oo00h0oooo
00<000000?ooo`3oool0C@3oool00`3o0000oooo0?ooo`020?ooo`D0c03o1@3oool30<co00@0oooo
103o0<M@0?ooo`@0o`00DP3oool00`3o0000oooo0?ooo`3o0?ooool0oooo=`3oool00`000000oooo
0?ooo`070?ooo`00;03oool00`2oM000001d0;ooo`080?ooo`030?oOW0180000B9cO00@0oooo00<0
_g@00000M02oool01P3oool00`3o_g@0000007Boo`0>0?ooo`030000003oool0oooo04d0oooo00<0
o`000?ooo`3oool00P3oool50<`0o``0oooo0`3o0<M@0?ooo`@0o`00E03oool20?l00?l0ooooo`3o
oolg0?ooo`030000003oool0oooo00L0oooo000/0?ooo`030;md000007@0_ooo00P0oooo00<0omnL
04P00018W=l0103oool00`3OW4P0001809cOo`050?ooo`040?oOW0180000001d0;ooo`h0oooo1P00
00190?ooo`030?l0003oool0oooo00<0oooo103<0?l30?ooo`<0c?l01P3oool40?l0ae00oooo0`3o
001G0?ooo`030?l0003oool0oooo0?l0ooooo`3oool_0?ooo`H000002@3oool002`0oooo00<0_g@0
0000M02oool0203oool00`3ogi`0B00004RLg`040?ooo`050=nLB00004P0W=oo0?ooo`3Ogml00P3o
ool0102oM000000000000018W=l?0?ooo`030000003oool0oooo04`0oooo00<0o`000?ooo`3oool0
0P3oool50<`0o`<0oooo0`3<o`060?ooo`<0o`37D03oool40?l005P0oooo00<0o`000?ooo`3oool0
o`3ooooo0?oooc<0oooo00<000000?ooo`3oool01`3oool002`0oooo00<0_g@00000M02oool0203o
ool00`3ookl0M000001d_`040?ooo`050;md000007@0_ooo0?ooo`3o_g@0100000000`00M;l0oooo
0?ooo`0>0?ooo`030000003oool0oooo04/0oooo00<0o`000?ooo`3oool00`3oool50<`0o`80oooo
103<o`050?ooo`@0o`37C`3oool40?l005X0oooo0P3o003o0?ooool0oooo<`3oool00`000000oooo
0?ooo`070?ooo`00;03oool00`2oM000001d0;ooo`090?ooo`030;md0000B9`0gooo0080oooo00<0
oooO09a80000M;l00P3oool01@3ooml0W4P00000000007@0_ooo0140oooo00<000000?ooo`3oool0
B`3oool00`3o0000oooo0?ooo`050?ooo`80c03o0`3oool30<co00D0oooo103o0<M@0?ooo`<0o`00
G@3oool00`3o0000oooo0?ooo`3o0?ooool0oooo<03oool00`000000oooo0?ooo`070?ooo`00;03o
ool00`2oM000001d0;ooo`090?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@007Bo0?ooo`0B0?ooo`030000003oool0oooo04X0oooo00<0o`000?ooo`3oool02P3o
ool40<co00D0oooo0`3o0<M@0?ooo`@0o`00GP3oool00`3o0000oooo0?ooo`3o0?ooool0oooo;`3o
ool00`000000oooo0?ooo`070?ooo`00:P3oool01@3OW4P000000000000007@0_ooo00X0oooo00H0
_g@00018W03Oool0oooo0;md0000M;l40?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3o
ool03@3oool00`000000oooo0?ooo`1:0?ooo`030?l0003oool0oooo00T0oooo1@3<o`040?ooo`@0
o`37C`3oool40?l00600oooo00<0o`000?ooo`3oool0o`3ooooo0?ooobh0oooo00<000000?ooo`3o
ool01`3oool002/0oooo00@0oono07@0000007@0_ooo2`3oool0102oM000000000000000M;l60?oo
o`030?noM000000000000080000000<0M;oo0?ooo`3oool0303oool00`000000oooo0?ooo`190?oo
o`030?l0003oool0oooo00/0oooo0P3<o`060?ooo`<0o`37D03oool30?l00680oooo0P3o003o0?oo
ool0oooo;P3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`190?ooo`03
0?l0003oool0oooo00@0oooo0P3<0?l<0?ooo`@0o`37C`3oool40?l006@0oooo00<0o`000?ooo`3o
ool0o`3ooooo0?ooob/0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0
B@3oool00`3o0000oooo0?ooo`030?ooo`D0c03o0P3oool30<co00D0oooo0`3o0<M?0?ooo`@0o`00
IP3oool00`3o0000oooo0?ooo`3o0?ooool0oooo:P3oool00`000000oooo0?ooo`070?ooo`00F03o
ool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo00@0oooo1@3<0?l20?ooo`<0c?l0103o
ool40?l0adl0oooo0`3o001X0?ooo`80o`00o`3ooooo0?ooobX0oooo00<000000?ooo`3oool01`3o
ool005P0oooo00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`040?ooo`@0c03o0P3oool4
0<co00@0oooo0`3o0<M?0?ooo`@0o`00JP3oool00`3o0000oooo0?ooo`3o0?ooool0oooo9`3oool0
0`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo
00<0oooo1@3<0?l00`3oool0c?l00<co00020<co00@0oooo103o0<M?0?ooo`<0o`00K03oool00`3o
0000oooo0?ooo`3o0?ooool0oooo9P3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000
oooo0?ooo`170?ooo`030?l0003oool0oooo00@0oooo1@3<0?l0103oool0c?l00<co003<o`050?oo
o`<0o`37D03oool30?l006d0oooo0P3o003o0?ooool0oooo9P3oool00`000000oooo0?ooo`070?oo
o`00F03oool00`000000oooo0?ooo`170?ooo`030?l0003oool0oooo00@0oooo103<0?l20?ooo`<0
c?l0103oool40?l0al80oooo00<0o`000?ooo`3oool0o`3ooooo0?ooob<0oooo00<000000?ooo`3o
ool01`3oool005P0oooo00<000000?ooo`3oool0A`3oool00`3o0000oooo0?ooo`030?ooo`D0c03o
2@3oool30?l0al@0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooob80oooo00<000000?ooo`3oool0
1`3oool005P0oooo00<000000?ooo`3oool0A`3oool00`3o0000oooo0?ooo`030?ooo`D0c03o0`3<
o`050?ooo`@0o`37a@3oool20?l00?l0ooooo`3ooolR0?ooo`030000003oool0oooo00L0oooo001H
0?ooo`030000003oool0oooo04H0oooo00<0o`000?ooo`3oool0103oool40<`0o`040?ooo`3<o`00
c?l00<co00D0oooo0`3o0<O80?ooo`030?l0003oool0oooo0?l0ooooo`3ooolO0?ooo`030000003o
ool0oooo00L0oooo001H0?ooo`030000003oool0oooo04H0oooo00<0o`000?ooo`3oool00`3oool5
0<`0o`@0c?l0103oool40?l0alT0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooah0oooo00<00000
0?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0C03oool50<`0o`<0c?l01@3oool30?l0
aol0ooooo`3oooo[0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo04h0
oooo0P3<0?l40<co00@0oooo103o0<Oo0?ooool0ooooj`3oool00`000000oooo0?ooo`070?ooo`00
F03oool00`000000oooo0?ooo`1@0?ooo`<0c?l01@3oool30?l0aol0ooooo`3oooo/0?ooo`030000
003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0500oooo0`3<o`040?ooo`@0o`37o`3o
oooo0?ooon`0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0E`3oool3
0?l0am<0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooaL0oooo00<000000?ooo`3oool01`3oool0
05P0oooo00<000000?ooo`3oool0B`3oool20<`0o`80oooo0`3<o`050?ooo`<0o`37e03oool00`3o
0000oooo0?ooo`3o0?ooool0oooo5P3oool00`000000oooo0?ooo`070?ooo`00F03oool4000004T0
oooo1@3<0?l30<co00@0oooo103o0<OE0?ooo`80o`00o`3ooooo0?oooa<0oooo100000090?ooo`00
F03oool00`000000oooo0?ooo`140?ooo`030?l0003oool0oooo00<0oooo103<0?l40<co00@0oooo
0`3o0<OH0?ooo`030?l0003oool0oooo0?l0ooooo`3ooolC0?ooo`030000003oool0oooo00L0oooo
001H0?ooo`030000003oool0oooo04@0oooo00<0o`000?ooo`3oool00`3oool40<`0o`<0c?l01@3o
ool30?l0amT0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooa80oooo00<000000?ooo`3oool01`3o
ool005P0oooo00<000000?ooo`3oool0A03oool00`3o0000oooo0?ooo`020?ooo`@0c03o103<o`04
0?ooo`@0o`37fP3oool20?l00?l0ooooo`3ooolB0?ooo`030000003oool0oooo00L0oooo001H0?oo
o`030000003oool0oooo04<0oooo00<0o`000?ooo`3oool00`3oool40<`0o`<0c?l01@3oool30?l0
amd0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooo`l0oooo00<000000?ooo`3oool01`3oool005P0
oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`030?ooo`@0c03o0`3<o`040?ooo`@0
o`37gP3oool00`3o0000oooo0?ooo`3o0?ooool0oooo3P3oool00`000000oooo0?ooo`070?ooo`00
F03oool00`000000oooo0?ooo`130?ooo`030?l0003oool0oooo0080oooo1@3<0?l70?ooo`<0o`37
h03oool20?l00?l0ooooo`3oool>0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003o
ool0oooo04<0oooo00<0o`000?ooo`3oool00P3oool30<`0o`<0c?l01P3oool30?l0an80oooo00<0
o`000?ooo`3oool0o`3ooooo0?ooo`/0oooo00<000000?ooo`3oool01`3oool005P0oooo00<00000
0?ooo`3oool0@P3oool00`3o0000oooo0?ooo`030?ooo`<0c03o0`3<o`050?ooo`@0o`37h`3oool0
0`3o0000oooo0?ooo`3o0?ooool0oooo2P3oool00`000000oooo0?ooo`070?ooo`00F03oool00`00
0000oooo0?ooo`120?ooo`030?l0003oool0oooo0080oooo0`3<0?l40<co00D0oooo0`3o0<OU0?oo
o`80o`00o`3ooooo0?ooo`X0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3o
ool0@P3oool00`3o0000oooo0?ooo`020?ooo`80c03o103<o`050?ooo`@0o`37i`3oool00`3o0000
oooo0?ooo`3o0?ooool0oooo1`3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo
0?ooo`120?ooo`030?l0003oool0oooo00@0oooo0`3<o`060?ooo`<0o`37j@3oool00`3o0000oooo
0?ooo`3o0?ooool0oooo1P3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?oo
o`110?ooo`030?l0003oool0oooo00D0oooo0`3<o`060?ooo`<0o`37jP3oool20?l00?l0ooooo`3o
ool60?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0440oooo00<0o`00
0?ooo`3oool03@3oool40?l0an`0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooo`<0oooo00<00000
0?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`040?oo
o`<0c?l01P3oool30?l0anh0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooo`80oooo00<000000?oo
o`3oool01`3oool005P0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`020?ooo`80
c03o0`3<o`060?ooo`<0o`37k`3oool20?l00?l0ooooo`3oool20?ooo`030000003oool0oooo00L0
oooo001H0?ooo`030000003oool0oooo0400oooo00<0o`000?ooo`3oool00`3oool00`3<0?l0c?l0
0<co00020<co00D0oooo103o0<Oa0?ooo`030?l0003oool0oooo0?l0oooooP3oool00`000000oooo
0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo0080oooo0P3<
0?l30<co00H0oooo0`3o0<Oc0?ooo`030?l0003oool0oooo0?l0ooooo@3oool00`000000oooo0?oo
o`070?ooo`00F03oool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo0080oooo00<0c03o
0<co003<o`000P3<o`050?ooo`@0o`37m03oool20?l00?l0ooooo@3oool00`000000oooo0?ooo`07
0?ooo`00F03oool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo0080oooo00@0c03o0<co
003<o`00c?l01P3oool30?l0aoL0oooo00<0o`000?ooo`3oool0o`3ooooj0?ooo`030000003oool0
oooo00L0oooo001H0?ooo`030000003oool0oooo03l0oooo00<0o`000?ooo`3oool00`3oool0103<
0?l0c?l00<co003<o`060?ooo`<0o`37n03oool00`3o0000oooo0?ooo`3o0?ooooT0oooo00<00000
0?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`030?oo
o`@0c03o1@3oool40?l0aoT0oooo0P3o003o0?ooooT0oooo00<000000?ooo`3oool01`3oool005P0
oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`030?ooo`<0c?l000<0c03o0?ooo`3o
ool00`3oool30?l0ao`0oooo00<0o`000?ooo`3oool0o`3oooof0?ooo`030000003oool0oooo00L0
oooo001H0?ooo`@00000?P3oool00`3o0000oooo0?ooo`030?ooo`<0c?l000<0c03o0?ooo`3oool0
0`3oool30?l0aod0oooo00<0o`000?ooo`3oool0o`3oooob0?ooo`@000002@3oool005P0oooo00<0
00000?ooo`3oool0?P3oool00`3o0000oooo0?ooo`040?ooo`<0c?l000<0c03o0?ooo`3oool00P3o
ool40?l0ad/0oooo0`3o003o0?ooool0ooooZ03oool00`000000oooo0?ooo`070?ooo`00F03oool0
0`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo00<0oooo103<o`000`3<0?l0oooo0?ooo`02
0?ooo`<0o`37C03oool30?l00?l0ooooo`3ooonX0?ooo`030000003oool0oooo00L0oooo001H0?oo
o`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool00`3oool30<co0080c03o0`3oool40?l0
ad/0oooo103o003o0?ooool0ooooZ03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000
oooo0?ooo`0n0?ooo`030?l0003oool0oooo00<0oooo0`3<o`000`3<0?l0oooo0?ooo`020?ooo`<0
o`37C03oool30?l00?l0ooooo`3ooonY0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000
003oool0oooo03d0oooo00<0o`000?ooo`3oool0103oool30<co00030<`0o`3oool0oooo0080oooo
0`3o0<M;0?ooo`@0o`00]`3oool00`3o0000oooo0?ooo`3o0?ooonh0oooo00<000000?ooo`3oool0
1`3oool005P0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`0;0?ooo`@0o`37B`3o
ool30?l00;T0oooo00<0o`000?ooo`3oool0o`3oooo]0?ooo`030000003oool0oooo00L0oooo001H
0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool00`3oool30<co00D0oooo0`3o0<M;
0?ooo`@0o`00^P3oool20?l00?l0ooook@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`00
0000oooo0?ooo`0m0?ooo`030?l0003oool0oooo00<0oooo0`3<o`040?ooo`@0o`37B`3oool30?l0
0;d0oooo00<0o`000?ooo`3oool0o`3ooooZ0?ooo`030000003oool0oooo00L0oooo001H0?ooo`03
0000003oool0oooo03`0oooo00<0o`000?ooo`3oool00`3oool40<co00@0oooo0`3o0<M;0?ooo`@0
o`00_P3oool00`3o0000oooo0?ooo`3o0?ooonT0oooo00<000000?ooo`3oool01`3oool005P0oooo
00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`030?ooo`<0c?l00P3<0?l30?ooo`<0o`37
B`3oool30?l00<00oooo00<0o`000?ooo`3oool0o`3ooooX0?ooo`030000003oool0oooo00L0oooo
001H0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool00P3oool40<co0080c03o0P3o
ool40?l0adX0oooo103o00310?ooo`80o`00o`3ooooX0?ooo`030000003oool0oooo00L0oooo001H
0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool00P3oool30<co0080c03o0`3oool3
0?l0ad/0oooo0`3o00340?ooo`030?l0003oool0oooo0?l0ooooi@3oool00`000000oooo0?ooo`07
0?ooo`00F03oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo00<0oooo0`3<o`020<`0
o`<0oooo0`3o0<M:0?ooo`@0o`00a@3oool00`3o0000oooo0?ooo`3o0?ooon@0oooo00<000000?oo
o`3oool01`3oool005P0oooo00<000000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`040?ooo`@0
c03o0P3oool40?l0adX0oooo0`3o00370?ooo`80o`00o`3ooooT0?ooo`030000003oool0oooo00L0
oooo001H0?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool00P3oool30<co00<0c03o
0P3oool30?l0adX0oooo103o00390?ooo`030?l0003oool0oooo0?l0ooooh@3oool00`000000oooo
0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo0080oooo0`3<
o`020<`0o`<0oooo0`3o0<M:0?ooo`<0o`00b`3oool00`3o0000oooo0?ooo`3o0?ooon00oooo00<0
00000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`03
0?ooo`<0c?l00P3<0?l20?ooo`@0o`37B@3oool40?l00<`0oooo00<0o`000?ooo`3oool0o`3ooooO
0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo03X0oooo00<0o`000?oo
o`3oool00P3oool40<co0080c03o0P3oool30?l0adX0oooo0`3o003>0?ooo`80o`004P3oool00`3o
_g@000000000000200000003001d_`3oool0oooo0?l0ooooa@3oool00`000000oooo0?ooo`070?oo
o`00F03oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo0080oooo0`3<o`030<`0o`80
oooo0`3o0<M90?ooo`@0o`00d03oool00`3o0000oooo0?ooo`0A0?ooo`030;md000007@0_ooo0?l0
oooob03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0o0?ooo`<0c?l0
0P3<0?l30?ooo`<0o`37B03oool40?l00=80oooo00<0o`000?ooo`3oool0403oool00`2oM000001d
0;ooo`3o0?ooolP0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0?`3o
ool30<co0080c03o0P3oool40?l0adP0oooo0`3o003D0?ooo`030?l0003oool0oooo00l0oooo00<0
_g@00000M02oool0o`3oooo80?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0
oooo04H0oooo0`3o0<M80?ooo`@0o`00e@3oool20?l000l0oooo00<0_g@00000M02oool0o`3oooo8
0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo03d0oooo0`3<o`060?oo
o`<0o`37B03oool30?l00=P0oooo00<0o`000?ooo`3oool0303oool00`2oM000001d0;ooo`3o0?oo
olP0oooo00<000000?ooo`3oool01`3oool005P0oooo1000000l0?ooo`<0c?l01@3oool40?l0adL0
oooo103o003I0?ooo`030?l0003oool0oooo00/0oooo00<0_g@00000M02oool0o`3oooo50?ooo`@0
00002@3oool005P0oooo00<000000?ooo`3oool0?@3oool30<co0080c03o0`3oool30?l0adP0oooo
0`3o003K0?ooo`80o`002`3oool00`2oM000001d0;ooo`3o0?ooolP0oooo00<000000?ooo`3oool0
1`3oool005P0oooo00<000000?ooo`3oool0?03oool40<co00@0c03o00@0oooo0?l0a`3o0<L0o`37
A`3oool40?l00=d0oooo00<0o`000?ooo`3oool0203oool00`2oM000001d0;ooo`3o0?ooolP0oooo
00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?oo
o`030<co00D0c03o00@0oooo0?l0a`3o0<L0o`37A`3oool30?l00=l0oooo00<0o`000?ooo`3oool0
1`3oool00`2oM000001d0;ooo`3o0?ooolP0oooo00<000000?ooo`3oool01`3oool005P0oooo00<0
00000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`030<co00@0c03o00<0oooo0?l0a`3o0<L00P3o
0<M60?ooo`@0o`00h03oool00`3o0000oooo0?ooo`060?ooo`030;md000007@0_ooo0?l0oooob03o
ool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0
oooo00<0c?l0103<0?l0103oool0o`370?l0a`3o0<M70?ooo`<0o`00hP3oool20?l000@0oooo00D0
gia8000000000000001d0;ooo`3o0?ooolP0oooo00<000000?ooo`3oool01`3oool005P0oooo00<0
00000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`030?ooo`@0c03o00@0oooo0?l0a`3o0<L0o`37
AP3oool40?l00>@0oooo00<0o`000?ooo`3oool00P3oool0103ookl0M0000000M02ooooo0?ooolP0
oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo
0?ooo`030<co00D0c03o00@0oooo0?l0a`3o0<L0o`37AP3oool30?l00>H0oooo00<0o`000?ooo`3o
ool0o`3oooo=0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo03P0oooo
00<0o`000?ooo`3oool00`3<o`040<`0o`030?ooo`3o0<L0o`370080o`37A@3oool40?l00?l0oooo
o`3ooong0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo03P0oooo00<0
o`000?ooo`3oool00`3<o`040<`0o`040?ooo`3o0<L0o`370?l0adH0oooo0`3o003o0?ooool0oooo
^03oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0h0?ooo`030?l0003o
ool0c?l000<0c?l0103<0?l0103oool0o`370?l0a`3o0<M50?ooo`@0o`00o`3ooooo0?oookP0oooo
00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0<co
00020<co00030?ooo`3<0?l0c03o0080c03o00@0oooo0?l0a`3o0<L0o`37A@3oool30?l00?l0oooo
o`3oooni0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo03P0oooo00<0
o`000?ooo`3<o`000P3<o`050<`0o`@0o`37A03oool40?l00>l0oooo00<0o`000?ooo`3oool0o`3o
ooo60?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo03P0oooo00<0o`00
0?ooo`3<o`000P3<o`040<`0o`040?ooo`3o0<L0o`370?l0adD0oooo0`3o003a0?ooo`030?l0003o
ool0oooo0?l0ooooa@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0g
0?ooo`030?l0003oool0oooo00D0oooo0P3<0?l0103oool0o`370?l0a`3o0<M40?ooo`@0o`00lP3o
ool20?l00?l0ooooa@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0g
0?ooo`040?l0003<o`00c?l00<co00H0oooo103o0<M40?ooo`<0o`00m@3oool00`3o0000oooo0?oo
o`3o0?oool80oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0=`3oool0
103o0000c?l00<co003<o`060?ooo`<0o`37A@3oool30?l00?H0oooo00<0o`000?ooo`3oool0o`3o
ooo10?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo03L0oooo00@0o`00
0<co003<o`00c?l01P3oool30?l0aol0oooo@03oool00`3o0000oooo0?ooo`3o0?oool00oooo00<0
00000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0=`3oool01@3o0000c?l00<co003<
o`00oooo0080c03o0`3oool30?l0aol0oooo@@3oool20?l00?l0oooo`03oool00`000000oooo0?oo
o`070?ooo`00F03oool00`000000oooo0?ooo`0g0?ooo`@0c?l000<0oooo0<`0o`3<0?l00P3<0?l4
0?l0aol0oooo@`3oool00`3o0000oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3oool01`3oool0
05P0oooo00<000000?ooo`3oool0=`3oool30<co00030?ooo`3<0?l0c03o00<0c03o0`3o0<Oo0?oo
odD0oooo00<0o`000?ooo`3oool0o`3ooonl0?ooo`030000003oool0oooo00L0oooo001H0?ooo`03
0000003oool0oooo03H0oooo00D0o`000<co003<o`00c?l00?ooo`040<`0o`040?ooo`3o0<L0o`37
0?l0aol0ooooAP3oool20?l00?l0oooo_03oool00`000000oooo0?ooo`070?ooo`00F03oool00`00
0000oooo0?ooo`0f0?ooo`030?l0003oool0oooo0080oooo103<0?l0103oool0o`370?l0a`3o0<Oo
0?ooodP0oooo00<0o`000?ooo`3oool0o`3oooni0?ooo`030000003oool0oooo00L0oooo001H0?oo
o`030000003oool0oooo03H0oooo0`3<o`020?ooo`@0c03o103o0<Oo0?ooodT0oooo00<0o`000?oo
o`3oool0o`3ooonh0?ooo`030000003oool0oooo00L0oooo001H0?ooo`@00000=@3oool30<co0080
oooo103<0?l30?l0aol0ooooB`3oool00`3o0000oooo0?ooo`3o0?oook@0oooo100000090?ooo`00
F03oool00`000000oooo0?ooo`0f0?ooo`<0c?l00P3oool40<`0o`<0o`37o`3ooom<0?ooo`80o`00
o`3ooong0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo03H0oooo0`3<
o`020?ooo`@0c03o0`3o0<Oo0?ooodh0oooo00<0o`000?ooo`3oool0o`3ooond0?ooo`030000003o
ool0oooo00L0oooo001H0?ooo`030000003oool0oooo03H0oooo0`3<o`020?ooo`<0c03o103o0<Oo
0?ooodl0oooo00<0o`000?ooo`3oool0o`3ooonc0?ooo`030000003oool0oooo00L0oooo001H0?oo
o`030000003oool0oooo03D0oooo00D0o`000<co003<o`00c?l00?ooo`040<`0o`<0o`37o`3ooomA
0?ooo`030?l0003oool0oooo0?l0oooo/P3oool00`000000oooo0?ooo`070?ooo`00F03oool00`00
0000oooo0?ooo`0e0?ooo`050?l0003<o`00c?l00<co003oool0103<0?l30?l0aol0ooooDP3oool2
0?l00?l0oooo/P3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0e0?oo
o`040?l0003<o`00c?l00<co00<0oooo00<0c03o0?l0a`3o0<L00P3o0<Oo0?oooe@0oooo00<0o`00
0?ooo`3oool0o`3ooon_0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo
03D0oooo00<0o`000?ooo`3oool01@3oool30?l0aol0ooooEP3oool00`3o0000oooo0?ooo`3o0?oo
ojh0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0=@3oool30<co00D0
oooo0`3o0<Oo0?oooeL0oooo0P3o003o0?ooojh0oooo00<000000?ooo`3oool01`3oool005P0oooo
00<000000?ooo`3oool0=@3oool30<co00D0oooo0`3o0<Oo0?oooeT0oooo00<0o`000?ooo`3oool0
o`3ooon[0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo03D0oooo0`3<
o`00103oool0c03o0<`0o`3oool40?l0aol0ooooFP3oool00`3o0000oooo0?ooo`3o0?ooojX0oooo
00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0=03oool40<co00040?ooo`3<
0?l0c03o0<`0o`<0o`37o`3ooomL0?ooo`030?l0003oool0oooo0?l0ooooZ@3oool00`000000oooo
0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0d0?ooo`<0c?l000<0oooo0<`0o`3<0?l00P3<
0?l30?l0aol0ooooG@3oool20?l00?l0ooooZ@3oool00`000000oooo0?ooo`070?ooo`00F03oool0
0`000000oooo0?ooo`0d0?ooo`<0c?l000<0oooo0<`0o`3<0?l00P3<0?l30?l0aol0ooooG`3oool0
0`3o0000oooo0?ooo`3o0?ooojH0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?oo
o`3oool0=03oool30<co00040?ooo`3<0?l0c03o0<`0o`@0o`37o`3ooomP0?ooo`030?l0003oool0
oooo0?l0ooooY@3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0d0?oo
o`040?l0003oool0oooo0?ooo`<0c03o0`3o0<Oo0?ooool0ooooo`3oool:0?ooo`030000003oool0
oooo00L0oooo001H0?ooo`030000003oool0oooo03<0oooo0`3<o`020?ooo`<0c03o0`3o0<Oo0?oo
ool0ooooo`3oool:0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo03<0
oooo0`3<o`020?ooo`<0c03o0`3o0<Oo0?ooof@0oooo00<0o`000?ooo`3oool0o`3ooonR0?ooo`03
0000003oool0oooo00L0oooo000d0?ooo`030?noM000000000000080000000L007Bo0?ooo`3oool0
oooo0=nLB0000000B9cO00<0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0=0?oo
o`030000003oool0oooo03<0oooo0`3<o`00103oool0c03o0<`0o`3<0?l40?l0aol0ooooI@3oool2
0?l00?l0ooooXP3oool00`000000oooo0?ooo`070?ooo`00=P3oool00`2oM000001d0;ooo`040?oo
o`030=nLB0000000B9cO00D0oooo00<0_g@00000M02oool0403oool00`000000oooo0?ooo`0b0?oo
o`@0c?l000@0oooo0<`0o`3<0?l0c03o0`3o0<Oo0?ooofP0oooo00<0o`000?ooo`3oool0o`3ooonO
0?ooo`030000003oool0oooo00L0oooo000f0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000
M02oool0403oool00`000000oooo0?ooo`0b0?ooo`<0c?l00P3oool30<`0o`<0o`37o`3ooomY0?oo
o`030?l0003oool0oooo0?l0ooooWP3oool00`000000oooo0?ooo`070?ooo`00=P3oool00`2oM000
001d0;ooo`0<0?ooo`030;md000007@0_ooo0100oooo00<000000?ooo`3oool0<P3oool30<co0004
0?ooo`3<0?l0c03o0<`0o`@0o`37o`3ooomZ0?ooo`80o`00o`3ooonN0?ooo`030000003oool0oooo
00L0oooo000f0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0403oool00`000000
oooo0?ooo`0b0?ooo`<0c?l000@0oooo0<`0o`3<0?l0c03o0`3o0<Oo0?ooofd0oooo00<0o`000?oo
o`3oool0o`3ooonK0?ooo`030000003oool0oooo00L0oooo000f0?ooo`030;md000007@0_ooo00`0
oooo00<0_g@00000M02oool0403oool6000003D0oooo00@0c03o0?l0a`3o0<L0o`37o`3ooom^0?oo
o`030?l0003oool0oooo0?l0ooooU@3oool6000000T0oooo000f0?ooo`030;md000007@0_ooo00`0
oooo00<0_g@00000M02oool0403oool00`000000oooo0?ooo`0a0?ooo`<0c?l01@3oool30?l0aol0
ooooK`3oool20?l00?l0ooooVP3oool00`000000oooo0?ooo`070?ooo`00=P3oool00`2oM000001d
0;ooo`0<0?ooo`030;md000007@0_ooo0100oooo00<000000?ooo`3oool0<@3oool30<co00@0oooo
103o0<Oo0?ooog40oooo00<0o`000?ooo`3oool0o`3ooonG0?ooo`030000003oool0oooo00L0oooo
000f0?ooo`030;md000007@0_ooo00`0oooo00<0_g@00000M02oool0403oool00`000000oooo0?oo
o`0a0?ooo`<0c?l0103oool30?l0aol0ooooL`3oool00`3o0000oooo0?ooo`3o0?oooiH0oooo00<0
00000?ooo`3oool01`3oool003H0oooo00<0_g@00000M02oool0303oool00`2oM000001d0;ooo`0@
0?ooo`030000003oool0oooo0340oooo0`3<o`020?ooo`80c03o0`3o0<Oo0?ooog@0oooo0P3o003o
0?oooiH0oooo00<000000?ooo`3oool01`3oool003H0oooo00<0_g@00000M02oool0303oool00`2o
M000001d0;ooo`0@0?ooo`030000003oool0oooo0340oooo0`3<o`020?ooo`80c03o0`3o0<Oo0?oo
ogH0oooo00<0o`000?ooo`3oool0o`3ooonC0?ooo`030000003oool0oooo00L0oooo000d0?ooo`05
0=nLB000000000000000M02oool02P3oool01@3OW4P000000000000007@0_ooo0100oooo00<00000
0?ooo`3oool0<@3oool30<co00040?ooo`3<0?l0c03o0<`0o`<0o`37o`3ooomg0?ooo`030?l0003o
ool0oooo0?l0ooooTP3oool00`000000oooo0?ooo`070?ooo`00=@3oool0103ookl0M0000000M02o
ool;0?ooo`040?oo_`1d0000001d0;oooa00oooo00<000000?ooo`3oool0<@3oool30<co00030?oo
o`3<0?l0c03o00<0o`37@@3oool30?l00?l0oooo=@3oool20?l00?l0ooooTP3oool00`000000oooo
0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0b0?ooo`030?l0003oool0oooo0080c03o0`3o
0<M10?ooo`<0o`00o`3ooolg0?ooo`030?l0003oool0oooo0?l0ooooS`3oool00`000000oooo0?oo
o`070?ooo`00F03oool00`000000oooo0?ooo`0`0?ooo`<0c?l00P3oool20<`0o`<0o`37@03oool4
0?l00?l0oooo>03oool20?l00?l0ooooS`3oool00`000000oooo0?ooo`070?ooo`00F03oool00`00
0000oooo0?ooo`0`0?ooo`<0c?l00P3oool20<`0o`<0o`37@03oool30?l00?l0oooo>`3oool00`3o
0000oooo0?ooo`3o0?oooh`0oooo00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3o
ool0<03oool30<co0080oooo0P3<0?l30?l0ad00oooo0`3o003o0?oooc`0oooo00<0o`000?ooo`3o
ool0o`3ooon;0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0300oooo
0`3<o`020?ooo`80c03o0`3o0<Lo0?ooo`@0o`00o`3ooolm0?ooo`80o`00o`3ooon;0?ooo`030000
003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo02l0oooo0`3<o`030?ooo`040<`0o`3o
0<L0o`370?l0ad00oooo0`3o003o0?oood00oooo00<0o`000?ooo`3oool0o`3ooon80?ooo`030000
003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo02l0oooo0`3<o`020?ooo`80c03o0`3o
0<M00?ooo`<0o`00o`3ooom10?ooo`030?l0003oool0oooo0?l0ooooQ`3oool00`000000oooo0?oo
o`070?ooo`00F03oool00`000000oooo0?ooo`0_0?ooo`<0c?l00P3oool20<`0o`<0o`37?`3oool4
0?l00?l0oooo@P3oool20?l00?l0ooooQ`3oool00`000000oooo0?ooo`070?ooo`00F03oool00`00
0000oooo0?ooo`0_0?ooo`<0c?l0103oool30?l0acl0oooo0`3o003o0?ooodD0oooo00<0o`000?oo
o`3oool0o`3ooon40?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0300
oooo00<0o`000?ooo`3oool00`3oool30?l0acl0oooo0`3o003o0?ooodH0oooo00<0o`000?ooo`3o
ool0o`3ooon30?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo02h0oooo
0`3<o`040?ooo`<0o`37?`3oool40?l00?l0ooooA`3oool20?l00?l0ooooP`3oool00`000000oooo
0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0^0?ooo`<0c?l0103oool30?l0acl0oooo0`3o
003o0?ooodX0oooo00<0o`000?ooo`3oool0o`3ooon00?ooo`030000003oool0oooo00L0oooo001H
0?ooo`030000003oool0oooo02h0oooo0`3<o`040?ooo`<0o`37?`3oool30?l00?l0ooooo`3oooo=
0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo02d0oooo103<o`030?oo
o`040<`0o`3o0<L0o`370?l0ach0oooo103o003o0?ooool0ooooc@3oool00`000000oooo0?ooo`07
0?ooo`00F03oool00`000000oooo0?ooo`0]0?ooo`<0c?l000D0o`000?ooo`3oool0oooo0<`0o`03
0?l0ach0oooo0`3o003o0?ooool0oooocP3oool00`000000oooo0?ooo`070?ooo`00F03oool00`00
0000oooo0?ooo`0]0?ooo`<0c?l000@0o`000?ooo`3oool0c03o0`3o0<L00`3<0?l0oooo0?ooo`0k
0?ooo`@0o`00o`3ooooo0?ooolh0oooo00<000000?ooo`3oool01`3oool005P0oooo1000000/0?oo
o`<0c?l00`3oool0103<0?l0o`370?l0a`3o0<Ln0?ooo`<0o`00o`3ooomC0?ooo`030?l0003oool0
oooo0?l0ooooMP3oool4000000T0oooo001H0?ooo`030000003oool0oooo02l0oooo00D0o`000?oo
o`3oool0oooo0<`0o`030?l0ach0oooo0`3o003o0?oooe@0oooo0P3o003o0?ooogT0oooo00<00000
0?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0;@3oool30<co00<0oooo00@0c03o0?l0
a`3o0<L0o`37?@3oool40?l00?l0ooooEP3oool00`3o0000oooo0?ooo`3o0?ooogH0oooo00<00000
0?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0;@3oool30<co00<0oooo00@0c03o0?l0
a`3o0<L0o`37?@3oool30?l00?l0ooooF03oool00`3o0000oooo0?ooo`3o0?ooogD0oooo00<00000
0?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool0;@3oool30<co00<0oooo00@0c03o0?l0
a`3o0<L0o`37?@3oool30?l00?l0ooooF@3oool20?l00?l0ooooM@3oool00`000000oooo0?ooo`07
0?ooo`00F03oool00`000000oooo0?ooo`0/0?ooo`@0c?l00`3oool30?l0a`030<`0o`3oool0oooo
03X0oooo103o003o0?oooe/0oooo00<0o`000?ooo`3oool0o`3ooomb0?ooo`030000003oool0oooo
00L0oooo001H0?ooo`030000003oool0oooo02`0oooo0`3<o`040?ooo`<0o`3700<0c03o0?ooo`3o
ool0>P3oool30?l00?l0ooooG@3oool20?l00?l0ooooLP3oool00`000000oooo0?ooo`070?ooo`00
F03oool00`000000oooo0?ooo`0/0?ooo`<0c?l00`3oool01@3<0?l0o`370?l0a`3o0<L0c03o03`0
oooo0`3o003o0?oooel0oooo00<0o`000?ooo`3oool0o`3ooom_0?ooo`030000003oool0oooo00L0
oooo001H0?ooo`030000003oool0oooo02`0oooo0`3<o`030?ooo`040<`0o`3o0<L0o`370?l0ac`0
oooo103o003o0?ooof00oooo00<0o`000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo00L0
oooo001H0?ooo`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool00P3oool30?l0ac`0oooo
0`3o003o0?ooof80oooo0P3o003o0?ooofh0oooo00<000000?ooo`3oool01`3oool005P0oooo00<0
00000?ooo`3oool0:`3oool30<co00040?l0003oool0oooo0?ooo`<0o`37?03oool40?l00?l0oooo
I03oool00`3o0000oooo0?ooo`3o0?ooof/0oooo00<000000?ooo`3oool01`3oool005P0oooo00<0
00000?ooo`3oool0:`3oool30<co00040?l0003oool0oooo0?ooo`<0o`37?03oool30?l00?l0oooo
IP3oool00`3o0000oooo0?ooo`3o0?ooofX0oooo00<000000?ooo`3oool01`3oool005P0oooo00<0
00000?ooo`3oool0:`3oool30<co00040?l0003oool0oooo0?ooo`<0o`37?03oool30?l00?l0oooo
I`3oool20?l00?l0ooooJP3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?oo
o`0Z0?ooo`@0c?l0103oool30?l0ac/0oooo103o003o0?ooofT0oooo00<0o`000?ooo`3oool0o`3o
oomW0?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo02X0oooo0`3<o`00
0`3o0000oooo0?ooo`020?ooo`<0o`3700<0c03o0?ooo`3oool0>03oool30?l00?l0ooooJ`3oool2
0?l00?l0ooooI`3oool00`000000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0Z0?oo
o`<0c?l000D0o`000?ooo`3oool0oooo0<`0o`030?l0a`030<`0o`3oool0oooo03P0oooo0`3o003o
0?ooofd0oooo00<0o`000?ooo`3oool0o`3ooomT0?ooo`030000003oool0oooo00L0oooo001H0?oo
o`030000003oool0oooo02X0oooo0`3<o`00103o0000oooo0?ooo`3oool30?l0a`030<`0o`3oool0
oooo03P0oooo103o003o0?ooofh0oooo00<0o`000?ooo`3oool0o`3ooomS0?ooo`030000003oool0
oooo00L0oooo001H0?ooo`030000003oool0oooo02d0oooo00@0o`000?ooo`3oool0oooo0`3o0<L0
0`3<0?l0oooo0?ooo`0h0?ooo`<0o`00o`3ooom`0?ooo`80o`00o`3ooomS0?ooo`030000003oool0
oooo00L0oooo001H0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool30<co
00030?ooo`3o0000oooo0080oooo0`3o0<L00`3<0?l0oooo0?ooo`0h0?ooo`<0o`00?`3oool00`00
0000oooo0?ooo`2M0?ooo`030000003oool0oooo08l0oooo00<0o`000?ooo`3oool02`3oool00`00
0000oooo0?ooo`2M0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0
oooo0`3<o`000`3oool0o`000?ooo`020?ooo`<0o`3700<0c03o0?ooo`3oool0=`3oool40?l003l0
oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`2@0?ooo`80o`002`3oool00`000000
oooo0?ooo`2M0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`070?ooo`00F03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo
0`3<o`000`3o0000oooo0?ooo`020?ooo`<0o`3700<0c03o0?ooo`3oool00P3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00X0oooo0`3o000H0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo00P0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool01`3oool005P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0D0?ooo`@0c?l000@0o`000?ooo`3oool0oooo0`3o0<L20<`0o`@0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0:0?ooo`<0o`00603oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`070?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0503o
ool30<co00030?ooo`3o0000oooo0080oooo0`3o0<L20<`0o`@0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`090?ooo`@0o`00603oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0703oool20?l000L0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01`3o
ool005P0oooo:`0000030<co00030000003o00000000008000000`3o0<L20<`0ocP000000`3o003o
000007/0000000<0o`00000000000000o`00001J000000T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 937.75}, {579.188, 0}} -> {-0.135217, 0.874746, \
0.00124903, 0.000423441}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ 
        Export\ Fig\ to\ eps\ using\ proper\ transformation\ of\ greek\ fonts\
\ so\ that\ they\ can\ show\ up\ properly\ in\ eps\ plot\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(MyGreekExport[epsname_?StringQ, greekletter_?StringQ] := 
      Module[{imp, qwe, qwe1, qwe2, pos}, imp = Import[epsname, "\<Lines\>"]; 
        qwe = greekletter; \[IndentingNewLine]qwe1 = 
          FromCharacterCode[
            ToCharacterCode[qwe, "\<Symbol\>"]]; \[IndentingNewLine]qwe2 = 
          ToUpperCase[qwe1]; 
        pos = Position[imp, "\<(\>" <> qwe1 <> "\<) show\>"] // 
            Flatten; \(If[
              imp[\([pos[\([#]\)] - 
                      4]\)] == "\<%%IncludeFont: Mathematica1\>", \
\(imp[\([pos[\([#]\)]]\)] = "\<(\>" <> qwe2 <> "\<) show\>";\)] &\) /@ 
          Range[Length[pos]]; 
        Export[epsname, imp, "\<Lines\>"]]\), "\[IndentingNewLine]", 
    \(\(MyGreekExport::usage = "\<MyGreekExport[epsname,greekletter] corrects \
Mathematica's problem of correctly exporting capital Greek letters to EPS. \
Note that both arguments must be strings.\>";\)\)}], "Input"],

Cell[BoxData[
    \(\(Export["\<fig2.eps\>", f2, ImageSize \[Rule] 800];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?MyGreekExport\)\)], "Input"],

Cell[BoxData[
    \("MyGreekExport[epsname,greekletter] corrects Mathematica's problem of \
correctly exporting capital Greek letters to EPS. Note that both arguments \
must be strings."\)], "Print",
  CellTags->"Info3418369753-9241937"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MyGreekExport["\<fig2.eps\>", "\<\[Omega]\>"]\)], "Input"],

Cell[BoxData[
    \("fig2.eps"\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 713}},
WindowSize->{693, 701},
WindowMargins->{{Automatic, -6}, {-4, Automatic}},
ShowSelection->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3418369753-9241937"->{
    Cell[710343, 17266, 237, 4, 44, "Print",
      CellTags->"Info3418369753-9241937"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3418369753-9241937", 711387, 17298}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 433, 9, 152, "Input"],
Cell[2190, 62, 142, 3, 61, "Input"],
Cell[2335, 67, 694, 21, 110, "Input"],
Cell[3032, 90, 83, 2, 35, "Input"],
Cell[3118, 94, 298, 5, 90, "Input"],
Cell[3419, 101, 121, 2, 35, "Input"],
Cell[3543, 105, 1456, 33, 330, "Input"],
Cell[5002, 140, 130, 3, 35, "Input"],
Cell[5135, 145, 187, 3, 70, "Input"],
Cell[5325, 150, 187, 4, 61, "Input"],

Cell[CellGroupData[{
Cell[5537, 158, 4869, 86, 1097, "Input"],
Cell[10409, 246, 449, 8, 25, "Print"],
Cell[10861, 256, 301, 6, 25, "Print"],
Cell[11165, 264, 445, 8, 25, "Print"],
Cell[11613, 274, 326, 7, 25, "Print"],
Cell[11942, 283, 447, 8, 25, "Print"],
Cell[12392, 293, 326, 7, 25, "Print"],
Cell[12721, 302, 447, 8, 25, "Print"],
Cell[13171, 312, 326, 7, 25, "Print"],
Cell[13500, 321, 448, 8, 25, "Print"],
Cell[13951, 331, 324, 7, 25, "Print"],
Cell[14278, 340, 448, 8, 25, "Print"],
Cell[14729, 350, 325, 7, 25, "Print"],
Cell[15057, 359, 447, 8, 25, "Print"],
Cell[15507, 369, 324, 7, 25, "Print"],
Cell[15834, 378, 448, 8, 25, "Print"],
Cell[16285, 388, 300, 6, 25, "Print"],
Cell[16588, 396, 447, 8, 25, "Print"],
Cell[17038, 406, 324, 7, 25, "Print"],
Cell[17365, 415, 447, 8, 25, "Print"],
Cell[17815, 425, 324, 7, 25, "Print"],
Cell[18142, 434, 448, 8, 25, "Print"],
Cell[18593, 444, 299, 6, 25, "Print"],
Cell[18895, 452, 446, 8, 25, "Print"],
Cell[19344, 462, 324, 7, 25, "Print"],
Cell[19671, 471, 446, 8, 25, "Print"],
Cell[20120, 481, 324, 7, 25, "Print"],
Cell[20447, 490, 447, 8, 25, "Print"],
Cell[20897, 500, 324, 7, 25, "Print"],
Cell[21224, 509, 448, 8, 25, "Print"],
Cell[21675, 519, 324, 7, 25, "Print"],
Cell[22002, 528, 448, 8, 25, "Print"],
Cell[22453, 538, 288, 5, 25, "Print"]
}, Open  ]],
Cell[22756, 546, 295, 6, 61, "Input"],

Cell[CellGroupData[{
Cell[23076, 556, 1107, 29, 31, "Input"],
Cell[24186, 587, 79775, 1735, 513, 20576, 1000, "GraphicsData", "PostScript", \
"Graphics"],
Cell[103964, 2324, 130, 3, 29, "Output"]
}, Open  ]],
Cell[104109, 2330, 177, 4, 61, "Input"],
Cell[104289, 2336, 217, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[104531, 2343, 3486, 62, 970, "Input"],
Cell[108020, 2407, 448, 8, 25, "Print"],
Cell[108471, 2417, 300, 6, 25, "Print"],
Cell[108774, 2425, 448, 8, 25, "Print"],
Cell[109225, 2435, 324, 7, 25, "Print"],
Cell[109552, 2444, 447, 8, 25, "Print"],
Cell[110002, 2454, 326, 7, 25, "Print"],
Cell[110331, 2463, 444, 8, 25, "Print"],
Cell[110778, 2473, 326, 7, 25, "Print"],
Cell[111107, 2482, 442, 8, 25, "Print"],
Cell[111552, 2492, 324, 7, 25, "Print"],
Cell[111879, 2501, 446, 8, 25, "Print"],
Cell[112328, 2511, 301, 6, 25, "Print"],
Cell[112632, 2519, 448, 8, 25, "Print"],
Cell[113083, 2529, 323, 7, 25, "Print"],
Cell[113409, 2538, 446, 8, 25, "Print"],
Cell[113858, 2548, 301, 6, 25, "Print"],
Cell[114162, 2556, 445, 8, 25, "Print"],
Cell[114610, 2566, 325, 7, 25, "Print"],
Cell[114938, 2575, 447, 8, 25, "Print"],
Cell[115388, 2585, 299, 6, 25, "Print"],
Cell[115690, 2593, 443, 8, 25, "Print"],
Cell[116136, 2603, 324, 7, 25, "Print"],
Cell[116463, 2612, 445, 8, 25, "Print"],
Cell[116911, 2622, 301, 6, 25, "Print"],
Cell[117215, 2630, 448, 8, 25, "Print"],
Cell[117666, 2640, 301, 6, 25, "Print"],
Cell[117970, 2648, 447, 8, 25, "Print"],
Cell[118420, 2658, 324, 7, 25, "Print"],
Cell[118747, 2667, 448, 8, 25, "Print"],
Cell[119198, 2677, 324, 7, 25, "Print"],
Cell[119525, 2686, 445, 8, 25, "Print"],
Cell[119973, 2696, 299, 6, 25, "Print"],
Cell[120275, 2704, 447, 8, 25, "Print"],
Cell[120725, 2714, 324, 7, 25, "Print"],
Cell[121052, 2723, 444, 8, 25, "Print"],
Cell[121499, 2733, 324, 7, 25, "Print"],
Cell[121826, 2742, 444, 8, 25, "Print"],
Cell[122273, 2752, 324, 7, 25, "Print"],
Cell[122600, 2761, 446, 8, 25, "Print"],
Cell[123049, 2771, 324, 7, 25, "Print"],
Cell[123376, 2780, 447, 8, 25, "Print"],
Cell[123826, 2790, 286, 5, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[124149, 2800, 119, 2, 30, "Input"],
Cell[124271, 2804, 56452, 1241, 326, 13823, 710, "GraphicsData", \
"PostScript", "Graphics"],
Cell[180726, 4047, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[180893, 4055, 1105, 29, 73, "Input"],
Cell[182001, 4086, 76389, 1597, 447, 18089, 873, "GraphicsData", \
"PostScript", "Graphics"],
Cell[258393, 5685, 130, 3, 29, "Output"]
}, Open  ]],
Cell[258538, 5691, 166, 4, 61, "Input"],
Cell[258707, 5697, 193, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[258925, 5704, 2943, 52, 890, "Input"],
Cell[261871, 5758, 454, 8, 25, "Print"],
Cell[262328, 5768, 232, 4, 25, "Print"],
Cell[262563, 5774, 456, 8, 25, "Print"],
Cell[263022, 5784, 232, 4, 25, "Print"],
Cell[263257, 5790, 456, 8, 25, "Print"],
Cell[263716, 5800, 232, 4, 25, "Print"],
Cell[263951, 5806, 455, 8, 25, "Print"],
Cell[264409, 5816, 232, 4, 25, "Print"],
Cell[264644, 5822, 452, 8, 25, "Print"],
Cell[265099, 5832, 232, 4, 25, "Print"],
Cell[265334, 5838, 453, 8, 25, "Print"],
Cell[265790, 5848, 232, 4, 25, "Print"],
Cell[266025, 5854, 454, 8, 25, "Print"],
Cell[266482, 5864, 232, 4, 25, "Print"],
Cell[266717, 5870, 453, 8, 25, "Print"],
Cell[267173, 5880, 230, 4, 25, "Print"],
Cell[267406, 5886, 453, 8, 25, "Print"],
Cell[267862, 5896, 232, 4, 25, "Print"],
Cell[268097, 5902, 454, 8, 25, "Print"],
Cell[268554, 5912, 232, 4, 25, "Print"],
Cell[268789, 5918, 456, 8, 25, "Print"],
Cell[269248, 5928, 232, 4, 25, "Print"],
Cell[269483, 5934, 454, 8, 25, "Print"],
Cell[269940, 5944, 232, 4, 25, "Print"],
Cell[270175, 5950, 452, 8, 25, "Print"],
Cell[270630, 5960, 232, 4, 25, "Print"],
Cell[270865, 5966, 453, 8, 25, "Print"],
Cell[271321, 5976, 231, 4, 25, "Print"],
Cell[271555, 5982, 455, 8, 25, "Print"],
Cell[272013, 5992, 230, 4, 25, "Print"],
Cell[272246, 5998, 455, 8, 25, "Print"],
Cell[272704, 6008, 231, 4, 25, "Print"],
Cell[272938, 6014, 454, 8, 25, "Print"],
Cell[273395, 6024, 232, 4, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[273664, 6033, 87, 1, 30, "Input"],
Cell[273754, 6036, 48701, 1175, 328, 14900, 753, "GraphicsData", \
"PostScript", "Graphics"],
Cell[322458, 7213, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[322625, 7221, 1105, 29, 73, "Input"],
Cell[323733, 7252, 57420, 1394, 348, 19122, 917, "GraphicsData", \
"PostScript", "Graphics"],
Cell[381156, 8648, 130, 3, 29, "Output"]
}, Open  ]],
Cell[381301, 8654, 163, 4, 35, "Input"],
Cell[381467, 8660, 183, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[381675, 8667, 2860, 49, 910, "Input"],
Cell[384538, 8718, 447, 8, 25, "Print"],
Cell[384988, 8728, 232, 4, 25, "Print"],
Cell[385223, 8734, 448, 8, 25, "Print"],
Cell[385674, 8744, 232, 4, 25, "Print"],
Cell[385909, 8750, 447, 8, 25, "Print"],
Cell[386359, 8760, 232, 4, 25, "Print"],
Cell[386594, 8766, 446, 8, 25, "Print"],
Cell[387043, 8776, 232, 4, 25, "Print"],
Cell[387278, 8782, 447, 8, 25, "Print"],
Cell[387728, 8792, 232, 4, 25, "Print"],
Cell[387963, 8798, 447, 8, 25, "Print"],
Cell[388413, 8808, 230, 4, 25, "Print"],
Cell[388646, 8814, 448, 8, 25, "Print"],
Cell[389097, 8824, 232, 4, 25, "Print"],
Cell[389332, 8830, 444, 8, 25, "Print"],
Cell[389779, 8840, 232, 4, 25, "Print"],
Cell[390014, 8846, 446, 8, 25, "Print"],
Cell[390463, 8856, 232, 4, 25, "Print"],
Cell[390698, 8862, 447, 8, 25, "Print"],
Cell[391148, 8872, 232, 4, 25, "Print"],
Cell[391383, 8878, 445, 8, 25, "Print"],
Cell[391831, 8888, 232, 4, 25, "Print"],
Cell[392066, 8894, 445, 8, 25, "Print"],
Cell[392514, 8904, 232, 4, 25, "Print"],
Cell[392749, 8910, 446, 8, 25, "Print"],
Cell[393198, 8920, 232, 4, 25, "Print"],
Cell[393433, 8926, 448, 8, 25, "Print"],
Cell[393884, 8936, 232, 4, 25, "Print"],
Cell[394119, 8942, 447, 8, 25, "Print"],
Cell[394569, 8952, 231, 4, 25, "Print"],
Cell[394803, 8958, 447, 8, 25, "Print"],
Cell[395253, 8968, 230, 4, 25, "Print"],
Cell[395486, 8974, 449, 8, 25, "Print"],
Cell[395938, 8984, 232, 4, 25, "Print"],
Cell[396173, 8990, 448, 8, 25, "Print"],
Cell[396624, 9000, 231, 4, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[396892, 9009, 117, 2, 30, "Input"],
Cell[397012, 9013, 56300, 1235, 409, 13830, 706, "GraphicsData", \
"PostScript", "Graphics"],
Cell[453315, 10250, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[453482, 10258, 1109, 29, 73, "Input"],
Cell[454594, 10289, 18145, 874, 458, 18022, 870, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[472742, 11165, 130, 3, 29, "Output"]
}, Open  ]],
Cell[472887, 11171, 1155, 44, 31, "Input"],
Cell[474045, 11217, 183, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[474253, 11224, 2869, 49, 910, "Input"],
Cell[477125, 11275, 452, 8, 25, "Print"],
Cell[477580, 11285, 232, 4, 25, "Print"],
Cell[477815, 11291, 455, 8, 25, "Print"],
Cell[478273, 11301, 232, 4, 25, "Print"],
Cell[478508, 11307, 451, 8, 25, "Print"],
Cell[478962, 11317, 232, 4, 25, "Print"],
Cell[479197, 11323, 452, 8, 25, "Print"],
Cell[479652, 11333, 231, 4, 25, "Print"],
Cell[479886, 11339, 452, 8, 25, "Print"],
Cell[480341, 11349, 232, 4, 25, "Print"],
Cell[480576, 11355, 454, 8, 25, "Print"],
Cell[481033, 11365, 232, 4, 25, "Print"],
Cell[481268, 11371, 452, 8, 25, "Print"],
Cell[481723, 11381, 232, 4, 25, "Print"],
Cell[481958, 11387, 452, 8, 25, "Print"],
Cell[482413, 11397, 232, 4, 25, "Print"],
Cell[482648, 11403, 456, 8, 25, "Print"],
Cell[483107, 11413, 232, 4, 25, "Print"],
Cell[483342, 11419, 454, 8, 25, "Print"],
Cell[483799, 11429, 232, 4, 25, "Print"],
Cell[484034, 11435, 454, 8, 25, "Print"],
Cell[484491, 11445, 232, 4, 25, "Print"],
Cell[484726, 11451, 454, 8, 25, "Print"],
Cell[485183, 11461, 232, 4, 25, "Print"],
Cell[485418, 11467, 454, 8, 25, "Print"],
Cell[485875, 11477, 231, 4, 25, "Print"],
Cell[486109, 11483, 454, 8, 25, "Print"],
Cell[486566, 11493, 232, 4, 25, "Print"],
Cell[486801, 11499, 455, 8, 25, "Print"],
Cell[487259, 11509, 231, 4, 25, "Print"],
Cell[487493, 11515, 454, 8, 25, "Print"],
Cell[487950, 11525, 232, 4, 25, "Print"],
Cell[488185, 11531, 455, 8, 25, "Print"],
Cell[488643, 11541, 232, 4, 25, "Print"],
Cell[488878, 11547, 455, 8, 25, "Print"],
Cell[489336, 11557, 231, 4, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[489604, 11566, 117, 2, 30, "Input"],
Cell[489724, 11570, 15139, 764, 409, 15012, 760, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[504866, 12336, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[505033, 12344, 1102, 29, 73, "Input"],
Cell[506138, 12375, 62751, 1465, 390, 19181, 923, "GraphicsData", \
"PostScript", "Graphics"],
Cell[568892, 13842, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[569059, 13850, 47, 1, 30, "Input"],
Cell[569109, 13853, 21075, 1029, 186, 20952, 1025, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[590187, 14884, 130, 3, 29, "Output"]
}, Open  ]],
Cell[590332, 14890, 87, 2, 35, "Input"],

Cell[CellGroupData[{
Cell[590444, 14896, 402, 8, 90, "Input"],
Cell[590849, 14906, 118030, 2320, 589, 25706, 1176, "GraphicsData", \
"PostScript", "Graphics"],
Cell[708882, 17228, 130, 3, 29, "Output"]
}, Open  ]],
Cell[709027, 17234, 209, 4, 87, "Input"],
Cell[709239, 17240, 935, 16, 250, "Input"],
Cell[710177, 17258, 87, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[710289, 17263, 51, 1, 30, "Input"],
Cell[710343, 17266, 237, 4, 44, "Print",
  CellTags->"Info3418369753-9241937"]
}, Open  ]],

Cell[CellGroupData[{
Cell[710617, 17275, 78, 1, 30, "Input"],
Cell[710698, 17278, 44, 1, 29, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

