(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    340445,       7740]*)
(*NotebookOutlinePosition[    341090,       7762]*)
(*  CellTagsIndexPosition[    341046,       7758]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    StyleBox[\( (*\ 
        This\ file\ produces\ one\ raw\ of\ Fig . \ 1\ of\ the\ paper\ ' 
          Testing\ GRBs\ as\ Standard\ Candles'\ \((Var - L)\) . \ 
            The\ parameter\ a1\ corresponds\ to\ the\ parameters\ b\_j\ in\ \
the\ paper\ \[IndentingNewLine]while\ the\ parameter\ b1\ corresponds\ to\ \
the\ parameters\ a\_j . \ 
            The\ produced\ Figs\ examine\ the\ dependence\ of\ the\ \
parameters\ a\_j, \ b\_j\ on\ redshift\ \(\(z\)\(.\)\)*) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Set\ Directory\ to\ Read\ GRB\ data\ from, \ 
        Input\ Packages\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{\(SetDirectory["\<D:/mathdata/grb\>"];\), "\[IndentingNewLine]",
   
    RowBox[{\($TextStyle = {FontFamily \[Rule] "\<Times\>", 
          FontSize \[Rule] 20}\), ";", 
      StyleBox[" ",
        "MR"], 
      StyleBox[\(Off[]\),
        "MR"], 
      StyleBox[";",
        "MR"], 
      StyleBox[\(Off[General::spell]\),
        "MR"], 
      StyleBox[";",
        "MR"], 
      RowBox[{"Off", 
        StyleBox["[",
          "MR"], \(NIntegrate::"\<inum\>"\), 
        StyleBox["]",
          "MR"]}], 
      StyleBox[";",
        "MR"]}], "\[IndentingNewLine]", \(<< 
      Statistics`LinearRegression`\), "\[IndentingNewLine]", \(<< 
      Graphics`Graphics`\), "\[IndentingNewLine]", \(<< 
      Graphics`MultipleListPlot`\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Read\ Data\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(data1 = 
        ReadList["\<grbdat.txt\>", {Number, Number, Number, Number, Number, 
            Number, Number, Number, Number, Number, Number, Number, Number, 
            Number, Number, Number}];\)\), "\[IndentingNewLine]", 
    \(\(ndat = Length[data1];\)\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Rescale\ Data, \ Define\ new\ Arrays\ with\ Data\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(zz = data1[\([#, 1]\)] &;\)\), "\n", 
    \(\(pbolo = data1[\([#, 2]\)] &;\)\), "\n", 
    \(\(spbolo = data1[\([#, 3]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(sbolo = data1[\([#, 4]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(ssbolo = data1[\([#, 5]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(fbeam = data1[\([#, 6]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(sfbeam = data1[\([#, 7]\)] &;\)\), "\[IndentingNewLine]", 
    \(\(tlag = 
        data1[\([#, 8]\)]/\((\((1 + zz[#])\) 
                0.1)\) &;\)\), "\[IndentingNewLine]", 
    \(\(stlag = 
        data1[\([#, 9]\)]/\((\((1 + zz[#])\) 
                0.1)\) &;\)\), "\[IndentingNewLine]", 
    \(\(var = 
        data1[\([#, 10]\)]\ \((1 + zz[#])\)/
              0.02 &;\)\), "\[IndentingNewLine]", 
    \(\(svar = 
        data1[\([#, 11]\)] \((1 + zz[#])\)/
              0.02 &;\)\), "\[IndentingNewLine]", 
    \(\(epeak = 
        data1[\([#, 12]\)]\ \((1 + zz[#])\)/
              300 &;\)\), "\[IndentingNewLine]", 
    \(\(sepeak1 = 
        data1[\([#, 13]\)] \((1 + zz[#])\)/
              300 &;\)\), "\[IndentingNewLine]", 
    \(\(sepeak2 = 
        data1[\([#, 14]\)] \((1 + zz[#])\)/
              300 &;\)\), "\[IndentingNewLine]", 
    \(\(trt = 
        data1[\([#, 
                15]\)]/\((\((1 + 
                    zz[#])\)\ 0.1)\) &;\)\), "\[IndentingNewLine]", 
    \(\(strt = data1[\([#, 16]\)]/\((\((1 + zz[#])\)\ 0.1)\) &;\)\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Fix\ \[CapitalOmega]\_m, \ 
        evaluate\ \(d\_L\) \((z)\)\ and\ evaluate\ L, \ 
        E\_\[Gamma]\ and\ corresponding\ errors\ \((for\ E\_\[Gamma]\ find\ \
error\ of\ Log \((E\_\[Gamma])\))\)\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(Clear[f, dl, dld, zmin, zmax]; om = 0.26; w0 = \(-1\); w1 = 0; 
    h0 = 10^5\ h; \ c = 3\ 10^8; h = 0.72; 
    res = {};\), "\[IndentingNewLine]", 
    \(\(f[z_] := 
        1/Sqrt[om*\((1 + z)\)^3\  + \((1 - 
                    om)\)*\((1 + z)\)^\((3 \((1 + w0\  + \ w1)\))\) 
                Exp[3\ w1\ \((\((1/\((1 + z)\))\) - 1)\)]];\)\), "\n", 
    \(\(dl[zz_] := 
        c \((1 + zz)\)\ NIntegrate[f[z], {z, 0, zz}]/h0;\)\)}], "Input"],

Cell[BoxData[{
    \(\(dld = dl[zz[#]] 3\ 10^24 &;\)\), "\n", 
    \(\(ll = 4\ Pi\ dld[#]^2\ pbolo[#] &;\)\), "\n", 
    \(\(sll = 4\ Pi\ dld[#]^2\ spbolo[#] &;\)\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Define\ redshift\ bin\ ranges\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zreg = {0, 1, 2, 3, 7}\)], "Input"],

Cell[BoxData[
    \({0, 1, 2, 3, 7}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Do", "[", 
      RowBox[{
        RowBox[{\(zmin = zreg[\([i]\)]\), ";", \(zmax = zreg[\([i + 1]\)]\), 
          ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ For\ a\ given\ redshift\ bin, \ 
              construct\ arrays\ with\ \((Log \((E\_peak)\) - 
                    Log \((E\_\[Gamma])\))\)\ and\ corresponding\ errors\ *) \
\),
            FontSize->18], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", \(Clear[llvar, sllvar, zzt]\), ";", 
          "\[IndentingNewLine]", \(llvar = {}\), ";", \(sllvar = {}\), 
          ";", \(zzt = {}\), ";", 
          "\n", \(Do[\[IndentingNewLine]If[
              var[i] > 0\  && \ zz[i] \[GreaterEqual] zmin\  && \ 
                zz[i] \[LessEqual] \ zmax, \[IndentingNewLine]AppendTo[zzt, 
                zz[i]]; \[IndentingNewLine]AppendTo[
                llvar, {Log[10, var[i]], 
                  Log[10, ll[i]]}]; \[IndentingNewLine]AppendTo[
                sllvar, {svar[i]/\((Log[10]\ var[i])\), 
                  sll[i]/\((Log[10]\ ll[i])\)}]], {i, 1, ndat}]\), ";", "\n", 
          "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ 
              Symmetrically\ Minimize\ \[Chi]\^2\ to\ find\ best\ fit\ \
parameters\ a\_j\ \ \((b1)\), \ 
              b\_j\ \((a1)\)\ for\ the\ given\ redshift\ bin . \ 
                  Set\ proper\ value\ to\ intrinsic\ error\ s1 . \ 
                  Use\ covariance\ matrix\ cij\ to\ find\ errors\ of\ a\_j, \ \
\(\(b\_j\)\(.\)\)\ *) \),
            FontSize->18], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", \(llp[a1_, b1_, x_] := a1\  + \ b1\ x\), ";",
           "\[IndentingNewLine]", \(varp[a1_, b1_, x_] := \((x - a1)\)/b1\), 
          ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", \(chi2[a1_, b1_, s1_] := 
            Sum[\((\((llvar[\([i, 2]\)] - 
                          llp[a1, b1, 
                            llvar[\([i, 1]\)]])\)^2/\((sllvar[\([i, 2]\)]^2 + 
                        s1^2)\))\), {i, 1, Length[llvar]}] + 
              Sum[\((\((llvar[\([i, 1]\)] - 
                          varp[a1, b1, 
                            llvar[\([i, 2]\)]])\)^2/\((sllvar[\([i, 1]\)]^2 + 
                        s1^2)\))\), {i, 1, Length[llvar]}]\), ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", \(s1 = 0.42\), ";", 
          "\n", \(par = {a1, b1}\), ";", 
          "\n", \(akl[a1_, b1_, k_, l_] := 
            1/2  D[D[chi2[a1, b1, 0.5], par[\([k]\)]], par[\([l]\)]\ ]\), ";",
           "\n", \(fmingrb = 
            FindMinimum[chi2\ [a1, b1, s1], {a1, 1}, {b1, \(-10\)}]\), ";", 
          "\n", \(a1o = fmingrb[\([2, 1, 2]\)]\), ";", 
          "\n", \(b1o = fmingrb[\([2, 2, 2]\)]\), ";", 
          "\n", \(aklo = 
            Table[If[
                k \[LessSlantEqual] 
                  l, \(akl[a1, b1, k, l] /. a1 \[Rule] a1o\) /. 
                  b1 \[Rule] b1o, \(akl[a1, b1, l, k] /. a1 \[Rule] a1o\) /. 
                  b1 \[Rule] b1o], {k, 1, 2}, {l, 1, 2}]\), 
          ";", \(cij = Inverse[aklo]\), 
          ";", \(spar = Table[Sqrt[cij[\([i, i]\)]], {i, 1, 2}]\), 
          ";", \(Print["\<a1= \>", a1o, "\<+-\>", 
            spar[\([1]\)], "\<  b1= \>", b1o, "\<+-\>", spar[\([2]\)]]\), 
          ";", \(cij // MatrixForm\), ";", 
          "\[IndentingNewLine]", \(erra1o = spar[\([1]\)]\), ";", 
          "\[IndentingNewLine]", \(errb1o = spar[\([2]\)]\), ";", 
          "\[IndentingNewLine]", \(chi2r = 
            Part[fmingrb, 1]/\((2\ Length[llvar])\)\), ";", 
          "\[IndentingNewLine]", \(ngrb = Length[llvar]\), ";", "  ", 
          "\[IndentingNewLine]", \(Print["\<chi2r=\>", chi2r, "\<  ngrb=\>", 
            ngrb]\), ";", "\n", "\[IndentingNewLine]", \(meanz = Mean[zzt]\), 
          ";", "\[IndentingNewLine]", \(AppendTo[
            res, {meanz, a1o, erra1o, b1o, errb1o, chi2r, ngrb}]\)}], ",", 
        " ", \({i, 1, 4}\)}], "]"}]], "Input"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.365388811553515`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.1319641894069223`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.5406861029351635`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.27441176580988264`\),
      SequenceForm[ 
      "a1= ", 52.365388811553515, "+-", .13196418940692231, "  b1= ", 
        1.5406861029351635, "+-", .27441176580988264],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]1.3069500062479138`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]14\),
      SequenceForm[ "chi2r=", 1.3069500062479138, "  ngrb=", 14],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.51097254431287`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.1175095497620017`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.9288157814807487`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.32391443297571887`\),
      SequenceForm[ 
      "a1= ", 52.510972544312871, "+-", .1175095497620017, "  b1= ", 
        1.9288157814807487, "+-", .32391443297571887],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.7081616940148939`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]15\),
      SequenceForm[ "chi2r=", .70816169401489393, "  ngrb=", 15],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.431632976154646`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.16624824114539044`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]1.8352290716310657`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.4715190830287017`\),
      SequenceForm[ 
      "a1= ", 52.431632976154646, "+-", .16624824114539044, "  b1= ", 
        1.8352290716310657, "+-", .47151908302870171],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.6285488659986654`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]9\),
      SequenceForm[ "chi2r=", .62854886599866544, "  ngrb=", 9],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("a1= "\[InvisibleSpace]52.828299710447325`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.100689663406974`\[InvisibleSpace]"  \
b1= "\[InvisibleSpace]\(-0.8879803177628923`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.21982298935240943`\),
      SequenceForm[ 
      "a1= ", 52.828299710447325, "+-", .10068966340697399, 
        "  b1= ", -.88798031776289232, "+-", .21982298935240943],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("chi2r="\[InvisibleSpace]0.8863793517477965`\
\[InvisibleSpace]"  ngrb="\[InvisibleSpace]13\),
      SequenceForm[ "chi2r=", .88637935174779647, "  ngrb=", 13],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ Plot\ best\ fit\ parameter\ values\ b\_j\ \((a1dtpl)\), \ 
        a\_j\ \((b1dtpl)\)\ as\ function\ of\ redshift\ bin\ \((mean\ \
redshift\ of\ each\ bin)\)\ with\ errors\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(a1pl = {}; b1pl = {};\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]AppendTo[
        a1pl, {res[\([i, 1]\)], res[\([i, 2]\)], 
          res[\([i, 3]\)]}]; \[IndentingNewLine]AppendTo[
        b1pl, {res[\([i, 1]\)], res[\([i, 4]\)], res[\([i, 5]\)]}], {i, 1, 
        4}]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a1dtpl = 
        ErrorListPlot[a1pl, Frame \[Rule] True, 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(b1dtpl = 
        ErrorListPlot[b1pl, Frame \[Rule] True, 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.184185 0.288595 -44.1865 0.846224 [
[.10441 -0.0125 -7.03125 -24.5625 ]
[.10441 -0.0125 7.03125 0 ]
[.24871 -0.0125 -14.5625 -24.5625 ]
[.24871 -0.0125 14.5625 0 ]
[.39301 -0.0125 -7.03125 -24.5625 ]
[.39301 -0.0125 7.03125 0 ]
[.5373 -0.0125 -14.5625 -24.5625 ]
[.5373 -0.0125 14.5625 0 ]
[.6816 -0.0125 -7.03125 -24.5625 ]
[.6816 -0.0125 7.03125 0 ]
[.8259 -0.0125 -14.5625 -24.5625 ]
[.8259 -0.0125 14.5625 0 ]
[.9702 -0.0125 -7.03125 -24.5625 ]
[.9702 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07105 -39.1875 -12.2813 ]
[-0.0125 .07105 0 12.2813 ]
[-0.0125 .15568 -39.1875 -12.2813 ]
[-0.0125 .15568 0 12.2813 ]
[-0.0125 .2403 -39.1875 -12.2813 ]
[-0.0125 .2403 0 12.2813 ]
[-0.0125 .32492 -39.1875 -12.2813 ]
[-0.0125 .32492 0 12.2813 ]
[-0.0125 .40954 -39.1875 -12.2813 ]
[-0.0125 .40954 0 12.2813 ]
[-0.0125 .49416 -39.1875 -12.2813 ]
[-0.0125 .49416 0 12.2813 ]
[-0.0125 .57879 -39.1875 -12.2813 ]
[-0.0125 .57879 0 12.2813 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10441 0 m
.10441 .00625 L
s
gsave
.10441 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.24871 0 m
.24871 .00625 L
s
gsave
.24871 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.39301 0 m
.39301 .00625 L
s
gsave
.39301 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5373 0 m
.5373 .00625 L
s
gsave
.5373 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.6816 0 m
.6816 .00625 L
s
gsave
.6816 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.8259 0 m
.8259 .00625 L
s
gsave
.8259 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
1.000 setlinewidth
grestore
.9702 0 m
.9702 .00625 L
s
gsave
.9702 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.13327 0 m
.13327 .00375 L
s
.16213 0 m
.16213 .00375 L
s
.19099 0 m
.19099 .00375 L
s
.21985 0 m
.21985 .00375 L
s
.27757 0 m
.27757 .00375 L
s
.30643 0 m
.30643 .00375 L
s
.33529 0 m
.33529 .00375 L
s
.36415 0 m
.36415 .00375 L
s
.42187 0 m
.42187 .00375 L
s
.45072 0 m
.45072 .00375 L
s
.47958 0 m
.47958 .00375 L
s
.50844 0 m
.50844 .00375 L
s
.56616 0 m
.56616 .00375 L
s
.59502 0 m
.59502 .00375 L
s
.62388 0 m
.62388 .00375 L
s
.65274 0 m
.65274 .00375 L
s
.71046 0 m
.71046 .00375 L
s
.73932 0 m
.73932 .00375 L
s
.76818 0 m
.76818 .00375 L
s
.79704 0 m
.79704 .00375 L
s
.85476 0 m
.85476 .00375 L
s
.88362 0 m
.88362 .00375 L
s
.91248 0 m
.91248 .00375 L
s
.94134 0 m
.94134 .00375 L
s
.07555 0 m
.07555 .00375 L
s
.04669 0 m
.04669 .00375 L
s
.01783 0 m
.01783 .00375 L
s
.99906 0 m
.99906 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07105 m
.00625 .07105 L
s
gsave
-0.0125 .07105 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.3) show
1.000 setlinewidth
grestore
0 .15568 m
.00625 .15568 L
s
gsave
-0.0125 .15568 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.4) show
1.000 setlinewidth
grestore
0 .2403 m
.00625 .2403 L
s
gsave
-0.0125 .2403 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.5) show
1.000 setlinewidth
grestore
0 .32492 m
.00625 .32492 L
s
gsave
-0.0125 .32492 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.6) show
1.000 setlinewidth
grestore
0 .40954 m
.00625 .40954 L
s
gsave
-0.0125 .40954 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.7) show
1.000 setlinewidth
grestore
0 .49416 m
.00625 .49416 L
s
gsave
-0.0125 .49416 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.8) show
1.000 setlinewidth
grestore
0 .57879 m
.00625 .57879 L
s
gsave
-0.0125 .57879 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.9) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08798 m
.00375 .08798 L
s
0 .1049 m
.00375 .1049 L
s
0 .12183 m
.00375 .12183 L
s
0 .13875 m
.00375 .13875 L
s
0 .1726 m
.00375 .1726 L
s
0 .18952 m
.00375 .18952 L
s
0 .20645 m
.00375 .20645 L
s
0 .22337 m
.00375 .22337 L
s
0 .25722 m
.00375 .25722 L
s
0 .27415 m
.00375 .27415 L
s
0 .29107 m
.00375 .29107 L
s
0 .308 m
.00375 .308 L
s
0 .34184 m
.00375 .34184 L
s
0 .35877 m
.00375 .35877 L
s
0 .37569 m
.00375 .37569 L
s
0 .39262 m
.00375 .39262 L
s
0 .42647 m
.00375 .42647 L
s
0 .44339 m
.00375 .44339 L
s
0 .46032 m
.00375 .46032 L
s
0 .47724 m
.00375 .47724 L
s
0 .51109 m
.00375 .51109 L
s
0 .52801 m
.00375 .52801 L
s
0 .54494 m
.00375 .54494 L
s
0 .56186 m
.00375 .56186 L
s
0 .05413 m
.00375 .05413 L
s
0 .0372 m
.00375 .0372 L
s
0 .02028 m
.00375 .02028 L
s
0 .00335 m
.00375 .00335 L
s
0 .59571 m
.00375 .59571 L
s
0 .61264 m
.00375 .61264 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.10441 .61178 m
.10441 .61803 L
s
.24871 .61178 m
.24871 .61803 L
s
.39301 .61178 m
.39301 .61803 L
s
.5373 .61178 m
.5373 .61803 L
s
.6816 .61178 m
.6816 .61803 L
s
.8259 .61178 m
.8259 .61803 L
s
.9702 .61178 m
.9702 .61803 L
s
.125 Mabswid
.13327 .61428 m
.13327 .61803 L
s
.16213 .61428 m
.16213 .61803 L
s
.19099 .61428 m
.19099 .61803 L
s
.21985 .61428 m
.21985 .61803 L
s
.27757 .61428 m
.27757 .61803 L
s
.30643 .61428 m
.30643 .61803 L
s
.33529 .61428 m
.33529 .61803 L
s
.36415 .61428 m
.36415 .61803 L
s
.42187 .61428 m
.42187 .61803 L
s
.45072 .61428 m
.45072 .61803 L
s
.47958 .61428 m
.47958 .61803 L
s
.50844 .61428 m
.50844 .61803 L
s
.56616 .61428 m
.56616 .61803 L
s
.59502 .61428 m
.59502 .61803 L
s
.62388 .61428 m
.62388 .61803 L
s
.65274 .61428 m
.65274 .61803 L
s
.71046 .61428 m
.71046 .61803 L
s
.73932 .61428 m
.73932 .61803 L
s
.76818 .61428 m
.76818 .61803 L
s
.79704 .61428 m
.79704 .61803 L
s
.85476 .61428 m
.85476 .61803 L
s
.88362 .61428 m
.88362 .61803 L
s
.91248 .61428 m
.91248 .61803 L
s
.94134 .61428 m
.94134 .61803 L
s
.07555 .61428 m
.07555 .61803 L
s
.04669 .61428 m
.04669 .61803 L
s
.01783 .61428 m
.01783 .61803 L
s
.99906 .61428 m
.99906 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07105 m
1 .07105 L
s
.99375 .15568 m
1 .15568 L
s
.99375 .2403 m
1 .2403 L
s
.99375 .32492 m
1 .32492 L
s
.99375 .40954 m
1 .40954 L
s
.99375 .49416 m
1 .49416 L
s
.99375 .57879 m
1 .57879 L
s
.125 Mabswid
.99625 .08798 m
1 .08798 L
s
.99625 .1049 m
1 .1049 L
s
.99625 .12183 m
1 .12183 L
s
.99625 .13875 m
1 .13875 L
s
.99625 .1726 m
1 .1726 L
s
.99625 .18952 m
1 .18952 L
s
.99625 .20645 m
1 .20645 L
s
.99625 .22337 m
1 .22337 L
s
.99625 .25722 m
1 .25722 L
s
.99625 .27415 m
1 .27415 L
s
.99625 .29107 m
1 .29107 L
s
.99625 .308 m
1 .308 L
s
.99625 .34184 m
1 .34184 L
s
.99625 .35877 m
1 .35877 L
s
.99625 .37569 m
1 .37569 L
s
.99625 .39262 m
1 .39262 L
s
.99625 .42647 m
1 .42647 L
s
.99625 .44339 m
1 .44339 L
s
.99625 .46032 m
1 .46032 L
s
.99625 .47724 m
1 .47724 L
s
.99625 .51109 m
1 .51109 L
s
.99625 .52801 m
1 .52801 L
s
.99625 .54494 m
1 .54494 L
s
.99625 .56186 m
1 .56186 L
s
.99625 .05413 m
1 .05413 L
s
.99625 .0372 m
1 .0372 L
s
.99625 .02028 m
1 .02028 L
s
.99625 .00335 m
1 .00335 L
s
.99625 .59571 m
1 .59571 L
s
.99625 .61264 m
1 .61264 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.02381 .01472 m
.02381 .23806 L
s
.015 w
.02381 .12639 Mdot
.002 w
.23601 .15014 m
.23601 .34902 L
s
.015 w
.23601 .24958 Mdot
.002 w
.51486 .04176 m
.51486 .32313 L
s
.015 w
.51486 .18244 Mdot
.002 w
.97619 .43291 m
.97619 .60332 L
s
.015 w
.97619 .51811 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{659.938, 407.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:C0001Ub000`400?l00000o`00003oo`3ooooo
0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo
003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00K@3oool00`3o_g@00000000000020000
0003001d_`3oool0oooo04P0oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3oool0
gia800000018W=l00P3oool01P2oM000000000000000000004RL0=ooodT0oooo00<0gia800000000
00001@0000000`1d_ol0oooo0?ooo`150?ooo`030=nLB0000000000000D0000000H0M;oo0?ooo`3o
ool0gia800000018W=l20?ooo`060;md00000000000000000000B9`0goooB@3oool00`3ooml0W4P0
00000002000000030018W03Oool0oooo04P0oooo00<0oooO09a8000000000P0000000`00B9`0gooo
0?ooo`030?ooo`030=nLB0000000B9cO0080oooo00H0_g@000000000000000000018W03Ooom>0?oo
o`030?noM0000000M;oo01<0oooo001_0?ooo`030;md000007@0_ooo04d0oooo00<0_g@00000M02o
ool0103oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`19
0?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool0AP3oool00`3OW4P0000000000004
0000000:001d_`3oool0oooo0=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`80oooo00<0omnL04Q8
W03Oool0B03oool0203ogi`0B0000018W03Oool0oooo0?oOW01804P0W=ooB03oool0203ogi`0B000
0018W03Oool0oooo0?oOW01804P0W=oo0`3oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l0
0P3oool00`3ogi`0B4RL0=ooo`1=0?ooo`030?noM0000000M;oo01<0oooo001_0?ooo`030;md0000
07@0_ooo04d0oooo00<0_g@00000M02oool03P3oool00`3ogi`0B7Bo0?ooo`190?ooo`030=nLB018
W=l0oooo0080oooo00<0oooO09a8M02oool0B03oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2L
B7@0_ooo00/0oooo00<0omnL04Qd_`3oool0C@3oool00`3o_g@004RL0=ooo`1=0?ooo`030?noM000
B9`0gooo00`0oooo00<0omnL04Qd_`3oool0C03oool00`3o_g@0000007Boo`0C0?ooo`00K`3oool0
0`2oM000001d0;ooo`1=0?ooo`030;md000007@0_ooo00h0oooo00<0oono07@0B02Lgol0BP3oool0
0`3OW4P0B9cO0?ooo`1=0?ooo`030=nLB018W=l0oooo00l0oooo00<0oono07@0B02Lgol0C@3oool0
0`3o_g@0001809cOo`1=0?ooo`030?noM00004P0W=oo00`0oooo00<0oono07@0B02Lgol0A`3oool0
0`3OW4P0000000000005000000030000B02Lgol0oooo0100oooo001_0?ooo`030;md000007@0_ooo
04d0oooo00<0_g@00000M02oool03P3oool00`3ookl0M00007Boo`1;0?ooo`030=nLB01d_ol0oooo
04d0oooo00<0gia807Boo`3oool03P3oool00`3ookl0M00007Boo`1=0?ooo`030;md000004P0W=oo
04d0oooo00<0_g@00000B02Lgol0303oool00`3ookl0M00007Boo`170?ooo`030?oOW018M;l0oooo
0080oooo00<0okmd0000001d_ol04`3oool006l0oooo00<0_g@00000M02oool0C@3oool00`2oM000
001d0;ooo`0>0?ooo`030?noM0000000M;oo04/0oooo00<0oooO09a8B02Lgol0C@3oool00`3ooml0
W4Q809cOo`0>0?ooo`030?noM0000000M;oo04`0oooo00@0_g@00000000007@0_oooC03oool0102o
M00000000000M02oool<0?ooo`030?noM0000000M;oo04P0oooo00L0gia807Boo`3oool0oooo0?no
M0000000M;oo01<0oooo001_0?ooo`030;md000007@0_ooo04d0oooo00<0_g@00000M02oool03@3o
ool0103ogi`0B0000000M02ooom<0?ooo`030?oOW01807@0_ooo04d0oooo00<0omnL04P0M02oool0
303oool0103ogi`0B0000000M02ooom90?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3o
ool0B03oool00`3ookl0M000000000020000000304RLg`3oool0oooo00X0oooo00@0omnL04P00000
07@0_oooB03oool01`3ookl0M01d0;ooo`3oool0okmd0000001d_ol04`3oool006l0oooo00<0_g@0
0000M02oool0C@3oool00`2oM000001d0;ooo`090?ooo`040=oOg`3oool0oooo0;md0080000000<0
B9cO0?ooo`3oool0C03oool00`2oM000B9cO0?ooo`1=0?ooo`030;md0018W=l0oooo00L0oooo00@0
gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`1:0?ooo`030?noM00004P0W=oo04d0oooo
00<0okmd0000B02Lgol02@3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo04P0
oooo00H0okmd001d_`3oool0okmd0000001d_olC0?ooo`00K`3oool00`2oM000001d0;ooo`1=0?oo
o`030;md000007@0_ooo00T0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`1=0?oo
o`030=nLB00007@0_ooo04d0oooo00<0gia80000M02oool01`3oool00`3o_g@00000000000020000
0003001d_`3oool0oooo04`0oooo00<0omnL04Qd_`3oool0C@3oool00`3ogi`0B7Bo0?ooo`080?oo
o`030?noM000000000000080000000<007Bo0?ooo`3oool0BP3oool01@2oM000M;oo0?noM0000000
M;oo01<0oooo001_0?ooo`030;md000007@0_ooo04d0oooo00<0_g@00000M02oool02@3oool01@3o
oml0W4P00000000007@0_ooo0500oooo00<0okmd0000001d_ol0C@3oool00`3o_g@0000007Boo`07
0?ooo`050?oog`2LB00000000000M02oool0C`3oool00`3ooml0W4P004RLg`1=0?ooo`030?oog`2L
B000B9cO00P0oooo00D0oooO09a800000000001d0;ooo`1=0?ooo`050?oo_`1d07@0_kmd0000001d
_ol04`3oool006l0oooo00<0_g@00000M02oool0C@3oool00`2oM000001d0;ooo`0:0?ooo`030?no
M000M;l0oooo04/0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`170?ooo`030?oO
W02L_ol0oooo00<0oooo00<0_g@00000001d_ol0203oool00`3o_g@007Bo0?ooo`1;0?ooo`030?oo
g`2LM9`0gooo0080oooo00<0oooO09a80000M;l0B03oool00`3ooml0W7BL0=ooo`020?ooo`030?oo
g`2LB00007Bo00T0oooo00<0okmd001d_`3oool0C`3oool0103o_g@000000000001d_olC0?ooo`00
K@3oool01@3OW4P000000000000007@0_ooo04/0oooo00D0gia8000000000000001d0;ooo`0:0?oo
o`030?oog`2LB00000000080000000<0001d0;ooo`3oool0A`3oool0202oM000M;oo0?ooo`3oool0
gia800000000B9`0goooB03oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo203oool0
0`3ooml0W4P000000002000000030000M02oool0oooo04L0oooo00L0omnL04Q8W03Oool0oooo0=nL
B0000000M;oo04T0oooo00L0omnL04Q8W03Oool0oooo0=nLB0000000M;oo00T0oooo00<0oooO09a8
000000000P0000000`0007@0_ooo0?ooo`1:0?ooo`040?oog`2LB000000007Booa<0oooo001^0?oo
o`040?oo_`1d0000001d0;oood`0oooo00@0oono07@0000007@0_ooo2`3oool00`3o_g@000000000
00020000000307Boo`3oool0oooo04L0oooo00D0_g@00000000000000000001d_`1;0?ooo`050;md
00000000000000000000M;l02`3oool00`3o_g@00000000000020000000307Boo`3oool0oooo04L0
oooo00D0omnL04P000000000000004RLg`1;0?ooo`050?oOW0180000000000000018W=l02`3oool0
0`3o_g@00000000000020000000307Boo`3oool0oooo04X0oooo00<0omnL04P0001d_ol04`3oool0
0?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3o
oonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00
o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oo
oiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00<@3ooooo00000?l00000H@00
00030?ooo`00<@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool00@3oool00340oooo0`0000080?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo0`0000030?oo
o`00<@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool00@3oool00340oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003o
ool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0
oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo
0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo0040
oooo000a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodh0oooo
00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`3o0?ooool0ooooCP3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0?l0ooooo`3ooom>0?ooo`030000003oool0oooo0040oooo000a0?oo
o`<00000303oool00`000000oooo0?ooo`3o0?ooool0ooooC03oool3000000<0oooo000a0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodh0oooo00<000000?ooo`3o
ool00@3oool00340oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooool0oooo
CP3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom>0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodh0oooo00<000000?ooo`3oool00@3oool0
0340oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooool0ooooCP3oool00`00
0000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
ooooo`3ooom>0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0o`3ooooo0?ooodh0oooo00<000000?ooo`3oool00@3oool00340oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooool0ooooCP3oool00`000000oooo0?oo
o`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooom>
0?ooo`030000003oool0oooo0040oooo000a0?ooo`<00000303oool00`000000oooo0?ooo`3o0?oo
ool0ooooC03oool3000000<0oooo000a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooodh0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`3o0?ooool0ooooCP3oool00`000000oooo0?ooo`010?ooo`00<@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?oo
o`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0
oooo0040oooo000a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolW0?oo
o`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`3o0?ooob@0
oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo
000a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003o
ool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<00000
0?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?oo
obL0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`<0
0000303oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`<0
00000`3oool00340oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooobL0oooo
00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo0?l0oooo903o
ool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0?l0oooo9`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool0
00D0oooo00H0_g@000000000000000000018W03Oool30?ooo`030=nLB0000000000000D0000000T0
M;oo0?ooo`3oool0gia800000018W=l0oooo0?oog`2LB0000`0000000`00B9`0gooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo
0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00103oool00`3ooml0W4P004RLg`020?ooo`03
0?oOW018B9`0gooo00<0oooo00<0gia8000000000000100000003`00M;l0oooo0?ooo`3OW4P00000
04RLg`3oool0omnL04P00000B9`0gooo0?ooo`3ogi`0B01809cOo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo0?l0oooo903oool00`00
0000oooo0?ooo`010?ooo`002P3oool00`3ogi`0B7Bo0?ooo`030?ooo`030=nLB018W=l0oooo0080
oooo00<0oooO09a8M02oool02`3oool00`3o_g@004RL0=ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo0?l0oooo903oool00`000000
oooo0?ooo`010?ooo`002P3oool00`3ookl0M01809cOo`040?ooo`030=nLB018W=l0oooo00l0oooo
00<0okmd0000B02Lgol02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo
9`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool000X0oooo00<0
oono07@0001d_ol01@3oool00`3OW4P0M;oo0?ooo`0>0?ooo`030;md000004P0W=oo00/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0o`3o
oolT0?ooo`030000003oool0oooo0040oooo000:0?ooo`030?noM0000000M;oo00D0oooo00<0oooO
09a8B02Lgol03@3oool0102oM00000000000M02oool;0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?oo
o`010?ooo`002@3oool0103ogi`0B0000000M02oool60?ooo`030?oOW01807@0_ooo00T0oooo00<0
oono07@0000000000P0000000`18W=l0oooo0?ooo`0:0?ooo`D000002P3oool00`000000oooo0?oo
o`3o0?ooobL0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`@000000`3oool000D0oooo00@0gmoO
0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`060?ooo`030;md0018W=l0oooo00X0oooo00<0
okmd0000B02Lgol03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo9`3o
ool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool000D0oooo00<0okmd
0000000000000P0000000`00M;l0oooo0?ooo`070?ooo`030=nLB00007@0_ooo00/0oooo00<0omnL
04Qd_`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo9`3oool0
0`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool000D0oooo00D0oooO09a8
00000000001d0;ooo`0:0?ooo`030?noM0000000M;oo00/0oooo00<0oooO09a80018W=l0303oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`3o
0?ooob@0oooo00<000000?ooo`3oool00@3oool000H0oooo00<0okmd001d_`3oool01@3oool00`3o
gi`0W;oo0?ooo`030?ooo`030;md00000000M;oo00H0oooo00<0oooO09adW03Oool00P3oool00`3o
oml0W4P0001d_`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolW0?oo
o`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`001P3oool00`3ooml0
W4P000000002000000060000M02oool0oooo0?ooo`2oM000M;oo0P3oool0103OW4P000000018W03O
ool70?ooo`070?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`0<0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo0?l0oooo903oool00`000000
oooo0?ooo`010?ooo`001`3oool00`3o_g@00000000000020000000507Boo`3oool0oooo0?ooo`2o
M0000`0000000`00M;l0oooo0?ooo`080?ooo`050?oOW0180000000000000018W=l03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`3o0?oo
ob@0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040
oooo000a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000
003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<0
00000?ooo`3oool00@3oool00340oooo0`00000<0?ooo`030000003oool0oooo0?l0oooo9`3oool0
0`000000oooo0?ooo`3o0?ooob80oooo0`0000030?ooo`00<@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?oo
o`3oool00@3oool00340oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooobL0
oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo0?l0oooo
903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3o
ool00340oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooobL0oooo00<00000
0?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo0?l0oooo903oool00`00
0000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0
oooo9`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0
o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?oo
o`010?ooo`00<@3oool3000000`0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0
oooo0?l0oooo8P3oool3000000<0oooo000a0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0o`3ooolW0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?oo
o`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo9`3oool00`000000
oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000
003oool0oooo0040oooo000a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3o
oolW0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00<@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`3o
0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo
0040oooo000a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`03
0000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`3o0?ooob@0oooo
00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool02`3oool300000?l0oooo:03o
ool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo00<00000
0?ooo`3oool02@3oool700000?l0oooo9P3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<00000
0?ooo`3oool00@3oool00340oooo0`0000090?ooo`L00000o`3ooolV0?ooo`030000003oool0oooo
0?l0oooo8P3oool3000000<0oooo000a0?ooo`030000003oool0oooo00P0oooo2@00003o0?ooobD0
oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000
003oool0oooo00P0oooo2@00003o0?ooobD0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000
003oool0oooo0040oooo000a0?ooo`030000003oool0oooo00P0oooo2@00003o0?ooobD0oooo00<0
00000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0
oooo00T0oooo1`00003o0?ooobH0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0
oooo0040oooo000a0?ooo`030000003oool0oooo00T0oooo1`00003o0?ooobH0oooo00<000000?oo
o`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo00/0
oooo0`00003o0?ooobP0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040
oooo000a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000
003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<0
00000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o
0?ooobL0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?oo
o`<00000303oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0o`3ooolR0?oo
o`<000000`3oool00340oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooobL0
oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo0?l0oooo
903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3o
ool000D0oooo00H0_g@000000000000000000018W03Oool30?ooo`030=nLB0000000000000D00000
00H0M;oo0?ooo`3oool0gia800000018W=l60?ooo`030?noM0000000M;oo00`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0o`3ooolT0?oo
o`030000003oool0oooo0040oooo00040?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8W03O
ool00`3oool00`3OW4P000000000000400000006001d_`3oool0oooo0=nLB0000000B9cO1P3oool0
0`3o_g@0000007Boo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolW
0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`002P3oool00`3o
gi`0B7Bo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool02P3oool00`3o
_g@0000007Boo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolW0?oo
o`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`002P3oool00`3ookl0
M01809cOo`040?ooo`030=nLB018W=l0oooo00T0oooo00<0gia80000000000001@0000000`0004P0
W=oo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`000000
oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00
2P3oool00`3ookl0M00007Boo`050?ooo`030=nLB01d_ol0oooo00P0oooo00<0omnL04Qd_`3oool0
0P3oool00`3o_g@0000007Boo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo
0?ooo`010?ooo`002P3oool00`3o_g@0000007Boo`050?ooo`030?oog`2LB4P0W=oo00T0oooo00L0
gia807Boo`3oool0oooo0?noM0000000M;oo00`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`03
0000003oool0oooo0040oooo00090?ooo`040?oOW0180000001d0;ooo`H0oooo00<0omnL04P0M02o
ool0203oool01`3ookl0M01d0;ooo`3oool0okmd0000001d_ol0303oool5000000X0oooo00<00000
0?ooo`3oool0O@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo8@3oool4
000000<0oooo00050?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool01P3oool0
0`2oM000B9cO0?ooo`080?ooo`060?noM000M;l0oooo0?noM0000000M;oo303oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0YP3oool00`000000oooo
0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool000D0oooo00<0okmd0000000000000P00
00000`00M;l0oooo0?ooo`070?ooo`030=nLB00007@0_ooo00T0oooo00D0_g@007Boo`3o_g@00000
07Boo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo
0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`001@3o
ool01@3ooml0W4P00000000007@0_ooo00X0oooo00<0okmd0000001d_ol02@3oool01@3ookl0M01d
0;noM0000000M;oo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040
oooo00060?ooo`030?noM000M;l0oooo00D0oooo00<0omnL09boo`3oool00`3oool00`2oM0000000
07Boo`0:0?ooo`040?noM0000000000007Boo``0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`03
0000003oool0oooo0040oooo00060?ooo`030?oog`2LB00000000080000000H0001d0;ooo`3oool0
oooo0;md001d_ol20?ooo`040=nLB000000004RL0=ooo`X0oooo00@0oooO09a800000000M;oo303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0YP3o
ool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool000L0oooo00<0okmd
0000000000000P0000001@1d_ol0oooo0?ooo`3oool0_g@000<0000000<007Bo0?ooo`3oool02`3o
ool00`3ogi`0B00007Boo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?oo
o`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00<00000
0?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool0
0340oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo
0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2V0?ooo`03
0000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00<@3oool3000000`0oooo
00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo
8P3oool3000000<0oooo000a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?oo
o`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00<00000
0?ooo`3oool0Y@3oool300000?l0oooo9@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0X`3oool70000
0?l0oooo8`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo07d0oooo00<000000?ooo`3oool0X`3oool700000?l0oooo8`3oool00`000000
oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo
00<000000?ooo`3oool0XP3oool900000?l0oooo8P3oool00`000000oooo0?ooo`010?ooo`00<@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0XP3o
ool900000?l0oooo8P3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0XP3oool900000?l0oooo8P3oool0
0`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
07d0oooo00<000000?ooo`3oool0X`3oool700000?l0oooo8`3oool00`000000oooo0?ooo`010?oo
o`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3o
ool0X`3oool700000?l0oooo8`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0Y@3oool300000?l0oooo
9@3oool00`000000oooo0?ooo`010?ooo`00<@3oool3000000`0oooo00<000000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo8P3oool3000000<0oooo000a
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0YP3oool00`00
0000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo
903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo07d0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<0
00000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m
0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0
oooo0040oooo000a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?oo
o`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo
00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`<00000303o
ool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3o
oolR0?ooo`<000000`3oool00340oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m
0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0
oooo0040oooo000a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?oo
o`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo
00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o
0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?oo
o`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0O@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000
oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool0
0@3oool00340oooo0`00000<0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0YP3o
ool00`000000oooo0?ooo`3o0?ooob80oooo0`0000030?ooo`00<@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o
0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?oo
o`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0O@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000
oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool0
0@3oool000D0oooo00H0_g@000000000000000000018W03Oool30?ooo`030=nLB0000000000000D0
000000H0M;oo0?ooo`3oool0gia800000018W=l20?ooo`060;md00000000000000000000B9`0gooo
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool000@0oooo00<0
oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`030?ooo`030=nLB0000000000000@0000000X0
07Bo0?ooo`3oool0gia800000018W=l0oooo0?oog`2LB000B9cO0P3oool00`3ogi`0B4RL0=ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`002P3oool00`3o
gi`0B7Bo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool02`3oool00`3o
gi`0B7Bo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?oo
o`002P3oool00`3ookl0M01809cOo`040?ooo`030=nLB018W=l0oooo00l0oooo00<0oono07@0B02L
gol02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool000X0oooo
00<0oono07@0001d_ol01@3oool00`3OW4P0M;oo0?ooo`0>0?ooo`030?oo_`1d0000M;oo00/0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo
00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000:0?ooo`030?noM000
0000M;oo00D0oooo00<0oooO09a8B02Lgol03P3oool00`3o_g@0000007Boo`0;0?ooo`D00000RP3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo8@3oool4000000<0oooo0009
0?ooo`040?oOW0180000001d0;ooo`H0oooo00<0omnL04P0M02oool0303oool0103ogi`0B0000000
M02oool;0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0YP3oool00`000000oooo
0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool000D0oooo00@0gmoO0?ooo`3oool0_g@0
0P0000000`18W=l0oooo0?ooo`060?ooo`030;md0018W=l0oooo00L0oooo00@0gmoO0?ooo`3oool0
_g@00P0000000`18W=l0oooo0?ooo`0:0?ooo`030000003oool0oooo08/0oooo0`00002W0?ooo`03
0000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`001@3oool00`3o_g@00000
0000000200000003001d_`3oool0oooo00L0oooo00<0gia80000M02oool01`3oool00`3o_g@00000
0000000200000003001d_`3oool0oooo00/0oooo00<000000?ooo`3oool0R@3oool700000:D0oooo
00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo00050?ooo`050?oog`2L
B00000000000M02oool02P3oool00`3o_g@0000007Boo`070?ooo`050?oog`2LB00000000000M02o
ool03P3oool00`000000oooo0?ooo`290?ooo`L00000Y@3oool00`000000oooo0?ooo`3o0?ooob@0
oooo00<000000?ooo`3oool00@3oool000H0oooo00<0okmd001d_`3oool01@3oool00`3ogi`0W;oo
0?ooo`030?ooo`030;md00000000M;oo00P0oooo00<0okmd001d_`3oool03`3oool00`000000oooo
0?ooo`280?ooo`T00000Y03oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool0
0@3oool000H0oooo00<0oooO09a8000000000P0000001P0007@0_ooo0?ooo`3oool0_g@007Boo`80
oooo00@0gia800000000B9`0gooo203oool00`3ooml0W4P000000002000000030000M02oool0oooo
00X0oooo00<000000?ooo`3oool0R03oool900000:@0oooo00<000000?ooo`3oool0o`3ooolT0?oo
o`030000003oool0oooo0040oooo00070?ooo`030?noM000000000000080000000D0M;oo0?ooo`3o
ool0oooo0;md000300000003001d_`3oool0oooo00T0oooo00<0okmd0000000000000P0000000`1d
_ol0oooo0?ooo`090?ooo`030000003oool0oooo08P0oooo2@00002T0?ooo`030000003oool0oooo
0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`290?ooo`L0
0000Y@3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool0R@3oool700000:D0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000
003oool0oooo0040oooo000a0?ooo`030000003oool0oooo08/0oooo0`00002W0?ooo`030000003o
ool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00<@3oool3000008`0oooo00<00000
0?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob80oooo0`0000030?ooo`00<@3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?oo
o`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo
903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o
0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?oo
o`00<@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool0
0@3oool00340oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00<@3oool3000008`0oooo00<00000
0?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob80oooo0`0000030?ooo`00<@3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?oo
o`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo
903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o
0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?oo
o`00<@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool0
0@3oool00340oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00<@3oool3000008`0oooo00<00000
0?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob80oooo0`0000030?ooo`00<@3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?oo
o`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo
903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o
0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?oo
o`00<@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool0o`3ooolT0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool0
0@3oool00340oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0
oooo0040oooo000a0?ooo`<00000S03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo
0?l0oooo8P3oool3000000<0oooo000a0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo
903oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo0005
0?ooo`060;md00000000000000000000B9`0gooo0`3oool00`3OW4P00000000000050000000607Bo
o`3oool0oooo0=nLB0000000B9cO0`3oool01P3ooml0W4P0000000000000001d0;ooo``0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903o
ool00`000000oooo0?ooo`010?ooo`00103oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0
gooo00<0oooo00<0gia8000000000000100000001P00M;l0oooo0?ooo`3OW4P0000004RLg`80oooo
00P0oono07@00000B9`0gooo0?ooo`3OW4P0001809cOo`/0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`01
0?ooo`002P3oool00`3ogi`0B7Bo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8
M02oool01P3oool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo00X0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`00
0000oooo0?ooo`010?ooo`002P3oool00`3ookl0M01809cOo`040?ooo`030=nLB018W=l0oooo00T0
oooo00<0oono07@00000M;l0103oool00`3OW4P0001d0;ooo`0:0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3o
ool00@3oool000X0oooo00<0oono07@0001d_ol01@3oool00`3OW4P0M;oo0?ooo`080?ooo`030?oO
W0180000B9cO00@0oooo00<0_g@00000B02Lgol02P3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0040oooo
000:0?ooo`030?noM0000000M;oo00D0oooo00<0oooO09a8B02Lgol0203oool00`3ogi`0B00004RL
g`030?ooo`040?oo_`1d0000001d0;ooo`X0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`010?ooo`002@3o
ool0103ogi`0B0000000M02oool60?ooo`030?oOW01807@0_ooo00L0oooo00T0oono07@000000000
04RL0=ooo`3oool0_g@000000018W=l02`3oool5000008X0oooo00<000000?ooo`3oool0o`3oooo:
0?ooo`@000000`3oool000D0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`06
0?ooo`030;md0018W=l0oooo00H0oooo00D0oooO09a8000007@0_mnL04P000020000000304RLg`3o
ool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3o0?ooold0oooo00<0
00000?ooo`3oool00@3oool000D0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`07
0?ooo`030=nLB00007@0_ooo00L0oooo00<0okmd00000018W=l0403oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo0?l0ooooc@3oool00`000000oooo0?ooo`010?ooo`001@3oool01@3o
oml0W4P00000000007@0_ooo00X0oooo00<0okmd0000001d_ol01`3oool0103ooml0W4P00000B02L
gol?0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0o`3oooo=0?ooo`030000003o
ool0oooo0040oooo00060?ooo`030?noM000M;l0oooo00D0oooo00<0omnL09boo`3oool00`3oool0
0`2oM000000007Boo`080?ooo`040?oo_`1d0000001d0;ooo`h0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`3o0?ooold0oooo00<000000?ooo`3oool00@3oool000H0oooo00<0oooO
09a8000000000P0000001P0007@0_ooo0?ooo`3oool0_g@007Boo`80oooo00@0gia800000000B9`0
gooo2@3oool0103ooml0W4P000000000M;l=0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool0o`3oooo=0?ooo`030000003oool0oooo0040oooo00070?ooo`030?noM000000000000080
000000D0M;oo0?ooo`3oool0oooo0;md000300000003001d_`3oool0oooo00/0oooo00D0omnL04P0
0000000004RL0=ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0o`3oooo=
0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool0o`3oooo=0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool0o`3oooo=0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0o`3oooo=0?ooo`030000003oool0oooo0040oooo
000a0?ooo`<00000S03oool00`000000oooo0?ooo`3o0?oool/0oooo0`0000030?ooo`00<@3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0?l0ooooc@3oool00`000000oooo0?ooo`01
0?ooo`00<@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0?l0ooooc@3oool00`00
0000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0?l0
ooooc@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo0?l0ooooc@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?oo
o`3o0?ooool0ooooG@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o
0?ooool0ooooG@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooG@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0
ooooG@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0oooo
G@3oool00`000000oooo0?ooo`010?ooo`00<@3oool300000?l0ooooo`3ooomK0?ooo`<000000`3o
ool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo00<000000?ooo`3oool00@3oool0
0340oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo00<000000?ooo`3oool00@3oool00340
oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo00<000000?ooo`3oool00@3oool00340oooo
00<000000?ooo`3oool0o`3ooooo0?oooed0oooo00<000000?ooo`3oool00@3oool00340oooo00<0
00000?ooo`3oool0o`3ooooo0?oooed0oooo00<000000?ooo`3oool00@3oool00340oooo00<00000
0?ooo`3oool0o`3ooooo0?oooed0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?oo
o`3oool0o`3ooooo0?oooed0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3o
ool0o`3ooooo0?oooed0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0
o`3ooooo0?oooed0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3o
oooo0?oooed0oooo00<000000?ooo`3oool00@3oool00340oooo0`00003o0?ooool0ooooF`3oool3
000000<0oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo
0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo0040
oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo0040oooo
000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo0040oooo000a
0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo0040oooo000a0?oo
o`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo0040oooo000a0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000
003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo0040oooo000a0?ooo`<00000o`3ooooo
0?oooe/0oooo0`0000030?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool00`00
0000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool00`000000
oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool00`000000oooo
0?ooo`010?ooo`001@3oool01P2oM000000000000000000004RL0=ooo`<0oooo00<0gia800000000
00001@0000001P1d_ol0oooo0?ooo`3OW4P0000004RLg`@0oooo00<0omnL04P0M02oool03P3oool0
0`000000oooo0?ooo`3o0?ooool0ooooG@3oool00`000000oooo0?ooo`010?ooo`00103oool00`3o
oml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00<0oooo00<0gia8000000000000100000001P00
M;l0oooo0?ooo`3OW4P0000004RLg`D0oooo00<0_g@007Boo`3oool03@3oool00`000000oooo0?oo
o`3o0?ooool0ooooG@3oool00`000000oooo0?ooo`010?ooo`002P3oool00`3ogi`0B7Bo0?ooo`03
0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool02@3oool00`3o_g@007Bo0?ooo`0=
0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo0040oooo000:0?oo
o`030?oo_`1d04P0W=oo00@0oooo00<0gia804RLg`3oool03@3oool00`3ookl0M01d0;ooo`0=0?oo
o`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo0040oooo000:0?ooo`03
0?oo_`1d0000M;oo00D0oooo00<0gia807Boo`3oool03@3oool00`2oM000M;oo0?ooo`0<0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo0040oooo000:0?ooo`030?no
M0000000M;oo00D0oooo00<0oooO09a8B02Lgol03@3oool00`3o_g@007Bo0?ooo`0<0?ooo`030000
003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo0040oooo00090?ooo`040?oOW018
0000001d0;ooo`H0oooo00<0omnL04P0M02oool0303oool00`3ookl0M01d0;ooo`0<0?ooo`D00000
o`3ooooo0?oooeP0oooo100000030?ooo`001@3oool0103Ogml0oooo0?ooo`2oM0020000000304RL
g`3oool0oooo00H0oooo00<0_g@004RLg`3oool0303oool00`2oM000M;oo0?ooo`0;0?ooo`030000
003oool0oooo0?l0ooooo`3ooomM0?ooo`030000003oool0oooo0040oooo00050?ooo`030?noM000
000000000080000000<007Bo0?ooo`3oool01`3oool00`3OW4P0001d0;ooo`0<0?ooo`030?noM000
M;l0oooo00/0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo00<000000?ooo`3oool00@3o
ool000D0oooo00D0oooO09a800000000001d0;ooo`0:0?ooo`030?noM0000000M;oo00H0oooo00<0
omno0;oOo`3oool00`3oool00`3ookl0M01d0;ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3o
oomM0?ooo`030000003oool0oooo0040oooo00060?ooo`030?noM000M;l0oooo00D0oooo00<0omnL
09boo`3oool00`3oool00`2oM000000007Boo`060?ooo`030?oog`2LB7@0_ooo00@0oooo00<0_g@0
07Boo`3oool02P3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool00`000000oooo0?ooo`01
0?ooo`001P3oool00`3ooml0W4P000000002000000060000M02oool0oooo0?ooo`2oM000M;oo0P3o
ool0103OW4P000000018W03Oool70?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool0
2@3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool00`000000oooo0?ooo`010?ooo`001`3o
ool00`3o_g@00000000000020000000507Boo`3oool0oooo0?ooo`2oM0000`0000000`00M;l0oooo
0?ooo`070?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool02@3oool00`000000oooo
0?ooo`3o0?ooool0ooooG@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?oo
o`3o0?ooool0ooooG@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o
0?ooool0ooooG@3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooG@3oool00`000000oooo0?ooo`010?ooo`00<@3oool300000?l0ooooo`3ooomK0?ooo`<0
00000`3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo00<000000?ooo`3oool0
0@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo00<000000?ooo`3oool00@3o
ool00340oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo00<000000?ooo`3oool00@3oool0
0340oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0oooo
o`3ooom?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool00340oooo00<0
00000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3o
ool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`00
<@3oool300000?l0ooooo`3ooom?0?ooo`030000003oool0oooo00T0oooo0`0000030?ooo`00<@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oo
odl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000
oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040
oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o
0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000a0?oo
o`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`010?ooo`00<@3oool300000?l0ooooo`3ooom?0?ooo`030000
003oool0oooo00T0oooo0`0000030?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0
oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool0
0340oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0oooo
o`3ooom?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool00340oooo00<0
00000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3o
ool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`00
<@3oool300000?l0ooooo`3ooom?0?ooo`030000003oool0oooo00T0oooo0`0000030?ooo`00<@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oo
odl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000
oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040
oooo00050?ooo`060;md00000000000000000000B9`0gooo0`3oool00`3OW4P00000000000050000
000607Boo`3oool0oooo0=nLB0000000B9cO0`3oool01P3ogi`0B000000000000000001809cOo``0
oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`010?ooo`00103oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00<0oooo
00<0gia8000000000000100000001P00M;l0oooo0?ooo`3OW4P0000004RLg`80oooo00P0omnL04P0
0000B9`0gooo0?ooo`3ogi`0B00007Boo`/0oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`002P3oool00`3ogi`0B7Bo0?oo
o`030?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool01P3oool00`2oM000001d0;oo
o`030?ooo`030=nLB000B9`0gooo00X0oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`002P3oool00`3ookl0M01809cOo`04
0?ooo`030=nLB018W=l0oooo00X0oooo00<0_g@00000M02oool00`3oool00`2oM00004RL0=ooo`0:
0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00@3oool000X0oooo00<0oono07@0001d_ol01@3oool00`3OW4P0M;oo0?ooo`090?oo
o`030?noM00004P0W=oo0080oooo00<0gia800000000M;l02`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000:0?ooo`03
0?noM0000000M;oo00D0oooo00<0oooO09a8B02Lgol02P3oool01`3OW4P007Bo0?ooo`2oM0000000
0000M02oool02`3oool500000?l0ooooo`3ooom=0?ooo`030000003oool0oooo00P0oooo10000003
0?ooo`002@3oool0103ogi`0B0000000M02oool60?ooo`030?oOW01807@0_ooo00X0oooo00D0okmd
00000000000004RL0=ooo`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00@3oool000D0oooo00@0gmoO0?ooo`3oool0_g@00P00
00000`18W=l0oooo0?ooo`060?ooo`030;md0018W=l0oooo00P0oooo00D0omnL04P0000000000000
04RLg`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00@3oool000D0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?oo
o`070?ooo`030=nLB00007@0_ooo00L0oooo00L0omnL04P0000004P0W=oo0?ooo`3OW4P007Bo00`0
oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`010?ooo`001@3oool01@3ooml0W4P00000000007@0_ooo00X0oooo00<0okmd0000001d
_ol01`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000M;oo00/0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`00
1P3oool00`3o_g@007Bo0?ooo`050?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0
1`3oool00`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO00/0oooo00<000000?ooo`3oool0
o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`001P3o
ool00`3ooml0W4P000000002000000060000M02oool0oooo0?ooo`2oM000M;oo0P3oool0103OW4P0
00000018W03Oool70?ooo`030?oOW0180000B9cO0080oooo00<0okmd0000B02Lgol02`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0040oooo00070?ooo`030?noM000000000000080000000D0M;oo0?ooo`3oool0oooo0;md00030000
0003001d_`3oool0oooo00P0oooo00H0oono07@00000000000000000B02Lgol<0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3o
ool00340oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0
ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool00340oooo
0`00003o0?ooool0ooooCP3oool3000000X0oooo0`0000030?ooo`00<@3oool00`000000oooo0?oo
o`3o0?ooool0ooooC03oool7000000X0oooo00<000000?ooo`3oool00@3oool00340oooo00<00000
0?ooo`3oool0o`3ooooo0?oood`0oooo1`00000:0?ooo`030000003oool0oooo0040oooo000a0?oo
o`030000003oool0oooo0?l0ooooo`3ooom;0?ooo`T000002@3oool00`000000oooo0?ooo`010?oo
o`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooB`3oool9000000T0oooo00<000000?ooo`3o
ool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oood/0oooo2@0000090?ooo`030000
003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooom<0?ooo`L000002P3o
ool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooC03oool7
000000X0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?oo
odh0oooo0`00000<0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0
ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool00340oooo
0`00003o0?ooool0ooooC`3oool00`000000oooo0?ooo`090?ooo`<000000`3oool00340oooo00<0
00000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3o
ool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`00
<@3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo
0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00@3oool00340oooo0`00003o0?ooool0ooooC`3oool00`000000oooo
0?ooo`090?ooo`<000000`3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o
0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000a0?oo
o`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0oooo
C`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3o
ool00340oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0
ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool00340oooo
0`00003o0?ooool0ooooC`3oool00`000000oooo0?ooo`090?ooo`<000000`3oool00340oooo00<0
00000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool00340oooo00<000000?ooo`3o
ool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`00
1@3oool01P2oM000000000000000000004RL0=ooo`<0oooo00<0gia80000000000001@000000301d
_ol0oooo0?ooo`3OW4P0000004RLg`3oool0oooO09a800000000001809cOo`l0oooo00<000000?oo
o`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?oo
o`00103oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00<0oooo00<0gia800000000
0000100000001P00M;l0oooo0?ooo`3OW4P0000004RLg`@0oooo00@0gia800000000B9`0gooo3@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0040oooo000:0?ooo`030?oOW018M;l0oooo00<0oooo00<0gia804RLg`3oool00P3oool0
0`3ooml0W4Qd0;ooo`090?ooo`040?oo_`1d0000001d0;ooo``0oooo00<000000?ooo`3oool0o`3o
oooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`002P3oool0
0`3ookl0M01809cOo`040?ooo`030=nLB018W=l0oooo00h0oooo00@0oono07@00000B9`0gooo2`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0040oooo000:0?ooo`030?oo_`1d0000M;oo00D0oooo00<0gia807Boo`3oool03P3oool0
0`3OW4P0000007Boo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00@3oool000X0oooo00<0okmd0000001d_ol01@3oool00`3o
oml0W4Q809cOo`0:0?ooo`030=nLB0000000000000<0000000<004RL0=ooo`3oool02@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0040oooo00090?ooo`040?oOW0180000001d0;ooo`H0oooo00<0omnL04P0M02oool0203oool00`2o
M0000000001d_`020?ooo`040?oo_`1d0000001d0;ooo`X0oooo1@00003o0?ooool0ooooC@3oool0
0`000000oooo0?ooo`080?ooo`@000000`3oool000D0oooo00@0gmoO0?ooo`3oool0_g@00P000000
0`18W=l0oooo0?ooo`060?ooo`030;md0018W=l0oooo00H0oooo00@0oono07@00000B9`0gooo0`3o
ool00`2oM000001809cOo`0:0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00@3oool000D0oooo00<0okmd0000000000000P000000
0`00M;l0oooo0?ooo`070?ooo`030=nLB00007@0_ooo00H0oooo00<0omnL04P00018W=l0103oool0
0`3OW4P0001809cOo`0:0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00@3oool000D0oooo00D0oooO09a800000000001d0;ooo`0:
0?ooo`030?noM0000000M;oo00H0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0:
0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00@3oool000H0oooo00<0okmd001d_`3oool01@3oool00`3ogi`0W;oo0?ooo`030?oo
o`030;md00000000M;oo00H0oooo00<0oooO09a80000M;l00`3oool00`3ookl0M00004RLg`0;0?oo
o`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00@3oool000H0oooo00<0oooO09a8000000000P0000001P0007@0_ooo0?ooo`3oool0_g@0
07Boo`80oooo00@0gia800000000B9`0gooo1`3oool0203ogi`0B00007Boo`3oool0oooO09a80000
B9`0gooo2`3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0040oooo00070?ooo`030?noM000000000000080000000D0M;oo0?ooo`3o
ool0oooo0;md000300000003001d_`3oool0oooo00P0oooo00H0oono07@00000000000000018W03O
ool<0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00@3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000a0?ooo`03
0000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00@3oool00340oooo0`00003o0?ooool0ooooC`3oool00`000000oooo0?ooo`090?ooo`<00000
0`3oool00340oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo
0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool00340
oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3o
oomM0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomM
0?ooo`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?oo
o`030000003oool0oooo0040oooo000a0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`03
0000003oool0oooo0040oooo000a0?ooo`<00000?03oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0=0?ooo`<00000
0`3oool00340oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0040oooo000a0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`010?ooo`00<@3ooooo00000?l00000H@0000030?ooo`00\
\>"],
  ImageRangeCache->{{{0, 658.938}, {406.875, 0}} -> {0.354615, 52.1534, \
0.00571482, 0.00194898}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.184185 0.288595 0.205679 0.172381 [
[.10441 -0.0125 -7.03125 -24.5625 ]
[.10441 -0.0125 7.03125 0 ]
[.24871 -0.0125 -14.5625 -24.5625 ]
[.24871 -0.0125 14.5625 0 ]
[.39301 -0.0125 -7.03125 -24.5625 ]
[.39301 -0.0125 7.03125 0 ]
[.5373 -0.0125 -14.5625 -24.5625 ]
[.5373 -0.0125 14.5625 0 ]
[.6816 -0.0125 -7.03125 -24.5625 ]
[.6816 -0.0125 7.03125 0 ]
[.8259 -0.0125 -14.5625 -24.5625 ]
[.8259 -0.0125 14.5625 0 ]
[.9702 -0.0125 -7.03125 -24.5625 ]
[.9702 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0333 -28 -12.2813 ]
[-0.0125 .0333 0 12.2813 ]
[-0.0125 .11949 -43.0625 -12.2813 ]
[-0.0125 .11949 0 12.2813 ]
[-0.0125 .20568 -14.0625 -12.2813 ]
[-0.0125 .20568 0 12.2813 ]
[-0.0125 .29187 -29.125 -12.2813 ]
[-0.0125 .29187 0 12.2813 ]
[-0.0125 .37806 -14.0625 -12.2813 ]
[-0.0125 .37806 0 12.2813 ]
[-0.0125 .46425 -29.125 -12.2813 ]
[-0.0125 .46425 0 12.2813 ]
[-0.0125 .55044 -14.0625 -12.2813 ]
[-0.0125 .55044 0 12.2813 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10441 0 m
.10441 .00625 L
s
gsave
.10441 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.24871 0 m
.24871 .00625 L
s
gsave
.24871 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.39301 0 m
.39301 .00625 L
s
gsave
.39301 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5373 0 m
.5373 .00625 L
s
gsave
.5373 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.6816 0 m
.6816 .00625 L
s
gsave
.6816 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.8259 0 m
.8259 .00625 L
s
gsave
.8259 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
1.000 setlinewidth
grestore
.9702 0 m
.9702 .00625 L
s
gsave
.9702 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.13327 0 m
.13327 .00375 L
s
.16213 0 m
.16213 .00375 L
s
.19099 0 m
.19099 .00375 L
s
.21985 0 m
.21985 .00375 L
s
.27757 0 m
.27757 .00375 L
s
.30643 0 m
.30643 .00375 L
s
.33529 0 m
.33529 .00375 L
s
.36415 0 m
.36415 .00375 L
s
.42187 0 m
.42187 .00375 L
s
.45072 0 m
.45072 .00375 L
s
.47958 0 m
.47958 .00375 L
s
.50844 0 m
.50844 .00375 L
s
.56616 0 m
.56616 .00375 L
s
.59502 0 m
.59502 .00375 L
s
.62388 0 m
.62388 .00375 L
s
.65274 0 m
.65274 .00375 L
s
.71046 0 m
.71046 .00375 L
s
.73932 0 m
.73932 .00375 L
s
.76818 0 m
.76818 .00375 L
s
.79704 0 m
.79704 .00375 L
s
.85476 0 m
.85476 .00375 L
s
.88362 0 m
.88362 .00375 L
s
.91248 0 m
.91248 .00375 L
s
.94134 0 m
.94134 .00375 L
s
.07555 0 m
.07555 .00375 L
s
.04669 0 m
.04669 .00375 L
s
.01783 0 m
.01783 .00375 L
s
.99906 0 m
.99906 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0333 m
.00625 .0333 L
s
gsave
-0.0125 .0333 -89 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .11949 m
.00625 .11949 L
s
gsave
-0.0125 .11949 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .20568 m
.00625 .20568 L
s
gsave
-0.0125 .20568 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .29187 m
.00625 .29187 L
s
gsave
-0.0125 .29187 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .37806 m
.00625 .37806 L
s
gsave
-0.0125 .37806 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .46425 m
.00625 .46425 L
s
gsave
-0.0125 .46425 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .55044 m
.00625 .55044 L
s
gsave
-0.0125 .55044 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05054 m
.00375 .05054 L
s
0 .06777 m
.00375 .06777 L
s
0 .08501 m
.00375 .08501 L
s
0 .10225 m
.00375 .10225 L
s
0 .13673 m
.00375 .13673 L
s
0 .15397 m
.00375 .15397 L
s
0 .1712 m
.00375 .1712 L
s
0 .18844 m
.00375 .18844 L
s
0 .22292 m
.00375 .22292 L
s
0 .24016 m
.00375 .24016 L
s
0 .25739 m
.00375 .25739 L
s
0 .27463 m
.00375 .27463 L
s
0 .30911 m
.00375 .30911 L
s
0 .32635 m
.00375 .32635 L
s
0 .34358 m
.00375 .34358 L
s
0 .36082 m
.00375 .36082 L
s
0 .3953 m
.00375 .3953 L
s
0 .41254 m
.00375 .41254 L
s
0 .42977 m
.00375 .42977 L
s
0 .44701 m
.00375 .44701 L
s
0 .48149 m
.00375 .48149 L
s
0 .49873 m
.00375 .49873 L
s
0 .51597 m
.00375 .51597 L
s
0 .5332 m
.00375 .5332 L
s
0 .01606 m
.00375 .01606 L
s
0 .56768 m
.00375 .56768 L
s
0 .58492 m
.00375 .58492 L
s
0 .60216 m
.00375 .60216 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.10441 .61178 m
.10441 .61803 L
s
.24871 .61178 m
.24871 .61803 L
s
.39301 .61178 m
.39301 .61803 L
s
.5373 .61178 m
.5373 .61803 L
s
.6816 .61178 m
.6816 .61803 L
s
.8259 .61178 m
.8259 .61803 L
s
.9702 .61178 m
.9702 .61803 L
s
.125 Mabswid
.13327 .61428 m
.13327 .61803 L
s
.16213 .61428 m
.16213 .61803 L
s
.19099 .61428 m
.19099 .61803 L
s
.21985 .61428 m
.21985 .61803 L
s
.27757 .61428 m
.27757 .61803 L
s
.30643 .61428 m
.30643 .61803 L
s
.33529 .61428 m
.33529 .61803 L
s
.36415 .61428 m
.36415 .61803 L
s
.42187 .61428 m
.42187 .61803 L
s
.45072 .61428 m
.45072 .61803 L
s
.47958 .61428 m
.47958 .61803 L
s
.50844 .61428 m
.50844 .61803 L
s
.56616 .61428 m
.56616 .61803 L
s
.59502 .61428 m
.59502 .61803 L
s
.62388 .61428 m
.62388 .61803 L
s
.65274 .61428 m
.65274 .61803 L
s
.71046 .61428 m
.71046 .61803 L
s
.73932 .61428 m
.73932 .61803 L
s
.76818 .61428 m
.76818 .61803 L
s
.79704 .61428 m
.79704 .61803 L
s
.85476 .61428 m
.85476 .61803 L
s
.88362 .61428 m
.88362 .61803 L
s
.91248 .61428 m
.91248 .61803 L
s
.94134 .61428 m
.94134 .61803 L
s
.07555 .61428 m
.07555 .61803 L
s
.04669 .61428 m
.04669 .61803 L
s
.01783 .61428 m
.01783 .61803 L
s
.99906 .61428 m
.99906 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0333 m
1 .0333 L
s
.99375 .11949 m
1 .11949 L
s
.99375 .20568 m
1 .20568 L
s
.99375 .29187 m
1 .29187 L
s
.99375 .37806 m
1 .37806 L
s
.99375 .46425 m
1 .46425 L
s
.99375 .55044 m
1 .55044 L
s
.125 Mabswid
.99625 .05054 m
1 .05054 L
s
.99625 .06777 m
1 .06777 L
s
.99625 .08501 m
1 .08501 L
s
.99625 .10225 m
1 .10225 L
s
.99625 .13673 m
1 .13673 L
s
.99625 .15397 m
1 .15397 L
s
.99625 .1712 m
1 .1712 L
s
.99625 .18844 m
1 .18844 L
s
.99625 .22292 m
1 .22292 L
s
.99625 .24016 m
1 .24016 L
s
.99625 .25739 m
1 .25739 L
s
.99625 .27463 m
1 .27463 L
s
.99625 .30911 m
1 .30911 L
s
.99625 .32635 m
1 .32635 L
s
.99625 .34358 m
1 .34358 L
s
.99625 .36082 m
1 .36082 L
s
.99625 .3953 m
1 .3953 L
s
.99625 .41254 m
1 .41254 L
s
.99625 .42977 m
1 .42977 L
s
.99625 .44701 m
1 .44701 L
s
.99625 .48149 m
1 .48149 L
s
.99625 .49873 m
1 .49873 L
s
.99625 .51597 m
1 .51597 L
s
.99625 .5332 m
1 .5332 L
s
.99625 .01606 m
1 .01606 L
s
.99625 .56768 m
1 .56768 L
s
.99625 .58492 m
1 .58492 L
s
.99625 .60216 m
1 .60216 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.02381 .42396 m
.02381 .51857 L
s
.015 w
.02381 .47126 Mdot
.002 w
.23601 .48233 m
.23601 .59401 L
s
.015 w
.23601 .53817 Mdot
.002 w
.51486 .44076 m
.51486 .60332 L
s
.015 w
.51486 .52204 Mdot
.002 w
.97619 .01472 m
.97619 .0905 L
s
.015 w
.97619 .05261 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{659.938, 407.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:C0001Ub000`400?l00000o`00003oo`3ooooo
0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo
003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00K`3oool00`3o_g@00000000000020000
0003001d_`3oool0oooo04P0oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3oool0
gia800000018W=l00P3oool01P2oM000000000000000000004RL0=ooodT0oooo00<0gia800000000
00001@0000000`1d_ol0oooo0?ooo`150?ooo`030=nLB0000000000000D0000000H0M;oo0?ooo`3o
ool0gia800000018W=l20?ooo`060;md00000000000000000000B9`0goooB@3oool00`3ooml0W4P0
00000002000000030018W03Oool0oooo04P0oooo00<0oooO09a8000000000P0000000`00B9`0gooo
0?ooo`030?ooo`030=nLB0000000B9cO0080oooo00H0_g@000000000000000000018W03Ooom>0?oo
o`030?noM0000000M;oo0140oooo001a0?ooo`030;md000007@0_ooo04d0oooo00<0_g@00000M02o
ool0103oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`19
0?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool0AP3oool00`3OW4P0000000000004
0000000:001d_`3oool0oooo0=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`80oooo00<0omnL04Q8
W03Oool0B03oool0203ogi`0B0000018W03Oool0oooo0?oOW01804P0W=ooB03oool0203ogi`0B000
0018W03Oool0oooo0?oOW01804P0W=oo0`3oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l0
0P3oool00`3ogi`0B4RL0=ooo`1=0?ooo`030?noM0000000M;oo0140oooo001a0?ooo`030;md0000
07@0_ooo04d0oooo00<0_g@00000M02oool03P3oool00`3ogi`0B7Bo0?ooo`190?ooo`030=nLB018
W=l0oooo0080oooo00<0oooO09a8M02oool0B03oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2L
B7@0_ooo00/0oooo00<0omnL04Qd_`3oool0C@3oool00`3o_g@004RL0=ooo`1=0?ooo`030?noM000
B9`0gooo00`0oooo00<0omnL04Qd_`3oool0C03oool00`3o_g@0000007Boo`0A0?ooo`00L@3oool0
0`2oM000001d0;ooo`1=0?ooo`030;md000007@0_ooo00h0oooo00<0oono07@0B02Lgol0BP3oool0
0`3OW4P0B9cO0?ooo`1=0?ooo`030=nLB018W=l0oooo00l0oooo00<0oono07@0B02Lgol0C@3oool0
0`3o_g@0001809cOo`1=0?ooo`030?noM00004P0W=oo00`0oooo00<0oono07@0B02Lgol0A`3oool0
0`3OW4P0000000000005000000030000B02Lgol0oooo00h0oooo001a0?ooo`030;md000007@0_ooo
04d0oooo00<0_g@00000M02oool03P3oool00`3ookl0M00007Boo`1;0?ooo`030=nLB01d_ol0oooo
04d0oooo00<0gia807Boo`3oool03P3oool00`3ookl0M00007Boo`1=0?ooo`030;md000004P0W=oo
04d0oooo00<0_g@00000B02Lgol0303oool00`3ookl0M00007Boo`170?ooo`030?oOW018M;l0oooo
0080oooo00<0okmd0000001d_ol04@3oool00740oooo00<0_g@00000M02oool0C@3oool00`2oM000
001d0;ooo`0>0?ooo`030?noM0000000M;oo04/0oooo00<0oooO09a8B02Lgol0C@3oool00`3ooml0
W4Q809cOo`0>0?ooo`030?noM0000000M;oo04`0oooo00@0_g@00000000007@0_oooC03oool0102o
M00000000000M02oool<0?ooo`030?noM0000000M;oo04P0oooo00L0gia807Boo`3oool0oooo0?no
M0000000M;oo0140oooo001a0?ooo`030;md000007@0_ooo04d0oooo00<0_g@00000M02oool03@3o
ool0103ogi`0B0000000M02ooom<0?ooo`030?oOW01807@0_ooo04d0oooo00<0omnL04P0M02oool0
303oool0103ogi`0B0000000M02ooom90?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3o
ool0B03oool00`3ookl0M000000000020000000304RLg`3oool0oooo00X0oooo00@0omnL04P00000
07@0_oooB03oool01`3ookl0M01d0;ooo`3oool0okmd0000001d_ol04@3oool00740oooo00<0_g@0
0000M02oool0C@3oool00`2oM000001d0;ooo`090?ooo`040=oOg`3oool0oooo0;md0080000000<0
B9cO0?ooo`3oool0C03oool00`2oM000B9cO0?ooo`1=0?ooo`030;md0018W=l0oooo00L0oooo00@0
gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`1:0?ooo`030?noM00004P0W=oo04d0oooo
00<0okmd0000B02Lgol02@3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo04P0
oooo00H0okmd001d_`3oool0okmd0000001d_olA0?ooo`00L@3oool00`2oM000001d0;ooo`1=0?oo
o`030;md000007@0_ooo00T0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`1=0?oo
o`030=nLB00007@0_ooo04d0oooo00<0gia80000M02oool01`3oool00`3o_g@00000000000020000
0003001d_`3oool0oooo04`0oooo00<0omnL04Qd_`3oool0C@3oool00`3ogi`0B7Bo0?ooo`080?oo
o`030?noM000000000000080000000<007Bo0?ooo`3oool0BP3oool01@2oM000M;oo0?noM0000000
M;oo0140oooo001a0?ooo`030;md000007@0_ooo04d0oooo00<0_g@00000M02oool02@3oool01@3o
oml0W4P00000000007@0_ooo0500oooo00<0okmd0000001d_ol0C@3oool00`3o_g@0000007Boo`07
0?ooo`050?oog`2LB00000000000M02oool0C`3oool00`3ooml0W4P004RLg`1=0?ooo`030?oog`2L
B000B9cO00P0oooo00D0oooO09a800000000001d0;ooo`1=0?ooo`050?oo_`1d07@0_kmd0000001d
_ol04@3oool00740oooo00<0_g@00000M02oool0C@3oool00`2oM000001d0;ooo`0:0?ooo`030?no
M000M;l0oooo04/0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`170?ooo`030?oO
W02L_ol0oooo00<0oooo00<0_g@00000001d_ol0203oool00`3o_g@007Bo0?ooo`1;0?ooo`030?oo
g`2LM9`0gooo0080oooo00<0oooO09a80000M;l0B03oool00`3ooml0W7BL0=ooo`020?ooo`030?oo
g`2LB00007Bo00T0oooo00<0okmd001d_`3oool0C`3oool0103o_g@000000000001d_olA0?ooo`00
K`3oool01@3OW4P000000000000007@0_ooo04/0oooo00D0gia8000000000000001d0;ooo`0:0?oo
o`030?oog`2LB00000000080000000<0001d0;ooo`3oool0A`3oool0202oM000M;oo0?ooo`3oool0
gia800000000B9`0goooB03oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo203oool0
0`3ooml0W4P000000002000000030000M02oool0oooo04L0oooo00L0omnL04Q8W03Oool0oooo0=nL
B0000000M;oo04T0oooo00L0omnL04Q8W03Oool0oooo0=nLB0000000M;oo00T0oooo00<0oooO09a8
000000000P0000000`0007@0_ooo0?ooo`1:0?ooo`040?oog`2LB000000007Booa40oooo001`0?oo
o`040?oo_`1d0000001d0;oood`0oooo00@0oono07@0000007@0_ooo2`3oool00`3o_g@000000000
00020000000307Boo`3oool0oooo04L0oooo00D0_g@00000000000000000001d_`1;0?ooo`050;md
00000000000000000000M;l02`3oool00`3o_g@00000000000020000000307Boo`3oool0oooo04L0
oooo00D0omnL04P000000000000004RLg`1;0?ooo`050?oOW0180000000000000018W=l02`3oool0
0`3o_g@00000000000020000000307Boo`3oool0oooo04X0oooo00<0omnL04P0001d_ol04@3oool0
0?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3o
oonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00
o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oo
oiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00<`3ooooo00000?l00000H@00
00010?ooo`00<`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo0@000001
0?ooo`00<`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo0@0000010?oo
o`00<`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00l0oooo0@0000010?ooo`00
<`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00l0oooo0@0000010?ooo`00<`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0
oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040
oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo
0@0000010?ooo`00<`3oool300000?l0ooooo`3ooom?0?ooo`030000003oool0oooo00T0oooo0`00
00010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;
0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?oo
o`3oool02`3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`03
0000003oool0oooo00/0oooo0@0000010?ooo`008@3oool00`3o_g@000000000000200000003001d
_`3oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool0
2`3oool100000040oooo000S0?ooo`030;md000007@0_ooo00d0oooo00<000000?ooo`3oool0o`3o
oooo0?ooodl0oooo00<000000?ooo`3oool02`3oool100000040oooo000S0?ooo`030;md000007@0
_ooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool1
00000040oooo000S0?ooo`030;md000007@0_ooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?oo
odl0oooo00<000000?ooo`3oool02`3oool100000040oooo000S0?ooo`030;md000007@0_ooo00d0
oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool100000040
oooo000C0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool00`3oool00`2oM000001d
0;ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo
0@0000010?ooo`008`3oool00`2oM000001d0;ooo`0=0?ooo`D00000o`3ooooo0?ooodd0oooo00<0
00000?ooo`3oool0203oool400000040oooo000S0?ooo`030;md000007@0_ooo00d0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool100000040oooo000S0?oo
o`030;md000007@0_ooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?oo
o`3oool02`3oool100000040oooo000S0?ooo`030;md000007@0_ooo00d0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool100000040oooo000S0?ooo`030;md
000007@0_ooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool0
2`3oool100000040oooo000Q0?ooo`050=nLB000000000000000M02oool03@3oool00`000000oooo
0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool00280oooo00@0
oono07@0000007@0_ooo3@3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo
0?ooo`0;0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<0
00000?ooo`3oool02`3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooom>
0?ooo`<00000303oool100000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooom<0?oo
o`L000002P3oool100000040oooo000c0?ooo`<00000o`3ooooo0?oood`0oooo1`0000080?ooo`<0
00000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oood/0oooo2@0000090?ooo`400000
0@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oood/0oooo2@0000090?ooo`4000000@3o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oood/0oooo2@0000090?ooo`4000000@3oool0
03<0oooo00<000000?ooo`3oool0o`3ooooo0?oood`0oooo1`00000:0?ooo`4000000@3oool003<0
oooo00<000000?ooo`3oool0o`3ooooo0?oood`0oooo1`00000:0?ooo`4000000@3oool003<0oooo
00<000000?ooo`3oool0o`3ooooo0?ooodh0oooo0`00000<0?ooo`4000000@3oool003<0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool100000040oooo000c
0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo0@000001
0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?oo
o`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3o
ool02`3oool100000040oooo000c0?ooo`<00000o`3ooooo0?ooodl0oooo00<000000?ooo`3oool0
2@3oool300000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003o
ool0oooo00/0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool0
0`000000oooo0?ooo`0;0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
odl0oooo00<000000?ooo`3oool02`3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0
ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`00<`3oool00`000000oooo
0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool003<0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool02`3oool100000040oooo000c
0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo0@000001
0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0;0?oo
o`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo00<000000?ooo`3o
ool02`3oool100000040oooo000c0?ooo`<00000o`3ooooo0?ooodl0oooo00<000000?ooo`3oool0
2@3oool300000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooom?0?ooo`030000003o
ool0oooo00/0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool0
0`000000oooo0?ooo`0;0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
odl0oooo00<000000?ooo`3oool02`3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0
ooooo`3ooom?0?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`00<`3oool00`000000oooo
0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3o
oomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@000001
0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0
o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool300000?l0ooooo`3ooomK0?ooo`<000000@3o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0
ooooo`3ooomM0?ooo`4000000@3oool001<0oooo00@0_g@0000000000000B9cO103oool00`3OW4P0
000004RLg`020?ooo`060;md00000000000000000000B9`0gooo3@3oool00`000000oooo0?ooo`3o
0?ooool0ooooG@3oool100000040oooo000A0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d
_`030?ooo`070=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00`0
oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`004@3oool00`3o_g@00018
09cOo`020?ooo`030?oOW0180000M;oo00`0oooo00<0omnL04Qd_`3oool02`3oool00`000000oooo
0?ooo`3o0?ooool0ooooG@3oool100000040oooo000@0?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0oooO09a80000M;l0303oool00`3ookl0M01809cOo`0;0?ooo`030000003oool0oooo0?l0oooo
o`3ooomM0?ooo`4000000@3oool00100oooo00<0oono07@00000M;l0103oool00`2oM000001d0;oo
o`0;0?ooo`030?oo_`1d0000M;oo00/0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@00
00010?ooo`000`3oool00`2oM0000000000000070000000604RLg`3oool0oooo0?oOW0180000B9cO
103oool00`2oM000001d0;ooo`0;0?ooo`030?noM0000000M;oo00/0oooo00<000000?ooo`3oool0
o`3ooooo0?oooed0oooo0@0000010?ooo`00403oool00`3ogi`0B00004RLg`040?ooo`030=nLB000
04P0W=oo00X0oooo00@0omnL04P0000007@0_ooo2`3oool500000?l0ooooo`3ooomH0?ooo`@00000
0@3oool00100oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`060?ooo`040=oOg`3o
ool0oooo0;md0080000000<0B9cO0?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooool0oooo
G@3oool100000040oooo000@0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3o
ool00`3o_g@000000000000200000003001d_`3oool0oooo00/0oooo00<000000?ooo`3oool0o`3o
oooo0?oooed0oooo0@0000010?ooo`004@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB000
07Bo00L0oooo00D0oooO09a800000000001d0;ooo`0>0?ooo`030000003oool0oooo0?l0ooooo`3o
oomM0?ooo`4000000@3oool00140oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`08
0?ooo`030?noM000M;l0oooo00l0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@000001
0?ooo`004P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`T0oooo00<0oooO09a8000000000P00
00000`0007@0_ooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3o
ool001<0oooo00@0_g@000000000000007Bo2`3oool00`3o_g@00000000000020000000307Boo`3o
ool0oooo00T0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0
oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo
000c0?ooo`<00000o`3ooooo0?oooe/0oooo0`0000010?ooo`00<`3oool00`000000oooo0?ooo`3o
0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?oo
o`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00
<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo
0?oooed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool10000
0040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo
00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool300000?l0ooooo`3o
oomK0?ooo`<000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@000001
0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0
o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3o
ool100000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool0
03<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool00`000000
oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0oooo
o`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@00
00010?ooo`00<`3oool300000?l0ooooo`3ooomK0?ooo`<000000@3oool003<0oooo00<000000?oo
o`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0
ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`400000
0@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0
oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo
000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo0`00003o
0?ooool0ooooF`3oool300000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?oo
o`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00
<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool00280oooo00@0_g@0000000000000B9cO3@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000P0?ooo`070?oog`2LB000
07Bo0?ooo`3ooml0W4P0001d_`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`400000
0@3oool00200oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0;0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool001l0oooo00@0oooO09a80000B9`0gooo0P3o
ool00`3ooml0W4P0001d_`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3o
ool001l0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0
oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool001l0oooo00<0omnL04P00018W=l0103oool00`2o
M000001d0;ooo`0:0?ooo`D00000o`3ooooo0?oooeP0oooo100000010?ooo`007`3oool00`3ogi`0
B00004RLg`040?ooo`030=nLB00004P0W=oo00X0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0
oooo0@0000010?ooo`007`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00X0oooo
00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`007`3oool00`3ookl0M000001d
_`040?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@00
00010?ooo`00803oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00/0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00803oool00`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo00/0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?oo
o`008@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_``0oooo00<000000?ooo`3oool0o`3ooooo
0?oooed0oooo0@0000010?ooo`008P3oool0102oM000000000000000M;l=0?ooo`030000003oool0
oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040
oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo0`00
003o0?ooool0ooooF`3oool300000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM
0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?oo
o`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000
003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3o
oooo0?oooed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool1
00000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0
oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool00`000000oooo
0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`<00000o`3ooooo0?oooe/0oooo0`00
00010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?oo
o`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo
G@3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3o
ool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool00`00
0000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0
ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo
0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c
0?ooo`<00000o`3ooooo0?oooe/0oooo0`0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`40
00000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0
oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040
oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool300000?l0ooooo`3ooomK
0?ooo`<000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?oo
o`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000
003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3o
oooo0?oooed0oooo0@0000010?ooo`004`3oool0102oM000000000000018W=l40?ooo`030=nLB000
0000B9cO0080oooo00H0_g@000000000000000000018W03Oool=0?ooo`030000003oool0oooo0?l0
ooooo`3ooomM0?ooo`4000000@3oool00140oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo
00<0oooo00L0gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool0303o
ool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000A0?ooo`030?noM00004P0
W=oo0080oooo00<0omnL04P0001d_ol0303oool00`3ogi`0B7Bo0?ooo`0;0?ooo`030000003oool0
oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool00100oooo00@0oooO09a80000B9`0gooo0P3oool0
0`3ooml0W4P0001d_`0<0?ooo`030?oo_`1d04P0W=oo00/0oooo00<000000?ooo`3oool0o`3ooooo
0?oooed0oooo0@0000010?ooo`00403oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo
00/0oooo00<0oono07@0001d_ol02`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool10000
0040oooo000@0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool02`3oool00`3o_g@0
000007Boo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool00100oooo
00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0:0?ooo`040?oOW0180000001d0;ooo`/0
oooo1@00003o0?ooool0ooooF03oool400000040oooo000@0?ooo`030?oOW0180000B9cO00@0oooo
00<0gia80000B02Lgol01P3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00X0
oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00403oool00`3ookl0M000
001d_`040?ooo`030;md000007@0_ooo00H0oooo00<0okmd0000000000000P0000000`00M;l0oooo
0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool00140oooo00<0
_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`070?ooo`050?oog`2LB00000000000M02oool0
3P3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000A0?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol0203oool00`3o_g@007Bo0?ooo`0?0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool00180oooo00H0_g@00018W03Oool0oooo0;md
0000M;l90?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool02P3oool00`000000oooo
0?ooo`3o0?ooool0ooooG@3oool100000040oooo000C0?ooo`040;md000000000000001d_`/0oooo
00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo
o`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@00
00010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?oo
o`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo0`00003o0?ooool0
ooooF`3oool300000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`400000
0@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0
oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo
000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`40
00000@3oool003<0oooo0`00003o0?ooool0ooooF`3oool300000040oooo000c0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo
0?oooed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool10000
0040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo
00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?oo
o`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM
0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?oo
o`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`<00000
o`3ooooo0?oooe/0oooo0`0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3o
ool100000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool0
03<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool00`000000
oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0oooo
o`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@00
00010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?oo
o`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0oooo
G@3oool100000040oooo000c0?ooo`<00000o`3ooooo0?oooe/0oooo0`0000010?ooo`00<`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0
oooo0@0000010?ooo`008@3oool00`3o_g@000000000000200000003001d_`3oool0oooo00X0oooo
00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`008`3oool00`2oM000001d0;oo
o`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool002<0oooo00<0_g@0
0000M02oool03@3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000S0?oo
o`030;md000007@0_ooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?oo
o`008`3oool00`2oM000001d0;ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`40
00000@3oool002<0oooo00<0_g@00000M02oool03@3oool00`000000oooo0?ooo`3o0?ooool0oooo
G@3oool100000040oooo000S0?ooo`030;md000007@0_ooo00d0oooo1@00003o0?ooool0ooooF03o
ool400000040oooo000S0?ooo`030;md000007@0_ooo00d0oooo00<000000?ooo`3oool0o`3ooooo
0?oooed0oooo0@0000010?ooo`008`3oool00`2oM000001d0;ooo`0=0?ooo`030000003oool0oooo
0?l0ooooo`3ooomM0?ooo`4000000@3oool002<0oooo00<0_g@00000M02oool03@3oool00`000000
oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000S0?ooo`030;md000007@0_ooo00d0oooo
00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`008@3oool01@3OW4P000000000
000007@0_ooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`008P3o
ool0103ookl0M0000000M02oool=0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`400000
0@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo0`00003o0?ooool0ooooF`3oool300000040
oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o
0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?oo
o`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@0000010?ooo`00
<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo
0?oooed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool10000
0040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo
0`00003o0?ooool0ooooF`3oool300000040oooo000c0?ooo`030000003oool0oooo0?l0ooooo`3o
oomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0oooo0@000001
0?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0
o`3ooooo0?oooed0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3o
ool100000040oooo000c0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooooo
0?ooodh0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0?l0ooooo`3ooom>0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`3o0?ooool0ooooCP3oool100000040oooo000c0?ooo`<00000303oool00`000000oooo
0?ooo`3o0?ooool0ooooC03oool300000040oooo000c0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooodh0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0?l0ooooo`3ooom>0?ooo`4000000@3oool003<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`3o0?ooool0ooooCP3oool100000040oooo000c0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooodh0oooo0@0000010?ooo`00
<`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooom>0?ooo`400000
0@3oool003<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooool0ooooCP3o
ool100000040oooo000c0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolW
0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo000c0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo0?l0oooo903oool10000
0040oooo000c0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`03
0000003oool0oooo0?l0oooo903oool100000040oooo000c0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo
000c0?ooo`<00000303oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0o`3o
oolR0?ooo`<000000@3oool003<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o
0?ooobL0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool003<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0o`3ooolT0?oo
o`4000000@3oool003<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooobL0
oooo00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`400000
0@3oool00180oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3oool0gia800000018
W=l00P3oool01P2oM000000000000000000004RL0=ooo`d0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool0
01@0oooo00<0_g@00000M02oool0103oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l00P3o
ool00`3ogi`0B4RL0=ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3o
oolW0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo000D0?ooo`030;md000007@0
_ooo00h0oooo00<0omnL04Qd_`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0?l0oooo9`3oool00`000000oooo0?ooo`3o0?ooob@0oooo0@0000010?ooo`00503oool00`2o
M000001d0;ooo`0>0?ooo`030?oo_`1d04P0W=oo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool001@0
oooo00<0_g@00000M02oool03P3oool00`3ookl0M00007Boo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo0?l0oooo903oool100000040
oooo000D0?ooo`030;md000007@0_ooo00h0oooo00<0okmd0000001d_ol02`3oool5000000X0oooo
00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo0?l0oooo8@3oool400000040oooo
000D0?ooo`030;md000007@0_ooo00d0oooo00@0omnL04P0000007@0_ooo2`3oool00`000000oooo
0?ooo`0;0?ooo`<00000o`3ooolX0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo
000D0?ooo`030;md000007@0_ooo00T0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo1`00003o0?ooobH0oooo00<000000?ooo`3oool0
o`3ooolT0?ooo`4000000@3oool001@0oooo00<0_g@00000M02oool02@3oool00`3o_g@000000000
000200000003001d_`3oool0oooo00/0oooo00<000000?ooo`3oool02@3oool700000?l0oooo9P3o
ool00`000000oooo0?ooo`3o0?ooob@0oooo0@0000010?ooo`00503oool00`2oM000001d0;ooo`09
0?ooo`050?oog`2LB00000000000M02oool03P3oool00`000000oooo0?ooo`080?ooo`T00000o`3o
oolU0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo000D0?ooo`030;md000007@0
_ooo00X0oooo00<0okmd001d_`3oool03`3oool00`000000oooo0?ooo`080?ooo`T00000o`3ooolU
0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo000B0?ooo`050=nLB00000000000
0000M02oool02P3oool00`3ooml0W4P000000002000000030000M02oool0oooo00X0oooo00<00000
0?ooo`3oool0203oool900000?l0oooo9@3oool00`000000oooo0?ooo`3o0?ooob@0oooo0@000001
0?ooo`004`3oool0103ookl0M0000000M02oool;0?ooo`030?noM000000000000080000000<0M;oo
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`L00000o`3ooolV0?ooo`030000003oool0
oooo0?l0oooo903oool100000040oooo000c0?ooo`030000003oool0oooo00T0oooo1`00003o0?oo
obH0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool003<0oooo00<000000?ooo`3o
ool02`3oool300000?l0oooo:03oool00`000000oooo0?ooo`3o0?ooob@0oooo0@0000010?ooo`00
<`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo9`3oool00`000000oooo
0?ooo`3o0?ooob@0oooo0@0000010?ooo`00<`3oool3000000`0oooo00<000000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo8P3oool300000040oooo000c
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo000c0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo
0?l0oooo903oool100000040oooo000c0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0O@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool100000040
oooo000c0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo
0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo000c0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo0?l0oooo903oool100000040oooo000c0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0O@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool1
00000040oooo000c0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo000c0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2V0?ooo`03
0000003oool0oooo0?l0oooo903oool100000040oooo000c0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo
903oool100000040oooo000c0?ooo`<00000303oool00`000000oooo0?ooo`1m0?ooo`030000003o
ool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`<000000@3oool003<0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo00<00000
0?ooo`3oool0o`3ooolT0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?oo
o`4000000@3oool003<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool003<0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo
00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3o
oolT0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m
0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool0
03<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo
0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool003<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool0o`3ooolT0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`1m0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`400000
0@3oool003<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`030000003o
ool0oooo0:D0oooo0`00003o0?ooobD0oooo0@0000010?ooo`00<`3oool3000000`0oooo00<00000
0?ooo`3oool0O@3oool00`000000oooo0?ooo`2S0?ooo`L00000o`3ooolQ0?ooo`<000000@3oool0
03<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo
0:<0oooo1`00003o0?ooob<0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo0:80oooo2@00003o0?ooob80oooo0@0000010?ooo`00<`3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo0:80oooo2@00003o0?ooob80oooo0@0000010?ooo`00<`3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:80oooo2@00003o0?ooob80oooo0@00
00010?ooo`00<`3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:<0oooo1`00003o
0?ooob<0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
0:<0oooo1`00003o0?ooob<0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo0:D0oooo0`00003o0?ooobD0oooo0@0000010?ooo`00<`3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`400000
0@3oool003<0oooo00<000000?ooo`3oool0R`3oool300000:L0oooo00<000000?ooo`3oool0o`3o
oolT0?ooo`4000000@3oool003<0oooo0`0000290?ooo`L00000Y@3oool00`000000oooo0?ooo`3o
0?ooob80oooo0`0000010?ooo`00<`3oool00`000000oooo0?ooo`290?ooo`L00000Y@3oool00`00
0000oooo0?ooo`3o0?ooob@0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`280?ooo`T0
0000Y03oool00`000000oooo0?ooo`3o0?ooob@0oooo0@0000010?ooo`00<`3oool00`000000oooo
0?ooo`280?ooo`T00000Y03oool00`000000oooo0?ooo`3o0?ooob@0oooo0@0000010?ooo`00<`3o
ool00`000000oooo0?ooo`280?ooo`T00000Y03oool00`000000oooo0?ooo`3o0?ooob@0oooo0@00
00010?ooo`007`3oool00`3OW4P00000000000050000000307Boo`3oool0oooo00T0oooo00<00000
0?ooo`3oool0R@3oool700000:D0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool0
0200oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`090?ooo`030000003oool0oooo
08T0oooo1`00002U0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo000Q0?ooo`03
0=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool02P3oool00`000000oooo0?ooo`2;0?ooo`<0
0000Y`3oool00`000000oooo0?ooo`3o0?ooob@0oooo0@0000010?ooo`008P3oool00`3OW4P0B9cO
0?ooo`0>0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0YP3oool00`000000oooo
0?ooo`3o0?ooob@0oooo0@0000010?ooo`008`3oool00`3OW4P0M;oo0?ooo`0=0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo0@00
00010?ooo`008`3oool00`3ooml0W4Q809cOo`0=0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo0@0000010?ooo`00903oool00`3o
gi`0B01d0;ooo`0<0?ooo`D00000RP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo
0?l0oooo8@3oool400000040oooo000U0?ooo`030;md0018W=l0oooo00/0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool100000040
oooo000U0?ooo`030=nLB00007@0_ooo00/0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo000U0?ooo`030?noM000
0000M;oo00/0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo0?l0oooo903oool100000040oooo000O0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@0
0000001d_ol02`3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:H0oooo00<00000
0?ooo`3oool0o`3ooolT0?ooo`4000000@3oool00200oooo00P0_g@007Boo`3oool0oooo0=nLB000
000004RL0=ooo`/0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2V0?ooo`030000
003oool0oooo0?l0oooo903oool100000040oooo000Q0?ooo`050;md00000000000000000000M;l0
3@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0
o`3ooolT0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`2V0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo000c0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo0@000001
0?ooo`00<`3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:H0oooo00<000000?oo
o`3oool0o`3ooolT0?ooo`4000000@3oool003<0oooo0`00002<0?ooo`030000003oool0oooo0:H0
oooo00<000000?ooo`3oool0o`3ooolR0?ooo`<000000@3oool003<0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo
000c0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?oo
o`3o0?ooob@0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool003<0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903oool10000
0040oooo000c0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0YP3oool00`000000
oooo0?ooo`3o0?ooob@0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool003<0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo903o
ool100000040oooo000c0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0YP3oool0
0`000000oooo0?ooo`3o0?ooob@0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool003<0
oooo0`00002<0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`<0
00000@3oool003<0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2V0?ooo`030000
003oool0oooo0?l0oooo903oool100000040oooo000c0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo0@0000010?ooo`00<`3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3ooolT
0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2V0?oo
o`030000003oool0oooo0?l0oooo903oool100000040oooo000c0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooob@0oooo0@0000010?ooo`00
<`3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0
o`3ooolT0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`030000003o
ool0oooo0?l0oooo903oool100000040oooo000c0?ooo`030000003oool0oooo0?l0oooo=P3oool0
0`000000oooo0?ooo`3o0?ooob@0oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?oo
ocH0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`4000000@3oool003<0oooo00<000000?ooo`3o
ool0o`3ooolf0?ooo`030000003oool0oooo0?l0oooo903oool100000040oooo000c0?ooo`<00000
o`3ooolf0?ooo`030000003oool0oooo0?l0oooo8P3oool300000040oooo000c0?ooo`030000003o
ool0oooo0?l0oooo=P3oool00`000000oooo0?ooo`3o0?ooob@0oooo0@0000010?ooo`00<`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo000c0?ooo`030000003oool0oooo
0?l0ooooo`3ooomM0?ooo`4000000@3oool003<0oooo00<000000?ooo`3oool0o`3ooooo0?oooed0
oooo0@0000010?ooo`00<`3oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool100000040oooo
000c0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool03`3oool100000040oooo000c
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool100000040oooo000c0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool100000040oooo000c0?ooool0
0000o`00001Q00000040oooo0000\
\>"],
  ImageRangeCache->{{{0, 658.938}, {406.875, 0}} -> {0.343542, -1.5007, \
0.00571482, 0.00956758}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ 
        Use\ Maximum\ Likelihood\ Method\ to\ find\ best\ fit\ straight\ \
lines\ going\ through\ the\ four\ datapoints\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    \(\(a1p[a1a1_, b1a1_, x_] := a1a1 + b1a1\ x;\)\)], "Input"],

Cell[BoxData[
    \(\(chi2a1[a1a1_, b1a1_] := 
        Sum[\((\((a1pl[\([i, 2]\)] - 
                    a1p[a1a1, b1a1, a1pl[\([i, 1]\)]])\)/\((a1pl[\([i, 
                      3]\)])\))\)^2, {i, 1, Length[a1pl]}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(par = {a1a1, b1a1};\)\), "\n", 
    \(\(akla1[a1a1_, b1a1_, k_, l_] := 
        1/2  D[D[chi2a1[a1a1, b1a1], par[\([k]\)]], 
            par[\([l]\)]\ ];\)\), "\n", 
    \(\(fmina1 = 
        FindMinimum[
          chi2a1\ [a1a1, b1a1], {a1a1, 1}, {b1a1, \(-10\)}];\)\), "\n", 
    \(\(a1a1o = fmina1[\([2, 1, 2]\)];\)\), "\n", 
    \(\(b1a1o = fmina1[\([2, 2, 2]\)];\)\), "\n", 
    \(akloa1 = 
      Table[If[k \[LessSlantEqual] 
            l, \(akla1[a1a1, b1a1, k, l] /. a1a1 \[Rule] a1a1o\) /. 
            b1a1 \[Rule] b1a1o, \(akla1[a1a1, b1a1, l, k] /. 
              a1a1 \[Rule] a1a1o\) /. b1a1 \[Rule] b1a1o], {k, 1, 2}, {l, 1, 
          2}]; cij = Inverse[akloa1]; 
    spara1 = Table[Sqrt[cij[\([i, i]\)]], {i, 1, 2}]; 
    Print["\<a1a1= \>", a1a1o, "\<+-\>", spara1[\([1]\)], "\<  b1a1= \>", 
      b1a1o, "\<+-\>", spara1[\([2]\)]]; 
    cij // MatrixForm\), "\[IndentingNewLine]", 
    \(chi2ra1 = Part[fmina1, 1]/\((Length[a1pl])\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("a1a1= "\[InvisibleSpace]52.26750450179505`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.1244519135569835`\[InvisibleSpace]"  \
b1a1= "\[InvisibleSpace]0.13391047359679753`\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.045383076173026275`\),
      SequenceForm[ 
      "a1a1= ", 52.267504501795052, "+-", .1244519135569835, 
        "  b1a1= ", .13391047359679753, "+-", .045383076173026275],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.015488278787994893`", \(-0.004910991471139333`\)},
            {\(-0.004910991471139333`\), "0.0020596236029267055`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    \(0.28718073166409513`\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(a1pr = a1a1o + \ b1a1o\ z;\)\), "\[IndentingNewLine]", 
    \(\(a1prpl = 
        Plot[a1pr, {z, 0, 5}, 
          DisplayFunction \[Rule] Identity];\)\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ 
        Construct\ plot\ of\ best\ fit\ straight\ lines\ along\ with\ \
\(\(data\)\(.\)\)\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fb4 = 
      Show[a1prpl, a1dtpl, 
        Graphics[{Text["\<4: V-L  Correlation Coefficient: r=0.89\>", {1.6, 
                52.8}]}], Frame \[Rule] True, Axes \[Rule] False, 
        DisplayFunction \[Rule] $DisplayFunction, PlotRange \[Rule] All, 
        FrameLabel \[Rule] {"\<<z>\>", \*"\"\<\!\(b\_4\)\>\""}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 -43.6797 0.836522 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -7.03125 -24.5625 ]
[.21429 -0.0125 7.03125 0 ]
[.40476 -0.0125 -7.03125 -24.5625 ]
[.40476 -0.0125 7.03125 0 ]
[.59524 -0.0125 -7.03125 -24.5625 ]
[.59524 -0.0125 7.03125 0 ]
[.78571 -0.0125 -7.03125 -24.5625 ]
[.78571 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.375 -49.125 ]
[.5 -0.0125 19.375 -24.5625 ]
[-0.0125 .07041 -39.1875 -12.2813 ]
[-0.0125 .07041 0 12.2813 ]
[-0.0125 .15406 -39.1875 -12.2813 ]
[-0.0125 .15406 0 12.2813 ]
[-0.0125 .23771 -39.1875 -12.2813 ]
[-0.0125 .23771 0 12.2813 ]
[-0.0125 .32136 -39.1875 -12.2813 ]
[-0.0125 .32136 0 12.2813 ]
[-0.0125 .40502 -39.1875 -12.2813 ]
[-0.0125 .40502 0 12.2813 ]
[-0.0125 .48867 -39.1875 -12.2813 ]
[-0.0125 .48867 0 12.2813 ]
[-0.0125 .57232 -39.1875 -12.2813 ]
[-0.0125 .57232 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -63.75 -10.8125 ]
[-0.01875 .30902 -39.1875 10.8125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.32857 .48867 -162.813 -12.2813 ]
[.32857 .48867 162.813 12.2813 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.375 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
75.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
84.813 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
97.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07041 m
.00625 .07041 L
s
gsave
-0.0125 .07041 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.3) show
1.000 setlinewidth
grestore
0 .15406 m
.00625 .15406 L
s
gsave
-0.0125 .15406 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.4) show
1.000 setlinewidth
grestore
0 .23771 m
.00625 .23771 L
s
gsave
-0.0125 .23771 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.5) show
1.000 setlinewidth
grestore
0 .32136 m
.00625 .32136 L
s
gsave
-0.0125 .32136 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.6) show
1.000 setlinewidth
grestore
0 .40502 m
.00625 .40502 L
s
gsave
-0.0125 .40502 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.7) show
1.000 setlinewidth
grestore
0 .48867 m
.00625 .48867 L
s
gsave
-0.0125 .48867 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.8) show
1.000 setlinewidth
grestore
0 .57232 m
.00625 .57232 L
s
gsave
-0.0125 .57232 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52.9) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08714 m
.00375 .08714 L
s
0 .10387 m
.00375 .10387 L
s
0 .1206 m
.00375 .1206 L
s
0 .13733 m
.00375 .13733 L
s
0 .17079 m
.00375 .17079 L
s
0 .18752 m
.00375 .18752 L
s
0 .20425 m
.00375 .20425 L
s
0 .22098 m
.00375 .22098 L
s
0 .25444 m
.00375 .25444 L
s
0 .27117 m
.00375 .27117 L
s
0 .2879 m
.00375 .2879 L
s
0 .30463 m
.00375 .30463 L
s
0 .33809 m
.00375 .33809 L
s
0 .35482 m
.00375 .35482 L
s
0 .37155 m
.00375 .37155 L
s
0 .38829 m
.00375 .38829 L
s
0 .42175 m
.00375 .42175 L
s
0 .43848 m
.00375 .43848 L
s
0 .45521 m
.00375 .45521 L
s
0 .47194 m
.00375 .47194 L
s
0 .5054 m
.00375 .5054 L
s
0 .52213 m
.00375 .52213 L
s
0 .53886 m
.00375 .53886 L
s
0 .55559 m
.00375 .55559 L
s
0 .05368 m
.00375 .05368 L
s
0 .03695 m
.00375 .03695 L
s
0 .02022 m
.00375 .02022 L
s
0 .00349 m
.00375 .00349 L
s
0 .58905 m
.00375 .58905 L
s
0 .60578 m
.00375 .60578 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -123.281 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.8125 16.2813 translate
90 rotate
-71.8125 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
80.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07041 m
1 .07041 L
s
.99375 .15406 m
1 .15406 L
s
.99375 .23771 m
1 .23771 L
s
.99375 .32136 m
1 .32136 L
s
.99375 .40502 m
1 .40502 L
s
.99375 .48867 m
1 .48867 L
s
.99375 .57232 m
1 .57232 L
s
.125 Mabswid
.99625 .08714 m
1 .08714 L
s
.99625 .10387 m
1 .10387 L
s
.99625 .1206 m
1 .1206 L
s
.99625 .13733 m
1 .13733 L
s
.99625 .17079 m
1 .17079 L
s
.99625 .18752 m
1 .18752 L
s
.99625 .20425 m
1 .20425 L
s
.99625 .22098 m
1 .22098 L
s
.99625 .25444 m
1 .25444 L
s
.99625 .27117 m
1 .27117 L
s
.99625 .2879 m
1 .2879 L
s
.99625 .30463 m
1 .30463 L
s
.99625 .33809 m
1 .33809 L
s
.99625 .35482 m
1 .35482 L
s
.99625 .37155 m
1 .37155 L
s
.99625 .38829 m
1 .38829 L
s
.99625 .42175 m
1 .42175 L
s
.99625 .43848 m
1 .43848 L
s
.99625 .45521 m
1 .45521 L
s
.99625 .47194 m
1 .47194 L
s
.99625 .5054 m
1 .5054 L
s
.99625 .52213 m
1 .52213 L
s
.99625 .53886 m
1 .53886 L
s
.99625 .55559 m
1 .55559 L
s
.99625 .05368 m
1 .05368 L
s
.99625 .03695 m
1 .03695 L
s
.99625 .02022 m
1 .02022 L
s
.99625 .00349 m
1 .00349 L
s
.99625 .58905 m
1 .58905 L
s
.99625 .60578 m
1 .60578 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .04322 m
.06244 .06595 L
.10458 .09072 L
.14415 .114 L
.18221 .13638 L
.22272 .1602 L
.26171 .18313 L
.30316 .20751 L
.34309 .23099 L
.3815 .25358 L
.42237 .27761 L
.46172 .30076 L
.49955 .32301 L
.53984 .3467 L
.57861 .3695 L
.61984 .39375 L
.65954 .4171 L
.69774 .43956 L
.73838 .46346 L
.77751 .48648 L
.81909 .51093 L
.85916 .53449 L
.89771 .55717 L
.93871 .58128 L
.97619 .60332 L
s
.002 w
.16109 .01472 m
.16109 .2355 L
s
.015 w
.16109 .12511 Mdot
.002 w
.30114 .14859 m
.30114 .34519 L
s
.015 w
.30114 .24689 Mdot
.002 w
.48519 .04145 m
.48519 .31959 L
s
.015 w
.48519 .18052 Mdot
.002 w
.78967 .42811 m
.78967 .59657 L
s
.015 w
.78967 .51234 Mdot
gsave
.32857 .48867 -223.813 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
73.063 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
83.563 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(V) show
98.063 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
111.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
133.250 23.000 moveto
(Correlation) show
229.375 23.000 moveto
(Coefficient) show
319.313 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
329.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
336.500 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
349.438 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.89) show
384.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{612.375, 378.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009T0001NR000`400?l00000o`00003oo`3ooooo
0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo
003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?oooe00
oooo00<0okmd001d_`2oM0001P0000001@18W=l0oooo0?ooo`2oM4P0W=oo0?l0oooo203oool00?l0
ooooCP3oool01`3o_g@000000000M02oool0oono07@00000M;l00`3oool0203ogi`0M9cO0?ooo`3o
ool0omnL04P0000004P0W=ooo`3oool60?ooo`00o`3ooom<0?ooo`040?noM0000000001809cOo`<0
oooo00<0omnL04P0001d_ol00P3oool00`3ooml0_koO0?ooo`030?ooo`040?oOW0180000001809cO
ool0oooo103oool00?l0ooooBP3oool0103ogi`0B0000000B02Lgol60?ooo`030=nLB00004P0W=oo
00T0oooo00@0okmd0000000004P0W=ooo`3oool20?ooo`00o`3ooom80?ooo`040?oOW01800000018
09cOo`P0oooo00@0oooO09a80000B9`0gooo2P3oool0103o_g@000000000M02ooooo0?ooo`00o`3o
oom70?ooo`030;md000004P0W=oo00/0oooo00<0oono07@00000M;l0303oool00`3o_g@0000004RL
g`3n0?ooo`00o`3ooom80?ooo`040?oOW0180000001809cOo`H0oooo00L0omnL09boo`3oool0oooo
0?noM0000000M;oo00T0oooo00@0okmd0000000007@0_oooo`3oool00?l0ooooBP3oool0103ogi`0
B0000000B02Lgol40?ooo`030?oo_`2LW=l0oooo0080oooo00<0_g@00000M02oool01P3oool0103o
_g@000000000B02Lgooo0?ooo`80oooo003o0?oood`0oooo00@0okmd0000000004P0W=oo0P3oool0
0`3ookl0M00000000004000000030018W03Oool0oooo0080oooo00@0omnL04P0000004P0W=ooo`3o
ool40?ooo`00o`3ooom>0?ooo`040?noM0000000001d0;ooo`X0oooo00@0omnL04P0000004P0W=oo
o`3oool60?ooo`00o`3ooom@0?ooo`030?noM000M;l0oooo00T0oooo00<0_gA809cOo`3oool0o`3o
ool70?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00
o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?oo
ofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o
0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo001L0?ooo`040;md
00000000000004RLgeh0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`1I0?ooo`03
0=nLB0000000000000D0000000<0M;oo0?ooo`3oool0F03oool00`3ooml0W4P00000000200000003
0018W03Oool0oooo0640oooo00<0okmd0000001d_ol0G03oool01P2oM000000000000000000004RL
0=oooa@0oooo001J0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`1O0?ooo`030;md0000
07@0_ooo05d0oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`1H0?ooo`080?oOW018
000004RL0=ooo`3oool0omnL04P0B02LgomQ0?ooo`030?noM0000000M;oo05/0oooo00<0oooO09a8
0018W=l00P3oool00`3ogi`0B4RL0=ooo`0C0?ooo`00FP3oool00`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo05h0oooo00<0_g@00000M02oool0GP3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?oog`2LB7@0_ooo05l0oooo00<0okmd0018W03Oool0H03oool00`3o_g@0000007Boo`1Q0?ooo`03
0?oOW018M;l0oooo0180oooo001I0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000
M;l0GP3oool00`2oM000001d0;ooo`1O0?ooo`030=nLB018W=l0oooo06<0oooo00<0okmd0000B02L
gol0F`3oool00`3OW4P0000000000005000000030000B02Lgol0oooo05h0oooo00<0oono07@0B02L
gol04P3oool005T0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`1M0?ooo`030;md
000007@0_ooo0600oooo00<0gia807Boo`3oool0HP3oool00`2oM000001809cOo`1K0?ooo`030?oO
W018M;l0oooo0080oooo00<0okmd0000001d_ol0H@3oool00`3ookl0M00007Boo`0B0?ooo`00F@3o
ool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo05d0oooo00<0_g@00000M02oool0H03o
ool00`3ooml0W4Q809cOo`1Q0?ooo`040;md00000000001d0;oooe`0oooo00L0gia807Boo`3oool0
oooo0?noM0000000M;oo0640oooo00<0okmd0000001d_ol04P3oool005T0oooo00<0omnL04P00018
W=l0103oool00`3OW4P0001809cOo`1M0?ooo`030;md000007@0_ooo0640oooo00<0omnL04P0M02o
ool0G@3oool00`3ookl0M000000000020000000304RLg`3oool0oooo05/0oooo00L0oono07@0M02o
ool0oooo0?noM0000000M;oo0600oooo00@0omnL04P0000007@0_ooo4P3oool005T0oooo00<0omnL
04P00018W=l0103oool00`3OW4P0001809cOo`1M0?ooo`030;md000007@0_ooo0680oooo00<0_g@0
04RLg`3oool0GP3oool00`3o_g@0001809cOo`1O0?ooo`060?noM000M;l0oooo0?noM0000000M;oo
G03oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo0140oooo001I0?ooo`030?oo
_`1d000007Bo00@0oooo00<0_g@00000M02oool0G@3oool00`2oM000001d0;ooo`1R0?ooo`030=nL
B00007@0_ooo05l0oooo00<0omnL04Qd_`3oool0G`3oool01@2oM000M;oo0?noM0000000M;oo05`0
oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0B0?ooo`00FP3oool00`2oM00004RL
0=ooo`020?ooo`030?oog`2LB00007Bo05h0oooo00<0_g@00000M02oool0HP3oool00`3o_g@00000
07Boo`1O0?ooo`030?oog`2LB000B9cO05l0oooo00D0oono07@0M02o_g@0000007Boo`1L0?ooo`05
0?oog`2LB00000000000M02oool05@3oool005X0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0
B00007Boo`1N0?ooo`030;md000007@0_ooo05`0oooo00<0omnL09boo`3oool00`3oool00`2oM000
000007Boo`1J0?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO09a80000M;l0H03oool0103o_g@0
00000000001d_omM0?ooo`030?noM000M;l0oooo01H0oooo001K0?ooo`060;md0000B9`0gooo0?oo
o`2oM00007BoG@3oool01@3OW4P000000000000007@0_ooo05d0oooo00P0_g@007Boo`3oool0oooo
0=nLB000000004RL0=oooe/0oooo00L0omnL04Q8W03Oool0oooo0=nLB0000000M;oo0600oooo00@0
oooO09a800000000M;ooG@3oool00`3ooml0W4P000000002000000030000M02oool0oooo0140oooo
001L0?ooo`040;md000000000000001d_el0oooo00@0oono07@0000007@0_oooGP3oool01@2oM000
000000000000000007Bo05h0oooo00D0omnL04P000000000000004RLg`1R0?ooo`030?oOW0180000
M;oo05h0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0@0?ooo`00o`3ooooo0?oo
ofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o
0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0oooo
IP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0
ooooo`3ooomV0?ooo`00D@3ooooo00000?l00000300000090?ooo`00D@3oool3000000X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`<000002@3oool00540oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?oo
o`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo203oool00`000000oooo0?ooo`070?ooo`00
D@3oool00`000000oooo0?ooo`3o0?ooool0oooo203oool00`000000oooo0?ooo`070?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo203oool00`000000oooo0?ooo`070?ooo`00D@3oool0
0`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0?l0oooo/`3oool00`000000oooo0?ooo`07
0?ooo`00D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0?l0oooo/`3oool00`00
0000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0?l0
oooo/`3oool00`000000oooo0?ooo`070?ooo`00D@3oool300000540oooo00<000000?ooo`3oool0
o`3ooona0?ooo`<000002@3oool00540oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?oo
o`3o0?oook<0oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`3o0?oook<0oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`3o0?oook<0oooo00<000000?ooo`3oool01`3oool00540
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3o0?oook<0oooo00<000000?ooo`3o
ool01`3oool00540oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3o0?oook<0oooo
00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?oo
o`3o0?oook<0oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`3o0?oook<0oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`3o0?oook<0oooo00<000000?ooo`3oool01`3oool00540
oooo0`00001A0?ooo`030000003oool0oooo0?l0oooo/@3oool3000000T0oooo001A0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool0o`3ooonc0?ooo`030000003oool0oooo00L0oooo
001A0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?oo
o`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3oool:
0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo00/0oooo0P0000140?oo
o`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo
00L0oooo001A0?ooo`030000003oool0oooo00d0oooo0P0000120?ooo`030000003oool0oooo0:H0
oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2V0?ooo`030000
003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?oo
o`0@0?ooo`800000?`3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo2P3o
ool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`0B0?ooo`800000?@3oool0
0`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`07
0?ooo`00D@3oool3000001@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`2V0?oo
o`030000003oool0oooo0?l0oooo203oool3000000T0oooo001A0?ooo`030000003oool0oooo01D0
oooo0P00000j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3oool:0?ooo`03
0000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo01L0oooo0P00000h0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo
000W0?ooo`060;md00000000000000000000B9`0gooo0`3oool00`3OW4P000000000000500000009
07Boo`3oool0oooo0=nLB0000000B9cO0?ooo`3ooml0W4P000<0000000<004RL0=ooo`3oool02P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0YP3o
ool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool002H0oooo00<0oooO
09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`030?ooo`030=nLB0000000000000@0000000l007Bo
0?ooo`3oool0gia800000018W=l0oooo0?oOW018000004RL0=ooo`3oool0omnL04P0B02Lgol02P3o
ool00`000000oooo0?ooo`0J0?ooo`800000=@3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00;03oool00`3ogi`0B7Bo0?ooo`03
0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool02`3oool00`3o_g@004RL0=ooo`09
0?ooo`030000003oool0oooo01`0oooo0P00000c0?ooo`030000003oool0oooo0:H0oooo00<00000
0?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo000/0?ooo`030?oo_`1d04P0W=oo
00@0oooo00<0gia804RLg`3oool03`3oool00`3o_g@0001809cOo`090?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo
0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00;03oool00`3ookl0M00007Boo`050?ooo`03
0=nLB01d_ol0oooo00h0oooo00<0_g@00000B02Lgol02@3oool00`000000oooo0?ooo`0O0?ooo`80
0000<03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000
oooo0?ooo`070?ooo`00;03oool00`3o_g@0000007Boo`050?ooo`030?oog`2LB4P0W=oo00d0oooo
00@0_g@00000000007@0_ooo2@3oool5000001l0oooo0P00000^0?ooo`030000003oool0oooo0:H0
oooo00<000000?ooo`3oool0o`3oool70?ooo`@000002@3oool002/0oooo00@0omnL04P0000007@0
_ooo1P3oool00`3ogi`0B01d0;ooo`090?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3o
ool0203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool002L0oooo
00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`060?ooo`030;md0018W=l0oooo00X0
oooo00<0okmd0000B02Lgol02`3oool00`000000oooo0?ooo`0T0?ooo`800000:`3oool00`000000
oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00
9`3oool00`3o_g@000000000000200000003001d_`3oool0oooo00L0oooo00<0gia80000M02oool0
2`3oool00`3ogi`0B7Bo0?ooo`0:0?ooo`030000003oool0oooo02H0oooo0P00000Y0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo
000W0?ooo`050?oog`2LB00000000000M02oool02P3oool00`3o_g@0000007Boo`0;0?ooo`030?oo
g`2LB000B9cO00X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo
000X0?ooo`030?noM000M;l0oooo00D0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Bo
o`060?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO09a80000M;l02P3oool00`000000oooo0?oo
o`0Y0?ooo`8000009P3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo2P3o
ool00`000000oooo0?ooo`070?ooo`00:03oool00`3ooml0W4P000000002000000060000M02oool0
oooo0?ooo`2oM000M;oo0P3oool0103OW4P000000018W03Oool70?ooo`070?oOW018B9`0gooo0?oo
o`3OW4P0000007Boo`0:0?ooo`030000003oool0oooo02/0oooo0P00000T0?ooo`030000003oool0
oooo0:H0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo000Y0?oo
o`030?noM000000000000080000000D0M;oo0?ooo`3oool0oooo0;md000300000003001d_`3oool0
oooo00P0oooo00D0omnL04P000000000000004RLg`0;0?ooo`030000003oool0oooo02d0oooo0P00
000R0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003o
ool0oooo00L0oooo001A0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`07
0?ooo`00D@3oool300000300oooo0P00000O0?ooo`030000003oool0oooo0:H0oooo00<000000?oo
o`3oool0o`3oool80?ooo`<000002@3oool00540oooo00<000000?ooo`3oool0<P3oool2000001d0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3o
ool01`3oool00540oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo
001A0?ooo`030000003oool0oooo03D0oooo0P00000J0?ooo`030000003oool0oooo0:H0oooo00<0
00000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0
oooo03L0oooo0P00000H0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3oool:
0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo03T0oooo0P00000F0?oo
o`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo
00L0oooo001A0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00
D@3oool00`000000oooo0?ooo`0l0?ooo`8000004`3oool00`000000oooo0?ooo`2V0?ooo`030000
003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?oo
o`0n0?ooo`8000004@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo2P3o
ool00`000000oooo0?ooo`070?ooo`00D@3oool300000400oooo0P00000?0?ooo`030000003oool0
oooo0:H0oooo00<000000?ooo`3oool0o`3oool80?ooo`<000002@3oool00540oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0:H0oooo00<000000?oo
o`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo04<0
oooo0P00000<0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3oool:0?ooo`03
0000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo04D0oooo0P00000:0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo
001A0?ooo`030000003oool0oooo04L0oooo0P0000080?ooo`030000003oool0oooo0:H0oooo00<0
00000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0
oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`1:0?oo
o`8000001@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0?l0oooo2P3oool00`00
0000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3o
ool01`3oool00540oooo0`00001=0?ooo`80000000@0oooo0000000000000000Y`3oool00`000000
oooo0?ooo`3o0?ooo`P0oooo0`0000090?ooo`00D@3oool00`000000oooo0?ooo`1?0?ooo`D00000
YP3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool00540oooo00<0
00000?ooo`3oool0CP3oool700000:D0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003o
ool0oooo00L0oooo001A0?ooo`030000003oool0oooo04h0oooo1`00002U0?ooo`030000003oool0
oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`1>0?oo
o`L00000Y@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool00540
oooo00<000000?ooo`3oool0C`3oool5000000030?ooo`00000000000:<0oooo00<000000?ooo`3o
ool0o`3oool:0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0500oooo
0`0000040?ooo`800000X@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0
1`3oool00540oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo09h0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo001A
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool01P3oool2000009h0oooo00<00000
0?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo001A0?ooo`<00000D@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0o`3oool80?oo
o`<000002@3oool00540oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`090?ooo`80
0000V`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool00540oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0;0?ooo`800000V@3oool00`000000oooo
0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool002L0oooo00H0_g@00000000000000000
0018W03Oool30?ooo`030=nLB0000000000000D0000000H0M;oo0?ooo`3oool0gia800000018W=l6
0?ooo`030?noM0000000M;oo00X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0=
0?ooo`800000U`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool0
02H0oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`030?ooo`030=nLB00000000000
00@0000000H007Bo0?ooo`3oool0gia800000018W=l60?ooo`030?noM0000000M;oo00X0oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo09@0oooo00<0
00000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo000/0?ooo`030?oOW018M;l0
oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`0:0?ooo`030?noM0000000
M;oo00X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0@0?ooo`800000U03oool0
0`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool002`0oooo00<0oono07@0
B02Lgol0103oool00`3OW4P0B9cO0?ooo`090?ooo`030=nLB0000000000000D0000000<0001809cO
o`3oool01`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0180oooo0P00000b0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo
00L0oooo000/0?ooo`030?oo_`1d0000M;oo00D0oooo00<0gia807Boo`3oool0203oool00`3ogi`0
B7Bo0?ooo`020?ooo`030?noM0000000M;oo00X0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`0D0?ooo`800000<03oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?l0
oooo2P3oool00`000000oooo0?ooo`070?ooo`00;03oool00`3o_g@0000007Boo`050?ooo`030?oo
g`2LB4P0W=oo00T0oooo00L0gia807Boo`3oool0oooo0?noM0000000M;oo00X0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0G@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool002/0
oooo00@0omnL04P0000007@0_ooo1P3oool00`3ogi`0B01d0;ooo`080?ooo`070?oo_`1d07@0_ooo
0?ooo`3o_g@0000007Boo`0:0?ooo`D00000C`3oool00`000000oooo0?ooo`0G0?ooo`800000;@3o
ool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?l0oooo1`3oool4000000T0oooo000W
0?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool01P3oool00`2oM000B9cO0?oo
o`080?ooo`060?noM000M;l0oooo0?noM0000000M;oo2P3oool00`000000oooo0?ooo`1A0?ooo`03
0000003oool0oooo01T0oooo0P00000[0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3o
ool0o`3oool:0?ooo`030000003oool0oooo00L0oooo000W0?ooo`030?noM0000000000000800000
00<007Bo0?ooo`3oool01`3oool00`3OW4P0001d0;ooo`090?ooo`050;md001d_ol0okmd0000001d
_ol02P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01/0oooo0P00000Y0?ooo`03
0000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0
oooo000W0?ooo`050?oog`2LB00000000000M02oool02P3oool00`3o_g@0000007Boo`090?ooo`05
0?oo_`1d07@0_kmd0000001d_ol02P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo
0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00:03oool00`3o_g@007Bo0?ooo`050?ooo`03
0?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol02P3oool0103o_g@000000000001d_ol:0?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3oool2000002H0oooo00<000000?oo
o`3oool0G@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool002P0
oooo00<0oooO09a8000000000P0000001P0007@0_ooo0?ooo`3oool0_g@007Boo`80oooo00@0gia8
00000000B9`0gooo2P3oool0103ooml0W4P00000001d_ol:0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool0803oool2000002@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool002T0oooo00<0okmd0000000000000P00
00001@1d_ol0oooo0?ooo`3oool0_g@000<0000000<007Bo0?ooo`3oool02`3oool00`3ogi`0B000
07Boo`0:0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool08P3oool200000280oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0
1`3oool00540oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<0
00000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0U
0?ooo`8000007`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?l0oooo2P3oool0
0`000000oooo0?ooo`070?ooo`00D@3oool300000540oooo00<000000?ooo`3oool09`3oool20000
01d0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo0`0000090?oo
o`00D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02T0oooo0P00000K0?ooo`03
0000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0
oooo001A0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo05`0oooo0`00003o0?ooo`/0oooo00<000000?ooo`3oool0
1`3oool00540oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0/0?ooo`800000603o
ool00`000000oooo0?ooo`1K0?ooo`D00000o`3oool:0?ooo`030000003oool0oooo00L0oooo001A
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0;P3oool2000001H0oooo00<00000
0?ooo`3oool0FP3oool700000?l0oooo2@3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo0300oooo0P00000D0?ooo`030000003oool0oooo
05X0oooo1`00003o0?ooo`T0oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0FP3oool700000?l0oooo2@3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo03<0oooo0P00000A0?ooo`030000003oool0oooo05/0oooo
1@00003o0?ooo`X0oooo00<000000?ooo`3oool01`3oool00540oooo0`00001A0?ooo`030000003o
ool0oooo03D0oooo0P00000?0?ooo`030000003oool0oooo05`0oooo0`00003o0?ooo`T0oooo0`00
00090?ooo`00D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?l0oooo2P3oool0
0`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
03P0oooo0P00000<0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool:0?oo
o`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3o
ool0o`3oool:0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool0>`3oool2000000T0oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`0m0?ooo`8000001`3oool00`000000oooo0?ooo`1M0?ooo`030000003o
ool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1M
0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo0400oooo0P0000040?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo001A0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool0@P3oool01@000000oooo0?ooo`3oool00000
05l0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo001A0?ooo`<0
0000D@3oool00`000000oooo0?ooo`130?ooo`80000000<0oooo0000003oool0GP3oool00`000000
oooo0?ooo`3o0?ooo`P0oooo0`0000090?ooo`00D@3oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo04D0oooo0P00001O0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo
0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo04H0oooo0P00
001N0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00D@3oool0
0`000000oooo0?ooo`1A0?ooo`030000003oool0oooo04H0oooo00@000000?ooo`0000000000G03o
ool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool00540oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`160?ooo`040000003oool0oooo0?ooo`800000FP3o
ool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool00540oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00<0oooo0P00001H
0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?oo
o`00D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool01P3oool2000005D0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0
oooo001A0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`080?ooo`800000D`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0
1`3oool00540oooo0`00001A0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool02P3o
ool200000540oooo00<000000?ooo`3oool0o`3oool80?ooo`<000002@3oool00540oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool0
0540oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
00d0oooo0P00001>0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?oo
o`009`3oool01P2oM000000000000000000004RL0=ooo`<0oooo00<0gia80000000000001@000000
1P1d_ol0oooo0?ooo`3OW4P0000004RLg`80oooo00H0_g@000000000000000000018W03Oool;0?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?oo
o`800000C03oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool002H0
oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`030?ooo`030=nLB0000000000000@0
000000X007Bo0?ooo`3oool0gia800000018W=l0oooo0?oog`2LB000B9cO0P3oool00`3ogi`0B4RL
0=ooo`0:0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0A0?ooo`800000BP3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0
1`3oool002`0oooo00<0omnL04Qd_`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2L
B7@0_ooo00/0oooo00<0omnL04Qd_`3oool02@3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00;03oool00`3ookl0M01809cOo`04
0?ooo`030=nLB018W=l0oooo00l0oooo00<0oono07@0B02Lgol02@3oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool2000004L0oooo00<00000
0?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo000/0?ooo`030?oo_`1d0000M;oo
00D0oooo00<0gia807Boo`3oool03P3oool00`3ookl0M00007Boo`090?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0F0?ooo`800000A@3oool00`00
0000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool002`0oooo00<0okmd0000001d
_ol01@3oool00`3ooml0W4Q809cOo`0>0?ooo`030?noM0000000M;oo00T0oooo1@00002H0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?ooo`L0
oooo100000090?ooo`00:`3oool0103ogi`0B0000000M02oool60?ooo`030?oOW01807@0_ooo00`0
oooo00@0omnL04P0000007@0_ooo2@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo
01T0oooo0P0000120?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?oo
o`009`3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00H0oooo00<0_g@004RL
g`3oool01`3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00P0oooo00<00000
0?ooo`3oool0VP3oool00`000000oooo0?ooo`0K0?ooo`800000@03oool00`000000oooo0?ooo`3o
0?ooo`X0oooo00<000000?ooo`3oool01`3oool002L0oooo00<0okmd0000000000000P0000000`00
M;l0oooo0?ooo`070?ooo`030=nLB00007@0_ooo00L0oooo00<0okmd0000000000000P0000000`00
M;l0oooo0?ooo`090?ooo`030000003oool0oooo09T0oooo0`00000N0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo000W0?ooo`05
0?oog`2LB00000000000M02oool02P3oool00`3o_g@0000007Boo`070?ooo`050?oog`2LB0000000
0000M02oool0303oool00`000000oooo0?ooo`2H0?ooo`D000007P3oool2000003d0oooo00<00000
0?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030?noM000M;l0oooo
00D0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`080?ooo`030?noM000M;l0oooo
00d0oooo00<000000?ooo`3oool0U`3oool7000001l0oooo0P00000k0?ooo`030000003oool0oooo
0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00:03oool00`3ooml0W4P00000000200000006
0000M02oool0oooo0?ooo`2oM000M;oo0P3oool0103OW4P000000018W03Oool80?ooo`030?oog`2L
B00000000080000000<0001d0;ooo`3oool0203oool00`000000oooo0?ooo`2G0?ooo`L000008@3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?oo
o`070?ooo`00:@3oool00`3o_g@00000000000020000000507Boo`3oool0oooo0?ooo`2oM0000`00
00000`00M;l0oooo0?ooo`090?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool01`3o
ool00`000000oooo0?ooo`2G0?ooo`L000008P3oool2000003P0oooo00<000000?ooo`3oool0o`3o
ool:0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo09P0oooo1@00000U
0?ooo`800000=P3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool0
0540oooo0`00002I0?ooo`<00000:03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
0?l0oooo203oool3000000T0oooo001A0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0:03oool2000003<0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0
oooo001A0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0:P3oool200000340oooo
00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003o
ool0oooo09X0oooo00<000000?ooo`3oool0;03oool2000002l0oooo00<000000?ooo`3oool0o`3o
ool:0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo09X0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0oooo2P3oool0
0`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo
02l0oooo0P00000/0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?oo
o`00D@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo0P00000Z0?ooo`03
0000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo
0?ooo`2J0?ooo`030000003oool0oooo03<0oooo0P00000X0?ooo`030000003oool0oooo0?l0oooo
2P3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`2J0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<0
00000?ooo`3oool01`3oool00540oooo0`00002J0?ooo`030000003oool0oooo03H0oooo0P00000U
0?ooo`030000003oool0oooo0?l0oooo203oool3000000T0oooo001A0?ooo`030000003oool0oooo
09X0oooo00<000000?ooo`3oool0>03oool2000002<0oooo00<000000?ooo`3oool0o`3oool:0?oo
o`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>P3oool200000240oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0
oooo001A0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00D@3o
ool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo03d0oooo0P00000N0?ooo`030000003o
ool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo03l0oooo0P00000L0?ooo`030000003oool0oooo0?l0oooo2P3oool0
0`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo
0440oooo0P00000J0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?oo
o`00D@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool00540oooo
00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`140?ooo`8000005`3oool00`000000oooo
0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool01`3oool00540oooo0`00002J0?ooo`030000003o
ool0oooo04H0oooo0P00000E0?ooo`030000003oool0oooo0?l0oooo203oool3000000T0oooo001A
0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0B03oool2000001<0oooo00<00000
0?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo
09X0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`003@3oool00`3ogi`0W;oo0?ooo`110?ooo`03
0000003oool0oooo09X0oooo00<000000?ooo`3oool0B`3oool200000100oooo00<000000?ooo`3o
ool0o`3oool:0?ooo`030000003oool0oooo00L0oooo000=0?ooo`030;md00000000000000T00000
00<0001809cOo`3oool0=@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo04d0oooo
0P00000>0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`00303o
ool00`3ookl0M0000000000;00000003001d_`3oool0oooo03@0oooo00<000000?ooo`3oool0VP3o
ool00`000000oooo0?ooo`1?0?ooo`800000303oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<0
00000?ooo`3oool01`3oool00180oooo00<0omnL04Qd_`3oool0103oool00`3ogi`0B01d0;ooo`0e
0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`070?ooo`004@3oool00`3o
okl0M01809cOo`060?ooo`030;mdM02oool0oooo03@0oooo00<000000?ooo`3oool0VP3oool00`00
0000oooo0?ooo`1B0?ooo`8000002@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?oo
o`3oool01`3oool00140oooo00<0okmd0000B02Lgol01@3oool00`3ooml0W7BL0=ooo`0e0?ooo`<0
0000VP3oool00`000000oooo0?ooo`1D0?ooo`8000001`3oool00`000000oooo0?ooo`3o0?ooo`P0
oooo0`0000090?ooo`004@3oool0103ogi`0B0000000B02Lgol30?ooo`030?oog`2LB000M;oo03H0
oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00L0oooo000B0?ooo`030;md
00000000000000@0000000<007Bo0?ooo`3oool0=@3oool00`000000oooo0?ooo`2J0?ooo`030000
003oool0oooo05L0oooo0P0000040?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo
0?ooo`070?ooo`004`3oool00`3OW4P00000000000020000000307Boo`3oool0oooo00`0oooo00H0
_g@000000000000000000018W03Oool30?ooo`030=nLB0000000000000D0000000H0M;oo0?ooo`3o
ool0gia800000018W=l30?ooo`060?oog`2LB00000000000000007@0_ooo2P3oool00`000000oooo
0?ooo`2J0?ooo`030000003oool0oooo05T0oooo0P0000020?ooo`030000003oool0oooo0?l0oooo
2P3oool00`000000oooo0?ooo`070?ooo`009P3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018
B9`0gooo00<0oooo00<0gia8000000000000100000001P00M;l0oooo0?ooo`3OW4P0000004RLg`80
oooo00P0oono07@00000B9`0gooo0?ooo`3OW4P0001809cOo`T0oooo00<000000?ooo`3oool0VP3o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool000000?l0oooo303oool00`000000oooo0?oo
o`070?ooo`006@3oool00`2oM000000004RLg`0@0?ooo`030?oOW018M;l0oooo00<0oooo00<0gia8
04RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`060?ooo`030;md000007@0_ooo00<0oooo00<0_g@0
001d_`3oool0203oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo05`0oooo0P00003o
0?ooo``0oooo00<000000?ooo`3oool01`3oool001L0oooo00D0omnL04P0001d_ol0gia804RLg`0@
0?ooo`030?oo_`1d04P0W=oo00@0oooo00<0gia804RLg`3oool02@3oool00`3ookl0M000001d_`04
0?ooo`030=nLB00007@0_ooo00P0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`1M
0?ooo`<00000o`3oool:0?ooo`030000003oool0oooo00L0oooo000F0?ooo`060=nLB000B9`0gooo
0?ooo`3OW4P0B9cO403oool00`3ookl0M00007Boo`050?ooo`030=nLB01d_ol0oooo00P0oooo00<0
omnL04P00018W=l0103oool00`2oM000001809cOo`080?ooo`030000003oool0oooo09X0oooo00<0
00000?ooo`3oool0G@3oool010000000oooo0?ooo`00003o0?ooo`T0oooo00<000000?ooo`3oool0
1`3oool001D0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0?0?ooo`030?noM000
0000M;oo00D0oooo00<0oooO09a8B02Lgol0203oool00`3ogi`0B00004RLg`030?ooo`040?oo_`1d
0000001d0;ooo`P0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`1M0?ooo`040000
003oool0oooo0?ooo`800000o`3oool70?ooo`030000003oool0oooo00L0oooo000D0?ooo`030=nL
B0000000000000H0000000<0001d0;ooo`3oool02`3oool0103ogi`0B0000000M02oool60?ooo`03
0?oOW01807@0_ooo00L0oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l02@3o
ool5000009P0oooo00<000000?ooo`3oool0H`3oool200000?l0oooo0P3oool4000000T0oooo000J
0?ooo`030=nLB018W=l0oooo00X0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?oo
o`060?ooo`030;md0018W=l0oooo00H0oooo00D0oooO09a8000007@0_mnL04P000020000000304RL
g`3oool0oooo00P0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo0?l0oooo0P3oool00`000000oooo0?ooo`070?ooo`009`3oool00`3o_g@000000000
000200000003001d_`3oool0oooo00L0oooo00<0gia80000M02oool01`3oool00`3o_g@0000004RL
g`0>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0IP3oool200000?l0oooo0P3o
ool00`000000oooo0?ooo`070?ooo`009`3oool01@3ooml0W4P00000000007@0_ooo00X0oooo00<0
okmd0000001d_ol01`3oool0103ooml0W4P00000B02Lgol=0?ooo`030000003oool0oooo09X0oooo
00<000000?ooo`3oool0J03oool200000?l0oooo00<000000?ooo`3oool01`3oool002P0oooo00<0
okmd001d_`3oool01@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo00P0oooo00@0
oono07@0000007@0_ooo303oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo06X0oooo
0P00003m0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030?oog`2LB00000000080000000H0
001d0;ooo`3oool0oooo0;md001d_ol20?ooo`040=nLB000000004RL0=ooo`T0oooo00@0oooO09a8
0000000007Bo2`3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo06`0oooo00<00000
0?ooo`3oool0nP3oool00`000000oooo0?ooo`070?ooo`00:@3oool00`3o_g@00000000000020000
000507Boo`3oool0oooo0?ooo`2oM0000`0000000`00M;l0oooo0?ooo`0;0?ooo`050?oOW0180000
00000018W03Oool0203oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo06d0oooo0P00
003j0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo09X0oooo00<00000
0?ooo`3oool0K`3oool200000?P0oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?oo
o`3oool0VP3oool00`000000oooo0?ooo`1a0?ooo`800000mP3oool00`000000oooo0?ooo`070?oo
o`00D@3oool3000009X0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`3a0?ooo`<0
00002@3oool00540oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`1d0?ooo`800000
l`3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`2J0?ooo`030000003o
ool0oooo07H0oooo0P00003a0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0
oooo09X0oooo00<000000?ooo`3oool0N03oool200000>l0oooo00<000000?ooo`3oool01`3oool0
0540oooo00<000000?ooo`3oool0o`3ooolH0?ooo`030000003oool0oooo0>`0oooo00<000000?oo
o`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3ooolI0?ooo`800000k03oool00`000000
oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooa/0oooo0P00003Z0?ooo`030000
003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0?l0oooo7@3oool00`000000oooo0?oo
o`3W0?ooo`030000003oool0oooo00L0oooo001A0?ooo`<00000o`3ooolN0?ooo`800000i@3oool3
000000T0oooo001A0?ooo`030000003oool0oooo0?l0oooo803oool200000>D0oooo00<000000?oo
o`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3ooolR0?ooo`030000003oool0oooo0>80
oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3ooolS0?ooo`800000
hP3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooobD0oooo0P00
003P0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0?l0oooo9`3oool0
0`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo
0?l0oooo:03oool200000=d0oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3o
ool0o`3ooolZ0?ooo`800000f`3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo
0?ooo`3o0?ooob`0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`070?ooo`00D@3o
ool300000?l0oooo;@3oool200000=H0oooo0`0000090?ooo`00D@3oool00`000000oooo0?ooo`3o
0?ooobl0oooo0P00003F0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo
0?l0oooo<@3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00L0oooo001A0?ooo`03
0000003oool0oooo0?l0oooo<P3oool200000=<0oooo00<000000?ooo`3oool01`3oool00540oooo
00<000000?ooo`3oool0o`3ooold0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool0
1`3oool00540oooo00<000000?ooo`3oool0o`3ooole0?ooo`800000d03oool00`000000oooo0?oo
o`070?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooocL0oooo0P00003>0?ooo`030000003oool0
oooo00L0oooo001A0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`3;0?oo
o`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0?l0oooo>P3oool200000</0
oooo00<000000?ooo`3oool01`3oool00540oooo0`00003o0?oooc`0oooo00<000000?ooo`3oool0
aP3oool3000000T0oooo001A0?ooo`030000003oool0oooo0?l0oooo?@3oool200000<P0oooo00<0
00000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3ooolo0?ooo`800000aP3oool0
0`000000oooo0?ooo`070?ooo`009`3oool01P2oM000000000000000000004RL0=ooo`<0oooo00<0
gia80000000000001@0000001P1d_ol0oooo0?ooo`3OW4P0000004RLg`@0oooo00<0omnL04P0M02o
ool0303oool00`000000oooo0?ooo`3o0?oood40oooo00<000000?ooo`3oool0``3oool00`000000
oooo0?ooo`070?ooo`009P3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00<0oooo
00<0gia8000000000000100000001P00M;l0oooo0?ooo`3OW4P0000004RLg`D0oooo00<0_g@007Bo
o`3oool02`3oool00`000000oooo0?ooo`3o0?oood80oooo0P0000330?ooo`030000003oool0oooo
00L0oooo000/0?ooo`030?oOW018M;l0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3ooml0
W4Qd0;ooo`090?ooo`030?noM000M;l0oooo00/0oooo00<000000?ooo`3oool0o`3ooom40?ooo`80
0000`@3oool00`000000oooo0?ooo`070?ooo`00;03oool00`3ookl0M01809cOo`040?ooo`030=nL
B018W=l0oooo00d0oooo00<0oono07@0M02oool02`3oool00`000000oooo0?ooo`3o0?ooodH0oooo
0P00002o0?ooo`030000003oool0oooo00L0oooo000/0?ooo`030?oo_`1d0000M;oo00D0oooo00<0
gia807Boo`3oool03@3oool00`2oM000M;oo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooB03o
ool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo00L0oooo000/0?ooo`030?noM0000000
M;oo00D0oooo00<0oooO09a8B02Lgol03@3oool00`3o_g@007Bo0?ooo`0:0?ooo`030000003oool0
oooo0?l0ooooB@3oool200000;`0oooo00<000000?ooo`3oool01`3oool002/0oooo00@0omnL04P0
000007@0_ooo1P3oool00`3ogi`0B01d0;ooo`0<0?ooo`030?oo_`1d07@0_ooo00X0oooo1@00003o
0?ooodT0oooo0P00002g0?ooo`@000002@3oool002L0oooo00@0gmoO0?ooo`3oool0_g@00P000000
0`18W=l0oooo0?ooo`060?ooo`030;md0018W=l0oooo00`0oooo00<0_g@007Boo`3oool02@3oool0
0`000000oooo0?ooo`3o0?ooodd0oooo0P00002h0?ooo`030000003oool0oooo00L0oooo000W0?oo
o`030?noM000000000000080000000<007Bo0?ooo`3oool01`3oool00`3OW4P0001d0;ooo`0<0?oo
o`030?noM000M;l0oooo00T0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool01`3oool002L0oooo00D0oooO09a800000000001d0;ooo`0:0?oo
o`030?noM0000000M;oo00H0oooo00<0omno0;oOo`3oool00`3oool00`3ookl0M01d0;ooo`090?oo
o`030000003oool0oooo0?l0ooooD03oool200000;D0oooo00<000000?ooo`3oool01`3oool002P0
oooo00<0okmd001d_`3oool01@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo00H0
oooo00<0oooO09a8M02oool0103oool00`2oM000M;oo0?ooo`080?ooo`030000003oool0oooo0?l0
ooooDP3oool200000;<0oooo00<000000?ooo`3oool01`3oool002P0oooo00<0oooO09a800000000
0P0000001P0007@0_ooo0?ooo`3oool0_g@007Boo`80oooo00@0gia800000000B9`0gooo1`3oool0
0`3OW4P000000000000400000003001d_`3oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomD
0?ooo`800000/@3oool00`000000oooo0?ooo`070?ooo`00:@3oool00`3o_g@00000000000020000
000507Boo`3oool0oooo0?ooo`2oM0000`0000000`00M;l0oooo0?ooo`070?ooo`030?oOW0180000
000000@0000000<0001809cOo`3oool01`3oool00`000000oooo0?ooo`3o0?oooeH0oooo00<00000
0?ooo`3oool0[P3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`3o0?oo
oeL0oooo0P00002^0?ooo`030000003oool0oooo00L0oooo001A0?ooo`<00000o`3ooomI0?ooo`80
0000ZP3oool3000000T0oooo001A0?ooo`030000003oool0oooo0?l0ooooF`3oool00`000000oooo
0?ooo`2Y0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0?l0ooooG03o
ool200000:T0oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3ooomN
0?ooo`800000Y`3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`3o0?oo
of00oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo
00L0oooo001A0?ooo`030000003oool0oooo0?l0ooooH@3oool2000003L0oooo00<000000?ooo`3o
ool0JP3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooof<0oooo
0P00000e0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool01`3oool00540oooo00<0
00000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0JP3o
ool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooofH0oooo0P00000b
0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool01`3oool00540oooo0`00003o0?oo
ofP0oooo0P00000`0?ooo`030000003oool0oooo06P0oooo0`0000090?ooo`00D@3oool00`000000
oooo0?ooo`3o0?ooofX0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0?l0ooooJ`3oool2000002d0oooo
00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?oo
o`3o0?ooofd0oooo0P00000[0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool01`3o
ool00540oooo00<000000?ooo`3oool0o`3ooom_0?ooo`800000:@3oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0?l0ooooL@3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool01`3oool00540
oooo00<000000?ooo`3oool0o`3ooomb0?ooo`8000009P3oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0?l0ooooM03oool2000002@0oooo
00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?oo
o`3o0?ooogH0oooo0P00000R0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool01`3o
ool00540oooo0`00003o0?ooogP0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1X
0?ooo`<000002@3oool00540oooo00<000000?ooo`3oool0o`3ooomi0?ooo`8000007`3oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0?l0
ooooN`3oool2000001d0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`070?ooo`00
D@3oool00`000000oooo0?ooo`3o0?ooogd0oooo0P00000K0?ooo`030000003oool0oooo06X0oooo
00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3ooomo0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`070?ooo`00D@3oool0
0`000000oooo0?ooo`3o0?oooh00oooo0P00000H0?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3ooon20?ooo`8000005P3oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0?l0
ooooQ03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3o
ool01`3oool00540oooo0`00003o0?ooohD0oooo0P00000C0?ooo`030000003oool0oooo06P0oooo
0`0000090?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooohL0oooo0P00000A0?ooo`030000003o
ool0oooo06X0oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3ooon9
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`07
0?ooo`009`3oool01P2oM000000000000000000004RL0=ooo`<0oooo00<0gia80000000000001@00
00001P1d_ol0oooo0?ooo`3OW4P0000004RLg`<0oooo00H0omnL04P00000000000000000B02Lgol:
0?ooo`030000003oool0oooo00d0oooo00<0okmd0000001d_ol00`3oool0103ooml0W4P00000B02L
gol;0?ooo`030;mdM02oool0oooo0180oooo00<0oooO09a8000000001`0000000`1d_ol0oooo0?oo
o`0>0?ooo`030;md0000000000000080000000<0001d0;ooo`3oool00`3oool01P3ogi`0B0000000
00000000001d0;ooo`80oooo00D0gia80000000000000000001d_`020?ooo`050=nLB00000000000
00000000M;l0103oool01@3ogi`0B00000000000000007Bo0080oooo00P0oono07@0000000000000
0000B02Lgol0oooo0;md0080000000`0001809cO_`1d00000000001d_`3oool0oono07@000000000
04RL0=oo_`1d0002000000060000B02Lgol0oooo0?ooo`3ogi`0B0000P0000001@0007@0_ooo0?oo
o`3oool0_g@000<0000000H0M;no07@00000000000000000M02oool80?ooo`030;md000000000000
0080000000<0001d0;ooo`3oool00`3oool01P3ogi`0B000000000000000001d0;ooo`@0oooo00D0
omnL04P0000000000000001d_`020?ooo`030?noM000000000000080000000<004RL0=noM0000000
0`0000000`00B9`0gono07@00002000000050000B02Lgol0oooo0?ooo`3o_g@00`0000001@00B9`0
gooo0?ooo`3ookl0M0000080000000H0001809cOo`3oool0oooo0?oOW018000200000004001d_`3o
ool0oooo0;md00<0000000/0M;no07@00000000000000000M02oool0oono07@00000000004RL0=oo
o`020?ooo`040?oog`2LB000001809cOo`H0oooo00D0gia80000000000000000001d_`0A0?ooo`04
0;md00000000000004RLg`@0oooo00<0gia800000018W=l00`3oool01P3ogi`0B000000000000000
001809cOo`80oooo00D0oooO09a800000000001809cOo`150?ooo`8000003P3oool00`000000oooo
0?ooo`1Z0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030?oog`2LB000B9cO0080oooo00<0
omnL04Q8W03Oool00`3oool00`3OW4P000000000000400000006001d_`3oool0oooo0=nLB0000000
B9cO0P3oool0203ogi`0B0000018W03Oool0oooo0?oOW0180000M;oo2@3oool00`000000oooo0?oo
o`0=0?ooo`030?noM0000000M;oo00<0oooo00@0oooO09a8000004P0W=oo2P3oool00`3ogi`0B000
04RLg`0E0?ooo`030?oOW018000007Bo00@0oooo00<0_g@0001d_`3oool03@3oool0103o_g@00000
0000001d_ol30?ooo`030?oo_`1d0000M;oo0080oooo00P0okmd00000000B9`0gooo0?ooo`3o_g@0
001809cOo`80oooo00<0okmd0000001d_ol0103oool00`3o_g@0000007Boo`040?ooo`0Q0?noM000
0000001809cOo`3oool0gia80018W03Oool0oooo0?oog`2LB00004RL0=ooo`3oool0okmd00000000
M;l0oooo0?oog`2LB000000004RLg`3o_kl0_ooo0=nLB00004P0W=oo0?oOW02L_ol0oooo0;md0000
07@0_ooo0080oooo00P0okmd00000000B9`0gooo0?ooo`3o_g@0001809cOo`80oooo00P0gia80000
B02Lgol0oooo0?oog`2LB00004RL0=ooo`L0oooo00@0okmd000000000000M;oo0`3oool00`3ookl0
M00007Boo`020?ooo`080?noM000000004RL0=ooo`3oool0okmd0000B02Lgol20?ooo`0=0?noM000
0000001809cOo`3oool0gia80018W03Oool0oooo0?oog`2LB000001d0;ooo`020?ooo`040?oog`2L
B000001d0;ooo`<0oooo00<0_g@00000M02oool00P3oool00`3OW4P0000000000003000000070018
W03Oool0oooo0?ooo`2oM000001d0;ooo`020?ooo`0G0?noM0000000001809cOo`3oool0gia80018
W03Oool0oooo0=nLB00004P0W=oo0?ooo`3ooml0W4P00018W03Oool0oooo0=nLB00004P0W=oo0?oO
W02L_ol00P3oool0103ooml0W4P00000B02Lgol70?ooo`030?noM0000000M;oo0100oooo00L0oooO
09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l00P3oool0203ogi`0B000
0018W03Oool0oooo0?oOW0180000M;oo103oool0103OW4P000000018W03Ooom50?ooo`800000303o
ool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00L0oooo000/0?ooo`030?oOW018M;l0
oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`060?ooo`030;md000007@0
_ooo00<0oooo00<0gia80018W03Oool0203oool00`000000oooo0?ooo`0=0?ooo`030?noM0000000
M;oo0140oooo00@0gia800000000B9`0gooo503oool00`3ogi`0B00004RLg`040?ooo`030?oog`2L
M9`0gooo00`0oooo00@0omnL04P0000004P0W=oo1P3oool01P2oM4P0W=oo0?oog`2LB000001809cO
o`<0oooo00L0_g@00018W03Oool0oooo0?noM0000000M;oo00@0oooo00<0okmd0000001d_ol00`3o
ool0103ookl0M0000018W03Oool30?ooo`0;0?noM01d_ol0oooo0?oog`2LB00004RL0=ooo`3oool0
okmd0000001d_ol00P3oool00`3ogi`0B00004RLg`020?ooo`030=nLB00004P0W=oo00<0oooo00P0
_g@00018W03Oool0oooo0?oog`2LB000001809cOo`<0oooo00`0_g@00018W03Oool0oooo0=nLB000
04P0W=oo0?ooo`3ooml0W4P00018W03Oool60?ooo`040?oOW0180000001809cOo`H0oooo00H0_gA8
09cOo`3ooml0W4P00000B02Lgol30?ooo`070;md0000B9`0gooo0?oo_`1d000004RL0=ooo`030?oo
o`070?noM01d_ol0oooo0?ooo`2oM00004RL0=ooo`030?ooo`030;md0000B9`0gooo00<0oooo00P0
_g@00018W03Oool0oooo0?oo_`1d0000000004RLg`<0oooo00`0giad09cOo`3oool0oooo0;md0000
B9`0gooo0?ooo`3ookl0M0000018W03Oool30?ooo`0?0?noM01d_ol0oooo0=nLB00004P0W=oo0?oo
o`3ooml0W4P00018W03Oool0oooo0=nLB00004P0W=oo00l0oooo00<0okmd0000001d_ol0403oool0
0`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<0_g@00000M02oool00`3oool0
0`3OW4P004RL0=ooo`040?ooo`040?oo_`1d0000001d0;ooodH0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00L0oooo000/0?ooo`030?oo_`1d04P0
W=oo00@0oooo00<0gia804RLg`3oool02P3oool00`2oM000001d0;ooo`030?ooo`030;md0000B9`0
gooo00P0oooo00<000000?ooo`3oool0203oool00`3OW4P0000000000005000000030000B02Lgol0
oooo00d0oooo00D0oono07@00000B9`0_ia807Boo`0D0?ooo`030?oOW0180000B9cO00D0oooo00<0
oknL09cOo`3oool02`3oool00`2oM000000004RLg`090?ooo`030?oOW018000007Bo00@0oooo00L0
gia80000B02Lgol0oooo0?noM0000000M;oo00@0oooo00<0okmd0000001d_ol00`3oool00`3ogi`0
B00007Boo`070?ooo`080?oog`2LB00004RL0=ooo`3oool0oono07@00000M;l20?ooo`030?oOW018
0000B9cO0080oooo00<0gia80000B02Lgol00`3oool01`2oM00004RL0=ooo`3oool0omnL04P00000
M;l0103oool0303OW4P0001809cOo`3oool0gia80000B02Lgol0oooo0?oog`2LB00004RL0=ooo`H0
oooo00<0_g@000000018W=l02@3oool00`3ogi`0B000001d_`040?ooo`060=nLB00004P0W=oo0?oO
W0180000M;oo203oool00`2oM00004RL0=ooo`030?ooo`030;md0000B9`0gooo00<0oooo00L0_g@0
0018W03Oool0oooo0?noM000000007Bo00P0oooo00L0_g@00018W03Oool0oooo0?oOW0180000M;oo
00L0oooo00`0gia80000B02Lgol0oooo0?oog`2LB00004RL0=ooo`3oool0gia80000B02Lgol?0?oo
o`030?noM0000000M;oo00<0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?oog`2LB000
04RL0=ooo`80oooo00<0oooO09a80000M;l01`3oool00`2oM000001d0;ooo`030?ooo`030;md0000
B9`0gooo00D0oooo00@0oono07@00000B9`0goooAP3oool2000000T0oooo00<000000?ooo`3oool0
JP3oool00`000000oooo0?ooo`070?ooo`00;03oool00`3ookl0M00007Boo`050?ooo`030=nLB01d
_ol0oooo00T0oooo00<0okmd0000B02Lgol00P3oool00`3OW4P00000001d_`090?ooo`030000003o
ool0oooo00P0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`0@0?ooo`050=nLB000
0000M;oo0?oOW018M;l0503oool00`3ogi`0B00004RLg`0B0?ooo`040?oo_`1d0000001809cOo`T0
oooo00<0okmd00000018W=l0103oool01`3OW4P0000007Boo`3oool0okmd0000001d_ol0103oool0
0`3o_g@0000007Boo`030?ooo`030?oOW01804P0W=oo00L0oooo00@0oooO09a80000B9`0gooo0P3o
ool01`3ooml0W4P00000001d_ol0omnL04P00018W=l00P3oool00`3OW4P0001809cOo`030?ooo`07
0;md0000B9`0gooo0?ooo`3o_g@0000004RLg`040?ooo`0<0=nLB0000000M;oo0?ooo`3OW4P00018
09cOo`3oool0oooO09a80000B9`0gooo1@3oool0103ookl0M0000000B02Lgol90?ooo`030?noM000
0000B9cO00@0oooo00H0gia80000001d_ol0omnL04P0B02Lgol80?ooo`030;md0000B9`0gooo00<0
oooo00<0_g@00018W03Oool00`3oool01`2oM00004RL0=ooo`3oool0okmd0000001d_ol0203oool0
1`2oM00004RL0=ooo`3oool0omnL04P0B02Lgol01`3oool0303OW4P0001809cOo`3oool0oooO09a8
0000B9`0gooo0?ooo`3OW4P0001809cOo`l0oooo00<0okmd0000001d_ol03`3oool00`3ookl0M000
001d_`040?ooo`030;md000007@0_ooo00H0oooo00<0okmd0000B02Lgol00P3oool00`3OW4P00000
001d_`070?ooo`030=nLB0000000M;oo04P0oooo0P0000070?ooo`030000003oool0oooo06X0oooo
00<000000?ooo`3oool01`3oool002`0oooo00<0okmd0000001d_ol01@3oool00`3ooml0W4Q809cO
o`0:0?ooo`070=nLB000M;l0oooo0;md00000000001d0;ooo`090?ooo`030000003oool0oooo00T0
oooo00L0gia807Boo`3oool0oooo0?noM0000000M;oo00l0oooo00L0oooO09a8000007@0_ooo0?oo
o`2oM7@0_ooo00H0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3ogi`0B00004RL
ga80oooo00@0okmd0000000007@0_ooo2@3oool00`3ogi`0B00004RLg`040?ooo`070;md000004P0
W=oo0?ooo`3o_g@0000007Boo`040?ooo`030?noM0000000M;oo00<0oooo00<0omnL04P000000000
1@0000001P1d_ol0oooo0?oog`2LB00004RL0=ooo`D0oooo00@0_g@0000000000000B9cO0P3oool0
0`3OW4P0001809cOo`030?ooo`070;md0000B9`0gooo0?ooo`3ogi`0B00004RLg`040?ooo`0<0;md
000004P0W=oo0?ooo`3OW4P0001809cOo`3oool0oooO09a80000B9`0gooo1@3oool0103o_g@00000
0000M02oool90?ooo`030?oOW0180000B9cO00@0oooo00D0_g@00000B02Lgol0omnL04P000060000
000607Boo`3oool0oooo0;md0000B9`0gooo0`3oool00`2oM00004RL0=ooo`030?ooo`070;md0000
B9`0gooo0?ooo`3o_g@0001809cOo`080?ooo`060;md0000B9`0gooo0?ooo`3ogi`0B0001P000000
3P1d_ol0oooo0=nLB00004P0W=oo0?ooo`3ooml0W4P00018W03Oool0oooo0=nLB00004P0W=oo3`3o
ool00`3o_g@0000007Boo`0?0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01`3o
ool01`3OW4P007Bo0?ooo`2oM00000000000M02oool00`3oool00`3OW4P000000000000300000003
0018W03Oool0oooo04P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo00L0oooo000[0?ooo`040?oOW0180000001d0;ooo`H0oooo00<0omnL04P0M02o
ool02P3oool01@3o_g@0000000000000B9`0gooo00X0oooo1@0000070?ooo`070?oo_`1d07@0_ooo
0?ooo`3o_g@0000007Boo`0?0?ooo`030?noM0000000B9cO0080oooo00<0okmd04RLg`3oool04P3o
ool00`3ogi`0B00004RLg`0B0?ooo`040?noM0000000001d0;ooo`T0oooo00<0oooO09a80000M;l0
0`3oool0203ookl0M0000000M02oool0oooo0?noM000000007Bo103oool00`3o_g@00000001d_`03
0?ooo`030?oog`2LB4P0W=oo00<0oooo00`0_g@00000B02Lgol0oooo0?oog`2LB00004RL0=ooo`3o
ool0oooO09a80000M;l20?ooo`030?oOW0180000B9cO0080oooo00<0gia80000B02Lgol00P3oool0
203ooml0W4P00018W03Oool0oooo0?oog`2LB00007Bo0`3oool03@3ookl0M0000000M02oool0oooo
0;md00000000M;oo0?ooo`3ooml0W4P00018W03Oool01@3oool0103o_g@000000000M02oool90?oo
o`030?oog`2LB00007Bo00<0oooo00L0oono07@0000007@0_ooo0?oog`2LB4P0W=oo00<0oooo00<0
_g@00000B02Lgol00P3oool00`2oM00004RL0=ooo`030?ooo`030;md0000B9`0gooo0080oooo00P0
oooO09a80000B9`0gooo0?ooo`3ookl0M00007Boo`80oooo00d0oooO09a80000B9`0gooo0?ooo`3o
oml0W4P00018W03Oool0oooo0?oog`2LB4P0W=oo00<0oooo0100_g@00000B02Lgol0oooo0;md0000
0000M;oo0?ooo`3ooml0W4P00018W03Oool0oooo0=nLB00004P0W=oo3`3oool00`3o_g@00000001d
_`0?0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0203oool01@3o_g@000000000
0000B9`0gooo00<0oooo00<0_g@000000000M;l00P3oool0103ookl0M0000000M02ooom:0?ooo`80
0000103oool00`000000oooo0?ooo`1W0?ooo`@000002@3oool002L0oooo00@0gmoO0?ooo`3oool0
_g@00P0000000`18W=l0oooo0?ooo`060?ooo`030;md0018W=l0oooo00P0oooo00D0omnL04P00000
0000000004RLg`0;0?ooo`030000003oool0oooo00X0oooo00H0okmd001d_`3oool0okmd0000001d
_ol30?ooo`040?oog`2LB000001809cOo`P0oooo00<0_g@00000B02Lgol00P3oool00`3ookl0M4RL
0=ooo`0B0?ooo`030?oOW0180000B9cO0180oooo00@0omnL04P0000007@0_ooo2P3oool02P3ogi`0
B00007Boo`3oool0oooO09a800000000M;oo0?oog`2LB0020000000507AdM018W=l0_g@00018M01d
B0000P0000009P1dM7@0B9cO0;md0000B9`0gooo0?noM00007@0_ooo0?ooo`3ogi`0B0000018W03O
ool0oooo0?oog`2LB00004RL0=ooo`3oool0oooO09a80000B9`0gooo0?ooo`3OW4P0000007Boo`3o
oml0gmoo0=nLB00004P0W=oo0?ooo`3ogi`0B00000000000B9`0gooo0P3oool04@3ogi`0B00007Bo
o`3oool0oooO09a800000000M;oo0?oo_`1d000000000000B018B000B9cO0?oo_`1d000007Bo00H0
oooo00@0omnL04P0000007@0_ooo2P3oool0203ogi`0B00007Boo`3oool0oooO09a800000000M;oo
0P3oool0203o_g@0001d0;ooo`3oool0omnL04P00000B9`0gooo0P3oool00`2oM00004RL0=ooo`03
0?ooo`090;md0000B9`0gooo0?ooo`3ogi`0B00000000000B9`0gooo0080oooo00d0okmd0000B02L
gol0oooo0?noM000000004RL0=ooo`3ogi`0B00000000000B9`0gooo0080oooo01D0okmd0000M02o
ool0oooo0?oOW018000004RL0=oo_`1d000000000000B018B000B9cO0?oo_`1d000007Bo0?oog`3O
gol0gia80000B02Lgol0103oool0103ooml0W4P00000B02Lgol50?ooo`090?oog`2LB00000000000
001dM7@0B9cO0;md0000B9`0Yg@000T0000000D0B9cO0?ooo`3ogi`0B00004RLg`040?ooo`030=nL
B00004P0W=oo00L0oooo00D0omnL04P000000000000004RLg`030?ooo`040?oo_`1d000004RL0=oo
o`<0oooo00<0_g@00000B02Lgol0C03oool200000080oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`070?ooo`009`3oool00`3o_g@000000000000200000003001d_`3oool0oooo00L0
oooo00<0gia80000M02oool01`3oool01`3ogi`0B0000000B02Lgol0oooo0=nLB000M;l02P3oool0
0`000000oooo0?ooo`0;0?ooo`050;md001d_ol0okmd0000001d_ol00`3oool0103ooml0W4P00000
B02Lgol70?ooo`030?oOW018000007Bo00@0oooo00<0gia807Boo`3oool04@3oool00`3ogi`0B000
04RLg`0B0?ooo`040?oo_`1d0000001809cOo`H0oooo00<0oooO09adW03Oool00P3oool01P3ookl0
M000000000000000001809cOo`<0oooo00d0gia80000001d_ol0gia800000000M;l0oooo0=nLB000
0000M;oo0=nLB000000007Bo0080oooo00H0omnL04P00000000000000018W03Oool20?ooo`040?oo
g`2LB00004RL0=ooo`80oooo00<0oooO09a8000000000P0000001000M;l0oooo0?ooo`2oM0030000
00060000B02Lgol0oooO09a80000B9`0gooo0`3oool01P3ookl0M000000000000000001809cOo`<0
oooo00L0_g@00000B02Lgol0gia80000000004P0W=oo00H0oooo00@0oono07@0000004P0W=oo1P3o
ool00`3ooml0W7BL0=ooo`020?ooo`060?oo_`1d000000000000000004P0W=oo103oool0203ogi`0
B00000000000000004RL0=ooo`3oool0gia8100000000`0004P0M7A800000003000000060000B02L
gol0oooO09a80000B9`0gooo0`3oool01P3ogi`0B00000000000000004RL0=ooo`80oooo00@0oooO
09a80000B9`0gooo0`3oool01P3ogi`0B00000000000000004RL0=ooo`80oooo00T0_g@00000B02L
gol0gia80000000004P0W=oo0?ooo`2oM0000`000000200004P0W=oo0?ooo`3oool0oooO09a80000
04P0W=oo1`3oool01P3OW4P0000007Boo`3OW4P00000001d_``0oooo00<0oono07@00000M;l0103o
ool00`2oM000001d0;ooo`060?ooo`070?oOW0180000001809cOo`3oool0gia8001d_`020?ooo`03
0?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0CP3oool00`000000oooo0000001/0?ooo`03
0000003oool0oooo00L0oooo000W0?ooo`050?oog`2LB00000000000M02oool02P3oool00`3o_g@0
000007Boo`070?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a8001d_ol02@3oool00`000000
oooo0?ooo`0;0?ooo`050?oo_`1d07@0_kmd0000001d_ol03P3oool00`3OW4P0001809cOo`040?oo
o`030?oOW018M;l0oooo0140oooo00<0omnL04P00018W=l04`3oool00`3OW4P0000004RLg`060?oo
o`030?oOW018B9`0gooo0280oooo00@0oooO09a80000B9`0gooo2`3oool00`3OW4P0001809cOo`0P
0?ooo`030=nLB0000000B9cO00H0oooo00<0omnL04Q8W03Oool05@3oool00`2oM00004RL0=ooo`03
0?ooo`030;md0000B9`0gooo02T0oooo00<0gia80000B02Lgol08P3oool00`2oM00004RL0=ooo`02
0?ooo`030?oog`2LB00007Bo00L0oooo00<0gia80000B02Lgol00P3oool01`3ooml0W4P007Boo`3o
ool0omnL04P00018W=l0103oool00`2oM000001d0;ooo`1?0?ooo`800000K03oool00`000000oooo
0?ooo`070?ooo`00:03oool00`3o_g@007Bo0?ooo`050?ooo`030?oOW02L_ol0oooo00<0oooo00<0
_g@00000001d_ol01`3oool00`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO00T0oooo00<0
00000?ooo`3oool0303oool0103o_g@000000000001d_ol=0?ooo`040?oo_`1d000004RL0=ooo`@0
oooo00<0oooO09a8B02Lgol04@3oool00`3ogi`0B00004RLg`0C0?ooo`040?oo_`1d0000001809cO
o`D0oooo00<0_g@0001d_`3oool08P3oool0103ooml0W4P00018W03Oool;0?ooo`030?oo_`1d04P0
W=oo0200oooo00@0oono07@0000004P0W=oo1@3oool00`2oM00007Bo0?ooo`0E0?ooo`030;md0000
B9`0gooo00<0oooo00<0_g@00018W03Oool0:@3oool00`3ookl0M01809cOo`0R0?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`3OW4P004RL0=ooo`020?ooo`070?oog`2L
B000B9cO0?ooo`3ooml0W4P0001d_`030?ooo`030?oo_`1d0000B9cO0540oooo0`00001Z0?ooo`03
0000003oool0oooo00L0oooo000X0?ooo`030?oog`2LB00000000080000000H0001d0;ooo`3oool0
oooo0;md001d_ol20?ooo`040=nLB000000004RL0=ooo`L0oooo00<0omnL04P00018W=l00P3oool0
0`3o_g@0001809cOo`090?ooo`030000003oool0oooo00`0oooo00@0oooO09a800000000M;oo3@3o
ool0103OW4P000000018W03Oool40?ooo`030?oog`2LB00007Bo0140oooo00<0omnL04P00018W=l0
503oool0103ookl0M0000000B02Lgol20?ooo`040?oog`2LB0000000001d_b<0oooo00@0oooO09a8
0000B9`0gooo303oool00`3OW7@0W=oo0?ooo`0P0?ooo`040?oo_`1d0000001809cOo`80oooo00@0
oooO09a80000000007Bo5P3oool00`3OW4P0001d0;ooo`030?ooo`030=nLB00007@0_ooo02X0oooo
00<0giad09cOo`3oool08P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00<0omnL04P0
0018W=l00P3oool00`3o_g@0001809cOo`020?ooo`080?oOW0180000M;oo0?ooo`3ooml0W4P00018
W03OoomA0?ooo`040000003oool0oooo000006T0oooo00<000000?ooo`3oool01`3oool002T0oooo
00<0okmd0000000000000P0000001@1d_ol0oooo0?ooo`3oool0_g@000<0000000<007Bo0?ooo`3o
ool0203oool01P3ookl0M000000000000000001809cOo`X0oooo00<000000?ooo`3oool03@3oool0
0`3ogi`0B00007Boo`0;0?ooo`030?oog`2LB00000000080000000H0001d0;ooo`3oool0oooo0?oo
g`2LB002000000030018W03Oool0oooo00`0oooo00<0oooO09a8000000000`0000000`1d_ol0oooo
0?ooo`0B0?ooo`080=nLB000000000000000000004P0W=oo0?oo_`1dM;lR0?ooo`050?oOW0180000
00000018W03Oool0403oool0103ooml0W4P00000M02ooolM0?ooo`080=nLB0000000000000000000
04P0W=oo0?oo_`1dM;lF0?ooo`0;0?oo_`1d04P0W=oo0?ooo`3OW4P0000004RLW01d04P0W=oo0?oo
o`3OW4P00P0000000`0007@0_ooo0?ooo`0:0?ooo`040?oog`2LB000001d0;oooc/0oooo00@0_g@0
00000000000007Bo2P3oool01P3ookl0M000000000000000001809cOo`@0oooo00H0oono07@00000
000000000018W03OoomB0?ooo`040000003oool0oooo0?ooo`800000I`3oool00`000000oooo0?oo
o`070?ooo`00D@3oool00`000000oooo0?ooo`1m0?ooo`040?oo_`1d000004RL0=oooa00oooo00@0
oooO09a8000007@0_ooo?03oool0203ooml0W4P000000000000004RL0=ooo`3ooml0W4P00P000000
1000B7@0M4P00000M02oool;0?ooo`040?oog`2LB000001d0;oooj/0oooo00<000000?ooo`3oool0
0`3oool2000006D0oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3o
oonJ0?ooo`030000003oool0oooo00D0oooo0P00001S0?ooo`030000003oool0oooo00L0oooo001A
0?ooo`<00000o`3ooonJ0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0GP3oool3
000000T0oooo001A0?ooo`030000003oool0oooo0?l0ooooV03oool3000000X0oooo0P00001P0?oo
o`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0?l0ooooU`3oool5000000/0
oooo0P00001N0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0?l0oooo
UP3oool7000000`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`070?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?oooiH0oooo1`00000=0?ooo`800000F`3oool00`000000oooo0?oo
o`070?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooiH0oooo1`00000?0?ooo`800000F@3oool0
0`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooiL0oooo1@00000B0?oo
o`800000E`3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooiP0
oooo0`00000E0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool01`3oool00540oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`030000003oool0oooo01@0oooo0P00001D0?ooo`030000
003oool0oooo00L0oooo001A0?ooo`<00000o`3ooonJ0?ooo`030000003oool0oooo01H0oooo0P00
001@0?ooo`<000002@3oool00540oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000003oool0
oooo01P0oooo0P00001@0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo
0?l0ooooVP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000003oool0oooo01/0
oooo0P00001=0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo0?l0oooo
VP3oool00`000000oooo0?ooo`0M0?ooo`800000B`3oool00`000000oooo0?ooo`070?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?ooo`3oool07`3oool2000004T0oooo00<0
00000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00<000000?ooo`3oool08P3oool2000004H0oooo00<000000?oo
o`3oool01`3oool00540oooo0`00003o0?oooiX0oooo00<000000?ooo`3oool0903oool200000480
oooo0`0000090?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003o
ool0oooo0?l0ooooVP3oool00`000000oooo0?ooo`0W0?ooo`800000@@3oool00`000000oooo0?oo
o`070?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?ooo`3oool0:@3oool2
000003l0oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`070?oo
o`00D@3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?ooo`3oool0;03oool2000003`0
oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000
003oool0oooo02h0oooo0P00000j0?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003o
ool0oooo0?l0ooooVP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000003oool0
oooo0340oooo0P00000g0?ooo`030000003oool0oooo00L0oooo001A0?ooo`<00000o`3ooonJ0?oo
o`030000003oool0oooo03<0oooo0P00000c0?ooo`<000002@3oool00540oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?ooo`3oool0
=P3oool200000380oooo00<000000?ooo`3oool01`3oool002L0oooo00H0_g@00000000000000000
0018W03Oool30?ooo`030=nLB0000000000000D0000000`0M;oo0?ooo`3oool0gia800000018W=l0
oooo0?oog`2LB00000000000B02Lgol=0?ooo`030000003oool0oooo0?l0ooooVP3oool00`000000
oooo0?ooo`0h0?ooo`800000<03oool00`000000oooo0?ooo`070?ooo`009P3oool00`3ooml0W4P0
04RLg`020?ooo`030?oOW018B9`0gooo00<0oooo00<0gia8000000000000100000001P00M;l0oooo
0?ooo`3OW4P0000004RLg`@0oooo00@0gia800000000B9`0gooo2`3oool00`000000oooo0?ooo`3o
0?oooiX0oooo00<000000?ooo`3oool0>P3oool2000002h0oooo00<000000?ooo`3oool01`3oool0
02`0oooo00<0omnL04Qd_`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo
00T0oooo00@0oono07@0000007@0_ooo2P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00L0oooo000/0?oo
o`030?oo_`1d04P0W=oo00@0oooo00<0gia804RLg`3oool03P3oool0103ookl0M0000018W03Oool9
0?ooo`030000003oool0oooo0?l0ooooVP3oool00`000000oooo0?ooo`0m0?ooo`800000:`3oool0
0`000000oooo0?ooo`070?ooo`00;03oool00`3ookl0M00007Boo`050?ooo`030=nLB01d_ol0oooo
00h0oooo00<0gia80000001d_ol02@3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?oo
o`3oool0?`3oool2000002T0oooo00<000000?ooo`3oool01`3oool002`0oooo00<0okmd0000001d
_ol01@3oool00`3ooml0W4Q809cOo`0:0?ooo`030=nLB0000000000000<0000000<004RL0=ooo`3o
ool01`3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?ooo`3oool0@@3oool2000002L0
oooo00<000000?ooo`3oool01`3oool002/0oooo00@0omnL04P0000007@0_ooo1P3oool00`3ogi`0
B01d0;ooo`080?ooo`030;md0000000007Bo0080oooo00@0oono07@0000007@0_ooo203oool50000
0?l0ooooV03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0240oooo100000090?oo
o`009`3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00H0oooo00<0_g@004RL
g`3oool01P3oool0103ookl0M0000018W03Oool30?ooo`030;md000004P0W=oo00P0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`030000003oool0oooo04@0oooo0P00000T0?ooo`030000003oool0
oooo00L0oooo000W0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool01`3oool00`3O
W4P0001d0;ooo`060?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0203oool00`00
0000oooo0?ooo`3o0?oooiX0oooo00<000000?ooo`3oool0AP3oool200000280oooo00<000000?oo
o`3oool01`3oool002L0oooo00D0oooO09a800000000001d0;ooo`0:0?ooo`030?noM0000000M;oo
00H0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`080?ooo`030000003oool0oooo
0?l0ooooVP3oool00`000000oooo0?ooo`180?ooo`800000803oool00`000000oooo0?ooo`070?oo
o`00:03oool00`3o_g@007Bo0?ooo`050?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d
_ol01P3oool00`3ooml0W4P0001d_`030?ooo`030?oo_`1d0000B9cO00T0oooo00<000000?ooo`3o
ool0o`3ooonJ0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`070?ooo`00:03oool00`3ooml0W4P000000002000000060000M02oool0oooo0?ooo`2o
M000M;oo0P3oool0103OW4P000000018W03Oool70?ooo`080?oOW0180000M;oo0?ooo`3ooml0W4P0
0018W03Oool90?ooo`030000003oool0oooo0?l0ooooVP3oool00`000000oooo0?ooo`1;0?ooo`80
00007@3oool00`000000oooo0?ooo`070?ooo`00:@3oool00`3o_g@00000000000020000000507Bo
o`3oool0oooo0?ooo`2oM0000`0000000`00M;l0oooo0?ooo`080?ooo`060?oo_`1d000000000000
0000B9`0gooo2P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?ooo`3oool0C@3oool2
000001/0oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool0o`3ooonJ0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?oo
o`00D@3oool300000?l0ooooVP3oool00`000000oooo0?ooo`1@0?ooo`8000005P3oool3000000T0
oooo001A0?ooo`030000003oool0oooo0?l0ooooVP3oool00`000000oooo0?ooo`1B0?ooo`800000
5P3oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo001A
0?ooo`030000003oool0oooo0?l0ooooVP3oool00`000000oooo0?ooo`1E0?ooo`8000004`3oool0
0`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?oo
o`3oool0E`3oool200000140oooo00<000000?ooo`3oool01`3oool00540oooo00<000000?ooo`3o
ool0o`3oooof0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00540oooo
00<000000?ooo`3oool0o`3oooog0?ooo`8000003P3oool00`000000oooo0?ooo`070?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?ooooT0oooo0P00000<0?ooo`030000003oool0oooo00L0oooo001A
0?ooo`030000003oool0oooo0?l0oooon`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00L0oooo001A0?ooo`<00000o`3ooooo0?ooo`H0oooo0`0000090?ooo`00D@3oool00`000000
oooo0?ooo`3o0?ooool0oooo203oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo
0?ooo`3o0?ooool0oooo203oool00`000000oooo0?ooo`070?ooo`00D@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00L0oooo001A0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool00540oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00540ooooo`00003o000000`0
00002@3oool00001\
\>"],
  ImageRangeCache->{{{0, 611.375}, {377.5, 0}} -> {-0.951523, 52.0881, \
0.0100809, 0.00229542}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(b1p[a1b1_, b1b1_, x_] := a1b1\  + \ b1b1\ x;\)\)], "Input"],

Cell[BoxData[
    \(\(chi2b1[a1b1_, b1b1_] := 
        Sum[\((\((b1pl[\([i, 2]\)] - 
                    b1p[a1b1, b1b1, b1pl[\([i, 1]\)]])\)/\((b1pl[\([i, 
                      3]\)])\))\)^2, {i, 1, Length[b1pl]}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(par = {a1b1, b1b1};\)\), "\n", 
    \(\(aklb1[a1b1_, b1b1_, k_, l_] := 
        1/2  D[D[chi2b1[a1b1, b1b1], par[\([k]\)]], 
            par[\([l]\)]\ ];\)\), "\n", 
    \(\(fminb1 = 
        FindMinimum[
          chi2b1\ [a1b1, b1b1], {a1b1, 1}, {b1b1, \(-10\)}];\)\), "\n", 
    \(\(a1b1o = fminb1[\([2, 1, 2]\)];\)\), "\n", 
    \(\(b1b1o = fminb1[\([2, 2, 2]\)];\)\), "\n", 
    \(aklob1 = 
      Table[If[k \[LessSlantEqual] 
            l, \(aklb1[a1b1, b1b1, k, l] /. a1b1 \[Rule] a1b1o\) /. 
            b1b1 \[Rule] b1b1o, \(aklb1[a1b1, b1b1, l, k] /. 
              a1b1 \[Rule] a1b1o\) /. b1b1 \[Rule] b1b1o], {k, 1, 2}, {l, 1, 
          2}]; cij = Inverse[aklob1]; 
    sparb1 = Table[Sqrt[cij[\([i, i]\)]], {i, 1, 2}]; 
    Print["\<a1b1= \>", a1b1o, "\<+-\>", sparb1[\([1]\)], "\<  b1b1= \>", 
      b1b1o, "\<+-\>", sparb1[\([2]\)]]; 
    cij // MatrixForm\), "\[IndentingNewLine]", 
    \(chi2rb1 = Part[fminb1, 1]/\((Length[b1pl])\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("a1b1= "\[InvisibleSpace]2.6199594114720637`\
\[InvisibleSpace]"+-"\[InvisibleSpace]0.28404778208062864`\[InvisibleSpace]"  \
b1b1= "\[InvisibleSpace]\(-0.8255549928606278`\)\[InvisibleSpace]"+-"\
\[InvisibleSpace]0.09990378746717338`\),
      SequenceForm[ 
      "a1b1= ", 2.6199594114720637, "+-", .28404778208062864, 
        "  b1b1= ", -.82555499286062783, "+-", .099903787467173377],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.08068314250492428`", \(-0.02444096398615441`\)},
            {\(-0.02444096398615441`\), "0.009980766750286148`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    \(3.244269897216144`\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(b1pr = a1b1o + \ b1b1o\ z;\)\), "\[IndentingNewLine]", 
    \(\(b1prpl = 
        Plot[b1pr, {z, 0, 5}, 
          DisplayFunction \[Rule] Identity];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fa4 = 
      Show[b1prpl, b1dtpl, 
        Graphics[{Text["\<4: V-L  Correlation Coefficient: r=0.83\>", {1.6, \
\(-1\)}]}], Frame \[Rule] True, Axes \[Rule] False, 
        DisplayFunction \[Rule] $DisplayFunction, PlotRange \[Rule] All, 
        FrameLabel \[Rule] {"\<<z>\>", \*"\"\<\!\(a\_4\)\>\""}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.229723 0.142596 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.21429 -0.0125 -7.03125 -24.5625 ]
[.21429 -0.0125 7.03125 0 ]
[.40476 -0.0125 -7.03125 -24.5625 ]
[.40476 -0.0125 7.03125 0 ]
[.59524 -0.0125 -7.03125 -24.5625 ]
[.59524 -0.0125 7.03125 0 ]
[.78571 -0.0125 -7.03125 -24.5625 ]
[.78571 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -19.375 -49.125 ]
[.5 -0.0125 19.375 -24.5625 ]
[-0.0125 .08713 -28 -12.2813 ]
[-0.0125 .08713 0 12.2813 ]
[-0.0125 .22972 -14.0625 -12.2813 ]
[-0.0125 .22972 0 12.2813 ]
[-0.0125 .37232 -14.0625 -12.2813 ]
[-0.0125 .37232 0 12.2813 ]
[-0.0125 .51492 -14.0625 -12.2813 ]
[-0.0125 .51492 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -52.5625 -10.2188 ]
[-0.01875 .30902 -28 10.2188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.32857 .08713 -162.813 -12.2813 ]
[.32857 .08713 162.813 12.2813 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -80.375 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
75.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
84.813 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
97.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08713 m
.00625 .08713 L
s
gsave
-0.0125 .08713 -89 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .22972 m
.00625 .22972 L
s
gsave
-0.0125 .22972 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .37232 m
.00625 .37232 L
s
gsave
-0.0125 .37232 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .51492 m
.00625 .51492 L
s
gsave
-0.0125 .51492 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11565 m
.00375 .11565 L
s
0 .14417 m
.00375 .14417 L
s
0 .17269 m
.00375 .17269 L
s
0 .2012 m
.00375 .2012 L
s
0 .25824 m
.00375 .25824 L
s
0 .28676 m
.00375 .28676 L
s
0 .31528 m
.00375 .31528 L
s
0 .3438 m
.00375 .3438 L
s
0 .40084 m
.00375 .40084 L
s
0 .42936 m
.00375 .42936 L
s
0 .45788 m
.00375 .45788 L
s
0 .4864 m
.00375 .4864 L
s
0 .05861 m
.00375 .05861 L
s
0 .03009 m
.00375 .03009 L
s
0 .00157 m
.00375 .00157 L
s
0 .54343 m
.00375 .54343 L
s
0 .57195 m
.00375 .57195 L
s
0 .60047 m
.00375 .60047 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -111.5 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.2188 16.2813 translate
90 rotate
-71.2188 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
71.875 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
79.438 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08713 m
1 .08713 L
s
.99375 .22972 m
1 .22972 L
s
.99375 .37232 m
1 .37232 L
s
.99375 .51492 m
1 .51492 L
s
.125 Mabswid
.99625 .11565 m
1 .11565 L
s
.99625 .14417 m
1 .14417 L
s
.99625 .17269 m
1 .17269 L
s
.99625 .2012 m
1 .2012 L
s
.99625 .25824 m
1 .25824 L
s
.99625 .28676 m
1 .28676 L
s
.99625 .31528 m
1 .31528 L
s
.99625 .3438 m
1 .3438 L
s
.99625 .40084 m
1 .40084 L
s
.99625 .42936 m
1 .42936 L
s
.99625 .45788 m
1 .45788 L
s
.99625 .4864 m
1 .4864 L
s
.99625 .05861 m
1 .05861 L
s
.99625 .03009 m
1 .03009 L
s
.99625 .00157 m
1 .00157 L
s
.99625 .54343 m
1 .54343 L
s
.99625 .57195 m
1 .57195 L
s
.99625 .60047 m
1 .60047 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .60332 m
.06244 .57944 L
.10458 .5534 L
.14415 .52894 L
.18221 .50542 L
.22272 .48039 L
.26171 .45629 L
.30316 .43067 L
.34309 .406 L
.3815 .38225 L
.42237 .357 L
.46172 .33268 L
.49955 .30929 L
.53984 .2844 L
.57861 .26043 L
.61984 .23495 L
.65954 .21041 L
.69774 .18681 L
.73838 .16169 L
.77751 .13751 L
.81909 .11181 L
.85916 .08704 L
.89771 .06322 L
.93871 .03788 L
.97619 .01472 L
s
.002 w
.16109 .41029 m
.16109 .48855 L
s
.015 w
.16109 .44942 Mdot
.002 w
.30114 .45858 m
.30114 .55095 L
s
.015 w
.30114 .50476 Mdot
.002 w
.48519 .42418 m
.48519 .55866 L
s
.015 w
.48519 .49142 Mdot
.002 w
.78967 .07176 m
.78967 .13445 L
s
.015 w
.78967 .1031 Mdot
gsave
.32857 .08713 -223.813 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
73.063 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
83.563 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(V) show
98.063 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
111.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
133.250 23.000 moveto
(Correlation) show
229.375 23.000 moveto
(Coefficient) show
319.313 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
329.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
336.500 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
349.438 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.83) show
384.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{613.438, 379.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009U0001Nb000`400?l00000o`00003oo`3ooooo
0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo
003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooodX0
oooo00@0okmd001d_`3oool0_g@01P0000001@18W=l0oooo0?ooo`2oM4P0W=oo0?l0oooo3P3oool0
0?l0ooooB03oool0203o_g@000000000M02oool0oooo0?oo_`1d000007Bo0`3oool0203ogi`0M9cO
0?ooo`3oool0omnL04P0000004P0W=ooo`3oool<0?ooo`00o`3ooom60?ooo`040?noM00000000018
09cOo`@0oooo00<0omnL04P0001d_ol00P3oool00`3ooml0_koO0?ooo`030?ooo`040?oOW0180000
001809cOool0oooo2P3oool00?l0ooooA03oool0103ogi`0B0000000B02Lgol70?ooo`030=nLB000
04P0W=oo00T0oooo00@0okmd0000000004P0W=ooo`3oool80?ooo`00o`3ooom20?ooo`040?oOW018
0000001809cOo`T0oooo00@0oooO09a80000B9`0gooo2P3oool0103o_g@000000000M02ooooo0?oo
o`H0oooo003o0?oood40oooo00<0_g@00000B02Lgol0303oool00`3ookl0M000001d_`0<0?ooo`03
0?noM0000000B9cO0?l0oooo1@3oool00?l0oooo@P3oool0103ogi`0B0000000B02Lgol70?ooo`07
0?oOW02L_ol0oooo0?ooo`3o_g@0000007Boo`090?ooo`040?noM0000000001d0;ooool0oooo1P3o
ool00?l0ooooA03oool0103ogi`0B0000000B02Lgol50?ooo`030?oo_`2LW=l0oooo0080oooo00<0
_g@00000M02oool01P3oool0103o_g@000000000B02Lgooo0?ooo`P0oooo003o0?ooodH0oooo00@0
okmd0000000004P0W=oo0`3oool00`3ookl0M00000000004000000030018W03Oool0oooo0080oooo
00@0omnL04P0000004P0W=ooo`3oool:0?ooo`00o`3ooom80?ooo`040?noM0000000001d0;ooo`/0
oooo00@0omnL04P0000004P0W=ooo`3oool<0?ooo`00o`3ooom:0?ooo`030?noM000M;l0oooo00X0
oooo00<0_gA809cOo`3oool0o`3oool=0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3o
ool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0oooo
o`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?oo
o`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo
0?ooofL0oooo001F0?ooo`040;md00000000000004RLgel0oooo00<0okmd0000000000000P000000
0`00M;l0oooo0?ooo`1I0?ooo`030=nLB0000000000000D0000000<0M;oo0?ooo`3oool0F03oool0
0`3ooml0W4P000000002000000030018W03Oool0oooo0640oooo00<0okmd0000001d_ol0G03oool0
1P2oM000000000000000000004RL0=oooaX0oooo001D0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0
W4P0001d_`1P0?ooo`030;md000007@0_ooo05d0oooo00<0gia8000000000000100000000`00M;l0
oooo0?ooo`1H0?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0B02LgomQ0?ooo`030?noM000
0000M;oo05/0oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0I0?ooo`00E03oool0
0`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo05l0oooo00<0_g@00000M02oool0GP3oool0
0`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo05l0oooo00<0okmd0018W03Oool0H03oool0
0`3o_g@0000007Boo`1Q0?ooo`030?oOW018M;l0oooo01P0oooo001C0?ooo`040?oog`2LB00004RL
0=ooo`80oooo00<0oooO09a80000M;l0G`3oool00`2oM000001d0;ooo`1O0?ooo`030=nLB018W=l0
oooo06<0oooo00<0okmd0000B02Lgol0F`3oool00`3OW4P0000000000005000000030000B02Lgol0
oooo05h0oooo00<0oono07@0B02Lgol0603oool005<0oooo00<0oono07@00000M;l0103oool00`2o
M000001d0;ooo`1N0?ooo`030;md000007@0_ooo0600oooo00<0gia807Boo`3oool0HP3oool00`2o
M000001809cOo`1K0?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000001d_ol0H@3oool00`3o
okl0M00007Boo`0H0?ooo`00D`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo05h0
oooo00<0_g@00000M02oool0H03oool00`3ooml0W4Q809cOo`1Q0?ooo`040;md00000000001d0;oo
oe`0oooo00L0gia807Boo`3oool0oooo0?noM0000000M;oo0640oooo00<0okmd0000001d_ol0603o
ool005<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`1N0?ooo`030;md000007@0
_ooo0640oooo00<0omnL04P0M02oool0G@3oool00`3ookl0M000000000020000000304RLg`3oool0
oooo05/0oooo00L0oono07@0M02oool0oooo0?noM0000000M;oo0600oooo00@0omnL04P0000007@0
_ooo603oool005<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`1N0?ooo`030;md
000007@0_ooo0680oooo00<0_g@004RLg`3oool0GP3oool00`3o_g@0001809cOo`1O0?ooo`060?no
M000M;l0oooo0?noM0000000M;ooG03oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0
oooo01L0oooo001C0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0GP3oool00`2o
M000001d0;ooo`1R0?ooo`030=nLB00007@0_ooo05l0oooo00<0omnL04Qd_`3oool0G`3oool01@2o
M000M;oo0?noM0000000M;oo05`0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0H
0?ooo`00E03oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo05l0oooo00<0_g@00000
M02oool0HP3oool00`3o_g@0000007Boo`1O0?ooo`030?oog`2LB000B9cO05l0oooo00D0oono07@0
M02o_g@0000007Boo`1L0?ooo`050?oog`2LB00000000000M02oool06`3oool005@0oooo00<0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`1O0?ooo`030;md000007@0_ooo05`0oooo00<0omnL
09boo`3oool00`3oool00`2oM000000007Boo`1J0?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO
09a80000M;l0H03oool0103o_g@000000000001d_omM0?ooo`030?noM000M;l0oooo01`0oooo001E
0?ooo`060;md0000B9`0gooo0?ooo`2oM00007BoGP3oool01@3OW4P000000000000007@0_ooo05d0
oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=oooe/0oooo00L0omnL04Q8W03Oool0oooo
0=nLB0000000M;oo0600oooo00@0oooO09a800000000M;ooG@3oool00`3ooml0W4P0000000020000
00030000M02oool0oooo01L0oooo001F0?ooo`040;md000000000000001d_f00oooo00@0oono07@0
000007@0_oooGP3oool01@2oM000000000000000000007Bo05h0oooo00D0omnL04P0000000000000
04RLg`1R0?ooo`030?oOW0180000M;oo05h0oooo00<0okmd0000000000000P0000000`1d_ol0oooo
0?ooo`0F0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?oo
o`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo
0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo
003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00C03ooooo00000?l000003@00000>0?oo
o`00C03oool3000000T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`<0
00003P3oool004`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooool0oooo2@3oool0
0`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooool0oooo2@3oool00`00
0000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooool0oooo2@3oool00`000000
oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooool0oooo2@3oool00`000000oooo
0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?oooo/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooooT0oooo0P00000=
0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0oooon03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0
oooomP3oool200000100oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0
o`3ooood0?ooo`8000004P3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?oo
o`3o0?oooo<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0<0?ooo`00C03oool0
0`000000oooo0?ooo`3o0?oooo40oooo0P00000E0?ooo`030000003oool0oooo00`0oooo001<0?oo
o`030000003oool0oooo0?l0ooool03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00`0oooo001<0?ooo`<00000o`3oooo^0?ooo`8000005P3oool3000000h0oooo001<0?ooo`030000
003oool0oooo0?l0ooook03oool2000001X0oooo00<000000?ooo`3oool0303oool004`0oooo00<0
00000?ooo`3oool0o`3oooo[0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0303o
ool004`0oooo00<000000?ooo`3oool0o`3ooooY0?ooo`8000007@3oool00`000000oooo0?ooo`0<
0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooonP0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooonH0oooo0P00000P0?ooo`03
0000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooi03oool200000280oooo
00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooooS0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooooQ
0?ooo`8000009@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?oo
oml0oooo0P00000W0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0
oooogP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000
003oool0oooo0?l0oooog03oool2000002X0oooo00<000000?ooo`3oool0303oool004`0oooo00<0
00000?ooo`3oool0o`3ooooJ0?ooo`800000;03oool00`000000oooo0?ooo`0<0?ooo`00C03oool0
0`000000oooo0?ooo`3o0?ooomP0oooo0P00000^0?ooo`030000003oool0oooo00`0oooo001<0?oo
o`030000003oool0oooo0?l0ooooe`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
00`0oooo001<0?ooo`<00000o`3ooooE0?ooo`800000;`3oool3000000h0oooo001<0?ooo`030000
003oool0oooo0?l0ooood`3oool2000003<0oooo00<000000?ooo`3oool0303oool004`0oooo00<0
00000?ooo`3oool0o`3ooooB0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0303o
ool004`0oooo00<000000?ooo`3oool0o`3oooo@0?ooo`800000=P3oool00`000000oooo0?ooo`0<
0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooolh0oooo0P00000h0?ooo`030000003oool0oooo
00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooc@3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooVP3oool00`000000oooo
0?ooo`0^0?ooo`800000>`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?oo
o`3o0?oooiX0oooo00<000000?ooo`3oool0;03oool2000003d0oooo00<000000?ooo`3oool0303o
ool004`0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0<0?ooo`00>`3oool00`3o_g@00000000000020000
0003001d_`3oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`3o_g@0000007Boo`030?oo
o`040?oog`2LB000001809cOo`/0oooo00<0_gAd0;ooo`3oool04P3oool00`3ooml0W4P000000007
0000000307Boo`3oool0oooo00h0oooo00<0_g@00000000000000P0000000`0007@0_ooo0?ooo`03
0?ooo`060?oOW018000000000000000007@0_ooo0P3oool01@3OW4P0000000000000000007Bo0080
oooo00D0gia80000000000000000001d_`040?ooo`050?oOW0180000000000000000M;l00P3oool0
203ookl0M000000000000000001809cOo`3oool0_g@00P000000300004P0W=no07@00000000007Bo
0?ooo`3ookl0M00000000000B9`0gono07@00080000000H0001809cOo`3oool0oooo0?oOW0180002
000000050000M02oool0oooo0?ooo`2oM0000`0000001P1d_kl0M000000000000000001d0;ooo`P0
oooo00<0_g@00000000000000P0000000`0007@0_ooo0?ooo`030?ooo`060?oOW018000000000000
000007@0_ooo103oool01@3ogi`0B00000000000000007Bo0080oooo00<0okmd0000000000000P00
00000`00B9`0gkmd00000003000000030018W03Ookl0M0000080000000D0001809cOo`3oool0oooo
0?noM003000000050018W03Oool0oooo0?oo_`1d00000P0000001P0004P0W=oo0?ooo`3oool0omnL
04P00080000000@007Bo0?ooo`3oool0_g@00`0000002`1d_kl0M000000000000000001d0;ooo`3o
okl0M00000000000B9`0gooo0080oooo00@0oooO09a8000004P0W=oo1@3oool01@3OW4P000000000
0000000007Bo0180oooo00@0_g@0000000000000B9cO103oool00`3OW4P0000004RLg`030?ooo`06
0?oOW018000000000000000004P0W=oo0P3oool00`3ooml0W4P000000002000000030018W03Oool0
oooo0580oooo00<000000?ooo`3oool0:@3oool200000400oooo00<000000?ooo`3oool0303oool0
03d0oooo00<0_g@00000M02oool0303oool00`000000oooo0?ooo`0=0?ooo`030?noM0000000M;oo
00<0oooo00@0oooO09a8000004P0W=oo2P3oool00`3ogi`0B00004RLg`0E0?ooo`030?oOW0180000
07Bo00@0oooo00<0_g@0001d_`3oool03@3oool0103o_g@000000000001d_ol30?ooo`030?oo_`1d
0000M;oo0080oooo00P0okmd00000000B9`0gooo0?ooo`3o_g@0001809cOo`80oooo00<0okmd0000
001d_ol0103oool00`3o_g@0000007Boo`040?ooo`0Q0?noM0000000001809cOo`3oool0gia80018
W03Oool0oooo0?oog`2LB00004RL0=ooo`3oool0okmd00000000M;l0oooo0?oog`2LB000000004RL
g`3o_kl0_ooo0=nLB00004P0W=oo0?oOW02L_ol0oooo0;md000007@0_ooo0080oooo00P0okmd0000
0000B9`0gooo0?ooo`3o_g@0001809cOo`80oooo00P0gia80000B02Lgol0oooo0?oog`2LB00004RL
0=ooo`L0oooo00@0okmd000000000000M;oo0`3oool00`3ookl0M00007Boo`020?ooo`080?noM000
000004RL0=ooo`3oool0okmd0000B02Lgol20?ooo`0=0?noM0000000001809cOo`3oool0gia80018
W03Oool0oooo0?oog`2LB000001d0;ooo`020?ooo`040?oog`2LB000001d0;ooo`<0oooo00<0_g@0
0000M02oool00P3oool00`3OW4P0000000000003000000070018W03Oool0oooo0?ooo`2oM000001d
0;ooo`020?ooo`0G0?noM0000000001809cOo`3oool0gia80018W03Oool0oooo0=nLB00004P0W=oo
0?ooo`3ooml0W4P00018W03Oool0oooo0=nLB00004P0W=oo0?oOW02L_ol00P3oool0103ooml0W4P0
0000B02Lgol60?ooo`030?noM0000000M;oo0140oooo00L0oooO09a80000M;l0oooo0?oog`2LB000
07Bo00<0oooo00<0gia800000018W=l00P3oool04@3ogi`0B0000018W03Oool0oooo0?oOW0180000
M;oo0?ooo`3ogi`0B0000018W03Oool0oooo0?oOW01804P0W=oo0580oooo00<000000?ooo`3oool0
9`3oool200000480oooo00<000000?ooo`3oool0303oool003d0oooo00<0_g@00000M02oool0303o
ool00`000000oooo0?ooo`0=0?ooo`030?noM0000000M;oo0140oooo00@0gia800000000B9`0gooo
503oool00`3ogi`0B00004RLg`040?ooo`030?oog`2LM9`0gooo00`0oooo00@0omnL04P0000004P0
W=oo1P3oool01P2oM4P0W=oo0?oog`2LB000001809cOo`<0oooo00L0_g@00018W03Oool0oooo0?no
M0000000M;oo00@0oooo00<0okmd0000001d_ol00`3oool0103ookl0M0000018W03Oool30?ooo`0;
0?noM01d_ol0oooo0?oog`2LB00004RL0=ooo`3oool0okmd0000001d_ol00P3oool00`3ogi`0B000
04RLg`020?ooo`030=nLB00004P0W=oo00<0oooo00P0_g@00018W03Oool0oooo0?oog`2LB0000018
09cOo`<0oooo00`0_g@00018W03Oool0oooo0=nLB00004P0W=oo0?ooo`3ooml0W4P00018W03Oool6
0?ooo`040?oOW0180000001809cOo`H0oooo00H0_gA809cOo`3ooml0W4P00000B02Lgol30?ooo`07
0;md0000B9`0gooo0?oo_`1d000004RL0=ooo`030?ooo`070?noM01d_ol0oooo0?ooo`2oM00004RL
0=ooo`030?ooo`030;md0000B9`0gooo00<0oooo00P0_g@00018W03Oool0oooo0?oo_`1d00000000
04RLg`<0oooo00`0giad09cOo`3oool0oooo0;md0000B9`0gooo0?ooo`3ookl0M0000018W03Oool3
0?ooo`0?0?noM01d_ol0oooo0=nLB00004P0W=oo0?ooo`3ooml0W4P00018W03Oool0oooo0=nLB000
04P0W=oo00h0oooo00<0okmd0000001d_ol04@3oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo00L0oooo00<0_g@00000M02oool00`3oool00`3OW4P004RL0=ooo`060?ooo`030?noM000
B9`0gooo0540oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00`0oooo000m0?ooo`030;md000007@0_ooo00`0oooo00<000000?ooo`3oool0203oool0
0`3OW4P0000000000005000000030000B02Lgol0oooo00d0oooo00D0oono07@00000B9`0_ia807Bo
o`0D0?ooo`030?oOW0180000B9cO00D0oooo00<0oknL09cOo`3oool02`3oool00`2oM000000004RL
g`090?ooo`030?oOW018000007Bo00@0oooo00L0gia80000B02Lgol0oooo0?noM0000000M;oo00@0
oooo00<0okmd0000001d_ol00`3oool00`3ogi`0B00007Boo`070?ooo`080?oog`2LB00004RL0=oo
o`3oool0oono07@00000M;l20?ooo`030?oOW0180000B9cO0080oooo00<0gia80000B02Lgol00`3o
ool01`2oM00004RL0=ooo`3oool0omnL04P00000M;l0103oool0303OW4P0001809cOo`3oool0gia8
0000B02Lgol0oooo0?oog`2LB00004RL0=ooo`H0oooo00<0_g@000000018W=l02@3oool00`3ogi`0
B000001d_`040?ooo`060=nLB00004P0W=oo0?oOW0180000M;oo203oool00`2oM00004RL0=ooo`03
0?ooo`030;md0000B9`0gooo00<0oooo00L0_g@00018W03Oool0oooo0?noM000000007Bo00P0oooo
00L0_g@00018W03Oool0oooo0?oOW0180000M;oo00L0oooo00`0gia80000B02Lgol0oooo0?oog`2L
B00004RL0=ooo`3oool0gia80000B02Lgol>0?ooo`030?noM0000000M;oo00@0oooo00<0_g@00000
000000001`0000001P18W=l0oooo0?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l01`3o
ool00`2oM000001d0;ooo`030?ooo`030;md0000B9`0gooo00H0oooo00<0okmd0000B02Lgol0D@3o
ool00`000000oooo0?ooo`0T0?ooo`800000A@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool0
0`2oM000001d0;ooo`0<0?ooo`030000003oool0oooo00P0oooo00<0omnL04Qd_`3oool00P3oool0
0`3o_g@0000007Boo`0@0?ooo`050=nLB0000000M;oo0?oOW018M;l0503oool00`3ogi`0B00004RL
g`0B0?ooo`040?oo_`1d0000001809cOo`T0oooo00<0okmd00000018W=l0103oool01`3OW4P00000
07Boo`3oool0okmd0000001d_ol0103oool00`3o_g@0000007Boo`030?ooo`030?oOW01804P0W=oo
00L0oooo00@0oooO09a80000B9`0gooo0P3oool01`3ooml0W4P00000001d_ol0omnL04P00018W=l0
0P3oool00`3OW4P0001809cOo`030?ooo`070;md0000B9`0gooo0?ooo`3o_g@0000004RLg`040?oo
o`0<0=nLB0000000M;oo0?ooo`3OW4P0001809cOo`3oool0oooO09a80000B9`0gooo1@3oool0103o
okl0M0000000B02Lgol90?ooo`030?noM0000000B9cO00@0oooo00H0gia80000001d_ol0omnL04P0
B02Lgol80?ooo`030;md0000B9`0gooo00<0oooo00<0_g@00018W03Oool00`3oool01`2oM00004RL
0=ooo`3oool0okmd0000001d_ol0203oool01`2oM00004RL0=ooo`3oool0omnL04P0B02Lgol01`3o
ool0303OW4P0001809cOo`3oool0oooO09a80000B9`0gooo0?ooo`3OW4P0001809cOo`h0oooo00<0
okmd0000001d_ol0403oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo00<0
okmd0000B02Lgol00P3oool00`3OW4P00000001d_`070?ooo`030;md000004P0W=oo0540oooo00<0
00000?ooo`3oool08P3oool2000004L0oooo00<000000?ooo`3oool0303oool002`0oooo00<0_g@0
0000000000001`0000000`18W=l0oooo0?ooo`040?ooo`030;md000007@0_ooo00`0oooo10000008
0?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@0000007Boo`0?0?ooo`070?oog`2LB000001d0;ooo`3o
ool0_gAd0;ooo`060?ooo`030;md00000000000000L0000000H0B9cO0?ooo`3oool0omnL04P00018
W=lB0?ooo`040?noM0000000001d0;ooo`T0oooo00<0omnL04P00018W=l0103oool01`2oM0000018
09cOo`3oool0okmd0000001d_ol0103oool00`3o_g@0000007Boo`030?ooo`030?oOW01800000000
00D0000000H0M;oo0?ooo`3ooml0W4P00018W03Oool50?ooo`040;md00000000000004RLg`80oooo
00<0gia80000B02Lgol00`3oool01`2oM00004RL0=ooo`3oool0omnL04P00018W=l0103oool0302o
M000001809cOo`3oool0gia80000B02Lgol0oooo0?oog`2LB00004RL0=ooo`D0oooo00@0okmd0000
000007@0_ooo2@3oool00`3ogi`0B00004RLg`040?ooo`050;md000004P0W=oo0?oOW01800001P00
00001P1d_ol0oooo0?ooo`2oM00004RL0=ooo`<0oooo00<0_g@00018W03Oool00`3oool01`2oM000
04RL0=ooo`3oool0okmd0000B02Lgol0203oool01P2oM00004RL0=ooo`3oool0omnL04P000H00000
00h0M;oo0?ooo`3OW4P0001809cOo`3oool0oooO09a80000B9`0gooo0?ooo`3OW4P0001809cOo`h0
oooo00<0okmd0000001d_ol0403oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00L0
oooo00L0gia8001d_`3oool0_g@00000000007@0_ooo00H0oooo00@0_g@00000000007@0_oooD@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo04<0oooo1@00000>0?ooo`00?@3oool0
0`2oM000001d0;ooo`0<0?ooo`030000003oool0oooo00T0oooo00L0oono07@0M02oool0oooo0?no
M0000000M;oo00l0oooo00<0okmd00000018W=l00P3oool00`3o_g@0B9cO0?ooo`0B0?ooo`030?oO
W0180000B9cO0180oooo00@0okmd0000000007@0_ooo2@3oool00`3ooml0W4P0001d_`030?ooo`08
0?oo_`1d0000001d0;ooo`3oool0okmd00000000M;l40?ooo`030?noM000000007Bo00<0oooo00<0
oooO09a8B02Lgol00`3oool0302oM000001809cOo`3oool0oooO09a80000B9`0gooo0?ooo`3ooml0
W4P0001d_`80oooo00<0omnL04P00018W=l00P3oool00`3OW4P0001809cOo`020?ooo`080?oog`2L
B00004RL0=ooo`3oool0oooO09a80000M;l30?ooo`0=0?oo_`1d0000001d0;ooo`3oool0_g@00000
001d_ol0oooo0?oog`2LB00004RL0=ooo`050?ooo`040?noM0000000001d0;ooo`T0oooo00<0oooO
09a80000M;l00`3oool01`3ookl0M0000000M02oool0oooO09a8B02Lgol00`3oool00`2oM0000018
09cOo`020?ooo`030;md0000B9`0gooo00<0oooo00<0_g@00018W03Oool00P3oool0203ooml0W4P0
0018W03Oool0oooo0?oo_`1d0000M;oo0P3oool03@3ooml0W4P00018W03Oool0oooo0?oog`2LB000
04RL0=ooo`3oool0oooO09a8B02Lgol00`3oool0402oM000001809cOo`3oool0_g@00000001d_ol0
oooo0?oog`2LB00004RL0=ooo`3oool0gia80000B02Lgol>0?ooo`030?noM000000007Bo0100oooo
00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`080?ooo`050?noM000000000000018W03O
ool0103oool00`3ookl0M000000000020000000304RLg`3oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool2000004X0oooo00<000000?ooo`3oool0303oool003d0oooo00<0_g@00000M02oool0
303oool00`000000oooo0?ooo`0:0?ooo`060?noM000M;l0oooo0?noM0000000M;oo0`3oool0103o
oml0W4P00000B02Lgol80?ooo`030;md000004P0W=oo0080oooo00<0oono07A8W03Oool04P3oool0
0`3ogi`0B00004RLg`0B0?ooo`040?oOW0180000001d0;ooo`X0oooo00X0omnL04P0001d_ol0oooo
0?oog`2LB000000007Boo`3ooml0W4P00P0000001@1dM7@0B9cO0;md0000B7@0M4P00080000002H0
M7Ad04RLg`2oM00004RL0=ooo`3o_g@0001d0;ooo`3oool0omnL04P00000B9`0gooo0?ooo`3ooml0
W4P00018W03Oool0oooo0?oog`2LB00004RL0=ooo`3oool0gia80000001d_ol0oooO0=oOo`3OW4P0
001809cOo`3oool0omnL04P00000000004RL0=ooo`80oooo0140omnL04P0001d_ol0oooo0?oog`2L
B000000007Boo`3ookl0M0000000000004P0B4P004RLg`3ookl0M000001d_`060?ooo`040?oOW018
0000001d0;ooo`X0oooo00P0omnL04P0001d_ol0oooo0?oog`2LB000000007Boo`80oooo00P0okmd
0000M02oool0oooo0?oOW018000004RL0=ooo`80oooo00<0_g@00018W03Oool00`3oool02@2oM000
04RL0=ooo`3oool0omnL04P00000000004RL0=ooo`020?ooo`0=0?noM00004P0W=oo0?ooo`3o_g@0
00000018W03Oool0omnL04P00000000004RL0=ooo`020?ooo`0E0?noM00007@0_ooo0?ooo`3ogi`0
B0000018W03Ookl0M0000000000004P0B4P004RLg`3ookl0M000001d_`3ooml0gmoo0=nLB00004P0
W=oo00@0oooo00@0oooO09a8000004P0W=oo103oool02P3ooml0W4P0000000000000M7Ad04RLg`2o
M00004RL0=ooo`2oM0090000000504RLg`3oool0omnL04P00018W=l0103oool00`3OW4P0001809cO
o`070?ooo`050?oOW0180000000000000018W=l01`3oool00`3o_g@0001809cOo`1C0?ooo`030000
003oool0oooo01d0oooo0P00001<0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030;md0000
07@0_ooo00`0oooo00<000000?ooo`3oool02`3oool01@2oM000M;oo0?noM0000000M;oo00<0oooo
00@0oooO09a8000004P0W=oo1`3oool00`3ogi`0B000001d_`040?ooo`030=nLB01d_ol0oooo0140
oooo00<0omnL04P00018W=l04P3oool0103ookl0M0000000B02Lgol60?ooo`030?oog`2LM9`0gooo
0080oooo00H0oono07@00000000000000000B02Lgol30?ooo`0=0=nLB0000000M;oo0=nLB0000000
07Bo0?ooo`3OW4P0000007Boo`3OW4P00000001d_`020?ooo`060?oOW0180000000000000000B9`0
gooo0P3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00000000080000000@007Bo0?oo
o`3oool0_g@00`0000001P0004P0W=oo0?oog`2LB00004RL0=ooo`<0oooo00H0oono07@000000000
00000000B02Lgol30?ooo`070;md000004P0W=oo0=nLB0000000001809cOo`060?ooo`040?oo_`1d
0000001809cOo`H0oooo00<0oooO09adW03Oool00P3oool01P3ookl0M000000000000000001809cO
o`@0oooo00P0omnL04P00000000000000018W03Oool0oooo0=nLB0@0000000<0001807AdB0000000
0`0000001P0004P0W=oo0?oog`2LB00004RL0=ooo`<0oooo00H0omnL04P00000000000000018W03O
ool20?ooo`040?oog`2LB00004RL0=ooo`<0oooo00H0omnL04P00000000000000018W03Oool20?oo
o`090;md000004P0W=oo0=nLB0000000001809cOo`3oool0_g@000<0000000P0001809cOo`3oool0
oooo0?oog`2LB000001809cOo`H0oooo00H0gia80000001d_ol0gia800000000M;l=0?ooo`030?oo
_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool01`3ogi`0B0000000B02Lgol0oooo0=nL
B000M;l01`3oool00`3ogi`0B7Bo0?ooo`1B0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`2oM000001d0;ooo`0<0?ooo`03
0000003oool0oooo00/0oooo00D0oono07@0M02o_g@0000007Boo`0>0?ooo`030=nLB00004P0W=oo
00@0oooo00<0omnL04Qd_`3oool04@3oool00`3ogi`0B00004RLg`0C0?ooo`030=nLB0000000B9cO
00H0oooo00<0omnL04Q8W03Oool08P3oool0103ooml0W4P00018W03Oool;0?ooo`030=nLB00004P0
W=oo0200oooo00<0gia800000018W=l01P3oool00`3ogi`0B4RL0=ooo`0E0?ooo`030;md0000B9`0
gooo00<0oooo00<0_g@00018W03Oool0:@3oool00`3OW4P0001809cOo`0R0?ooo`030;md0000B9`0
gooo0080oooo00<0oooO09a80000M;l01`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000
M;oo00H0oooo00<0oooO09a80018W=l0DP3oool00`000000oooo0?ooo`0J0?ooo`800000C`3oool0
0`000000oooo0?ooo`0<0?ooo`00?@3oool00`2oM000001d0;ooo`0<0?ooo`030000003oool0oooo
00`0oooo00@0okmd000000000000M;oo3@3oool0103ookl0M0000018W03Oool40?ooo`030?oog`2L
B4P0W=oo0140oooo00<0omnL04P00018W=l04`3oool0103ookl0M0000000B02Lgol50?ooo`030;md
0000M;l0oooo0280oooo00@0oooO09a80000B9`0gooo2`3oool00`3ookl0M01809cOo`0P0?ooo`04
0?oo_`1d0000001809cOo`D0oooo00<0_g@0001d_`3oool05@3oool00`2oM00004RL0=ooo`030?oo
o`030;md0000B9`0gooo02T0oooo00<0oono07@0B02Lgol08P3oool00`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo00L0oooo00<0gia80018W03Oool00P3oool01`3ooml0W4P004RLg`3oool0
oooO09adW03Oool00P3oool00`3ooml0W4P0001d_`1B0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0<0?ooo`00>`3oool01@3OW4P0000000000000
07@0_ooo00`0oooo00<000000?ooo`3oool0303oool0103ooml0W4P00000001d_ol=0?ooo`040=nL
B000000004RL0=ooo`@0oooo00<0oooO09a80000M;l04@3oool00`3ogi`0B00004RLg`0D0?ooo`04
0?oo_`1d0000001809cOo`80oooo00@0oooO09a80000000007Bo8`3oool0103ooml0W4P00018W03O
ool<0?ooo`030=nLM02Lgol0oooo0200oooo00@0oono07@0000004P0W=oo0P3oool0103ooml0W4P0
00000000M;lF0?ooo`030=nLB00007@0_ooo00<0oooo00<0gia80000M02oool0:P3oool00`3OW7@0
W=oo0?ooo`0R0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203oool00`3ogi`0B00004RLg`02
0?ooo`030?noM00004P0W=oo0080oooo00L0omnL04Q8W03Oool0oooo0=nLB0000000M;oo0540oooo
0`00000H0?ooo`800000DP3oool00`000000oooo0?ooo`0<0?ooo`00?03oool0103ookl0M0000000
M02oool<0?ooo`030000003oool0oooo00d0oooo00<0omnL04P0001d_ol02`3oool00`3ooml0W4P0
00000002000000060000M02oool0oooo0?ooo`3ooml0W4P00P0000000`00B9`0gooo0?ooo`0<0?oo
o`030?oog`2LB000000000<0000000<0M;oo0?ooo`3oool04P3oool0203OW4P00000000000000000
001809cOo`3ookl0M7Bo8P3oool01@3ogi`0B00000000000B9`0gooo0100oooo00@0oooO09a80000
07@0_ooo7@3oool0203OW4P00000000000000000001809cOo`3ookl0M7Bo5P3oool02`3ookl0M018
09cOo`3oool0gia800000018W9`0M01809cOo`3oool0gia80080000000<0001d0;ooo`3oool02P3o
ool0103ooml0W4P00000M02ooolk0?ooo`040;md000000000000001d_`X0oooo00H0oono07@00000
000000000000B02Lgol40?ooo`050?oOW0180000000000000018W=l0D@3oool5000001D0oooo0P00
001D0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo07d0oooo00@0oono
07@00000B9`0gooo403oool0103ooml0W4P00000M02oooll0?ooo`080?oog`2LB000000000000000
B9`0gooo0?oog`2LB002000000040018M01dB000001d0;ooo`/0oooo00@0oooO09a8000007@0_ooo
Z03oool7000001<0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0<0?ooo`00C03o
ool00`000000oooo0?ooo`3o0?oooiL0oooo1`00000A0?ooo`800000E`3oool00`000000oooo0?oo
o`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?oooiL0oooo1`00000@0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooonH0?oo
o`D000003`3oool2000005X0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3o
ool0o`3ooonI0?ooo`<000003P3oool2000005`0oooo00<000000?ooo`3oool0303oool004`0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?oooiX0oooo00<0
00000?ooo`3oool02P3oool2000005l0oooo00<000000?ooo`3oool0303oool004`0oooo0`00003o
0?oooiX0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1M0?ooo`<000003P3oool0
04`0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000003oool0oooo00L0oooo0P00001R0?oo
o`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooVP3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0303oool004`0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`030000003oool0oooo00@0oooo0P00001U0?ooo`030000
003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooVP3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0303oool004`0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`040000003oool0oooo0?ooo`800000J03oool00`000000oooo0?oo
o`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?oooiX0oooo00@000000?ooo`3oool00000JP3o
ool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?oooiX0oooo0`00001[
0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooVP3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0
ooooV03oool3000006d0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0
o`3ooonG0?ooo`040000003oool0oooo000006d0oooo00<000000?ooo`3oool0303oool004`0oooo
00<000000?ooo`3oool0o`3ooonE0?ooo`800000L@3oool00`000000oooo0?ooo`0<0?ooo`00C03o
ool00`000000oooo0?ooo`3o0?oooi@0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?oo
o`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?oooi80oooo0P00001d0?ooo`030000003oool0
oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooT03oool2000007H0oooo00<000000?oo
o`3oool0303oool004`0oooo0`00003o0?ooohh0oooo0P00001f0?ooo`<000003P3oool004`0oooo
00<000000?ooo`3oool0o`3ooon=0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
303oool004`0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`800000N`3oool00`000000oooo0?oo
o`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooohT0oooo0P00001m0?ooo`030000003oool0
oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooQ`3oool2000007l0oooo00<000000?oo
o`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo07l0
oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooon40?ooo`800000
PP3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?oooh80oooo0P00
00240?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooP03oool2
000008H0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooomo0?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3o
ool0o`3ooomm0?ooo`800000R@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo
0?ooo`3o0?ooog/0oooo0P00002;0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003o
ool0oooo0?l0ooooNP3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00`0oooo001<
0?ooo`030000003oool0oooo0?l0ooooN03oool2000008h0oooo00<000000?ooo`3oool0303oool0
04`0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0303oool004`0oooo0`00003o0?ooogD0oooo0P00002?0?ooo`<000003P3oool004`0oooo
00<000000?ooo`3oool0o`3ooomc0?ooo`800000T`3oool00`000000oooo0?ooo`0<0?ooo`00C03o
ool00`000000oooo0?ooo`3o0?ooog80oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?oo
o`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooog00oooo0P00002F0?ooo`030000003oool0
oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooK`3oool00`000000oooo0?ooo`2F0?oo
o`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooK@3oool2000009T0
oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooom[0?ooo`800000
V`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooofX0oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o
0?ooofP0oooo0P00002N0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo
0?l0ooooI`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo00`0oooo001<0?ooo`03
0000003oool0oooo0?l0ooooI@3oool200000:40oooo00<000000?ooo`3oool0303oool004`0oooo
00<000000?ooo`3oool0o`3ooomT0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0
303oool004`0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`800000Y03oool00`000000oooo0?oo
o`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooof40oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?oooel0oooo0P00002W0?oo
o`030000003oool0oooo00`0oooo001<0?ooo`<00000o`3ooomM0?ooo`800000Y`3oool3000000h0
oooo001<0?ooo`030000003oool0oooo0?l0ooooG03oool00`000000oooo0?ooo`2Y0?ooo`030000
003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0ooooFP3oool200000:`0oooo00<0
00000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`030000003oool0
oooo0:`0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooomG0?oo
o`800000[`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?oooeH0
oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo
0?ooo`3o0?oooe@0oooo0P00002b0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003o
ool0oooo0?l0ooooDP3oool200000;@0oooo00<000000?ooo`3oool0303oool004`0oooo00<00000
0?ooo`3oool0o`3ooomA0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0303oool0
03`0oooo00@0_g@0000000000000B9cO303oool00`000000oooo0?ooo`3o0?ooodl0oooo0P00002g
0?ooo`030000003oool0oooo00`0oooo000j0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d
_`0;0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`2g0?ooo`030000003o
ool0oooo00`0oooo000j0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol02P3oool0
0`000000oooo0?ooo`3o0?oood`0oooo0P00002j0?ooo`030000003oool0oooo00`0oooo000i0?oo
o`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l02P3oool00`000000oooo0?ooo`3o
0?ooodX0oooo0P00002l0?ooo`030000003oool0oooo00`0oooo000i0?ooo`030?oo_`1d000007Bo
00@0oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?oo
o`3oool0_03oool00`000000oooo0?ooo`0<0?ooo`00>@3oool00`3ogi`0B00004RLg`040?ooo`03
0;md000007@0_ooo00T0oooo00<000000?ooo`3oool0o`3ooom70?ooo`800000_`3oool00`000000
oooo0?ooo`0<0?ooo`00>@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00T0oooo
1000003o0?ooodD0oooo00<000000?ooo`3oool0^`3oool5000000h0oooo000i0?ooo`030?oOW018
0000B9cO00@0oooo00<0gia80000B02Lgol02@3oool00`000000oooo0?ooo`3o0?oood@0oooo0P00
00320?ooo`030000003oool0oooo00`0oooo000i0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool02@3oool00`000000oooo0?ooo`3o0?oood80oooo0P0000340?ooo`030000003oool0
oooo00`0oooo000j0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l02P3oool00`00
0000oooo0?ooo`3o0?oood40oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0<0?oo
o`00>P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00X0oooo00<000000?ooo`3o
ool0o`3ooolo0?ooo`800000a`3oool00`000000oooo0?ooo`0<0?ooo`00>`3oool01P2oM00004RL
0=ooo`3oool0_g@0001d_`/0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`800000b@3oool00`00
0000oooo0?ooo`0<0?ooo`00?03oool0102oM000000000000000M;l<0?ooo`030000003oool0oooo
0?l0oooo?03oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00`0oooo001<0?ooo`03
0000003oool0oooo0?l0oooo>P3oool200000<`0oooo00<000000?ooo`3oool0303oool004`0oooo
00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0
303oool004`0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`800000c`3oool00`000000oooo0?oo
o`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooocD0oooo0P00003A0?ooo`030000003oool0
oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0oooo=03oool00`000000oooo0?ooo`3A0?oo
o`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0oooo<P3oool200000=@0
oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooola0?ooo`030000
003oool0oooo0=@0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3o
ool_0?ooo`800000e`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool300000?l0oooo;@3oool2
00000=L0oooo0`00000>0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooob`0oooo00<000000?oo
o`3oool0f@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?ooobX0
oooo0P00003L0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0oooo
:03oool200000=h0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3o
oolW0?ooo`030000003oool0oooo0=h0oooo00<000000?ooo`3oool0303oool004`0oooo00<00000
0?ooo`3oool0o`3ooolU0?ooo`800000h@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`00
0000oooo0?ooo`3o0?ooob<0oooo0P00003S0?ooo`030000003oool0oooo00`0oooo001<0?ooo`03
0000003oool0oooo0?l0oooo8P3oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo00`0
oooo001<0?ooo`030000003oool0oooo0?l0oooo803oool200000>H0oooo00<000000?ooo`3oool0
303oool004`0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`800000j03oool00`000000oooo0?oo
o`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?oooad0oooo00<000000?ooo`3oool0j03oool0
0`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?oooa/0oooo0P00003[0?oo
o`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0oooo6@3oool200000>d0
oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`030000
003oool0oooo0>d0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`800000l03oool00`000000oooo0?ooo`0<0?ooo`00C03oool300000?l0oooo503oool2
00000?00oooo0`00000>0?ooo`00C03oool00`000000oooo0?ooo`3o0?oooa<0oooo00<000000?oo
o`3oool0lP3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3o0?oooa40
oooo0P00003e0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003o
ool0oooo0?l0oooo3P3oool200000?P0oooo00<000000?ooo`3oool0303oool001P0oooo00H0omnL
04P00000B9`0gooo0?ooo`2oM0020000000307Boo`3oool0oooo02T0oooo00<000000?ooo`3oool0
o`3oool<0?ooo`800000nP3oool00`000000oooo0?ooo`0<0?ooo`005`3oool01P3ooml0W4P00000
0000B9`0gooo0=nLB0<0000000<004RL0=ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooo`/0
oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`0<0?ooo`005`3oool02`3ogi`0M9cO
0?ooo`3oool0oono07@0M02oool0oooo0=nLB00007@0_ooo02X0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`800000o@3oool00`000000oooo0?ooo`0<0?ooo`005`3oool01P3o_g@0M;oo0?ooo`3o
ool0gia807Boo`80oooo00<0omnL04Qd_`3oool0:P3oool00`000000oooo0?ooo`3o0?ooo`P0oooo
00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`0<0?ooo`005`3oool01P3o_g@007Bo0?oo
o`3ooml0W7BL0=ooo`80oooo00<0_gAd0;ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?ooo`H0
oooo0P00003o0?ooo`40oooo00<000000?ooo`3oool0303oool001L0oooo00<0oono07@000000000
1P0000000`00M;l0oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo103oool200000?l0oooo
0`3oool00`000000oooo0?ooo`0<0?ooo`00603oool00`3OW4P0000000000005000000030000M02o
ool0oooo02T0oooo00<000000?ooo`3oool0o`3oool30?ooo`030000003oool0oooo0?l0oooo0`3o
ool00`000000oooo0?ooo`0<0?ooo`007`3oool00`3o_g@007Bo0?ooo`0Z0?ooo`030000003oool0
oooo0?l0oooo0@3oool200000?l0oooo1P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0103o
oml0M20000000018W=lZ0?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3oool0o`3oool6
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`050?oOW0180000M;oo0=nLB018W=l0:P3oool0
0`000000oooo0?ooo`3m0?ooo`800000o`3oool90?ooo`030000003oool0oooo00`0oooo000L0?oo
o`060=nLB000B9`0gooo0?ooo`3OW4P0B9cO:P3oool300000?`0oooo00<000000?ooo`3oool0o`3o
ool70?ooo`<000003P3oool001/0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0Y
0?ooo`030000003oool0oooo0?X0oooo0P00003o0?ooo``0oooo00<000000?ooo`3oool0303oool0
01X0oooo00<0gia80000000000001P0000000`0007@0_ooo0?ooo`0V0?ooo`030000003oool0oooo
0?T0oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000003oool0oooo00`0oooo000P0?ooo`03
0=nLB018W=l0oooo02T0oooo00<000000?ooo`3oool0m`3oool200000?l0oooo3`3oool00`000000
oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3e0?ooo`800000o`3ooolA0?ooo`030000
003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool0o`3o
oolA0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0?80oooo0P00003o
0?oooa@0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0l@3oool00`00
0000oooo0?ooo`3o0?oooa@0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3o
ool0k`3oool200000?l0oooo5`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo
0?ooo`3^0?ooo`030000003oool0oooo0?l0oooo5`3oool00`000000oooo0?ooo`0<0?ooo`00C03o
ool00`000000oooo0?ooo`3/0?ooo`800000o`3ooolJ0?ooo`030000003oool0oooo00`0oooo001<
0?ooo`030000003oool0oooo0>X0oooo0P00003o0?oooa`0oooo00<000000?ooo`3oool0303oool0
04`0oooo00<000000?ooo`3oool0j03oool200000?l0oooo7P3oool00`000000oooo0?ooo`0<0?oo
o`00C03oool00`000000oooo0?ooo`3W0?ooo`030000003oool0oooo0?l0oooo7P3oool00`000000
oooo0?ooo`0<0?ooo`00C03oool300000>D0oooo0P00003o0?oooal0oooo0`00000>0?ooo`00C03o
ool00`000000oooo0?ooo`3S0?ooo`800000o`3ooolS0?ooo`030000003oool0oooo00`0oooo001<
0?ooo`030000003oool0oooo0>40oooo0P00003o0?ooobD0oooo00<000000?ooo`3oool0303oool0
04`0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`3o0?ooobD0oooo00<000000?oo
o`3oool0303oool004`0oooo00<000000?ooo`3oool0gP3oool200000?l0oooo:03oool00`000000
oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3L0?ooo`800000o`3ooolZ0?ooo`030000
003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0=X0oooo0P00003o0?ooob`0oooo00<0
00000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`3o
0?ooob`0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0e`3oool20000
0?l0oooo;`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`3E0?ooo`80
0000o`3ooola0?ooo`030000003oool0oooo00`0oooo000k0?ooo`030?noM0000000000000800000
00<007Bo0?ooo`3oool02@3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo0?l0oooo
<@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`2oM000001d0;ooo`0<0?ooo`030000003o
ool0oooo0=80oooo0P00003o0?oooc@0oooo00<000000?ooo`3oool0303oool003d0oooo00<0_g@0
0000M02oool0303oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo0?l0oooo=03oool0
0`000000oooo0?ooo`0<0?ooo`00?@3oool00`2oM000001d0;ooo`0<0?ooo`030000003oool0oooo
0<l0oooo0P00003o0?ooocL0oooo00<000000?ooo`3oool0303oool003d0oooo00<0_g@00000M02o
ool0303oool00`000000oooo0?ooo`3=0?ooo`800000o`3oooli0?ooo`030000003oool0oooo00`0
oooo000m0?ooo`030;md000007@0_ooo00`0oooo1000003;0?ooo`030000003oool0oooo0?l0oooo
=@3oool5000000h0oooo000m0?ooo`030;md000007@0_ooo00`0oooo00<000000?ooo`3oool0bP3o
ool200000?l0oooo?03oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`2oM000001d0;ooo`0<
0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0o`3oooll0?ooo`030000003oool0
oooo00`0oooo000m0?ooo`030;md000007@0_ooo00`0oooo00<000000?ooo`3oool0a`3oool20000
0?l0oooo?`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`2oM000001d0;ooo`0<0?ooo`03
0000003oool0oooo0<D0oooo0P00003o0?oood40oooo00<000000?ooo`3oool0303oool003d0oooo
00<0_g@00000M02oool0303oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo0?l0oooo
@@3oool00`000000oooo0?ooo`0<0?ooo`00>`3oool01@3OW4P000000000000007@0_ooo00`0oooo
00<000000?ooo`3oool0`P3oool200000?l0ooooA03oool00`000000oooo0?ooo`0<0?ooo`00?03o
ool0103ookl0M0000000M02oool<0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0
o`3ooom40?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0;l0oooo0P00
003o0?ooodL0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0_P3oool0
0`000000oooo0?ooo`3o0?ooodL0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?oo
o`3oool0_03oool200000?l0ooooBP3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000
oooo0?ooo`2k0?ooo`030000003oool0oooo0?l0ooooBP3oool00`000000oooo0?ooo`0<0?ooo`00
C03oool00`000000oooo0?ooo`2i0?ooo`800000o`3ooom=0?ooo`030000003oool0oooo00`0oooo
001<0?ooo`030000003oool0oooo0;L0oooo0P00003o0?ooodl0oooo00<000000?ooo`3oool0303o
ool004`0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`3o0?ooodl0oooo00<00000
0?ooo`3oool0303oool004`0oooo0`00002d0?ooo`800000o`3ooom@0?ooo`<000003P3oool004`0
oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`3o0?oooe80oooo00<000000?ooo`3o
ool0303oool004`0oooo00<000000?ooo`3oool0/@3oool200000?l0ooooE@3oool00`000000oooo
0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo0?l0ooooE@3o
ool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`2^0?ooo`800000o`3ooomH
0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool0F03oool200000?l0ooooFP3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`03
0000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
E@3oool200000?l0ooooG@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0o`3ooomM0?ooo`030000003o
ool0oooo00`0oooo001<0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0DP3oool2
00000?l0ooooH03oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`1A0?oo
o`030000003oool0oooo0500oooo0P00003o0?ooof80oooo00<000000?ooo`3oool0303oool004`0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0?l0
ooooHP3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo04d0oooo0P00001G0?ooo`030000003oool0oooo0?l0oooo2`3oool00`000000oooo
0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0303o
ool004`0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1:0?ooo`800000FP3oool0
0`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0303oool004`0oooo0`00001A0?oo
o`030000003oool0oooo04P0oooo0P00001L0?ooo`030000003oool0oooo0?l0oooo2@3oool30000
00h0oooo001<0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0oooo2`3oool00`000000oooo0?ooo`0<0?ooo`00
C03oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo04D0oooo0P00001O0?ooo`030000
003oool0oooo0?l0oooo2`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo04<0oooo0P00001Q0?ooo`030000003oool0oooo0?l0oooo2`3o
ool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<00000
0?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`100?oo
o`800000I03oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0303oool004`0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0n0?ooo`800000IP3oool00`000000
oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0
o`3oool;0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0500oooo0`00
000l0?ooo`800000J@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0303o
ool004`0oooo00<000000?ooo`3oool0C`3oool5000003T0oooo0P00001[0?ooo`030000003oool0
oooo0?l0oooo2`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`1>0?oo
o`L00000=P3oool2000006d0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo
00`0oooo001<0?ooo`030000003oool0oooo04h0oooo1`00000e0?ooo`030000003oool0oooo06d0
oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000
003oool0oooo04h0oooo1`00000c0?ooo`800000L03oool00`000000oooo0?ooo`3o0?ooo`/0oooo
00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0C`3oool500000380oooo0P00
001b0?ooo`030000003oool0oooo0?l0oooo2`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool0
0`000000oooo0?ooo`1@0?ooo`<00000<P3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0
oooo0?l0oooo2`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool300000540oooo00<000000?oo
o`3oool0;`3oool2000001D0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?oo
o`T0oooo0`00000>0?ooo`00C03oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?l0
oooo2`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo02`0oooo0P00000H0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0
o`3oool;0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0:@3oool2000001/0oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0G@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0303oool004`0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0V0?ooo`8000007P3oool00`000000
oooo0?ooo`1M0?ooo`030000003oool0oooo0?l0oooo2`3oool00`000000oooo0?ooo`0<0?ooo`00
C03oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02@0oooo0P00000P0?ooo`030000
003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo00`0oooo
001<0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003o
ool0oooo00`0oooo001<0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool08@3oool2
000002<0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<00000
0?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?oo
o`/0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`0N0?ooo`8000009P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?l0
oooo2`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1M0?ooo`030000
003oool0oooo0?l0oooo2`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo01/0oooo0P00000Y0?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool06@3oool2000002/0oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0303oool004`0oooo0`00001A0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1L0?oo
o`<00000o`3oool:0?ooo`<000003P3oool004`0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`0F0?ooo`800000;P3oool00`000000oooo0?ooo`1K0?ooo`D00000o`3oool;0?ooo`03
0000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`1J0?ooo`L00000o`3oool:0?ooo`030000003oool0oooo00`0oooo
001<0?ooo`030000003oool0oooo06L0oooo0P00000a0?ooo`030000003oool0oooo05X0oooo1`00
003o0?ooo`X0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0I@3oool2
000003<0oooo00<000000?ooo`3oool0FP3oool700000?l0oooo2P3oool00`000000oooo0?ooo`0<
0?ooo`00C03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool0F`3oool500000?l0oooo2`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000
oooo0?ooo`1R0?ooo`800000=P3oool00`000000oooo0?ooo`1L0?ooo`<00000o`3oool<0?ooo`03
0000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
=@3oool3000005h0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo00`0oooo
001<0?ooo`030000003oool0oooo05l0oooo0P00000g0?ooo`D00000G@3oool00`000000oooo0?oo
o`3o0?ooo`/0oooo00<000000?ooo`3oool0303oool003T0oooo00<0gia80000000000001@000000
0`1d_ol0oooo0?ooo`080?ooo`030000003oool0oooo05d0oooo0P00000h0?ooo`L00000G03oool0
0`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0303oool003X0oooo00<0gia80000
00000000100000000`00M;l0oooo0?ooo`080?ooo`030000003oool0oooo05`0oooo00<000000?oo
o`3oool0>03oool7000005`0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo
00`0oooo000k0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool02@3oool00`000000
oooo0?ooo`1J0?ooo`800000>`3oool7000005`0oooo00<000000?ooo`3oool0o`3oool;0?ooo`03
0000003oool0oooo00`0oooo000l0?ooo`030=nLB018W=l0oooo00d0oooo00<000000?ooo`3oool0
F03oool2000003h0oooo1@00001M0?ooo`030000003oool0oooo0?l0oooo2`3oool00`000000oooo
0?ooo`0<0?ooo`00?@3oool00`3OW4P0M;oo0?ooo`0<0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0?`3oool3000005h0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003o
ool0oooo00`0oooo000m0?ooo`030?oog`2LB4P0W=oo00`0oooo00<000000?ooo`3oool0E@3oool2
000004<0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<00000
0?ooo`3oool0303oool003h0oooo00<0omnL04P0M02oool02`3oool400000580oooo0P0000150?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool70?ooo`D000003P3oool003l0
oooo00<0_g@004RLg`3oool02P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3o
ool0303oool003l0oooo00<0gia80000M02oool02P3oool00`000000oooo0?ooo`1@0?ooo`800000
B03oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?l0oooo2`3oool00`000000oooo
0?ooo`0<0?ooo`00?`3oool00`3o_g@0000007Boo`0:0?ooo`030000003oool0oooo04h0oooo0P00
001:0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003o
ool0oooo00`0oooo000i0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol02P3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0303oool003X0oooo00P0_g@007Bo
o`3oool0oooo0=nLB000000004RL0=ooo`X0oooo00<000000?ooo`3oool0B`3oool2000004d0oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0
303oool003/0oooo00D0_g@00000000000000000001d_`0<0?ooo`030000003oool0oooo04T0oooo
0P00001?0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000
003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?l0oooo2`3oool00`000000oooo0?oo
o`0<0?ooo`00C03oool00`000000oooo0?ooo`160?ooo`800000DP3oool00`000000oooo0?ooo`1M
0?ooo`030000003oool0oooo0?l0oooo2`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3o
ool0@`3oool2000005D0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?ooo`/0
oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000
003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0400oooo0P00001H0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo00`0oooo001<
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1M
0?ooo`030000003oool0oooo0?l0oooo2`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`00
0000oooo0?ooo`0m0?ooo`800000F`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo
0?l0oooo2`3oool00`000000oooo0?ooo`0<0?ooo`00C03oool3000003/0oooo0P00001M0?ooo`03
0000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3oool90?ooo`<000003P3oool004`0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo05d0oooo
00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003o
ool0oooo03P0oooo0P00001P0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3o
ool;0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?l0oooo2`3oool0
0`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`0e0?ooo`800000``3oool00`00
0000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0?l0oooo2`3oool00`000000
oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`0b0?ooo`800000aP3oool00`000000oooo
0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0<03o
ool200000<P0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo00`0oooo001<
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`3o
0?ooo`/0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0;@3oool20000
0?l0oooof@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`0[0?ooo`80
0000o`3ooooK0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0o`3ooooK0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003o
ool0oooo02P0oooo0P00003o0?ooomh0oooo00<000000?ooo`3oool0303oool004`0oooo00<00000
0?ooo`3oool09P3oool200000?l0ooooh03oool00`000000oooo0?ooo`0<0?ooo`00C03oool30000
02@0oooo0P00003o0?ooon00oooo0`00000>0?ooo`00C03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0?l0oooohP3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo
0?ooo`0Q0?ooo`800000o`3ooooU0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003o
ool0oooo01l0oooo0P00003o0?ooonL0oooo00<000000?ooo`3oool0303oool004`0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooonL0oooo00<000000?ooo`3oool0303oool0
04`0oooo00<000000?ooo`3oool0703oool200000?l0oooojP3oool00`000000oooo0?ooo`0<0?oo
o`00C03oool00`000000oooo0?ooo`0J0?ooo`800000o`3oooo/0?ooo`030000003oool0oooo00`0
oooo001<0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3oooo/0?ooo`030000
003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo01L0oooo0P00003o0?ooonl0oooo00<0
00000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o
0?ooonl0oooo00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool0503oool20000
0?l0oooolP3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo0?ooo`0B0?ooo`80
0000o`3ooood0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0o`3ooood0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003o
ool0oooo00l0oooo0P00003o0?ooooL0oooo00<000000?ooo`3oool0303oool004`0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooooL0oooo00<000000?ooo`3oool0303oool0
04`0oooo0`00000<0?ooo`800000o`3ooooh0?ooo`<000003P3oool004`0oooo00<000000?ooo`3o
ool02P3oool200000?l0ooooo03oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0?l0ooooo03oool00`000000oooo0?ooo`0<0?ooo`00C03o
ool00`000000oooo0?ooo`3o0?ooool0oooo2@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool0
0`000000oooo0?ooo`3o0?ooool0oooo2@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`00
0000oooo0?ooo`3o0?ooool0oooo2@3oool00`000000oooo0?ooo`0<0?ooo`00C03oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo001<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0303oool004`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool004`0ooooo`00003o
000000d000003P3oool00001\
\>"],
  ImageRangeCache->{{{0, 612.438}, {378.125, 0}} -> {-0.894122, -2.35894, \
0.0100618, 0.0134402}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ 
        Evaluate\ \ linear\ correlation\ coefficient\ for\ each\ \
\(\(plot\)\(.\)\)\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(a1cor = {}; b1cor = {};\), "\n", 
    \(\(Do[\[IndentingNewLine]AppendTo[
          a1cor, {res[\([i, 1]\)], 
            res[\([i, 2]\)]}]; \[IndentingNewLine]AppendTo[
          b1cor, {res[\([i, 1]\)], res[\([i, 4]\)]}], {i, 1, 4}];\)\), "\n", 
    \(\(rega1 = Regress[a1cor, {1, x}, x];\)\), "\n", 
    \(ra1 = Sqrt[RSquared /. rega1]\), "\[IndentingNewLine]", 
    \(\(regb1 = Regress[b1cor, {1, x}, x];\)\), "\n", 
    \(rb1 = Sqrt[RSquared /. regb1]\)}], "Input"],

Cell[BoxData[
    \(0.8892736460039566`\)], "Output"],

Cell[BoxData[
    \(0.8252292011897732`\)], "Output"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ Export\ plots\ for\ use\ in\ Fig . \ 1\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(Export["\<fb4.eps\>", fb4, 
        ImageSize \[Rule] 800];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<fa4.eps\>", fa4, ImageSize \[Rule] 800];\)\)}], "Input"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 713}},
WindowSize->{697, 706},
WindowMargins->{{-7, Automatic}, {Automatic, -6}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 520, 9, 191, "Input"],
Cell[2277, 62, 142, 3, 61, "Input"],
Cell[2422, 67, 758, 23, 130, "Input"],
Cell[3183, 92, 83, 2, 35, "Input"],
Cell[3269, 96, 298, 5, 90, "Input"],
Cell[3570, 103, 121, 2, 35, "Input"],
Cell[3694, 107, 1456, 33, 330, "Input"],
Cell[5153, 142, 271, 5, 87, "Input"],
Cell[5427, 149, 465, 9, 110, "Input"],
Cell[5895, 160, 176, 3, 70, "Input"],
Cell[6074, 165, 102, 2, 35, "Input"],

Cell[CellGroupData[{
Cell[6201, 171, 55, 1, 30, "Input"],
Cell[6259, 174, 49, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6345, 180, 3968, 72, 999, "Input"],
Cell[10316, 254, 446, 8, 25, "Print"],
Cell[10765, 264, 232, 4, 25, "Print"],
Cell[11000, 270, 444, 8, 25, "Print"],
Cell[11447, 280, 232, 4, 25, "Print"],
Cell[11682, 286, 446, 8, 25, "Print"],
Cell[12131, 296, 230, 4, 25, "Print"],
Cell[12364, 302, 451, 8, 25, "Print"],
Cell[12818, 312, 232, 4, 25, "Print"]
}, Open  ]],
Cell[13065, 319, 244, 4, 87, "Input"],
Cell[13312, 325, 317, 6, 90, "Input"],

Cell[CellGroupData[{
Cell[13654, 335, 255, 6, 50, "Input"],

Cell[CellGroupData[{
Cell[13934, 345, 81296, 1791, 416, 19421, 1023, "GraphicsData", "PostScript", \
"Graphics"],
Cell[95233, 2138, 64751, 1586, 416, 19679, 1025, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[160011, 3728, 193, 4, 87, "Input"],
Cell[160207, 3734, 77, 1, 30, "Input"],
Cell[160287, 3737, 231, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[160543, 3745, 988, 20, 250, "Input"],
Cell[161534, 3767, 455, 8, 25, "Print"],
Cell[161992, 3777, 405, 10, 41, "Output"],
Cell[162400, 3789, 54, 1, 29, "Output"]
}, Open  ]],
Cell[162469, 3793, 188, 4, 50, "Input"],
Cell[162660, 3799, 163, 4, 61, "Input"],

Cell[CellGroupData[{
Cell[162848, 3807, 349, 6, 90, "Input"],
Cell[163200, 3815, 95646, 2085, 387, 25075, 1209, "GraphicsData", \
"PostScript", "Graphics"],
Cell[258849, 5902, 130, 3, 29, "Output"]
}, Open  ]],
Cell[258994, 5908, 81, 1, 30, "Input"],
Cell[259078, 5911, 231, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[259334, 5919, 988, 20, 250, "Input"],
Cell[260325, 5941, 462, 8, 25, "Print"],
Cell[260790, 5951, 401, 10, 41, "Output"],
Cell[261194, 5963, 52, 1, 29, "Output"]
}, Open  ]],
Cell[261261, 5967, 188, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[261474, 5975, 336, 6, 90, "Input"],
Cell[261813, 5983, 77379, 1714, 388, 21376, 1018, "GraphicsData", \
"PostScript", "Graphics"],
Cell[339195, 7699, 130, 3, 29, "Output"]
}, Open  ]],
Cell[339340, 7705, 158, 4, 61, "Input"],

Cell[CellGroupData[{
Cell[339523, 7713, 491, 9, 170, "Input"],
Cell[340017, 7724, 53, 1, 29, "Output"],
Cell[340073, 7727, 53, 1, 29, "Output"]
}, Open  ]],
Cell[340141, 7731, 111, 2, 35, "Input"],
Cell[340255, 7735, 186, 3, 50, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

